function [xhat, P, xPrior, PPrior, zEstContainer, xEstContainer, MSE_EstContainer, ...
    zPredContainer, xPredContainer, MSE_PredContainer] = applyKalmanFilter(...
    u, z, numTsteps, numFilters, measurementSpaceDim, stateSpaceDim, controlInputDim, ...
    xhat, xPrior, PPrior, A, B, P, Q, R, H, disableUpdate)
% Algorithm for Kalman Filter. This is called from stepImpl of
% dsp.KalmanFilter System object.

%   Copyright 2016 The MathWorks, Inc.

%#codegen

% Containers to store predictions and estimates for all time
% steps
dType = class(u);
zEstContainer = z;
xEstContainer = zeros(stateSpaceDim*numTsteps, numFilters, dType);
MSE_EstContainer = zeros(numTsteps,1,dType);
zPredContainer = z;
xPredContainer = zeros(stateSpaceDim*numTsteps, numFilters,dType);
MSE_PredContainer = zeros(numTsteps,1,dType);
            
% Loop over all time steps
for n=1:numTsteps
    
    % Gather chunks for current time step
    zRowIndexChunk = (n-1)*measurementSpaceDim + (1:measurementSpaceDim);
    stateEstsRowIndexChunk = (n-1)*stateSpaceDim + (1:stateSpaceDim);
    controlInputRowIndexChunk = (n-1)*controlInputDim + (1:controlInputDim);
    
    % Prediction step
    xPrior = A * xhat + B * u(controlInputRowIndexChunk,:);
    PPrior =  A * P * A' + Q;
    
    % Correction step
    if disableUpdate
        % Correction step is disabled
        % Copy states and error covariance from prediction step
        xhat = xPrior;
        P = PPrior;
    else
        % Correction step is not disabled
        % Compute Kalman gain
        PpriorH   = PPrior * H';
        HPpriorHR  = H * PpriorH + R;
        KalmanGain = (HPpriorHR \ PpriorH')';
        KH  = KalmanGain * H;
        
        % States and error covariance are updated in the
        % correction step
        xhat = xPrior + KalmanGain * z(zRowIndexChunk,:) - ...
            KH * xPrior;
        P = PPrior - KH * PPrior;
    end
    
    % Append estimates
    xEstContainer(stateEstsRowIndexChunk, :) = xhat;
    zEstContainer(zRowIndexChunk,:) = H*xhat;
    MSE_EstContainer(n) = trace(P);
    
    % Append predictions
    xPredContainer(stateEstsRowIndexChunk, :) = xPrior;
    zPredContainer(zRowIndexChunk,:) = H*xPrior;
    MSE_PredContainer(n) = trace(PPrior);
end

end