classdef (StrictDefaults)ArrayPlotBase <  matlabshared.scopes.mixin.CommandLineAutoscale & ...
        matlabshared.scopes.UnifiedSystemScope %#ok<*EMCLS>
%ArrayPlotBase Display vectors or arrays

%   Copyright 2019 The MathWorks, Inc.
  
  properties
    %Name Caption to display on Array Plot window
    %   Specify the caption to display on the ArrayPlot window as any
    %   string. The default value of this property is 'Array Plot'. This
    %   property is tunable.
    Name = 'Array Plot';
  end
  
  properties (Nontunable)
    %NumInputPorts Number of input signals
    %   Specify the number of input signals to display on the ArrayPlot as
    %   a positive integer. You must invoke the step method with the same
    %   number of inputs as the value of this property. The default value
    %   of this property is 1.
    NumInputPorts = 1;
  end
  
  properties(Nontunable,Dependent)
    %XDataMode Choose how to specify X-axis data
    %   Specify X-data mode as one of 'Sample increment and X-offset' or
    %   'Custom'. When you set this property to 'Sample increment and
    %   X-offset', Array Plot uses SampleIncrement and XOffset property
    %   values to compute the X-axis data points. When you set this
    %   property to 'Custom', Array Plot uses the CustomXData property
    %   value to set the X-axis data points. The default is 'Sample
    %   increment and X-offset'.
    XDataMode;
  end
  
  properties(Dependent)
    %SampleIncrement X-axis sample spacing
    %   Specify the spacing between samples along the X-axis as a finite
    %   numeric scalar. This property applies when you set the XDataMode
    %   property to 'Sample increment and X-offset'. The default value of
    %   this property is 1. This property is tunable.
    SampleIncrement;
    %CustomXData Custom X-axis data values
    %   Specify X-data values as a finite, monotonically increasing,
    %   numeric, vector of length greater than or equal to the frame size
    %   of the inputs. This property applies when you set the XDataMode
    %   property to 'Custom'. All the elements in the CustomXData vector
    %   must be non-negative when the XScale property is set to 'Log'. When
    %   this property is set to an empty vector [], X-data is set to
    %   (0:L-1) where L is the frame size of the inputs. The default value
    %   of this property is []. This property is tunable.
    CustomXData
    %XLabel X-axis label
    %   Specify the x-axis label as a string. The default value of this
    %   property is ''. This property is tunable.
    XLabel (1,:) char;
    %XScale X-axis scale
    %   Specify the X-axis scale as one of 'Linear' or 'Log'. The default
    %   is 'Linear'. You cannot set the X-axis scale to 'Log' when the
    %   XOffset property is set to a negative value. This property is
    %   tunable.
    XScale;
    %XOffset X-axis display offset
    %   Specify the offset to apply to the x-axis. This property is a
    %   numeric scalar with default value 0. You cannot set the XOffset
    %   property to a negative value when the XScale property is set to
    %   'Log'. This property applies when you set the XDataMode property to
    %   'Sample increment and X-offset'. This property is tunable.
    XOffset;
    %YScale Y-axis scale
    %   Specify the Y-axis scale as one of 'Linear' or 'Log'. The default
    %   is 'Linear'. This property is tunable.
    YScale;
    %YLimits Y-axis limits
    %   Specify the y-axis limits as a two-element numeric vector: [ymin
    %   ymax]. When the PlotAsMagnitudePhase property is false, the default
    %   value of this property is [-10 10]. When the PlotAsMagnitudePhase
    %   property is true, the default value of this property is [0 10] and
    %   it specifies the y-axis limits of magnitude plot. This property is
    %   tunable.
    YLimits;
    %YLabel Y-axis label
    %   Specify the y-axis label as a string. The default value of this
    %   property is 'Amplitude'. This property is applicable when the
    %   PlotAsMagnitudePhase property is false. When the
    %   PlotAsMagnitudePhase property is true, the y-axes labels are
    %   read-only values which are set to 'Magnitude' and 'Phase' for
    %   magnitude plot and phase plot, respectively. This property is
    %   tunable.
    YLabel (1,:) char;
    %ChannelNames Names for the input data channels
    %   Set this property to a cell array of strings to represent the input
    %   channels. These strings are used to label the data channels in the
    %   legend, in the Style dialog and in various measurement tools. The
    %   default is an empty cell array. When this property is an empty cell
    %   array, the channels will be named by default as Channel 1, Channel
    %   2 and so on. This property is tunable.
    ChannelNames
    %PlotType Option to control the type of plot
    %   Specify the type of plot to be used. Valid types are 'Line'
    %   'Stairs' and 'Stem'. The default is 'Stem'. This property is
    %   tunable.
    PlotType;
    %Title Display title
    %   Specify the display title as a string. The default value of this
    %   property is ''. This property is tunable.
    Title (1,:) char;
    %MaximizeAxes Maximize axes control
    %   Specify how axes should appear in the ArrayPlot's display as one of
    %   ['Auto' | 'On' | 'Off']. When this property is set to 'Auto',
    %   axes are maximized only the display does not contain label or title
    %   annotations.  When this property is set to 'On', axes are
    %   maximized.  When this property is set to 'Off', axes are not
    %   maximized. This property is tunable. The default is 'Auto'.
    MaximizeAxes;
    %AxesScaling Axes scaling mode
    %   Specify the scaling mode for the axes as one of ['Auto' | 'Manual'
    %   | 'Updates' | 'OnceAtStop'].  When this property is set to 'Auto'
    %   the scope will attempt to always keep the data in the display while
    %   minimizing the number of axes limit updates.  When this property is
    %   set to 'Manual', the scope will take no action unless specified by
    %   the user.  When this property is set to 'Updates' the scope will
    %   update the axes limits after a set number of visual updates.  When
    %   this property is set to 'OnceAtStop' the limits will be updated
    %   once at the stop of the simulation (when release is called).  This
    %   property is tunable. The default is 'OnceAtStop'.
    AxesScaling;
  end
  
  properties % This should be dependent
    %ShowLegend Show or hide legend
    %   When this property is set to false, no legend is displayed. When
    %   this property is set to true, a legend with automatic string
    %   labels for each input channel is displayed. You can use the legend
    %   to toggle signal visibility in the scope. In the legend, click on a
    %   signal name to hide the signal in the scope. To show the signal,
    %   click on the signal name again. To show only one signal,
    %   right-click the signal name. The default is false. This property is
    %   tunable.
    ShowLegend (1, 1) logical;
    %ShowGrid Show or hide grid
    %   Set this property to true to turn on the grid. The default value is
    %   true. This property is tunable.
    ShowGrid (1, 1) logical;
    %PlotAsMagnitudePhase Plot signal as Magnitude-and-Phase
    %   Set this property to true to plot magnitude and phase of the
    %   signal. The default value is false. This property is tunable.
    PlotAsMagnitudePhase (1, 1) logical;
    %ReduceUpdates Reduce updates to improve performance
    %   Set this property to false to update the scope every time the step
    %   method is called. This will negatively impact performance. The
    %   default is true. This property is tunable.
    ReduceUpdates (1, 1) logical;
  end
  
  properties(Constant, Hidden)
    PlotTypeSet = matlab.system.StringSet({'Stem', 'Line', 'Stairs'});
    MaximizeAxesSet = matlab.system.StringSet({'Auto', 'On', 'Off'});
    XScaleSet =  matlab.system.StringSet({'Linear','Log'});
    XDataModeSet = matlab.system.StringSet({'Sample increment and X-offset','Custom'});
    YScaleSet =  matlab.system.StringSet({'Linear','Log'});
    AxesScalingSet = matlabshared.scopes.mixin.CommandLineAutoscale.getAxesScalingSet;
  end
  
  properties (Access = private)
      NumInputPortsListener;
      CachedInputInfo;
  end
  
  methods

    function obj = ArrayPlotBase(varargin)
      obj@matlabshared.scopes.UnifiedSystemScope();
      
      % Specify the default size for ArrayPlot window to be [800,450] (16:9
      % aspect ratio) as against the default MATLAB figure size of [560,420]
      obj.Position = uiscopes.getDefaultPosition([800 450]);
      
      enableExtension(obj.pFramework.ExtDriver, 'Tools', 'Measurements');            
      
      setProperties(obj, nargin, varargin{:}, 'NumInputPorts');
      
      obj.NumInputPortsListener = event.proplistener(obj.pSource, ...
          obj.pSource.findprop('NumInputPorts'), 'PostSet', ...
          @(~,~) updateNumInputPorts(obj));
      
      % Turn off the playback control toolbar
      obj.pSource.setPropertyValue('ShowSnapShotButton',false);
      
      %setVisualProperty(obj, 'TimeRangeFrames', 'Spcuilib:scopes:TimeRangeInputSampleTime');      
    end
    
    function set.Name(obj, value)
      % Add String Support
      value = convertStringsToChars(value);  
      setScopeName(obj, value);
      obj.Name = value;
    end
    
    function set.NumInputPorts(obj, value)
      validateattributes(value, ...
        {'numeric'}, {'integer', 'scalar', '>=', 1, '<=', 96}, '', 'NumInputPorts'); %#ok<*EMCA>
      obj.NumInputPorts = value;
      if ~isScopeLaunched(obj)
        launchScope(obj);
      end      
      
      % Update displays to have correct ShowContent state
      hVisual = obj.pFramework.Visual;
      numDisplays = length(hVisual.Displays);
      numDisplaysWithData = min(numDisplays, value);
      for displayInd = 1:numDisplaysWithData
          hDisplay = hVisual.Displays{displayInd};
          if ~hDisplay.ShowContent
              hDisplay.ShowContent = true;
          end
      end
      for displayInd = numDisplaysWithData+1:numDisplays
          hDisplay = hVisual.Displays{displayInd};
          if hDisplay.ShowContent
              hDisplay.ShowContent = false;
          end
      end
      
      obj.pSource.NumInputPorts = value;
    end        
    
    function value = get.NumInputPorts(obj)
      if isScopeLaunched(obj)
        value = obj.pSource.NumInputPorts;
      else
        value = obj.NumInputPorts;
      end
    end

    function set.XDataMode(obj, value)
      % Validate if XScale is set to Log
      if strcmp(obj.XScale, 'Log')
        if strcmp(value, 'Sample increment and X-offset') && obj.XOffset < 0
          localError('invalidXScaleXOffsetCombination_Property');
        elseif strcmp(value, 'Custom') && ~isempty(obj.CustomXData) && any(obj.CustomXData<0)
          localError('invalidXScaleCustomXDataCombination_Property');
        end
      end
      setVisualProperty(obj, 'XDataMode', value);
    end
    
    function value = get.XDataMode(obj)
      value = getVisualProperty(obj, 'XDataMode');
    end
    
    function set.SampleIncrement(obj, value)
      validateattributes(value, ...
        {'numeric'},{'positive','finite', 'scalar'}, '', 'SampleIncrement');
      setVisualProperty(obj, 'SampleIncrement', value, true);
    end
    
    function value = get.SampleIncrement(obj)
        value = getVisualProperty(obj, 'SampleIncrement', true);
    end
    
    function set.XOffset(obj, value)
      validateattributes(value, ...
        {'numeric'}, {'real','finite', 'scalar'},'', 'XOffset');
      if strcmp(obj.XScale, 'Log') && value < 0
        localError('invalidXOffset');
      end
      setVisualProperty(obj, 'XOffset', value, true);
    end
    
    function value = get.XOffset(obj)
      value = getVisualProperty(obj, 'XOffset', true);
    end
    
    function set.CustomXData(obj, value)
      if ~isempty(value)
        validateattributes(value,{'numeric'},...
          {'vector','real','finite','increasing'}, '', 'CustomXData');
        if strcmp(obj.XScale, 'Log') && any(value<0)
          localError('invalidCustomXData_LogScale');
        end
      end
      setVisualProperty(obj, 'CustomXData', value, true);
    end
    
    function value = get.CustomXData(obj)
      if ~isScopeLaunched(obj)
        launchScope(obj);
      end
      value = getPropertyValue(obj.pFramework.Visual, 'CustomXData');
      if ~isempty(value)
        value = uiservices.evaluate(value);
      end
    end
    
    function set.XScale(obj, value)
      if strcmp(value,'Log')
        if strcmp(obj.XDataMode, 'Sample increment and X-offset') && obj.XOffset < 0
          localError('invalidXScale');
        elseif strcmp(obj.XDataMode, 'Custom') && ~isempty(obj.CustomXData) && any(obj.CustomXData<0)
          localError('invalidXScale_CustomXData');
        end
      end
      setVisualProperty(obj, 'XScale', value, false);
    end
    
    function value = get.XScale(obj)
      value = getVisualProperty(obj, 'XScale', false);
    end
    
    function set.MaximizeAxes(obj, value)
      
      setVisualProperty(obj, 'MaximizeAxes', value);
    end
    
    function value = get.MaximizeAxes(obj)
      value = getVisualProperty(obj, 'MaximizeAxes');
    end   
    
    function set.XLabel(obj, value)
      % Add String Support
      value = convertStringsToChars(value);
      % Check that value is a string
      if ~ischar(value)
        localError('invalidXLabel','XLabel');
      end      
      obj.setActiveDisplayProperty('XLabel', value);          
    end
    
    function value = get.XLabel(obj)
        value = obj.getActiveDisplayProperty('XLabel');
    end
    
    function set.ReduceUpdates(obj, value)
        setPropertyValue(obj.getSource, 'LockSynchronous', ~value);
    end
    
    function value = get.ReduceUpdates(obj)
        value = ~getPropertyValue(obj.getSource, 'LockSynchronous');
    end
    
    function set.PlotAsMagnitudePhase(obj, value)
      obj.setActiveDisplayProperty('PlotMagPhase', value);
    end
    
    function value = get.PlotAsMagnitudePhase(obj)
      
      value = obj.getActiveDisplayProperty('PlotMagPhase');
    end
    
    function set.YScale(obj, value)
      setVisualProperty(obj, 'YScale', value, false);
    end
    
    function value = get.YScale(obj)
      value = getVisualProperty(obj, 'YScale', false);
    end
    
    function set.YLimits(obj, value)
      % Check that value is a 2-element numeric vector
      if ~all(isnumeric(value)) || ~all(isfinite(value)) || ...
          numel(value)~=2 || value(1) >= value(2)
        localError('invalidYLimits','YLimits');
      end
      
      if ~isScopeLaunched(obj)
        launchScope(obj);
      end
      
      if obj.PlotAsMagnitudePhase
        
        if iscell(value)
          minYLimValue = cellfun(@(x){num2str(x(1))}, value); 
          maxYLimValue = cellfun(@(x){num2str(x(2))}, value);
        else
          minYLimValue = num2str(value(1));
          maxYLimValue = num2str(value(2));
        end
        obj.setActiveDisplayProperty('MinYLimMag', minYLimValue);
        obj.setActiveDisplayProperty('MaxYLimMag', maxYLimValue);
      else
        if iscell(value)
          minYLimValue = cellfun(@(x){num2str(x(1))}, value); 
          maxYLimValue = cellfun(@(x){num2str(x(2))}, value);
        else
          minYLimValue = num2str(value(1));
          maxYLimValue = num2str(value(2));
        end
        obj.setActiveDisplayProperty('MinYLimReal', minYLimValue);
        obj.setActiveDisplayProperty('MaxYLimReal', maxYLimValue);
      end
      hVisual = obj.pFramework.Visual;
      hDisplays = hVisual.Displays;
      updateYScale(hVisual);
      updateYLimits(hDisplays{1});
    end
    
    function value = get.YLimits(obj)
      
      if obj.PlotAsMagnitudePhase
        minYLimValue = str2double(obj.getActiveDisplayProperty('MinYLimMag'))';
        maxYLimValue = str2double(obj.getActiveDisplayProperty('MaxYLimMag'))';
        value = [minYLimValue, maxYLimValue];
      else
        minYLimValue = str2double(obj.getActiveDisplayProperty('MinYLimReal'))';
        maxYLimValue = str2double(obj.getActiveDisplayProperty('MaxYLimReal'))';
        value = [minYLimValue, maxYLimValue];
      end
    end
    
    function set.YLabel(obj, value)
      % Add String Support
      value = convertStringsToChars(value);  
      % Check that value is a string
      if ~ischar(value)
        localError('invalidYLabel','YLabel');
      end
      
      obj.setActiveDisplayProperty('YLabelReal', value);
    end
    
    function value = get.YLabel(obj)
      value = obj.getActiveDisplayProperty('YLabelReal');
    end
    
    function set.ChannelNames(obj, value)
        % Check that the value is a cell array of strings 
        if ~iscell(value) || (~isempty(value) && (~isvector(value) || ~iscellstr(value))) %#ok
            localError('invalidChannelNames', 'ChannelNames');
        end
        setVisualProperty(obj, 'UserDefinedChannelNames', value);
    end
    
    function value = get.ChannelNames(obj)
        % The ChannelNames property is a cell row vector of strings
        value = getVisualProperty(obj, 'UserDefinedChannelNames');
        value = value(:).';
    end
    
    function set.Title(obj, value)
      % Add String Support
      value = convertStringsToChars(value); 
      % Check that value is a string
      if ~ischar(value)
        localError('invalidTitle');
      end
      obj.setActiveDisplayProperty('Title', value);
    end
    
    function value = get.Title(obj)
      value = obj.getActiveDisplayProperty('Title');
    end
    
    function set.ShowGrid(obj, value)
      validateattributes(value, {'logical'}, {'scalar'}, '', 'ShowGrid');
      obj.setActiveDisplayProperty('XGrid', value);
      obj.setActiveDisplayProperty('YGrid', value);
    end
    
    function value = get.ShowGrid(obj)
      
      value = obj.getActiveDisplayProperty('XGrid');
    end
    
    function set.ShowLegend(obj, value)
      
      validateattributes(value, {'logical'}, {'scalar'}, '', 'ShowLegend');
      obj.setActiveDisplayProperty('LegendVisibility', value);
    end
    
    function value = get.ShowLegend(obj)
      
      onOffValues = obj.getActiveDisplayProperty('LegendVisibility');
      
      % Translate on/off values to none/auto
      switch lower(onOffValues)
        case 'off'
          value = false;
        case 'on'
          value = true;
      end
    end   
    
    function set.PlotType(obj, value)
      setVisualProperty(obj, 'PlotType', value);
    end
    
    function value = get.PlotType(obj)
      value = getVisualProperty(obj, 'PlotType');
    end
    
    function set.AxesScaling(obj, newScaling)
        setAxesScaling(obj, newScaling)
    end
    
    function scaling = get.AxesScaling(obj)
        scaling = getAxesScaling(obj);
    end
  end
  
  methods(Access = private)
    function setActiveDisplayProperty(obj, displayPropName, value)
      
      % Ensure we are not given a cell array
      if iscell(value)
        localError('invalidActiveDisplayPropertyValue');
      end
      
      if ~isScopeLaunched(obj)
        launchScope(obj);
      end
      
      % Set selected display property.  If applying a cell array for
      % 'All', then the code above applied the actual values to the
      % individual displays, and here the SelectedDisplay values should
      % just be cleared in order to update the properties dialog.
      switch displayPropName
        case {'XGrid', 'YGrid'}
          obj.pFramework.Visual.SelectedDisplayGrid = value;
        case 'LegendVisibility'
          obj.pFramework.Visual.SelectedDisplayLegend = value;
        otherwise
          obj.pFramework.Visual.(['SelectedDisplay' displayPropName]) = value;
      end
    end
    
    function value = getActiveDisplayProperty(obj, displayPropName)
      
      if ~isScopeLaunched(obj)
        launchScope(obj);
      end
      activeDisplay = 1;
      hDisplays = obj.pFramework.Visual.Displays;
      value = hDisplays{activeDisplay}.(displayPropName);
    end
  end
  
  methods(Hidden)
    function st = getInputSampleTime(~)
      % Sample Time is irrelevant in Array Plot
      st = 1; %ones(obj.NumInputPorts,1);
    end
    
    function inputInfo = getInputInfo(obj)
        inputInfo = obj.CachedInputInfo;
    end
  end
  
  methods (Access = protected)
    function releaseImpl(obj)
      releaseImpl@matlabshared.scopes.UnifiedSystemScope(obj);
      obj.CachedInputInfo = [];
    end
    
    function hScopeCfg = getScopeCfg(~)
      hScopeCfg = dsp.scopes.ArrayPlotSysObjCfg;      
    end
    
    function num = getNumInputsImpl(obj)
      num = obj.NumInputPorts;
    end
    
    function setupImpl(obj, varargin)
        % Call the superclass setupImpl method, and if the inputs are
        % empty, update the DataSource to handle the default frame length.
        setupImpl@matlabshared.scopes.UnifiedSystemScope(obj, varargin{:});
        if isempty(varargin{1})
            onInputSizeChanged(obj);
        end
    end
    
    function updateImpl(obj, varargin)
        % Replace empty inputs by arrays of NaNs before calling the super
        % class method.
        if isempty(varargin{1})
            % Since all input ports must maintain same frameLength, if one
            % input is empty, all inputs would be empty.
            inputInfo = getInputInfo(obj);
            for indx = 1:numel(varargin)
                nanArray = NaN(inputInfo(indx).size,'like',varargin{indx});
                nanArray = real(nanArray);
                if inputInfo(indx).complexity
                    varargin{indx} = complex(nanArray,nanArray);
                else
                    varargin{indx} = nanArray;
                end
            end
        end
        % If the scope does not exist, create one and post new data
        if isempty(obj.pFramework)
            launchScope(obj);
        end
        update(obj.pSource, varargin{:});
    end
    
    function validateInputsImpl(obj,varargin)
      % Validate the input frame size 
      
      % Frame size of all inputs must be the same
      if obj.NumInputPorts > 1
        [frameLength, ~] = cellfun(@size, varargin);
        if numel(unique(frameLength))~=1
          error(message('Spcuilib:scopes:FrameSizesDiffer'));
        end
      end
      
      % Frame size must be less than or equal to the length of CustomXData
      % property value when XDataMode is custom.
      frameLength = size(varargin{1},1);
      if strcmp(obj.XDataMode,'Custom')
        xData = obj.CustomXData;
        if ~isempty(xData) && frameLength > numel(xData)
          localError('invalidFrameSizeForCustomXData');
        end
      end
      
      % Cache the new input dimensions and complexity. Make sure the
      % NumChannels hasn't changed.
      cachedInputInfo = obj.CachedInputInfo;
      nInputs = numel(varargin);
      inputInfo = repmat(struct('size',[],'complexity',[]), 1, nInputs);
      defaultFrameLength = 10;
      for indx = 1:nInputs
          % Verify that NumChannels hasn't changed and is non-zero.
          currPortNumChans = size(varargin{indx},2);
          if currPortNumChans == 0
              localError('ZeroChannels');
          end
          if (numel(cachedInputInfo) >= indx) && ...
                  (cachedInputInfo(indx).size(2) ~= currPortNumChans)
              localError('varSizeChannelsNotSupported');
          end
          % Cache the new dimensions and complexity
          if ~isempty(varargin{indx})
              inputInfo(indx).size = [frameLength, currPortNumChans];
              inputInfo(indx).complexity = ~isreal(varargin{indx});
          elseif numel(cachedInputInfo) >= indx
              % If empty inputs, keep the frameLength and complexity from
              % previous step
              inputInfo(indx).size = cachedInputInfo(indx).size;
              inputInfo(indx).complexity = cachedInputInfo(indx).complexity;
          else
              % If empty inputs and if previous step info is not available,
              % set default values.
              inputInfo(indx).size = [defaultFrameLength, currPortNumChans];
              inputInfo(indx).complexity = ~isreal(varargin{indx});
          end
      end
      obj.CachedInputInfo = inputInfo;
      
      % Call onInputSizeChanged on the source if the input size has changed
      if isLocked(obj)
          onInputSizeChanged(obj);
      end
    end
    
    function validatePropertiesImpl(~)
      % Empty function
    end
    
    function flag = isInactivePropertyImpl(obj, prop)
      flag = false;
      switch prop
        case {'YLabel'}
            flag = obj.PlotAsMagnitudePhase;
        case {'SampleIncrement', 'XOffset'}
            flag = ~strcmp(obj.XDataMode,'Sample increment and X-offset');
        case {'CustomXData'}
            flag = ~strcmp(obj.XDataMode,'Custom');
      end
    end
    
    function S = saveObjectImpl(obj)
      S = saveObjectImpl@matlabshared.scopes.UnifiedSystemScope(obj);
      
      S.NumInputPorts = obj.NumInputPorts;
    end
    
    function loadObjectImpl(obj, S, wasLocked)
      
      obj.NumInputPorts = S.NumInputPorts;
      
      % For backward compatibility - 'SampleIncrement' property used to be
      % stored in the object until R2015b.
      if isfield(S, 'SampleIncrement')
          obj.SampleIncrement = S.SampleIncrement;
      end
      
      % Call the base class method
      loadObjectImpl@matlabshared.scopes.UnifiedSystemScope(obj, S, wasLocked);
      setup(obj.pFramework.Visual);
    end
    
    function flag = isInputSizeMutableImpl(~,~)
        flag = true;
    end
    
    function onInputSizeChanged(obj)
        % Call the onInputSizeChanged function on the DataSource
        for indx = 1:obj.NumInputPorts
            onInputSizeChanged(obj.pSource, obj, indx);
        end
    end
  end
  
  methods(Static, Hidden)
    function a = getAlternateBlock
      a = 'dspsnks4/Array Plot';
    end
  end

  methods(Static, Access=protected)
    function groups = getPropertyGroupsImpl
      % Only the properties listed in mainProps are displayed in the
      % command-line by default
      mainProps = {'NumInputPorts', 'XDataMode', 'SampleIncrement', ...
        'XOffset', 'CustomXData', 'XScale', 'YScale', 'PlotType', 'AxesScaling'};
      
      visualizationProps = {'Name', 'Position', 'ReduceUpdates', ...
        'MaximizeAxes', 'Title', 'ShowLegend', 'ChannelNames', ...
        'ShowGrid', 'PlotAsMagnitudePhase', 'XLabel', 'YLabel', 'YLimits'};
      
      visualizationPropsTitle = getString(message('dsp:system:Shared:VisualizationProperties'));
      mainGroup = matlab.system.display.SectionGroup(...
        'TitleSource', 'Auto', 'PropertyList', mainProps);
      visualizationGroup = matlab.system.display.SectionGroup(...
        'Title', visualizationPropsTitle, 'PropertyList', visualizationProps);
      
      groups = [mainGroup visualizationGroup];
    end
  end
end

function localError(ID, varargin)
id = ['dsp:system:ArrayPlot:' ID];
ME = MException(message(id, varargin{:}));
throwAsCaller(ME);
end

function updateNumInputPorts(obj)

obj.NumInputPorts = obj.pSource.NumInputPorts;
end

% [EOF]
