classdef QRSolver < matlab.System
    % QRSolver Find minimum-norm-residual solution to AX=B
    
    %   Copyright 2019-2022 The MathWorks, Inc.
    
    %#codegen
    %#ok<*EMCLS>
    methods
        %------------------------------------------------------------------
        % Constructor
        function obj = QRSolver(varargin)
            % Support name-value pair arguments when constructing object
            setProperties(obj,nargin,varargin{:})
        end
    end
    
    methods(Access = protected)
        %------------------------------------------------------------------
        function x = stepImpl(~,A,B)
            % Implement algorithm. Calculate x as a function of inputs A
            % and B
            if size(A,1) ~= size(A,2)
                x = mldivide(A,B); % A\B
            elseif coder.target('MATLAB')
                x = lscov(A,B);
            else
                x = coder.internal.qrsolve(A,B);
            end
        end
    end
end
