classdef ArrayPlotBase< matlabshared.scopes.mixin.CommandLineAutoscale & matlabshared.scopes.UnifiedSystemScope
%ArrayPlotBase Display vectors or arrays

 
%   Copyright 2019 The MathWorks, Inc.

    methods
        function out=ArrayPlotBase
        end

        function out=getNumInputsImpl(~) %#ok<STOUT>
        end

        function out=getPropertyGroupsImpl(~) %#ok<STOUT>
            % Only the properties listed in mainProps are displayed in the
            % command-line by default
        end

        function out=getScopeCfg(~) %#ok<STOUT>
        end

        function out=isInactivePropertyImpl(~) %#ok<STOUT>
        end

        function out=isInputSizeMutableImpl(~) %#ok<STOUT>
        end

        function out=loadObjectImpl(~) %#ok<STOUT>
        end

        function out=onInputSizeChanged(~) %#ok<STOUT>
            % Call the onInputSizeChanged function on the DataSource
        end

        function out=releaseImpl(~) %#ok<STOUT>
        end

        function out=saveObjectImpl(~) %#ok<STOUT>
        end

        function out=setupImpl(~) %#ok<STOUT>
            % Call the superclass setupImpl method, and if the inputs are
            % empty, update the DataSource to handle the default frame length.
        end

        function out=updateImpl(~) %#ok<STOUT>
            % Replace empty inputs by arrays of NaNs before calling the super
            % class method.
        end

        function out=validateInputsImpl(~) %#ok<STOUT>
            % Validate the input frame size
        end

        function out=validatePropertiesImpl(~) %#ok<STOUT>
            % Empty function
        end

    end
    properties
        %AxesScaling Axes scaling mode
        %   Specify the scaling mode for the axes as one of ['Auto' | 'Manual'
        %   | 'Updates' | 'OnceAtStop'].  When this property is set to 'Auto'
        %   the scope will attempt to always keep the data in the display while
        %   minimizing the number of axes limit updates.  When this property is
        %   set to 'Manual', the scope will take no action unless specified by
        %   the user.  When this property is set to 'Updates' the scope will
        %   update the axes limits after a set number of visual updates.  When
        %   this property is set to 'OnceAtStop' the limits will be updated
        %   once at the stop of the simulation (when release is called).  This
        %   property is tunable. The default is 'OnceAtStop'.
        AxesScaling;

        %ChannelNames Names for the input data channels
        %   Set this property to a cell array of strings to represent the input
        %   channels. These strings are used to label the data channels in the
        %   legend, in the Style dialog and in various measurement tools. The
        %   default is an empty cell array. When this property is an empty cell
        %   array, the channels will be named by default as Channel 1, Channel
        %   2 and so on. This property is tunable.
        ChannelNames;

        %CustomXData Custom X-axis data values
        %   Specify X-data values as a finite, monotonically increasing,
        %   numeric, vector of length greater than or equal to the frame size
        %   of the inputs. This property applies when you set the XDataMode
        %   property to 'Custom'. All the elements in the CustomXData vector
        %   must be non-negative when the XScale property is set to 'Log'. When
        %   this property is set to an empty vector [], X-data is set to
        %   (0:L-1) where L is the frame size of the inputs. The default value
        %   of this property is []. This property is tunable.
        CustomXData;

        %MaximizeAxes Maximize axes control
        %   Specify how axes should appear in the ArrayPlot's display as one of
        %   ['Auto' | 'On' | 'Off']. When this property is set to 'Auto',
        %   axes are maximized only the display does not contain label or title
        %   annotations.  When this property is set to 'On', axes are
        %   maximized.  When this property is set to 'Off', axes are not
        %   maximized. This property is tunable. The default is 'Auto'.
        MaximizeAxes;

        %Name Caption to display on Array Plot window
        %   Specify the caption to display on the ArrayPlot window as any
        %   string. The default value of this property is 'Array Plot'. This
        %   property is tunable.
        Name;

        %NumInputPorts Number of input signals
        %   Specify the number of input signals to display on the ArrayPlot as
        %   a positive integer. You must invoke the step method with the same
        %   number of inputs as the value of this property. The default value
        %   of this property is 1.
        NumInputPorts;

        %PlotAsMagnitudePhase Plot signal as Magnitude-and-Phase
        %   Set this property to true to plot magnitude and phase of the
        %   signal. The default value is false. This property is tunable.
        PlotAsMagnitudePhase;

        %PlotType Option to control the type of plot
        %   Specify the type of plot to be used. Valid types are 'Line'
        %   'Stairs' and 'Stem'. The default is 'Stem'. This property is
        %   tunable.
        PlotType;

        %ReduceUpdates Reduce updates to improve performance
        %   Set this property to false to update the scope every time the step
        %   method is called. This will negatively impact performance. The
        %   default is true. This property is tunable.
        ReduceUpdates;

        %SampleIncrement X-axis sample spacing
        %   Specify the spacing between samples along the X-axis as a finite
        %   numeric scalar. This property applies when you set the XDataMode
        %   property to 'Sample increment and X-offset'. The default value of
        %   this property is 1. This property is tunable.
        SampleIncrement;

        %ShowGrid Show or hide grid
        %   Set this property to true to turn on the grid. The default value is
        %   true. This property is tunable.
        ShowGrid;

        %ShowLegend Show or hide legend
        %   When this property is set to false, no legend is displayed. When
        %   this property is set to true, a legend with automatic string
        %   labels for each input channel is displayed. You can use the legend
        %   to toggle signal visibility in the scope. In the legend, click on a
        %   signal name to hide the signal in the scope. To show the signal,
        %   click on the signal name again. To show only one signal,
        %   right-click the signal name. The default is false. This property is
        %   tunable.
        ShowLegend;

        %Title Display title
        %   Specify the display title as a string. The default value of this
        %   property is ''. This property is tunable.
        Title;

        %XDataMode Choose how to specify X-axis data
        %   Specify X-data mode as one of 'Sample increment and X-offset' or
        %   'Custom'. When you set this property to 'Sample increment and
        %   X-offset', Array Plot uses SampleIncrement and XOffset property
        %   values to compute the X-axis data points. When you set this
        %   property to 'Custom', Array Plot uses the CustomXData property
        %   value to set the X-axis data points. The default is 'Sample
        %   increment and X-offset'.
        XDataMode;

        %XLabel X-axis label
        %   Specify the x-axis label as a string. The default value of this
        %   property is ''. This property is tunable.
        XLabel;

        %XOffset X-axis display offset
        %   Specify the offset to apply to the x-axis. This property is a
        %   numeric scalar with default value 0. You cannot set the XOffset
        %   property to a negative value when the XScale property is set to
        %   'Log'. This property applies when you set the XDataMode property to
        %   'Sample increment and X-offset'. This property is tunable.
        XOffset;

        %XScale X-axis scale
        %   Specify the X-axis scale as one of 'Linear' or 'Log'. The default
        %   is 'Linear'. You cannot set the X-axis scale to 'Log' when the
        %   XOffset property is set to a negative value. This property is
        %   tunable.
        XScale;

        %YLabel Y-axis label
        %   Specify the y-axis label as a string. The default value of this
        %   property is 'Amplitude'. This property is applicable when the
        %   PlotAsMagnitudePhase property is false. When the
        %   PlotAsMagnitudePhase property is true, the y-axes labels are
        %   read-only values which are set to 'Magnitude' and 'Phase' for
        %   magnitude plot and phase plot, respectively. This property is
        %   tunable.
        YLabel;

        %YLimits Y-axis limits
        %   Specify the y-axis limits as a two-element numeric vector: [ymin
        %   ymax]. When the PlotAsMagnitudePhase property is false, the default
        %   value of this property is [-10 10]. When the PlotAsMagnitudePhase
        %   property is true, the default value of this property is [0 10] and
        %   it specifies the y-axis limits of magnitude plot. This property is
        %   tunable.
        YLimits;

        %YScale Y-axis scale
        %   Specify the Y-axis scale as one of 'Linear' or 'Log'. The default
        %   is 'Linear'. This property is tunable.
        YScale;

    end
end
