classdef (StrictDefaults)CICCompensationDecimator < dsp.CICCompensationDecimator 
% This class is used for the CIC Compensation Decimator block in
% dspfdesign.

%   Copyright 2021 The MathWorks, Inc.

%#codegen
%#ok<*EMCA>

%----------------------------------------------------------------------
% Public methods
%----------------------------------------------------------------------
methods
    function obj = CICCompensationDecimator(varargin)
        obj = obj@dsp.CICCompensationDecimator(varargin{:});
    end
end
%----------------------------------------------------------------------
% Protected methods
%----------------------------------------------------------------------
methods (Access=protected)
    %------------------------------------------------------------------
    function varargout = getInputNamesImpl(~)
        % Name of input ports (shows on block icon)
        varargout{1} =   '';
    end
    %------------------------------------------------------------------
    function varargout = getOutputNamesImpl(~)
        % Name of output port (shows on block icon)
        varargout{1} =   '';
    end
    %------------------------------------------------------------------
    function icon = getIconImpl(~)
        % MATLAB system block icon
        icon = getString(message(...
                'dsp:system:CICCompensationDecimator:iconString'));
    end
    %------------------------------------------------------------------
    function val = supportsMultipleInstanceImpl(~)
        % Support in for-each subsystem
        val = true;
    end
    % PROPAGATOR METHODS: (used by Simulink)
    %------------------------------------------------------------------
    function varargout = getOutputSizeImpl(obj)
        inputSize = propagatedInputSize(obj,1);
        coder.internal.errorIf(mod(inputSize(1),obj.DecimationFactor)~=0, 'dsp:system:inputNotMultDecFac');
        varargout{1} = inputSize;
        varargout{1}(1) = varargout{1}(1)/obj.DecimationFactor;
    end
    %------------------------------------------------------------------
    function varargout = getOutputDataTypeImpl(obj)
        inputDT = propagatedInputDataType(obj,1);
        coder.internal.errorIf(obj.InheritSampleRate && ~ischar(inputDT), ...
            'dsp:system:FIRHalfbandDecimator:fixedPointWithInheritSampleRate');
        if isempty(inputDT)
            return;
        elseif (ischar(inputDT) && any(strcmp(inputDT,{'double', 'single'})))
            varargout{1} = inputDT;
        else
            num = dsp.CICCompensationDecimator.designCompensator( ...
                obj.DecimationFactor, obj.DesignForMinimumOrder, ...
                obj.CICNumSections, obj.CICDifferentialDelay, ...
                obj.CICRateChangeFactor, obj.FilterOrder, ...
                obj.PassbandFrequency, obj.StopbandFrequency, ...
                obj.PassbandRipple, obj.StopbandAttenuation, obj.SampleRate);
            w = fi(num, obj.CoefficientsDataType);  % vector of filter weights of type fi
            if ischar(inputDT)
                % For integer input
                inputDT = numerictype(inputDT);
            end
            [outputWL, outputFL] = coder.const(...
                @dsp.CICCompensationDecimator.filterPrecision, w, inputDT);
            varargout{1} = numerictype(1, outputWL, outputFL);
        end
    end
end
%----------------------------------------------------------------------
% Static protected methods
%----------------------------------------------------------------------
methods(Static,Access=protected)
    function groups = getPropertyGroupsImpl
        CICprops = dsp.internal.CICCompensationBase.getCICProperties;
        FilterProps = [{matlab.system.display.internal.Property('DecimationFactor', ...
                        Description='dsp:system:CICCompensationDecimator:DecimationFactor_MP')},... 
                       dsp.internal.CICCompensationBase.getFilterProperties];
        
        CICSection = matlab.system.display.Section(...
            Title = getString(message('dsp:system:CICCompensationBase:CICTitleString')), ...
            PropertyList = CICprops);
        
        filterSection = matlab.system.display.Section(...
            Title = getString(message('dsp:system:CICCompensationBase:FilterTitleString')), ...
            PropertyList = FilterProps);
        
        filterVis = dsp.internal.FilterVisualizationButton;
        filterSection.Actions = filterVis.fvtoolAction;
        
        mainSG = matlab.system.display.SectionGroup(...
            TitleSource='Auto', ...
            Sections=[CICSection filterSection]);
        dtSG = matlab.system.display.internal.DataTypesGroup('dsp.CICCompensationDecimator');
        dtSG.PropertyList{2} = matlab.system.display.internal.DataTypeProperty('CoefficientsDataType', ...
            Prefix='coeffs', ...
            Description = 'dsp:system:CICCompensationBase:Coefficients_MP');
        groups = [mainSG, dtSG];
    end
    %------------------------------------------------------------------
    function header = getHeaderImpl
        % MATLAB System block header
        header = matlab.system.display.Header(...
            'dsp.simulink.CICCompensationDecimator', ...
            ShowSourceLink = true, ...
            Title = 'dsp:system:CICCompensationDecimator:titleString',...
            Text = getString(message('dsp:system:CICCompensationDecimator:descriptionString')));
    end
end
end
