classdef IIRHalfbandInterpolator < dsp.IIRHalfbandInterpolator
    % This class is used for the IIR Halfband Interpolator block in dspfdesign
    
    % Copyright 2017-2020 The MathWorks, Inc.
    
    %#codegen
    %#ok<*EMCA>
    
    properties (Nontunable)
        %CoefficientsPort Specify coefficients from input port
        CoefficientsPort (1, 1) logical = false;
    end
    
    properties (Constant, Hidden)
        AllpassCoefficients1Set = matlab.system.SourceSet( ...
            dsp.simulink.internal.IIRHalfbandPolicy('SystemBlock', 'CoefficientsPort', 1, 'coeffs1'), ...
            {'Property','MATLAB','CoefficientsPort'})
        AllpassCoefficients2Set = matlab.system.SourceSet( ...
            dsp.simulink.internal.IIRHalfbandPolicy('SystemBlock', 'CoefficientsPort', 2, 'coeffs2'), ...
            {'Property','MATLAB','CoefficientsPort'})
    end
    %----------------------------------------------------------------------
    % Public Methods
    %----------------------------------------------------------------------
    methods
        function obj = IIRHalfbandInterpolator(varargin)
            obj@dsp.IIRHalfbandInterpolator(varargin{:});
        end
    end
    %----------------------------------------------------------------------
    % Protected Methods
    %----------------------------------------------------------------------
    methods (Access = protected)
        function validateInputsImpl(obj,varargin)
            validateInputsImpl@dsp.IIRHalfbandInterpolator(obj,varargin{:});
        end
        %------------------------------------------------------------------
        function val = getNumInputsImpl(obj)
            val = 1+obj.FilterBankInputPort;
        end
        %------------------------------------------------------------------
        function varargout = getInputNamesImpl(obj)
            % Name of input ports (shows on block icon)
            if ~obj.FilterBankInputPort && ~obj.CoefficientsPort
                varargout{1} =   '';
            elseif ~obj.FilterBankInputPort && obj.CoefficientsPort
                varargout{1} =   'x';
            else % power-complementary inputs
                varargout{1} =   'LP';
                varargout{2} =   'HP';
            end
        end
        %------------------------------------------------------------------
        function varargout = getOutputNamesImpl(~)
            % Name of output port (shows on block icon)
            varargout{1} =   '';
        end
        %------------------------------------------------------------------
        function icon = getIconImpl(obj)
            % MATLAB system block icon
            if ~obj.FilterBankInputPort
                icon = getString(message(...
                    'dsp:system:IIRHalfbandInterpolator:interpolatorIconString'));
            else % power-complementary outputs requested
                icon = getString(message(...
                    'dsp:system:IIRHalfbandInterpolator:synthesisIconString'));
            end
        end
        %------------------------------------------------------------------
        function val = supportsMultipleInstanceImpl(~)
            % Support in for-each subsystem
            val = true;
        end
        % PROPAGATOR METHODS: (used by Simulink)
        %------------------------------------------------------------------
        function varargout = getOutputSizeImpl(obj)
            varargout{1} = propagatedInputSize(obj,1);
            varargout{1}(1) = varargout{1}(1)*2;
        end
        %------------------------------------------------------------------
        function varargout = getOutputDataTypeImpl(obj)
            varargout{1} = propagatedInputDataType(obj,1);
        end
        %------------------------------------------------------------------
        function varargout = isOutputComplexImpl(obj)
            varargout{1} = propagatedInputComplexity(obj,1);
        end
        %------------------------------------------------------------------
        function varargout = isOutputFixedSizeImpl(obj)
            varargout{1} = propagatedInputFixedSize(obj,1);
        end
    end
    %----------------------------------------------------------------------
    % Static hidden methods
    %----------------------------------------------------------------------
    methods(Static,Hidden)
        function props = getDisplayPropertiesImpl()
            props = {...
                'Specification',...
                'FilterOrder', ...
                'TransitionWidth', ...
                'StopbandAttenuation', ...
                'DesignMethod', ...
                'FilterBankInputPort', ...
                'InheritSampleRate', ...
                'SampleRate', ...
                'Structure', ...
                'HasPureDelayBranch', ...
                'Delay', ...
                'CoefficientsPort', ...
                'AllpassCoefficients1', ...
                'AllpassCoefficients2', ...
                'WDFCoefficients1', ...
                'WDFCoefficients2', ...
                'HasTrailingFirstOrderSection'};
        end
    end
    %----------------------------------------------------------------------
    % Static protected methods
    %----------------------------------------------------------------------
    methods(Static,Access=protected)
        function mainS = getPropertyGroupsImpl
            props = dsp.simulink.IIRHalfbandInterpolator.getDisplayPropertiesImpl;
            mainS = matlab.system.display.Section(...
                'Title', getString(message('dsp:system:Shared:Parameters')), ...
                'PropertyList', props);
            
            filterVis = dsp.internal.FilterVisualizationButton;
            mainS.Actions = filterVis.fvtoolAction;
        end
        
        %------------------------------------------------------------------
        function header = getHeaderImpl
            % MATLAB System block header
            header = matlab.system.display.Header(...
                'dsp.simulink.IIRHalfbandInterpolator', ...
                'ShowSourceLink', true, ...
                'Title', getString(message('dsp:system:IIRHalfbandInterpolator:titleString')),...
                'Text',  getString(message('dsp:system:IIRHalfbandInterpolator:descriptionString')));
        end
    end
    %----------------------------------------------------------------------
    % Hidden methods
    %----------------------------------------------------------------------
    methods (Hidden) 
        function [flag,errID] = isFVtoolSupported(obj)
            % Specify if fvtool plot is supported, and what error should be
            % used when it is not supported.
            [flag,errID] = isFVtoolSupported@dsp.internal.FilterAnalysis(obj);
            if (strcmp(obj.Specification,'Coefficients') &&  ...
                    strcmp(obj.Structure,'Minimum multiplier') && obj.CoefficientsPort)
                flag = false;
                errID = 'dsp:system:Shared:fvtoolButtonSpecifyCoefficientsText';
            end
        end
    end
end
