classdef ZeroCrossingDetector< matlab.system.SFunSystem
%ZeroCrossingDetector Count number of times signal crosses zero
%   ZCD = dsp.ZeroCrossingDetector returns a zero crossing detection
%   System object, ZCD, that calculates the number of times the signal
%   crosses zero. This System object supports fixed-point data types.
%
%   Step method syntax:
%
%   Y = step(ZCD, X) calculates the number of zero crossings Y of input X.
%   Each column of X is treated as an independent channel of input.
%
%   System objects may be called directly like a function instead of using
%   the step method. For example, y = step(obj, x) and y = obj(x) are
%   equivalent.
%
%   ZeroCrossingDetector methods:
%
%   step     - See above description for use of this method
%   release  - Allow property value and input characteristics changes
%   clone    - Create zero crossing detector object with same property
%              values
%   isLocked - Locked status (logical)
%
%   ZeroCrossingDetector has no properties.
%
%   % EXAMPLE: Use ZeroCrossingDetector System object to calculate the 
%   %          number of zero crossings of a signal.
%       ZCD = dsp.ZeroCrossingDetector;
%       x = rand(20,1)-0.3;
%       y = step(ZCD,x)
%       plot((1:20)',x,'b-',[0 20], [0 0], 'r');
%       title('Zero crossings');

 
%   Copyright 1995-2017 The MathWorks, Inc.

    methods
        function out=ZeroCrossingDetector
        end

        function out=loadObjectImpl(~) %#ok<STOUT>
        end

    end
end
