function v = get_sysparam(sys, p)
% GET_SYSPARAM Get a system-level parameter.
%  This function is error-protected against calls on  subsystems or blocks,
%  which do not have system-level parameter.

% Copyright 1995-2019 The MathWorks, Inc.

if strmatch(lower(p), ...
      lower(fieldnames(get_param(sys,'objectparameters'))), 'exact') %#ok
   % Simulink does not do param-completion, so we use 'exact' above
   
   % Object has parameter - get the corresponding value:
   v = get_param(sys,p);
else
   % No system parameter - check parent:
   parent = get_param(sys,'Parent');
   if ~isempty(parent)
      % recurse
      v = get_sysparam(get_param(sys,'parent'),p);
   else
      % param not found
      error(message('dsp:get_sysparam:invalidFcnInput', p));
   end
end
