function sdspfscope2(varargin)
%SDSPFSCOPE2 Map legacy blocks OpenFig and CloseFig to open_system and
%close_system

%   Copyright 2010-2020 The MathWorks, Inc.
    feval(varargin{4:end});% GUI callback
end

function ScopeUpdate(blk, action) % This function is called from block (mdl file) directly
% Programmatic control of the scopes.
% Use:
% % define the block name or just use gcb while the block is selected
% block_name = gcb; % use gcb while the block is selected
% or
% block_name = 'Eye_Diagram_D/Discrete-Time Eye Diagram Scope' % define the block name
%
% % Command to open (OpenFig) the figure
% sdspfscope2([],[],[],'ScopeUpdate',block_name ,'OpenFig');
%
% % Command to close (CloseFig) the figure
% sdspfscope2([],[],[],'ScopeUpdate',block_name ,'CloseFig');
%
% % NOTE: OpenFig does nothing if the simulation is stopped or paused.
% %            CloseFig always closes the figure if there is one to close.
% %
% %  The vector scope and spectrum scope now have this ability too.


% We need to create the correct block string to call
% resetToFirstCall and Dialog Apply

% Handle SpectrumAnalyzer case (block replacement for SpectrumScope) and
% ConstellationDiagram (block replacement for Discrete-Time Scatter Plot
% scope block)
if ~isempty(regexp(get_param(blk,'BlockType'), ...
        '(SpectrumAnalyzer|ConstellationDiagram)', 'once'))
    switch action
        case 'OpenFig'
            open_system(blk,'parameter');
        case 'CloseFig'
            close_system(blk);
        otherwise
            error(message('Spcuilib:scopes:unhandledCase3'));
    end
    return;
end
end
