function [hContainer, displays] = deserializeLayoutGrid(~, hParent, ...
    layoutDims, serializedDisplays)
%DESERIALIZELAYOUTGRID

% Copyright 2012-2014 The MathWorks, Inc.

if strcmpi(get(hParent, 'Type'), 'figure')
    parentColor = get(hParent, 'Color');
else
    parentColor = get(hParent, 'BackgroundColor');
end
hContainer = uicontainer('Parent', hParent,...
    'Tag', 'LayoutGridContainer', ...
    'Units', 'norm', ...
    'Position', [0, 0, 1, 1], ...
    'BackgroundColor', parentColor, 'Visible', 'off');
% For each grid cell, create the display
displays = cell(1, prod(layoutDims));
displayInd = 1;

for colInd = 1:layoutDims(2)
    for rowInd = 1:layoutDims(1)
        % Default border type must be line to enable panel highlighting.
        gridContainer = uipanel('Parent', hContainer, ...
            'Tag', sprintf('DisplayPanel%d', displayInd), ...
            'BorderType', 'line', ...
            'BackgroundColor', parentColor, ...
            'Units', 'pixels');  % Resizing must be done manually
        objectProps = serializedDisplays{displayInd};
        hDisplay = dsp.scopes.ArrayPlotDisplay(gridContainer, displayInd);
        if ~isempty(objectProps)
            % Apply object properties
            if isfield(objectProps, 'Placement')
                objectProps = rmfield(objectProps, 'Placement');
            end
            objectProps = hDisplay.convertObsoleteProperties(objectProps);
        end
        setProperties(hDisplay, objectProps);
        displays{displayInd} = hDisplay;
        displayInd = displayInd + 1;
    end
end

end
