function onAnnotationChange(this)
%onAnnotationChange   Respond to annotation change and set MaximizeAxes.

%   Copyright 2012-2014 The MathWorks, Inc.

% Check each display for user-customizable annotations (e.g. Title). If all
% annotations are empty, then apply MaximizeAxes.
shouldMaximizeAxes = true;
hDisplays = this.Displays;
for displayInd = 1:numel(hDisplays)
    hDisplay = hDisplays{displayInd};
    if hDisplay.IsAnnotated
        shouldMaximizeAxes = false;
        break
    end
end
% Ensure all displays are in the correct state
for displayInd = 1:numel(hDisplays)
    hDisplay = hDisplays{displayInd};
    if shouldMaximizeAxes && ~hDisplay.MaximizeAxes
        hDisplay.MaximizeAxes = true;
    elseif ~shouldMaximizeAxes && hDisplay.MaximizeAxes
        hDisplay.MaximizeAxes = false;
    end
end
% Re-tile layout to ensure proper axes padding
if ~shouldMaximizeAxes
    matlabshared.scopes.visual.Displayable.tile(this.Displays{1}, ...
        this.LayoutGridContainer, hDisplays, ...
        getPropertyValue(this, 'DisplayLayoutDimensions'));
end
end
