function onDataSourceChanged(this,~,~)
%onDataSourceChanged React to Data Source changes.

%   Copyright 2012-2016 The MathWorks, Inc.

% Check if data source is available and has data
source = this.Application.DataSource;
if isempty(source) || isempty(source.getMaxDimensions) || isempty(source.getSampleTimes)
    return
end
% Cache source data
sourceData.MaxDimensions = getMaxDimensions(source);
sourceData.SampleTimes = getSampleTimes(source);
sourceData.NumInputs = getNumInputs(source);
sourceData.SubDimensions = getSubDimensions(source);
sourceData.InputNames = getInputNames(source);
sourceData.OriginTime = getOriginTime(source);
sourceData.IsEnumType = isDataEnumerated(source);
sourceData.DataTypes = getDataTypes(source);
sourceData.IsComplex = isInputComplex(source);
sourceData.IsDataContiguous = isDataContiguous(source);
this.SourceDataCache = sourceData;
cacheTotalTraceCount(this);
% React to data source being available
onDataSourceAvailable(this);
hAxes = [];
for indx = 1:numel(this.Displays)
    hAxes = [hAxes, this.Displays{indx}.Axes];  %#ok<AGROW>
end
linkaxes(hAxes, 'off', 'LinkAutoChanges', 'off');
% Set the current frame length (used by updateXSpan and calculateXLim)
if ~isempty(sourceData.MaxDimensions) && sourceData.MaxDimensions(1) > 0
    this.CurrentFrameLength = sourceData.MaxDimensions(1);
end
% Update XData related properties
updateXDataMode(this);
linkaxes(hAxes, 'x', 'LinkAutoChanges', 'off');
% Re-tile layout to ensure proper axes padding
matlabshared.scopes.visual.Displayable.tile(this.Displays{1}, this.LayoutGridContainer, ...
    this.Displays, getPropertyValue(this, 'DisplayLayoutDimensions'));
% Send the VisualChanged event to notify measurements and other tools that
% the lines have been updated.
sendEvent( this.Application, 'VisualChanged' );
% Number of displays may have changed. So update displays on the style
% dialog and re-initialize
refreshStyleDialog(this, this.SelectedDisplay);
this.SynchronousChangedListener = addlistener(source, 'SynchronousChanged', ...
    @(hSource,~) onSynchronousChanged(this, hSource));
end
