function onLayoutChange(this,newDisplays)
%onLayoutChange   Respond to display layout change

%   Copyright 2012-2014 The MathWorks, Inc.

% Get initial XLim to apply later, since adding displays and updating time
% axes causes limits to reset to default values
initXLim = this.Displays{1}.XLim;
% Update properties where displays are inter-dependent
updateMaximizeAxes(this);
% Apply display offset, which might be a vector that maps to channels that
% have moved displays. Don't throw errors at this point.
updateXOffset(this, newDisplays, false);
% Apply XSpan on displays
updateXSpan(this, newDisplays);
% Update display plots
source = this.Application.DataSource;
% Call requestUpdate to re-draw the lines in the new display - needed for
% SLA Scope
if ~isempty(source)
    requestUpdate(source);
end
if isDataAvailable(this)
    if isRunning(source)
        update(this);
    else
        % Second call necessary to get YExtents set so autoscale works
        update(this, getOriginTime(source), getTimeOfDisplayData(source));
        update(this, getOriginTime(source), getTimeOfDisplayData(source));
    end
end
% Reset XLim on all displays
hDisplays = this.Displays;
for displayInd = 1:numel(hDisplays)
    hDisplays{displayInd}.XLim = initXLim;
end
end
