function onSourcePauseStop(this,~,~)
%onSourcePauseStop React to the datasource pausing or stopping.

%   Copyright 2012-2015 The MathWorks, Inc.

% Make sure that we have as much data in the display as possible.
source = this.Application.DataSource;
if isempty(source) || isSnapshotMode(source)
    hDisplays = this.Displays;
    for displayInd = 1:length(hDisplays)
        hDisplay = hDisplays{displayInd};
        stop(hDisplay);
    end
    return
end

% Return early from pause event if there is no data.
if isDataEmpty(source)
    return
end
if this.IsSourceValid
    source.NeedsUpdate = false;
    update(this, getOriginTime(source), getTimeOfDisplayData(source));
    % If update happened as a result of stepping back the data buffer,
    % notify measurements with the VisualUpdated event.
    if source.SteppingBack
        sendEvent(this.Application, 'VisualUpdated');
        source.SteppingBack = false;
    end
end
hDisplays = this.Displays;
for displayInd = 1:length(hDisplays)
    hDisplay = hDisplays{displayInd};
    stop(hDisplay);
    if ~this.MissingDataWarningThrown
        if isDataBufferFull(source) && isDataMissing(hDisplay)
            warningDialog(this.Application, uiscopes.message('MissingDataInTimeDomain'));
            this.MissingDataWarningThrown = true;
        end
    end
end

% Refresh properties dialog to enable the widgets non-tunable properties
if this.IsOptionsDialogOpen && source.isStopped
    refreshPropertiesDialog(this);
end
end
