function onYLimChange(this,hDisplay)
%onYLimChange   Respond to change in display Y-Limits.
% This code executes when zoom or autoscale executed within a display. This
% occurs outside of the Properties dialog, and as a result we need to
% perform special handling here.  The selected display could be one of two
% possibilities:
%  1. Zoomed display, in which case SelectedDisplay values should be
%     updated.  Always enter this case if there is just one display.
%  2. A different display altogether, in which case SelectedDisplay values
%     should not be modified, but defaults should be cleared.

%   Copyright 2012-2014 The MathWorks, Inc.

if hDisplay.PlotMagPhase
    yLimProp = 'YLimMag';
    minYLimProp = 'MinYLimMag';
    maxYLimProp = 'MaxYLimMag';
else
    yLimProp = 'YLimReal';
    minYLimProp = 'MinYLimReal';
    maxYLimProp = 'MaxYLimReal';
end
displayYLim = hDisplay.(yLimProp);
% Format of the string
format = '%.6g';
if length(this.Displays)==1 || strcmpi(this.SelectedDisplay, num2str(hDisplay.Placement))
    if hDisplay.PlotMagPhase
        this.SelectedDisplayMinYLimMag = sprintf(format, displayYLim(1));
        this.SelectedDisplayMaxYLimMag = sprintf(format, displayYLim(2));
    else
        this.SelectedDisplayMinYLimReal = sprintf(format, displayYLim(1));
        this.SelectedDisplayMaxYLimReal = sprintf(format, displayYLim(2));
    end
else
    % Update serialized properties
    hDisplay.(minYLimProp) = sprintf(format, displayYLim(1));
    hDisplay.(maxYLimProp) = sprintf(format, displayYLim(2));
    % Remove default values for YLim
    defaultDisplayProperties = this.DisplayPropertyDefaults;
    if isfield(defaultDisplayProperties, minYLimProp)
        defaultDisplayProperties = rmfield(defaultDisplayProperties, minYLimProp);
    end
    if isfield(defaultDisplayProperties, maxYLimProp)
        defaultDisplayProperties = rmfield(defaultDisplayProperties, maxYLimProp);
    end
    this.DisplayPropertyDefaults = defaultDisplayProperties;
end
end
