function varargout = printToFigure(this, varargin)
%printToFigure   Print to figure. Overrides printToFigure of super class.

%   Copyright 2012-2015 The MathWorks, Inc.

openFigure = true;
if nargin==2
    openFigure = varargin{1};
end

% If PlotType is stem, sometimes the figure doesn't show the plot.
% Switching to PlotType 'Line' and then back to 'Stem seems to fix the
% problem. Note: The plot is in the figure. It just doesn't show unless you
% try to print the figure. Go figure.
if strcmp(getPropertyValue(this, 'PlotType'), 'Stem')
    hDisplay = this.Displays{1};  % Single display implemented
    num = numel(hDisplay.Lines);
    markers = cell(num, 1);
    for line = 1:num
        markers{line} = get(hDisplay.Lines(line), 'Marker');
    end
    setPropertyValue(this, 'PlotType', 'Line');
    setPropertyValue(this, 'PlotType', 'Stem');
    for line = 1:num
        set(hDisplay.Lines(line), 'Marker', markers{line});
    end
end
[printFig,gridContainer] = getPrintFigure(this);
% Mark tileOnResize so that grid layout gets updated on resize
matlabshared.scopes.visual.Displayable.tileOnResize(this.Displays{1}, gridContainer);

if openFigure
    movegui(printFig, 'center');
    set(printFig, 'Visible', 'on');
end

if nargout
    % Return the printed figure as an optional output.
    varargout = {printFig};
end
end
