function applyLineProperties(this)
%applyLineProperties Local function called from updateStyle of
% ArrayPlotVisual

%   Copyright 2012-2019 The MathWorks, Inc.

% It is assumed that displays with lines appear consecutively in
% this.Displays
hDisplay = this.Displays{str2double(this.SelectedDisplay)};
op = this.StyleDialog.Output;
totalLines = length(op.LineColors);
if totalLines>=1
    numLines = numel(hDisplay.Lines);
    if hDisplay.PlotMagPhase
        numLines = ceil(numLines/2);
    end
    aPrioriSetting = false;
    if numLines==0
        % This means we are setting properties a priori. Number of lines in
        % this case depends on the color order size.
        numLines = size(hDisplay.ColorOrder, 1);
        aPrioriSetting = true;
    end
    % Get line properties display
    tp.LineColors = op.LineColors(1:numLines);
    tp.LineStyles = op.LineStyles(1:numLines);
    tp.LineWidths = op.LineWidths(1:numLines);
    tp.MarkerStyles = op.MarkerStyles(1:numLines);
    tp.LineVisible = op.LineVisible(1:numLines);
    tp.LineDirty = op.LineDirty(1:numLines);
    % Apply the line properties to each display
    if aPrioriSetting
        % If we do not set properties of all lines,
        % hDisplay.LinePropertiesCache will have intermittent empties which
        % will cause errors when reopening the style dialog
        lineIndices = 1:numel(tp.LineColors);
        setLinePropsOnDisplay(hDisplay, tp, lineIndices);
        % Update the default color order with a priori line colors. This
        % will make sure line colors cycle with newly set colors.
        hDisplay.updateColorOrder;
    else
        lineIndices = find(tp.LineDirty);
        setLinePropsOnDisplay(hDisplay, tp, lineIndices);
    end
end
notify(this, 'DisplayUpdated');

end

% -------------------------------------------------------------------------
function setLinePropsOnDisplay(hDisplay,tp,lineIndices)
%setLinePropsOnDisplay Local function

lp = struct;
for k = lineIndices
    lp.Color = tp.LineColors{k};
    lp.LineStyle = tp.LineStyles{k};
    lp.LineWidth = tp.LineWidths{k};
    lp.Marker = tp.MarkerStyles{k};
    lp.Visible = tp.LineVisible{k};
    hDisplay.setLineProperties(k, lp);
end
end
