function commonPropsGroup = createCommonPropertiesGroup(this,hDlg)
%createCommonPropertiesGroup Local function called from createMainTab()

%   Copyright 2012-2018 The MathWorks, Inc.

dataSource = this.Application.DataSource;
showBufferingProps = isempty(dataSource) || isBufferingSource(dataSource);

% initialize a counter object to keep track of our current position.
row = uiservices.Counter(0);
hCfg = this.Config;
items = {};
if showBufferingProps
    isScopeLocked = ~isempty(dataSource) && (dataSource.isRunning || dataSource.isPaused);
    % XDataMode
    label = message('dsp:system:ArrayPlot:XDataModeLabel').getString();
    [xDataMode_lbl,xDataMode] = extmgr.getWidgetSchema(hCfg, 'XDataMode', label, 'combobox', next(row), 1);
    xDataMode.Entries = {getString(message('dsp:system:ArrayPlot:XDataModeSampleIncrementAndXOffset')),...
        getString(message('dsp:system:ArrayPlot:XDataModeCustom'))};
    xDataMode.DialogRefresh = true;
    xDataMode.Enabled = ~isScopeLocked && ~any(ismember(this.DisabledConfigurationProperties,'XDataMode'));
    
    % Sample increment
    label = message('dsp:system:ArrayPlot:SampleIncrementLabel').getString();
    [sampleIncrement_lbl,sampleIncrement] = extmgr.getWidgetSchema(hCfg, 'SampleIncrement', label, 'edit', next(row), 1);
    
    % X-offset
    label = uiscopes.message('DisplayOffsetLabel');
    [xoffset_lbl,xoffset] = extmgr.getWidgetSchema(hCfg, 'XOffset', label, 'edit', next(row), 1);
    
    % Custom XData
    label = message('dsp:system:ArrayPlot:CustomXDataLabel').getString();
    [customXData_lbl,customXData] = extmgr.getWidgetSchema(hCfg, 'CustomXData', label, 'edit', next(row), 1);
    
    % X-scale
    label = message('dsp:system:ArrayPlot:XScaleLabel').getString();
    [xScale_lbl,xScale] = extmgr.getWidgetSchema(hCfg, 'XScale', label, 'combobox', next(row), 1);
    xScale.Entries = {'Linear', 'Log'};
    
    %Y-scale
    label = message('dsp:system:ArrayPlot:YScaleLabel').getString();
    [yScale_lbl,yScale] = extmgr.getWidgetSchema(hCfg, 'YScale', label, 'combobox', next(row), 1);
    yScale.Entries = {'Linear', 'Log'};
    
    val = uiservices.getWidgetValue(xDataMode, hDlg);
    if ischar(val)
        if strcmp(val,'Sample increment and X-offset')
            val = 0;
        else
            val = 1;
        end
    end
    % SampleIncrement
    sampleIncrement_lbl.Visible = val==0;
    sampleIncrement.Visible     = val==0; 
    sampleIncrement.Enabled     = ~any(ismember(this.DisabledConfigurationProperties,'SampleIncrement'));
    % XOffset
    xoffset_lbl.Visible         = val==0; 
    xoffset.Visible             = val==0;
    xoffset.Enabled             = ~any(ismember(this.DisabledConfigurationProperties,'XOffset')); 
    %CustomXData
    customXData_lbl.Visible     = val==1;
    customXData.Visible         = val==1;
    customXData.Enabled         = ~any(ismember(this.DisabledConfigurationProperties,'CustomXData'));
    %YScale
    yScale.Enabled              = ~any(ismember(this.DisabledConfigurationProperties,'YScale'));
    items = {xDataMode_lbl, xDataMode, ...
        sampleIncrement_lbl, sampleIncrement, ...
        xoffset_lbl, xoffset, ...
        customXData_lbl, customXData,...
        xScale_lbl, xScale,...
        yScale_lbl, yScale};
end
[maxAxes_lbl,maxAxes] = uiscopes.getWidgetSchema(hCfg, 'MaximizeAxes', 'combobox', next(row), 1);
maxAxes.Entries = {uiscopes.message('MaximizeAxesTypeAuto'), ...
    uiscopes.message('MaximizeAxesTypeOn'), uiscopes.message('MaximizeAxesTypeOff')};
commonPropsGroup.Type = 'group';
commonPropsGroup.Items = [items, maxAxes_lbl, maxAxes];
commonPropsGroup.LayoutGrid = row.LayoutGrid;
commonPropsGroup.RowStretch = row.RowStretch;

end
