function displayPropsGroup = createDisplayPropertiesGroup(this,hDlg)
%createDisplayPropertiesGroup Local function called from createDisplayTab()

%   Copyright 2012-2018 The MathWorks, Inc.

[title_lbl,title] = getSelectedDisplayPropertyWidgetSchema(this, 'Title', 'edit', 2, 1);
legend = getSelectedDisplayPropertyWidgetSchema(this, 'Legend', 'checkbox', 3, 1);
grid = getSelectedDisplayPropertyWidgetSchema(this, 'Grid', 'checkbox', 3, 2);
plotMagPhase = getSelectedDisplayPropertyWidgetSchema(this, 'PlotMagPhase', 'checkbox', 4, 1);
plotMagPhase.DialogRefresh = true;
[xlabel_lbl,xlabel] = getSelectedDisplayPropertyWidgetSchema(this, 'XLabel', 'edit', 5, 1);
[ylabel_lbl,ylabel] = getSelectedDisplayPropertyWidgetSchema(this, 'YLabelReal', 'edit', 6, 1);
[minylim_lbl,minylim] = getSelectedDisplayPropertyWidgetSchema(this, 'MinYLimReal', 'edit', 7, 1);
[maxylim_lbl,maxylim] = getSelectedDisplayPropertyWidgetSchema(this, 'MaxYLimReal', 'edit', 8, 1);
[minylimmag_lbl,minylimmag] = getSelectedDisplayPropertyWidgetSchema(this, 'MinYLimMag', 'edit', 9, 1);
[maxylimmag_lbl,maxylimmag] = getSelectedDisplayPropertyWidgetSchema(this, 'MaxYLimMag', 'edit', 10, 1);
% XLabel
xlabel.Enabled = ~any(ismember(this.DisabledConfigurationProperties,'XLabel'));
% PlotMagPhase
plotMagPhase.Enabled = ~any(ismember(this.DisabledConfigurationProperties,'PlotMagPhase'));
val = uiservices.getWidgetValue(plotMagPhase, hDlg);
minylim_lbl.Visible     = ~val;
minylim.Visible         = ~val;
maxylim_lbl.Visible     = ~val;
maxylim.Visible         = ~val;
%YLabel
ylabel_lbl.Visible      = ~val;
ylabel.Visible          = ~val;
ylabel.Enabled = ~any(ismember(this.DisabledConfigurationProperties,'YLabelReal'));

minylimmag_lbl.Visible  = val;
minylimmag.Visible      = val;
maxylimmag_lbl.Visible  = val;
maxylimmag.Visible      = val;

displayPropsGroup.Type  = 'group';
displayPropsGroup.Items = {...
    title_lbl, title, ...
    legend, ...
    grid, ...
    plotMagPhase, ...
    xlabel_lbl, xlabel, ...
    minylim_lbl, minylim, ...
    maxylim_lbl, maxylim, ...
    ylabel_lbl,  ylabel, ...
    minylimmag_lbl, minylimmag, ...
    maxylimmag_lbl, maxylimmag};
displayPropsGroup.LayoutGrid = [9 2];
displayPropsGroup.RowStretch = [zeros(1,8) 1];

end

% -------------------------------------------------------------------------
function varargout = getSelectedDisplayPropertyWidgetSchema(this,propName,widgetType,row,col)
%getSelectedDisplayPropertyWidgetSchema Local function

% Create label schema
labelID = [propName, 'Label'];
labelSchema.Name = uiscopes.message(labelID);
labelSchema.Type = 'text';
labelSchema.RowSpan = [row, row];
labelSchema.ColSpan = [col, col];
labelSchema.Tag = [this.Config.Name, labelID];

% Create widget schema
widgetSchema.Type = widgetType;
widgetSchema.RowSpan = [row, row];
widgetSchema.ColSpan = [col, col] + 1;
widgetSchema.ObjectProperty = ['SelectedDisplay', propName];
widgetSchema.Source = this;
widgetSchema.Tag = [this.Config.Name, propName];
if strcmp(widgetType, 'checkbox')
    widgetSchema.Name = labelSchema.Name;
    widgetSchema.ColSpan = [widgetSchema.ColSpan(1) - 1, widgetSchema.ColSpan(1)];
    varargout = {widgetSchema};
else
    labelSchema.Buddy = widgetSchema.Tag;
    varargout = {labelSchema, widgetSchema};
end

end
