function updateProperties(this,newSelectedDisplay)
%updateProperties   Update selected display properties
% Local function called from updateSelectedDisplay()

%   Copyright 2012-2018 The MathWorks, Inc.

% Suppress negative Y values ignored warning, and restore
%  its status on cleanup
onState = warning('off', 'MATLAB:Axes:NegativeLimitsInLogAxis');
c = onCleanup(@() warning(onState));

% Only perform display highlighting if a property dialog is open and there
% is more than one display
isPropDialogOpen = this.IsOptionsDialogOpen || this.IsStyleDialogOpen;
highlightSelectedDisplay = isPropDialogOpen && length(this.Displays)>1;
selectedDisplayInd = str2double(newSelectedDisplay);
hDisplays = this.Displays;
for displayInd = 1:length(hDisplays)
    hDisplay = hDisplays{displayInd};
    if displayInd==selectedDisplayInd
        % This is the selected display, so update display properties and
        % highlight the display
        this.SelectedDisplayXLabel = hDisplay.XLabel;
        this.SelectedDisplayMinYLimReal = hDisplay.MinYLimReal;
        this.SelectedDisplayMaxYLimReal = hDisplay.MaxYLimReal;
        this.SelectedDisplayYLabelReal = hDisplay.YLabelReal;
        this.SelectedDisplayMinYLimMag = hDisplay.MinYLimMag;
        this.SelectedDisplayMaxYLimMag = hDisplay.MaxYLimMag;
        this.SelectedDisplayTitle = hDisplay.Title;
        this.SelectedDisplayLegend = uiservices.onOffToLogical(hDisplay.LegendVisibility);
        this.SelectedDisplayGrid = hDisplay.XGrid;
        this.SelectedDisplayPlotMagPhase = hDisplay.PlotMagPhase;
        if highlightSelectedDisplay
            hDisplay.Selected = true;
        else
            hDisplay.Selected = false;
        end
    else
        hDisplay.Selected = false;
    end
end

% Re-apply dialog tab to guarantee that current tab remains open despite a
% dialog refresh (which might otherwise reset the current tab)
this.SelectedDialogTab = this.SelectedDialogTab;
refreshStyleDialog(this, newSelectedDisplay);
refreshPropertiesDialog(this);
end
