function [b,exception] = validateCommonProps(this,hDlg,b,exception)
%validateCommonProps Local function called from validate()

%   Copyright 2012-2015 The MathWorks, Inc.

isCustomXDataMode = hDlg.getWidgetValue([this.Register.Name, 'XDataMode']);
if ~isCustomXDataMode   % Sample increment and X-offset mode 
    % Check that the inputs are valid variables or numbers.
    if b
        cb = @(val) ~(~isscalar(val) || any(isnan(val)) || any(isinf(val)) || any(~isreal(val)));
        [b,exception] = extmgr.validateWidgetValue(hDlg, 'XOffset', cb, this.Register);
    end
    
    % Check that SampleIncrement is non-negative
    if b
        val = uiservices.evaluate(hDlg.getWidgetValue([this.Register.Name, 'SampleIncrement']));
        if ~(isscalar(val) && ~isnan(val) && ~isinf(val) && isreal(val) && isnumeric(val) && val > 0);
            b = false;
            id = 'dsp:system:ArrayPlot:invalidSampleIncrement';
            exception = MException(id, getString(message(id)));
        end
    end
    
    % Check that offset is non-negative when XScale is log
    if b && hDlg.getWidgetValue([this.Register.Name, 'XScale'])
        val = uiservices.evaluate(hDlg.getWidgetValue([this.Register.Name, 'XOffset']));
        if val<0
            b = false;
            id = 'dsp:system:ArrayPlot:invalidXScaleXOffsetCombination';
            exception = MException(id, getString(message(id)));
        end
    end
else    % Custom X-data mode
    if b
        % Check if the variable is valid
        val = hDlg.getWidgetValue([this.Register.Name, 'CustomXData']);
        [val,id,msg] = uiservices.evaluate(val);
        if ~isempty(id)
            b = false;
            exception = MException(id,msg);
        end
        
        % Check that CustomXData is a monotonically increasing finite numeric vector
        if b && ~isempty(val) && ~(isnumeric(val) && isreal(val) && all(isfinite(val)) && isvector(val) && all(diff(val)>0))
            b = false;
            id = 'dsp:system:ArrayPlot:invalidCustomXData';
            exception = MException(id, getString(message(id)));
        end
        
        % Check that CustomXData values are non-negative when XScale is log
        if b && hDlg.getWidgetValue([this.Register.Name, 'XScale'])
            if any(val<0)
                b = false;
                id = 'dsp:system:ArrayPlot:invalidXScaleCustomXDataCombination';
                exception = MException(id, getString(message(id)));
            end
        end
    end
end
