function [b,exception] = validateDisplayProps(this,hDlg,b,exception)
%validateDisplayProps Local functions called from validate()

%   Copyright 2012-2014 The MathWorks, Inc.

cb = matlabshared.scopes.Validator.Limit;
plotMagPhaseTag = [this.Config.Name, 'PlotMagPhase'];
val = hDlg.getWidgetValue(plotMagPhaseTag);
if ~val
    if b
        % validate MinYLimReal property/widget
        [b,exception,minYLimReal] = validateYLimWidgetValue(this, hDlg, 'MinYLimReal', 'MinYLim', cb);
    end
    if b
        % validate MaxYLimReal property/widget
        [b,exception,maxYLimReal] = validateYLimWidgetValue(this, hDlg, 'MaxYLimReal', 'MaxYLim', cb);
    end
    % Check if the min and max limits make sense for Real axis.
    if b && (minYLimReal>=maxYLimReal)
        b = false;
        [msg,id] = uiscopes.message('InvalidYLim');
        exception = MException(id, msg);
    end
else
    if b
        % validate MinYLimMag property/widget
        [b,exception,minYLimMag] = validateYLimWidgetValue(this, hDlg, 'MinYLimMag', 'MinYLim', cb);
    end
    if b
        % validate MaxYLimMag property/widget
        [b,exception,maxYLimMag] = validateYLimWidgetValue(this, hDlg, 'MaxYLimMag', 'MaxYLim', cb);
    end
    % Check if the min and max limits make sense for Magnitude axis.
    if b && (minYLimMag>=maxYLimMag)
        b = false;
        [msg,id] = uiscopes.message('InvalidYLim');
        exception = MException(id, msg);
    end
end
end

% -------------------------------------------------------------------------
function [b,exception,val] = validateYLimWidgetValue(this,hDlg,tag,messageTag,validator)
%validateYLimWidgetValue Validate the widget value for YLim widgets.

% Get the value from the DDG widget.
fulltag = [this.Register.Name, tag];
variable = hDlg.getWidgetValue(fulltag);

% Try to evaluate it.
[val,errid,errmsg] = uiservices.evaluate(variable);

% If the evaluation fails, throw that error.
if ~isempty(errid)
    b = false;
    exception = MException(errid, errmsg);
elseif ~validator(val)
    % Test whether the value is valid with the fcn handle given to us.
    b = false;
    [msg,id] = uiscopes.message(['Invalid', messageTag]);
    exception = MException(id, msg);
else
    b = true;
    exception = MException.empty;
end
end
