function propertyChangedVisual(this,ev)
%propertyChangedVisual   Visual-specific property change

%   Copyright 2012-2018 The MathWorks, Inc.

if ~ischar(ev)
    ev = get(ev.AffectedObject, 'Name');
end
hAxes = [];
for indx = 1:numel(this.Displays)
    hAxes = [hAxes, this.Displays{indx}.Axes];  %#ok<AGROW>
end
linkaxes(hAxes, 'off', 'LinkAutoChanges', 'off');
switch ev
    case 'PlotType'
        updatePlotType(this);
    case 'XDataMode'
        updateXDataMode(this);
    case 'CustomXData'
        updateCustomXData(this);
    case 'XOffset'
        updateXOffset(this, this.Displays, false);
        if isDataAvailable(this)
            update(this);
        end
    case 'SampleIncrement'
        updateSampleIncrement(this);
    case 'XScale'
        updateXScale(this);
    case 'YScale'
      updateYScale(this);
    case 'MaximizeAxes'
        updateMaximizeAxes(this);
    case 'UserDefinedChannelNames'
        updateChannelNames(this);
end
%  % Suppress negative Y values ignored warning, and restore
%  its status on cleanup
onState = warning('off', 'MATLAB:Axes:NegativeLimitsInLogAxis');
c = onCleanup(@() warning(onState));
linkaxes(hAxes, 'x', 'LinkAutoChanges', 'off');
% Notify measurements that properties have changed. Currently, all the
% above properties should trigger a display updated event.
notify(this, 'DisplayUpdated');
end
