function setSelectedDisplayPlotMagPhase(this,val,selectedDisplay)
%setSelectedDisplayPlotMagPhase Perform all the required actions when
% SelectedDisplayPlotMagPhase is set. The SET method of
% SelectedDisplayPlotMagPhase uses SelectedDisplay property. There are
% cases when SelectedDisplayPlotMagPhase is set in a state where
% SelectedDisplay is not yet correctly set - e.g. during set method of
% SelectedDisplay (see updateSelectedDisplay method).
% setSelectedDisplayPlotMagPhase method is intended to handle this
% situation and performs all the tasks required during SET of
% SelectedDisplayPlotMagPhase property.

%   Copyright 2012-2014 The MathWorks, Inc.

if this.SelectedDisplayUpdateEnabled
    updateSelectedDisplayProperty(this, 'PlotMagPhase', val);
    % Update display plots to show the latest selected transformation
    % (real-imag or mag-phase)
    source = this.Application.DataSource;
    if ~isempty(source) && this.IsSourceValid && ~isDataEmpty(source)
        if isRunning(source)
            update(this);
        else
            % Second call necessary to get YExtents set so autoscale works
            update(this, getOriginTime(source), getTimeOfDisplayData(source));
            update(this, getOriginTime(source), getTimeOfDisplayData(source));
        end
    end
    % Setting PlotMagPhase resets the plotter, which makes the offset text
    % go to 0.  Update text to get correct value shown again.
    updateText(this);
    % Re-tile layout to ensure proper axes padding
    matlabshared.scopes.visual.Displayable.tile(this.Displays{1}, ...
        this.LayoutGridContainer, this.Displays, ...
        getPropertyValue(this,'DisplayLayoutDimensions'));
    % Update legend location to be best fit for the data
    hDisplays = this.Displays;
    bestFitLegendLocation(hDisplays{selectedDisplay});
    cacheTotalTraceCount(this);
end
end
