function showStyleDialog(this,newDisplayNum)
%SHOWSTYLEDIALOG Change graphical properties of the axes
%   This function should be called only after data is plotted on the Scope.
%   It launches the graphical property editor dialog and waits for user to
%   make changes to the graphical properties. If the user presses the OK
%   button, the graphical properties are updated only if they are different
%   from the input properties.

%   Copyright 2012-2014 The MathWorks, Inc.

if (nargin==1)
    % Function is called from the view menu item.  Get the currently
    % selected display, which will default to 1.
    newDisplayStr = this.SelectedDisplay;
    newDisplayNum = str2double(newDisplayStr);
else
    newDisplayStr = num2str(newDisplayNum);
end
% Open the graphical property editor for editing the style of chosen
% display
this.IsStyleDialogOpen = true;
if isempty(this.StyleDialog)
    okCallback = makeCallback(this, @updateStyle, 'OK');
    applyCallback = makeCallback(this, @updateStyle, 'Apply');
    displaySelectedCallback = '';  % Empty for single display Scopes
    hideCallback = makeCallback(this, @hideStyleDialog);
    ip = getStyleDialogInput(this, newDisplayNum);
    this.SelectedDisplay = newDisplayStr;
    this.StyleDialog = dsp.scopes.GraphicalPropertyEditorArrayPlot(ip, ...
        okCallback, applyCallback, displaySelectedCallback, hideCallback);
    if strcmp(this.Application.DataSource.Type, 'SPTool')
        checkbox = this.StyleDialog.Widgets.LineVisibleCheckbox;
        checkbox.Visible = 'off';
    end
else
    if (this.StyleDialog.Visible && strcmpi(newDisplayStr, this.SelectedDisplay))
        % Bring to focus if already open and selected display did not
        % change
        this.StyleDialog.Visible = true;
    else
        % Change display and show the dialog
        this.SelectedDisplay = newDisplayStr;
        ip = getStyleDialogInput(this, newDisplayNum);
        initialize(this.StyleDialog, ip);
        % Update display names as it is possible that number of displays
        % have changed
        %this.StyleDialog.DisplayNames = ip.DisplayNames;
        % Set selected display to the new display
        %this.StyleDialog.SelectedDisplay = ip.SelectedDisplay;
        this.StyleDialog.Visible = true;
    end
end
end
