function updateCustomXData(this, showErrors)
%updateCustomXData Update CustomXData in the display

%   Copyright 2015-2016 The MathWorks, Inc.

% There is only one display
hDisplay = this.Displays{1};

% Validate the new CustomXData property value
newXData = getPropertyValue(this, 'CustomXData');
if ~isempty(newXData) && ischar(newXData)
    [newXData,errID,errmsg] = evalPropertyValue(this, 'CustomXData');
    if ~isempty(errID)
        if (nargin < 2 || showErrors)
            uiscopes.errorHandler(uiscopes.message('ErrorTimeDomVis', ...
                'CustomXData', errmsg, sprintf('%g', newXData)), ...
                uiscopes.message('TitleScopeError'), errID);
        end
        return;
    end
end

hDisplay.CustomXData = newXData;
updateXSpan(this);
if isDataAvailable(this)
    % If the frameLength of current data is less than or equal to
    % CustomXData, update the lines. Else, reset and clear the lines.
    if hDisplay.CurrentFrameLength <= length(hDisplay.CustomXData)
        update(this);
    else
        resetLines(hDisplay);
    end
end
sendEvent(this.Application, 'VisualLimitsChanged');
end