function updateDisplays(this)
%updateDisplays   Update displays from source data

%   Copyright 2012-2016 The MathWorks, Inc.

% Get source data from cache
cachedSourceData = this.SourceDataCache;
maxDims = cachedSourceData.MaxDimensions;
sampleTimes = cachedSourceData.SampleTimes;
numInputs = cachedSourceData.NumInputs;
subDims = cachedSourceData.SubDimensions;
inputNames = cachedSourceData.InputNames;
originTime = cachedSourceData.OriginTime;
isEnumType = cachedSourceData.IsEnumType;
dataTypes = cachedSourceData.DataTypes;
isComplex = cachedSourceData.IsComplex;
isContiguous = cachedSourceData.IsDataContiguous;
hDisplays = this.Displays;
numDisplays = length(hDisplays);
numDisplaysWithData = min(numDisplays, numInputs);
% Get initial XLim to apply later, since adding displays and updating time
% axes causes limits to reset to default values
if ~isempty(hDisplays)
    initXLim = hDisplays{1}.XLim;
end
% There is a one-to-one mapping of input ports to displays until the last
% display, which gets all remaining input ports.
totalChannelCount = 0;
for displayInd = 1:numDisplaysWithData - 1
    hDisplay = hDisplays{displayInd};
    % Set all of the plotter properties
    hDisplay.SettingProperties = true;
    hDisplay.SampleTimes = sampleTimes(displayInd);
    hDisplay.MaxDimensions = maxDims(displayInd, :);
    hDisplay.SubDimensions = subDims(displayInd, :);
    hDisplay.OriginTime = originTime;
    hDisplay.EndTime = hDisplay.OriginTime;
    hDisplay.IsHomogeneousEnumType = isEnumType(displayInd);
    hDisplay.EnumClass = dataTypes{displayInd};
    hDisplay.IsComplex = any(isComplex(displayInd));
    hDisplay.ChannelCountOffset = totalChannelCount;
    hDisplay.IsDataContiguous = isContiguous(displayInd);
    totalChannelCount = totalChannelCount + sum(hDisplay.NumberOfChannels);
    % Tell the display that we are done setting multiple properties. At
    % this time all the lines will be generated.
    hDisplay.SettingProperties = false;
    hDisplay.InputNames = inputNames(displayInd);
    updateDisplayProperties(hDisplay);
end
% Check numDisplaysWithData to protect against the case where all displays
% are empty.
if numDisplaysWithData>0
    % Map all remaining inputs to this display
    hDisplay = hDisplays{numDisplaysWithData};
    % Set all of the plotter properties
    hDisplay.SettingProperties = true;
    hDisplay.SampleTimes = sampleTimes(numDisplaysWithData:end);
    hDisplay.MaxDimensions = maxDims(numDisplaysWithData:end, :);
    hDisplay.SubDimensions = subDims(numDisplaysWithData:end, :);
    hDisplay.OriginTime = originTime;
    hDisplay.EndTime = hDisplay.OriginTime;
    hDisplay.IsComplex = any(isComplex(numDisplaysWithData:end));
    hDisplay.ChannelCountOffset = totalChannelCount;
    hDisplay.IsDataContiguous = isContiguous(numDisplaysWithData:end);
    % Determine if datatype are enumerations of the same class.
    aDataType = dataTypes{numDisplaysWithData};
    sametype = true(size(dataTypes));
    for indx = numDisplaysWithData:numel(dataTypes)
        sametype(indx) = strcmpi(aDataType, dataTypes{indx});
    end
    hDisplay.IsHomogeneousEnumType = all(isEnumType(numDisplaysWithData:end)) && all(sametype);
    hDisplay.EnumClass = aDataType;
    % Tell the display that we are done setting multiple properties. At
    % this time all the lines will be generated.
    hDisplay.SettingProperties = false;
    hDisplay.InputNames = inputNames(numDisplaysWithData:end);
    updateDisplayProperties(hDisplay);
end
% Reset XLim on all displays
hDisplays = this.Displays;
for displayInd = 1:numel(hDisplays)
    hDisplays{displayInd}.XLim = initXLim;
end
% Use markers for lines and stairs if framelength=1
updateMarkers(this);
cacheTotalTraceCount(this);
end
