function updateMaximizeAxes(this)
%updateMaximizeAxes   Update MaximizeAxes of displays

%   Copyright 2012-2014 The MathWorks, Inc.

hDisplays = this.Displays;
maxAxesStr = getPropertyValue(this, 'MaximizeAxes');
if any(strcmp(maxAxesStr, {'On', 'Off'}))
    % Apply value to all displays and set callback to empty
    maxAxes = uiservices.onOffToLogical(maxAxesStr);
    for displayInd = 1:numel(hDisplays)
        hDisplay = hDisplays{displayInd};
        hDisplay.UserAnnotationCallback = '';
        hDisplay.MaximizeAxes = maxAxes;
    end
    % Re-tile layout to ensure proper axes padding
    if ~maxAxes
        matlabshared.scopes.visual.Displayable.tile(this.Displays{1}, ...
            this.LayoutGridContainer, hDisplays, ...
            getPropertyValue(this, 'DisplayLayoutDimensions'));
    end
else
    % Set callback on all displays and apply
    for displayInd = 1:numel(hDisplays)
        hDisplays{displayInd}.UserAnnotationCallback = @() onAnnotationChange(this);
    end
    onAnnotationChange(this);
end
end
