function updateStyle(this,action)
%UPDATESTYLE Update style of the selected display. Properties are updated
%only if they have changed.

%   Copyright 2012-2015 The MathWorks, Inc.
if this.IsUpdatingStyle
    % Prevent callback reentry. Required because this is a Java button
    % listener callback
    return;
end
this.IsUpdatingStyle = true;
try
    updateOutput(this.StyleDialog);
    % Figure Color
    fc = this.StyleDialog.Output.FigureColor;
    if ~isempty(fc)
        % Set the updated figure properties back into the object.
        hApp = this.Application;
        generalUIExt = hApp.getExtInst('Core', 'General UI');
        setPropertyValue(generalUIExt, 'FigureColor', fc);
    end
    setPropertyValue(this, 'PlotType', this.StyleDialog.PlotType);
    % Axes Color
    if ~isempty(this.StyleDialog.Output.AxesColor)
        updateSelectedDisplayProperty(this, 'AxesColor', this.StyleDialog.Output.AxesColor);
    end
    % Axes Tick Color
    if ~isempty(this.StyleDialog.Output.AxesTickColor)
        updateSelectedDisplayProperty(this, 'AxesTickColor', this.StyleDialog.Output.AxesTickColor);
    end
    % Line Properties
    if any(this.StyleDialog.Output.LineDirty)
        applyLineProperties(this);
    end
    if strcmpi(action, 'ok')
        hideStyleDialog(this);
    else
        % Apply - We need to refresh the dialog as line properties may have
        % changed when PlotType or Axes background was changed.
        refreshStyleDialog(this, this.SelectedDisplay);
    end
    this.IsUpdatingStyle = false;
catch
    this.IsUpdatingStyle = false;
end
end
