function varargout = validateSource(this,hSource)
%validateSource Validate the source

%   Copyright 2012-2019 The MathWorks, Inc.

if nargin<2
    hSource = this.Application.DataSource;
end
b = true;
exception = MException.empty;
maxDimensions = getMaxDimensions(hSource);
% The frame sizes of all inputs must be the same.
if numel(unique(maxDimensions(:,1))) ~= 1
    b = false;
    [msg,id] = uiscopes.message('FrameSizesDiffer');
    exception = MException(id, msg);
end
% When in Custom X-data mode, the length of Custom X-data must be equal to
% the frame size.
if strcmpi(getPropertyValue(this, 'XDataMode'),'Custom')
    newXData = getPropertyValue(this, 'CustomXData');
    if ischar(newXData)
        [~,errID,errmsg] = evalPropertyValue(this, 'CustomXData');
        if ~isempty(errID)
            b = false;
            exception = MException(errID, errmsg);
        end
    end
end

% Do post propagation tasks. There are none at present.
if nargout
    varargout = {b, exception};
elseif ~b
    throw(exception);
end
end
