classdef ArrayPlotSysObjCfg < spbscopes.TimeScopeSystemObjectCfg
  %ArrayPlotSysObjCfg   Define the ArrayPlotSysObjCfg class.
  
  %   Copyright 2012-2016 The MathWorks, Inc.
  
  
  methods
    function this = ArrayPlotSysObjCfg(varargin)
      %ArrayPlotSysObjCfg   Construct the ArrayPlotSysObjCfg class.
      
      % Prevent clear classes warnings
      mlock;
      this@spbscopes.TimeScopeSystemObjectCfg(varargin{:});
    end
  end
  
  methods
    function appName = getScopeTag(~)
      %getScopeTag Returns the simple application name.
      appName = 'Array Plot';
    end
    
    function b = shouldShowControls(this, id)
        if strcmp(id, 'TimeStatus')
            b = false;
        else
            b = shouldShowControls@spbscopes.TimeScopeSystemObjectCfg(this, id);
        end
    end
    
    function b = isMenuCompact(~, menuName)
        % Use compact autoscale menu
        b = strcmp(menuName, 'autoscale');
    end
    
    function measurementTags = getSupportedMeasurements(~)
      measurementTags = {'acursors','signalstats','peaks'};
    end
    
    function [mApp, mExample, mAbout] = createHelpMenuItems(~, mHelp)
      
      if ~isdeployed() % docroot and demo not available under deployment
        % Help menus
        mapFileLocation = fullfile(docroot,'toolbox','dsp','dsp.map');
        
        mApp(1) = uimenu(mHelp, ...
          'Tag', 'uimgr.uimenu_dsp.ArrayPlot', ...
          'Label', getString(message('dsp:system:ArrayPlot:SystemObjectHelp')), ...
          'Callback', @(hco,ev) helpview(mapFileLocation, 'dsparrayplot'));
        
        mApp(2) = uimenu(mHelp, ...
          'Tag', 'uimgr.uimenu_DSP System Toolbox', ...
          'Label', getString(message('Spcuilib:scopes:DSPSystemToolboxHelp')), ...
          'Callback', @(hco,ev) helpview(mapFileLocation, 'dspinfo'));
        
        % NOTE: The Keyboard Command and Message Log menus are added by the
        % Framework in: ...\@uiscopes\@Framework\Framework.m
        
        mExample = uimenu(mHelp, ...
          'Tag', 'uimgr.uimenu_DSP System Toolbox Examples', ...
          'Label', getString(message('dsp:system:ArrayPlot:DSPSystemToolboxExamples')), ...
          'Callback', @(hco,ev) demo('toolbox', 'dsp'));
      else
        mApp = [];
        mExample = [];
      end
      
      % Want the "About" option separated, so we group everything above
      % into a menugroup and leave "About" as a singleton menu
      mAbout = uimenu(mHelp, ...
        'Tag', 'uimgr.uimenu_About', ...
        'Label', getString(message('Spcuilib:scopes:AboutDSPSystemToolbox')), ...
        'Callback', @(hco,ev) aboutdspsystbx);
    end
    
    function cfgFile = getConfigurationFile(~)
      cfgFile = 'arrayplotsysobj.cfg';
    end
    
    function b = isToolbarCompact(~, toolbarName)
        % Use compact collapsible toolbars only for zoom operations
        b = strcmp(toolbarName, 'zoom') || strcmp(toolbarName, 'properties');
    end
    
    function renderToolbars(~,~)
        % NO OP
    end
    
    function cb = getSettingsDialogCallback(~,hScope)
        %getSettingsDialogCallback
        cb = @(~, ~) onEditOptions(hScope.Visual);
    end
  end
  
  methods (Hidden)
    function b = useMCOSExtMgr(~)
      b = true;
    end
    
    function hgRoot = getHGRoot(~)
      hgRoot = groot;
    end
    
    function onViewMenuOpening(this, ~, ~)
      % This must be a NO-OP to hide the Data History Properties menu
      this.ViewMenuOpeningListener = [];
    end
    
    function onFileMenuOpening(this, hScope, ~)
      %ONFILEMENUOPENING Respond to the FileMenuOpening event.
      
      % Create the menus
      hFileMenu = findobj(hScope.Parent, 'Tag', 'uimgr.uimenugroup_File');
      
      hNumInputs = findobj(hFileMenu, 'Tag', 'uimgr.uimenugroup_NumberOfInputPorts');
      if isempty(hNumInputs)
        hNumInputs = uimenu('Parent', hFileMenu, ...
          'Tag', 'uimgr.uimenugroup_NumberOfInputPorts', ...
          'Position', 1, ...
          'UserData', hScope, ...
          'Label', getString(message('Spcuilib:scopes:NumInputPortsWithKBShortcut')), ...
          'Callback', @this.numInputPortsCB);
        
        cb = @this.numInputsCallback;
        uimenu('Parent', hNumInputs, ...
          'Tag', 'uimgr.spctogglemenu_1InputPort', ...
          'Label', '&1', ...
          'Callback', cb);
        uimenu('Parent', hNumInputs, ...
          'Label', '&2', ...
          'Tag', 'uimgr.spctogglemenu_2InputPort', ...
          'Callback', cb);
        uimenu('Parent', hNumInputs, ...
          'Label', '&3', ...
          'Tag', 'uimgr.spctogglemenu_3InputPort', ...
          'Callback', cb);
        uimenu('Parent', hNumInputs, ...
          'Interruptible', 'off', ...
          'BusyAction', 'cancel', ...
          'Label', getString(message('Spcuilib:scopes:MenuMore')), ...
          'Tag', 'uimgr.spctogglemenu_CustomInputPorts', ...
          'Callback', cb);
        
        % Add a separator to any preexisting menu items.
        set(findobj(hFileMenu, 'Parent', hFileMenu, 'Position', 2), 'Separator', 'on');
        % Hide if its a floating scope
        set(hNumInputs,'Visible', uiservices.logicalToOnOff(~hScope.DataSource.Floating));
      end
      
      % Update the states of the menu.
      isStopped = ~hScope.DataSource.DataSpecsLocked;
      set(hNumInputs, 'Enable', uiservices.logicalToOnOff(isStopped));
    end
  end
  
  methods (Hidden, Static)
    function this = loadobj(s)
      this = loadobj@matlabshared.scopes.SystemObjectScopeSpecification(s);
    end
  end
end

% [EOF]
