function tpsBlkHandle = addBlock(blk,preOrPost,tpsBlkHOffset,tpsBlkVOffset,...
                        libToLoad, blkToInsert,tpsBlkName)
% Helper function adds block in model with correct orientation and location
       
% Copyright 2014 The MathWorks, Inc.

% Orient block w.r.t. the instance block being updated
if nargin > 0
    blk = convertStringsToChars(blk);
end

if nargin > 1
    preOrPost = convertStringsToChars(preOrPost);
end

if nargin > 4
    if isstring(libToLoad)
        libToLoad = convertStringsToChars(libToLoad);
    elseif iscell(libToLoad)
        libToLoad = cellfun(@cellstr,libToLoad);
    end
end

if nargin > 5
    blkToInsert = convertStringsToChars(blkToInsert);
end

if nargin > 6
    tpsBlkName = convertStringsToChars(tpsBlkName);
end

blkPos    = get_param(blk, 'Position');
blkOrient = get_param(blk, 'Orientation');
blkCenter = mean([blkPos(1:2); blkPos(3:4)]);
blkWidth  = blkPos(3) - blkPos(1);
blkHeight = blkPos(4) - blkPos(2);

if strcmpi(blkOrient, 'left') || strcmpi(blkOrient, 'right')
    sign = (strcmpi(blkOrient, 'left')  && strcmpi(preOrPost, 'Pre')) ||...
        (strcmpi(blkOrient, 'right') && strcmpi(preOrPost, 'Post'));
    sign = sign * 2 - 1; % Map 0 to -1 and 1 to 1
    tpsBlkCenter = [blkCenter(1) + sign * (blkWidth/2 + tpsBlkHOffset),...
        blkCenter(2) - tpsBlkVOffset];
    tpsBlkWidth  = 20;
    tpsBlkHeight = blkHeight;
elseif (strcmpi(blkOrient, 'up') || strcmpi(blkOrient, 'down'))
    sign = (strcmpi(blkOrient, 'up')   && strcmpi(preOrPost, 'Pre')) ||...
        (strcmpi(blkOrient, 'down') && strcmpi(preOrPost, 'Post'));
    sign = sign * 2 - 1; % Map 0 to -1 and 1 to 1
    tpsBlkCenter = [blkCenter(1) - tpsBlkVOffset,...
        blkCenter(2) + sign * (blkHeight/2 + tpsBlkHOffset)];
    tpsBlkWidth  = blkWidth;
    tpsBlkHeight = 20;
end

tpsBlkPos = [tpsBlkCenter(1) - tpsBlkWidth  / 2, ...
    tpsBlkCenter(2) - tpsBlkHeight / 2, ...
    tpsBlkCenter(1) + tpsBlkWidth  / 2, ...
    tpsBlkCenter(2) + tpsBlkHeight / 2];

% Load library that contains the block to be added.
load_system(libToLoad);

% Add the block and hide its name
tpsBlkHandle = add_block(blkToInsert, tpsBlkName, ...
    'Position',           tpsBlkPos, ...
    'Orientation',        blkOrient, ...
    'ShowName',           'off');