function coeffs = convertParamEQToBiquad(f0, bw, g , fs)
%CONVERTPARAMEQROBIQUAD Convert parametric equalizer specifications to
%biquad coefficients
% f0 : Equalizer center frequency in Hz
% bw : Equalizer bandwidth in Hz, measured at the arithmetic mean between 
%      the peak gain in absolute power units and one.
% g  : Filter gain in decibels
% fs : Sampling frequency

%   Copyright 2014-2021 The MathWorks, Inc.

%#codegen
if isempty(coder.target)
    w = warning('off', 'dsp:iirparameq:iirparameq_NotSupported'); 
    restoreWarn = onCleanup(@() warning(w));
end
N = 2;
[sos,g] = iirparameq(N,g,f0/(fs/2),bw/(fs/2)); % This only works for N=2
sosg    = [prod(g)*sos(1:3),sos(4:6)].';
coeffs  = [sosg(1:3);sosg(5:6)];

