
/* Copyright 2019-2020 The MathWorks, Inc. */

/* decim_dbl_avx2_blk.h

    This file contains the prototypes for FIRDecimation implementation
*/
#ifndef __DECIM_DBL_H__
#define __DECIM_DBL_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdio.h>

/*------------------Proto types----------------------*/
/* This structure encapsulates the information required for
    the FIRDecimation.

*/
typedef struct tFIRDecimatorDblRealHandle
{
    size_t nDecimateFactor;
    size_t nFilterLen;
    size_t nNumChannels;
    size_t nFrameLen;
    size_t nStatesLen;
    size_t nPhaseIdx;

    /* Pointer to Coefficients with len 'nFilterLen'*/
    double *pfCoeff;

    /* Pointer to States with len '(nFilterLen+nFrameLen) * nNumChannels'*/
    double *pfStates;

    /* Pointer to the accumulator with length 'nNumChannels' */
    double *pfAccumulator;
}tFIRDecimatorDblRealHandle;


void MWDSPCRL_avx2_decim_dbl_real_init(tFIRDecimatorDblRealHandle *S,
    size_t nDecimateFactor,
    size_t nFilterLen,
    size_t nFrameLen,
    size_t nNumChannels,
    size_t StateSize,
    double *convCoefficients,
    double *arrState,
    double *arrAccum);

/* function for stepProcess*/
int MWDSPCRL_avx2_decim_dbl_real_portcoeffs_process(
    const double *afInput,
    double *afOutput,
    tFIRDecimatorDblRealHandle *psHandle,
    const double *afCoeffs,
    size_t length);

int MWDSPCRL_avx2_decim_dbl_real_process(const double *afInput,
    double *afOutput,
    tFIRDecimatorDblRealHandle *psHandle);

#ifdef __cplusplus
}
#endif

#endif
