/* Copyright 2020 The MathWorks, Inc. */
/* decim_sgl_cmplx_avx2_blk.h

    This file contains the prototypes for FIRDecimation implementation
*/
#ifndef __DECIM_SGL_CMPLX_H__
#define __DECIM_SGL_CMPLX_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdio.h>

/*------------------Proto types----------------------*/
/* This structure encapsulates the information required for
    the FIRDecimation.

*/
typedef struct tFIRDecimatorSglCmplxHandle
{
    size_t nDecimateFactor;
    size_t nFilterLen;
    size_t nNumChannels;
    size_t nFrameLen;
    size_t nStatesLen;
    size_t nPhaseIdx;
    size_t nIsRealCoeff;

    /* Pointer to Coefficients with len 'nFilterLen'*/
    float *pfCoeff;

    /* Pointer to States with len '(nFilterLen+nFrameLen) * nNumChannels'*/
    float *pfStates;

    /* Pointer to the accumulator with length 'nNumChannels' */
    float *pfAccumulator;
}tFIRDecimatorSglCmplxHandle;


void MWDSPCRL_avx2_decim_sgl_cmplx_init(tFIRDecimatorSglCmplxHandle *S,
    size_t nDecimateFactor,
    size_t nFilterLen,
    size_t nFrameLen,
    size_t nNumChannels,
    size_t StateSize,
    size_t nIsRealCoeff,
    float *convCoefficients,
    float *arrState,
    float *arrAccum);

/* function for stepProcess*/
int MWDSPCRL_avx2_decim_sgl_cmplx_portcoeffs_process(
    const float *afInput,
    float *afOutput,
    tFIRDecimatorSglCmplxHandle *psHandle,
    const float *afCoeffs,
    size_t length);

int MWDSPCRL_avx2_decim_sgl_cmplx_process(const float *afInput,
    float *afOutput,
    tFIRDecimatorSglCmplxHandle *psHandle);

#ifdef __cplusplus
}
#endif

#endif
