/* Copyright 2020 The MathWorks, Inc. */
#include "fir_dft_dbl_cmplx_avx2_blk.h"
#include <immintrin.h>
#define VECTOR_UNITS_FOR_256 (256/64)
#define UF1 (1 * VECTOR_UNITS_FOR_256)
#define UF2 (2 * VECTOR_UNITS_FOR_256)
#define UF3 (3 * VECTOR_UNITS_FOR_256)
#define UF4 (4 * VECTOR_UNITS_FOR_256)

static void firTransRealCoeffs(discreteFIRTransDblCmplx *S, const double* in, double* out)   /* Compex Inputs and Real Coeffs */
{
    size_t k;
    size_t samplesOffset;
    size_t statesOffset;
    size_t filtOrder;
    size_t frameLen;
    size_t nChan;
    double* states;
    const double* coeffs;
    frameLen = S->frameLen;
    nChan = S->nChan;
    filtOrder = S->filtOrder;
    states = S->states;
    coeffs = S->coeffs;
    
    for (k = 0; k < nChan; k++)                         
    {
        size_t i;
        size_t vectorLoopCount;
        size_t scalarLoopCount;
        size_t statesSize;
        statesSize = filtOrder + 1;
        samplesOffset = k * frameLen;
        statesOffset = k * 2 * statesSize;
        vectorLoopCount = filtOrder >> 4;
        scalarLoopCount = filtOrder & 15;
        /* per channel */
        for (i = 0; i < frameLen; i+=2)
        {
            __m256d vCoeffs;
            __m256d vCoeffs_2;
            __m256d vCoeffs_3;
            __m256d vCoeffs_4;
            __m256d vInputsRe;
            __m256d vInputsIm;
            __m256d vProdRe;
            __m256d vProdRe_2;
            __m256d vProdRe_3;
            __m256d vProdRe_4;
            __m256d vProdIm;
            __m256d vProdIm_2;
            __m256d vProdIm_3;
            __m256d vProdIm_4;
            __m256d vStatesRe;
            __m256d vStatesRe_2;
            __m256d vStatesRe_3;
            __m256d vStatesRe_4;
            __m256d vStatesIm;
            __m256d vStatesIm_2;
            __m256d vStatesIm_3;
            __m256d vStatesIm_4;
            __m256d vUpdatesStatesRe;
            __m256d vUpdatesStatesRe_2;
            __m256d vUpdatesStatesRe_3;
            __m256d vUpdatesStatesRe_4;
            __m256d vUpdatesStatesIm;
            __m256d vUpdatesStatesIm_2;
            __m256d vUpdatesStatesIm_3;
            __m256d vUpdatesStatesIm_4;
            double inputRe;
            double inputIm;
            double prodRe;
            double prodIm;
            double *fTemp;
            const double *fTempCoeffs;
            double *pStates = states + statesOffset;
            size_t j, vIdx;
            inputRe = in[samplesOffset + i];
            inputIm = in[samplesOffset + i + 1];
            
            prodRe = 0;
            prodIm = 0;
            j = 0;
            vInputsRe = _mm256_set1_pd(inputRe);
            vInputsIm = _mm256_set1_pd(inputIm);
            /* Loop unrolling four times */
            for (vIdx = 0; vIdx < vectorLoopCount; vIdx++)
            {
                fTempCoeffs = coeffs + j;
                vCoeffs = _mm256_loadu_pd(fTempCoeffs);
                vCoeffs_2 = _mm256_loadu_pd(fTempCoeffs + UF1);
                vCoeffs_3 = _mm256_loadu_pd(fTempCoeffs + UF2);
                vCoeffs_4 = _mm256_loadu_pd(fTempCoeffs + UF3);
                
                vProdRe = _mm256_mul_pd(vCoeffs, vInputsRe);
                vProdRe_2 = _mm256_mul_pd(vCoeffs_2, vInputsRe);
                vProdRe_3 = _mm256_mul_pd(vCoeffs_3, vInputsRe);
                vProdRe_4 = _mm256_mul_pd(vCoeffs_4, vInputsRe);
                
                vProdIm = _mm256_mul_pd(vCoeffs, vInputsIm);
                vProdIm_2 = _mm256_mul_pd(vCoeffs_2, vInputsIm);
                vProdIm_3 = _mm256_mul_pd(vCoeffs_3, vInputsIm);
                vProdIm_4 = _mm256_mul_pd(vCoeffs_4, vInputsIm);
                
                fTemp =  pStates + j + 1;
                vStatesRe = _mm256_loadu_pd(fTemp);
                vStatesRe_2 = _mm256_loadu_pd(fTemp + UF1);
                vStatesRe_3 = _mm256_loadu_pd(fTemp + UF2);
                vStatesRe_4 = _mm256_loadu_pd(fTemp + UF3);
                
                fTemp = pStates + statesSize + j + 1;
                vStatesIm = _mm256_loadu_pd(fTemp);
                vStatesIm_2 = _mm256_loadu_pd(fTemp + UF1);
                vStatesIm_3 = _mm256_loadu_pd(fTemp + UF2);
                vStatesIm_4 = _mm256_loadu_pd(fTemp + UF3);
                
                vUpdatesStatesRe = _mm256_add_pd(vStatesRe, vProdRe);
                vUpdatesStatesRe_2 = _mm256_add_pd(vStatesRe_2, vProdRe_2);
                vUpdatesStatesRe_3 = _mm256_add_pd(vStatesRe_3, vProdRe_3);
                vUpdatesStatesRe_4 = _mm256_add_pd(vStatesRe_4, vProdRe_4);
                
                vUpdatesStatesIm = _mm256_add_pd(vStatesIm, vProdIm);
                vUpdatesStatesIm_2 = _mm256_add_pd(vStatesIm_2, vProdIm_2);
                vUpdatesStatesIm_3 = _mm256_add_pd(vStatesIm_3, vProdIm_3);
                vUpdatesStatesIm_4 = _mm256_add_pd(vStatesIm_4, vProdIm_4);
                
                fTemp =  pStates + j;
                _mm256_storeu_pd(fTemp, vUpdatesStatesRe);
                _mm256_storeu_pd(fTemp + UF1, vUpdatesStatesRe_2);
                _mm256_storeu_pd(fTemp + UF2, vUpdatesStatesRe_3);
                _mm256_storeu_pd(fTemp + UF3, vUpdatesStatesRe_4);
                
                fTemp = pStates + statesSize + j;
                _mm256_storeu_pd(fTemp, vUpdatesStatesIm);
                _mm256_storeu_pd(fTemp + UF1, vUpdatesStatesIm_2);
                _mm256_storeu_pd(fTemp + UF2, vUpdatesStatesIm_3);
                _mm256_storeu_pd(fTemp + UF3, vUpdatesStatesIm_4);
                j += UF4;
            }
            if (scalarLoopCount) {
                /* Perform vector operations if the remaining elements are greater than equal to VECTOR_UNITS_FOR_256 */
                for (; j + UF1 < filtOrder; j += UF1)
                {
                    vCoeffs = _mm256_loadu_pd(coeffs + j);
                    vProdRe = _mm256_mul_pd(vCoeffs, vInputsRe);
                    vProdIm = _mm256_mul_pd(vCoeffs, vInputsIm);
                    vStatesRe = _mm256_loadu_pd(pStates + j + 1);
                    vStatesIm = _mm256_loadu_pd(pStates + statesSize + j + 1);
                    vUpdatesStatesRe = _mm256_add_pd(vStatesRe, vProdRe);
                    vUpdatesStatesIm = _mm256_add_pd(vStatesIm, vProdIm);
                    _mm256_storeu_pd(pStates + j, vUpdatesStatesRe);
                    _mm256_storeu_pd(pStates + statesSize + j, vUpdatesStatesIm);
                }
                /* Process the remaining elements using scalar operations */
                for (; j < filtOrder; j++)
                {
                    prodRe = coeffs[j] * inputRe;
                    prodIm = coeffs[j] * inputIm;
                    pStates[j] = pStates[j + 1] + prodRe;
                    pStates[j+ statesSize] = pStates[statesSize + j + 1] + prodIm;
                }
            }
            out[i + samplesOffset] = pStates[0];
            out[i + 1 + samplesOffset] = pStates[statesSize];
        }
    }
}

static void firTransCmplxCoeffs(discreteFIRTransDblCmplx *S, const double* in, double* out)      /* Complex Inputs and Complex Coeffs */
{
    size_t k;
    size_t samplesOffset;
    size_t statesOffset;
    size_t filtOrder;
    size_t frameLen;
    size_t nChan;
    double* states;
    const double* coeffs;
    frameLen = S->frameLen;
    nChan = S->nChan;
    filtOrder = S->filtOrder;
    states = S->states;
    coeffs = S->coeffs;
    
    for (k = 0; k < nChan; k++)
    {
        size_t i;
        size_t vectorLoopCount;
        size_t scalarLoopCount;
        size_t statesSize;
        statesSize = filtOrder + 2;
        samplesOffset = k * frameLen;
        statesOffset = k * statesSize;
        vectorLoopCount = (filtOrder >> 4) ;
        scalarLoopCount = filtOrder & 15;
        /* per channel */
        for (i = 0; i < frameLen; i += 2)
        {
            __m256d vCoeffs;
            __m256d vCoeffs_2;
            __m256d vCoeffs_3;
            __m256d vCoeffs_4;
            __m256d vInputs;
            __m256d prod;
            __m256d prod_2;
            __m256d prod_3;
            __m256d prod_4;
            __m256d vStates;
            __m256d vStates_2;
            __m256d vStates_3;
            __m256d vStates_4;
            __m256d vUpdatesStates;
            __m256d vUpdatesStates_2;
            __m256d vUpdatesStates_3;
            __m256d vUpdatesStates_4;
            __m256d negFactor;
            __m256d vRealMul;
            __m256d vRealMul_2;
            __m256d vRealMul_3;
            __m256d vRealMul_4;
            __m256d vImagMul;
            __m256d vImagMul_2;
            __m256d vImagMul_3;
            __m256d vImagMul_4;
            double inputRe;
            double inputIm;
            double prodRe;
            double prodIm;
            double *fTemp;
            const double *fTempCoeffs;
            double *pStates = states + statesOffset;
            size_t j, vIdx;
            inputRe = in[samplesOffset + i];
            inputIm = in[samplesOffset + i + 1];
            vInputs = _mm256_setr_pd(inputRe, inputIm, inputRe, inputIm);
            negFactor= _mm256_setr_pd(1, -1, 1, -1);
            prodRe = 0;
            prodIm = 0;
            j = 0;
            /* Loop unrolling four times */
            for (vIdx = 0; vIdx < vectorLoopCount; vIdx++)
            {
                fTempCoeffs = coeffs + j;
                vCoeffs = _mm256_loadu_pd(fTempCoeffs);
                vCoeffs_2 = _mm256_loadu_pd(fTempCoeffs + UF1);
                vCoeffs_3 = _mm256_loadu_pd(fTempCoeffs + UF2);
                vCoeffs_4 = _mm256_loadu_pd(fTempCoeffs + UF3);
                
                vRealMul = _mm256_mul_pd(vInputs, vCoeffs);
                vCoeffs = _mm256_permute_pd(vCoeffs, 0x5);
                vCoeffs = _mm256_mul_pd(vCoeffs, negFactor);
                vImagMul = _mm256_mul_pd(vInputs, vCoeffs);
                prod = _mm256_hsub_pd(vRealMul, vImagMul);
                
                vRealMul_2 = _mm256_mul_pd(vInputs, vCoeffs_2);
                vCoeffs_2 = _mm256_permute_pd(vCoeffs_2, 0x5);
                vCoeffs_2 = _mm256_mul_pd(vCoeffs_2, negFactor);
                vImagMul_2 = _mm256_mul_pd(vInputs, vCoeffs_2);
                prod_2 = _mm256_hsub_pd(vRealMul_2, vImagMul_2);
                
                vRealMul_3 = _mm256_mul_pd(vInputs, vCoeffs_3);
                vCoeffs_3 = _mm256_permute_pd(vCoeffs_3, 0x5);
                vCoeffs_3 = _mm256_mul_pd(vCoeffs_3, negFactor);
                vImagMul_3 = _mm256_mul_pd(vInputs, vCoeffs_3);
                prod_3 = _mm256_hsub_pd(vRealMul_3, vImagMul_3);
                
                vRealMul_4 = _mm256_mul_pd(vInputs, vCoeffs_4);
                vCoeffs_4 = _mm256_permute_pd(vCoeffs_4, 0x5);
                vCoeffs_4 = _mm256_mul_pd(vCoeffs_4, negFactor);
                vImagMul_4 = _mm256_mul_pd(vInputs, vCoeffs_4);
                prod_4 = _mm256_hsub_pd(vRealMul_4, vImagMul_4);
                
                fTemp = pStates + j + 2;
                vStates = _mm256_loadu_pd(fTemp);
                vStates_2 = _mm256_loadu_pd(fTemp + UF1);
                vStates_3 = _mm256_loadu_pd(fTemp + UF2);
                vStates_4 = _mm256_loadu_pd(fTemp + UF3);
                
                vUpdatesStates = _mm256_add_pd(vStates, prod);
                vUpdatesStates_2 = _mm256_add_pd(vStates_2, prod_2);
                vUpdatesStates_3 = _mm256_add_pd(vStates_3, prod_3);
                vUpdatesStates_4 = _mm256_add_pd(vStates_4, prod_4);
                
                fTemp = pStates + j;
                _mm256_storeu_pd(fTemp, vUpdatesStates);
                _mm256_storeu_pd(fTemp + UF1, vUpdatesStates_2);
                _mm256_storeu_pd(fTemp + UF2, vUpdatesStates_3);
                _mm256_storeu_pd(fTemp + UF3, vUpdatesStates_4);
                
                j += UF4;
            }
            if (scalarLoopCount) {
                /* Perform vector operations if the remaining elements are greater than equal to VECTOR_UNITS_FOR_256 */
                for (; j + UF1 < filtOrder; j += UF1)
                {
                    vCoeffs = _mm256_loadu_pd(coeffs + j);
                    vRealMul = _mm256_mul_pd(vInputs, vCoeffs);
                    vCoeffs = _mm256_permute_pd(vCoeffs, 0x5);
                    vCoeffs = _mm256_mul_pd(vCoeffs, negFactor);
                    vImagMul = _mm256_mul_pd(vInputs, vCoeffs);
                    prod = _mm256_hsub_pd(vRealMul, vImagMul);
                    vStates = _mm256_loadu_pd(pStates + j + 2);
                    vUpdatesStates = _mm256_add_pd(vStates, prod);
                    _mm256_storeu_pd(pStates + j, vUpdatesStates);
                }
                /* Process the remaining elements using scalar operations */
                for (; j < filtOrder; j+=2)
                {
                    prodRe = coeffs[j] * inputRe - (coeffs[j + 1] * inputIm);
                    prodIm = coeffs[j] * inputIm + (coeffs[j + 1] * inputRe);
                    pStates[j] = pStates[j + 2] + prodRe;
                    pStates[j + 1] = pStates[j + 3] + prodIm;
                }
            }
            out[i + samplesOffset] = pStates[0];
            out[i + 1 + samplesOffset] = pStates[1];
        }
    }
}
/**
 * Copies the initial states into the states array
 * @param S : structure discreteFIRTransDblCmplx
 * @param frameLen : length of each frame
 * @param nChan : number of channels
 * @param filtOrder : Filter Length
 * @param states : states array
 * @param coeffs : coefficients array
 * @param initialStates : initial conditions array
 * @param stateSize : final statesize
 * @param initStateSize : Initial conditions StateSize
 * @param isRealCoeffs : is true when coeffs are real datatype
 * Output
 * @return void
 **/
void MWDSPCRL_avx2_fir_dft_dbl_cmplx_init(discreteFIRTransDblCmplx *S, size_t frameLen, size_t nChan, size_t filtOrder, double* states, const double* coeffs, double* initialStates, size_t stateSize, size_t initStateSize, size_t isRealCoeffs){
    
    double* pStatesRe;
    double* pStatesIm;
    size_t idx, k, stateLen, tmp, i;
    if((nChan > 1) && (initStateSize != 2))
    {
        if((stateSize) && (initStateSize != stateSize - 4 * nChan))
        {
            for (i = 0; i < nChan; i++) {
                tmp = i * (initStateSize + 4);
                memcpy(&states[tmp + 2],&initialStates[0],initStateSize * sizeof(double));
            }
        }
        else if((stateSize) && (initStateSize==stateSize- 4 * nChan))
        {
            size_t tempStateSize;
            tempStateSize = initStateSize/nChan;
            for (i = 0; i < nChan; i++) {
                tmp=i * (tempStateSize + 4);
                memcpy(&states[tmp + 2],&initialStates[i * tempStateSize],tempStateSize * sizeof(double));
            }
            
        }
    }
    else if(initStateSize==stateSize - 4){
        memcpy(&states[2],&initialStates[0],initStateSize*sizeof(double));
    }
    else
    {
        if(nChan==1)
        {
            for(i = 2; i < stateSize-2; i+=2){
                states[i] = initialStates[0];
                states[i+1] = initialStates[1];
            }
        }
        else
        {
            size_t j;
            for (i = 0; i < nChan; i++) {
                tmp=i * 2 * (filtOrder+1) + 2;
                for(j=0; j < filtOrder-1; j++)
                {
                    states[tmp++]=initialStates[0];
                    states[tmp++]=initialStates[1];
                }
            }
        }
    }
    if (isRealCoeffs){
        stateLen = filtOrder + 1;
        pStatesRe=(double*)calloc(stateLen * nChan, sizeof(double));
        pStatesIm=(double*)calloc(stateLen * nChan, sizeof(double));
        idx=0;
        for (k = 0; k < stateLen * nChan; k++)
        {
            pStatesRe[k] = states[idx++];
            pStatesIm[k] = states[idx++];
        }
        idx=0;
        for(i =0; i < nChan; i++)
        {
            tmp = i * stateLen * 2;
            for(k = 0; k < stateLen; k++)
            {
                states[tmp]=pStatesRe[idx];
                states[tmp + stateLen]=pStatesIm[idx++];
                tmp++;
            }
        }
        free(pStatesRe);
        free(pStatesIm);
    }
    
    
    S->frameLen = frameLen;
    S->nChan = nChan;
    if(isRealCoeffs)
        S->filtOrder = filtOrder;
    else
        S->filtOrder = filtOrder * 2;
    S->isRealCoeffs = isRealCoeffs;
    S->coeffs=coeffs;
    S->states=states;
}
/* function for stepProcess */
void MWDSPCRL_avx2_fir_dft_dbl_cmplx_process(discreteFIRTransDblCmplx *S, const double* in, double* out){
    if(S->isRealCoeffs){
        firTransRealCoeffs(S, in, out);
    }
    else{
        firTransCmplxCoeffs(S, in, out);
    }
}
