/* Copyright 2020 The MathWorks, Inc. */
#include "fir_dft_sgl_cmplx_avx2_blk.h"
#include <immintrin.h>
#define VECTOR_UNITS_FOR_256 (256/32)
#define UF1 (1 * VECTOR_UNITS_FOR_256)
#define UF2 (2 * VECTOR_UNITS_FOR_256)
#define UF3 (3 * VECTOR_UNITS_FOR_256)
#define UF4 (4 * VECTOR_UNITS_FOR_256)

static void firTransRealCoeffs(discreteFIRTransSglCmplx *S, const float* in, float* out)          /* Compex Inputs and Real Coeffs */
{
    size_t k;
    size_t samplesOffset;
    size_t statesOffset;
    size_t filtOrder;
    size_t frameLen;
    size_t nChan;
    float* states;
    const float* coeffs;
    frameLen = S->frameLen;
    nChan = S->nChan;
    filtOrder = S->filtOrder;
    states = S->states;
    coeffs = S->coeffs;
    
    for (k = 0; k < nChan; k++)
    {
        size_t i;
        size_t vectorLoopCount;
        size_t scalarLoopCount;
        size_t statesSize;
        statesSize = filtOrder + 1;
        samplesOffset = k * frameLen;
        statesOffset = k * 2 * statesSize;
        vectorLoopCount = filtOrder >> 5;
        scalarLoopCount = filtOrder & 31;
        /* per channel */
        for (i = 0; i < frameLen; i+=2)
        {
            __m256 vCoeffs;
            __m256 vCoeffs_2;
            __m256 vCoeffs_3;
            __m256 vCoeffs_4;
            __m256 vInputsRe;
            __m256 vInputsIm;
            __m256 vProdRe;
            __m256 vProdRe_2;
            __m256 vProdRe_3;
            __m256 vProdRe_4;
            __m256 vProdIm;
            __m256 vProdIm_2;
            __m256 vProdIm_3;
            __m256 vProdIm_4;
            __m256 vStatesRe;
            __m256 vStatesRe_2;
            __m256 vStatesRe_3;
            __m256 vStatesRe_4;
            __m256 vStatesIm;
            __m256 vStatesIm_2;
            __m256 vStatesIm_3;
            __m256 vStatesIm_4;
            __m256 vUpdatesStatesRe;
            __m256 vUpdatesStatesRe_2;
            __m256 vUpdatesStatesRe_3;
            __m256 vUpdatesStatesRe_4;
            __m256 vUpdatesStatesIm;
            __m256 vUpdatesStatesIm_2;
            __m256 vUpdatesStatesIm_3;
            __m256 vUpdatesStatesIm_4;
            float inputRe;
            float inputIm;
            float prodRe;
            float prodIm;
            float *fTemp;
            const float *fTempCoeffs;
            float *pStates = states + statesOffset;
            size_t j, vIdx;
            inputRe = in[samplesOffset + i];
            inputIm = in[samplesOffset + i + 1];
            
            prodRe = 0;
            prodIm = 0;
            j = 0;
            vInputsRe = _mm256_set1_ps(inputRe);
            vInputsIm = _mm256_set1_ps(inputIm);
            /* Loop unrolling four times */
            for (vIdx = 0; vIdx < vectorLoopCount; vIdx++)
            {
                fTempCoeffs = coeffs + j;
                vCoeffs = _mm256_loadu_ps(fTempCoeffs);
                vCoeffs_2 = _mm256_loadu_ps(fTempCoeffs + UF1);
                vCoeffs_3 = _mm256_loadu_ps(fTempCoeffs + UF2);
                vCoeffs_4 = _mm256_loadu_ps(fTempCoeffs + UF3);
                
                vProdRe = _mm256_mul_ps(vCoeffs, vInputsRe);
                vProdRe_2 = _mm256_mul_ps(vCoeffs_2, vInputsRe);
                vProdRe_3 = _mm256_mul_ps(vCoeffs_3, vInputsRe);
                vProdRe_4 = _mm256_mul_ps(vCoeffs_4, vInputsRe);
                
                vProdIm = _mm256_mul_ps(vCoeffs, vInputsIm);
                vProdIm_2 = _mm256_mul_ps(vCoeffs_2, vInputsIm);
                vProdIm_3 = _mm256_mul_ps(vCoeffs_3, vInputsIm);
                vProdIm_4 = _mm256_mul_ps(vCoeffs_4, vInputsIm);
                
                fTemp =  pStates + j + 1;
                vStatesRe = _mm256_loadu_ps(fTemp);
                vStatesRe_2 = _mm256_loadu_ps(fTemp + UF1);
                vStatesRe_3 = _mm256_loadu_ps(fTemp + UF2);
                vStatesRe_4 = _mm256_loadu_ps(fTemp + UF3);
                
                fTemp = pStates + statesSize + j + 1;
                vStatesIm = _mm256_loadu_ps(fTemp);
                vStatesIm_2 = _mm256_loadu_ps(fTemp + UF1);
                vStatesIm_3 = _mm256_loadu_ps(fTemp + UF2);
                vStatesIm_4 = _mm256_loadu_ps(fTemp + UF3);
                /* Update the states */
                vUpdatesStatesRe = _mm256_add_ps(vStatesRe, vProdRe);
                vUpdatesStatesRe_2 = _mm256_add_ps(vStatesRe_2, vProdRe_2);
                vUpdatesStatesRe_3 = _mm256_add_ps(vStatesRe_3, vProdRe_3);
                vUpdatesStatesRe_4 = _mm256_add_ps(vStatesRe_4, vProdRe_4);
                
                vUpdatesStatesIm = _mm256_add_ps(vStatesIm, vProdIm);
                vUpdatesStatesIm_2 = _mm256_add_ps(vStatesIm_2, vProdIm_2);
                vUpdatesStatesIm_3 = _mm256_add_ps(vStatesIm_3, vProdIm_3);
                vUpdatesStatesIm_4 = _mm256_add_ps(vStatesIm_4, vProdIm_4);
                
                fTemp =  pStates + j;
                _mm256_storeu_ps(fTemp, vUpdatesStatesRe);
                _mm256_storeu_ps(fTemp + UF1, vUpdatesStatesRe_2);
                _mm256_storeu_ps(fTemp + UF2, vUpdatesStatesRe_3);
                _mm256_storeu_ps(fTemp + UF3, vUpdatesStatesRe_4);
                
                fTemp = pStates + statesSize + j;
                _mm256_storeu_ps(fTemp, vUpdatesStatesIm);
                _mm256_storeu_ps(fTemp + UF1, vUpdatesStatesIm_2);
                _mm256_storeu_ps(fTemp + UF2, vUpdatesStatesIm_3);
                _mm256_storeu_ps(fTemp + UF3, vUpdatesStatesIm_4);
                j += UF4;
            }
            if (scalarLoopCount) {
                /* Perform vector operations if the remaining elements are greater than equal to VECTOR_UNITS_FOR_256 */
                for (; j + UF1 < filtOrder; j += UF1)
                {
                    vCoeffs = _mm256_loadu_ps(coeffs + j);
                    vProdRe = _mm256_mul_ps(vCoeffs, vInputsRe);
                    vProdIm = _mm256_mul_ps(vCoeffs, vInputsIm);
                    vStatesRe = _mm256_loadu_ps(pStates + j + 1);
                    vStatesIm = _mm256_loadu_ps(pStates + statesSize + j + 1);
                    vUpdatesStatesRe = _mm256_add_ps(vStatesRe, vProdRe);
                    vUpdatesStatesIm = _mm256_add_ps(vStatesIm, vProdIm);
                    _mm256_storeu_ps(pStates + j, vUpdatesStatesRe);
                    _mm256_storeu_ps(pStates + statesSize + j, vUpdatesStatesIm);
                }
                /* Process the remaining elements using scalar operations */
                for (; j < filtOrder; j++)
                {
                    prodRe = coeffs[j] * inputRe;
                    prodIm = coeffs[j] * inputIm;
                    pStates[j] = pStates[j + 1] + prodRe;
                    pStates[j+ statesSize] = pStates[statesSize + j + 1] + prodIm;
                }
            }
            out[i + samplesOffset] = pStates[0];
            out[i + 1 + samplesOffset] = pStates[statesSize];
        }
    }
}

static void firTransCmplxCoeffs(discreteFIRTransSglCmplx *S, const float* in, float* out)          /* Complex Inputs and Complex Coeffs */
{
    size_t k;
    size_t samplesOffset;
    size_t statesOffset;
    size_t filtOrder;
    size_t frameLen;
    size_t nChan;
    float* states;
    const float* coeffs;
    frameLen = S->frameLen;
    nChan = S->nChan;
    filtOrder = S->filtOrder;
    states = S->states;
    coeffs = S->coeffs;
    
    for (k = 0; k < nChan; k++)
    {
        size_t i;
        size_t vectorLoopCount;
        size_t scalarLoopCount;
        size_t statesSize;
        statesSize = filtOrder + 2;
        samplesOffset = k * frameLen;
        statesOffset = k * statesSize;
        vectorLoopCount = (filtOrder >> 5) ;
        scalarLoopCount = filtOrder & 31;
        /* per channel */
        for (i = 0; i < frameLen; i += 2)
        {
            __m256 vCoeffs;
            __m256 vCoeffs_2;
            __m256 vCoeffs_3;
            __m256 vCoeffs_4;
            __m256 vInputs;
            __m256 prod;
            __m256 prod_2;
            __m256 prod_3;
            __m256 prod_4;
            __m256 vStates;
            __m256 vStates_2;
            __m256 vStates_3;
            __m256 vStates_4;
            __m256 vUpdatesStates;
            __m256 vUpdatesStates_2;
            __m256 vUpdatesStates_3;
            __m256 vUpdatesStates_4;
            __m256 vRealMul;
            __m256 vRealMul_2;
            __m256 vRealMul_3;
            __m256 vRealMul_4;
            __m256 vImagMul;
            __m256 vImagMul_2;
            __m256 vImagMul_3;
            __m256 vImagMul_4;
            __m256 negFactor;
            float inputRe;
            float inputIm;
            float prodRe;
            float prodIm;
            float *fTemp;
            const float *fTempCoeffs;
            float *pStates = states + statesOffset;
            size_t j, vIdx;
            inputRe = in[samplesOffset + i];
            inputIm = in[samplesOffset + i + 1];
            vInputs = _mm256_setr_ps(inputRe, inputIm, inputRe, inputIm, inputRe, inputIm, inputRe, inputIm);
            negFactor= _mm256_setr_ps(1, -1, 1, -1, 1, -1, 1, -1);
            prodRe = 0;
            prodIm = 0;
            j = 0;
            /* Loop unrolling four times */
            for (vIdx = 0; vIdx < vectorLoopCount; vIdx++)
            {
                fTempCoeffs = coeffs + j;
                vCoeffs = _mm256_loadu_ps(fTempCoeffs);
                vCoeffs_2 = _mm256_loadu_ps(fTempCoeffs + UF1);
                vCoeffs_3 = _mm256_loadu_ps(fTempCoeffs + UF2);
                vCoeffs_4 = _mm256_loadu_ps(fTempCoeffs + UF3);
                
                vRealMul = _mm256_mul_ps(vInputs, vCoeffs);
                vCoeffs = _mm256_permute_ps(vCoeffs, 0xb1);
                vCoeffs = _mm256_mul_ps(vCoeffs, negFactor);
                vImagMul = _mm256_mul_ps(vInputs, vCoeffs);
                prod = _mm256_hsub_ps(vRealMul, vImagMul);
                prod = _mm256_permute_ps(prod, 0xD8);
                
                vRealMul_2 = _mm256_mul_ps(vInputs, vCoeffs_2);
                vCoeffs_2 = _mm256_permute_ps(vCoeffs_2, 0xb1);
                vCoeffs_2 = _mm256_mul_ps(vCoeffs_2, negFactor);
                vImagMul_2 = _mm256_mul_ps(vInputs, vCoeffs_2);
                prod_2 = _mm256_hsub_ps(vRealMul_2, vImagMul_2);
                prod_2 = _mm256_permute_ps(prod_2, 0xD8);
                
                vRealMul_3 = _mm256_mul_ps(vInputs, vCoeffs_3);
                vCoeffs_3 = _mm256_permute_ps(vCoeffs_3, 0xb1);
                vCoeffs_3 = _mm256_mul_ps(vCoeffs_3, negFactor);
                vImagMul_3 = _mm256_mul_ps(vInputs, vCoeffs_3);
                prod_3 = _mm256_hsub_ps(vRealMul_3, vImagMul_3);
                prod_3 = _mm256_permute_ps(prod_3, 0xD8);
                
                vRealMul_4 = _mm256_mul_ps(vInputs, vCoeffs_4);
                vCoeffs_4 = _mm256_permute_ps(vCoeffs_4, 0xb1);
                vCoeffs_4 = _mm256_mul_ps(vCoeffs_4, negFactor);
                vImagMul_4 = _mm256_mul_ps(vInputs, vCoeffs_4);
                prod_4 = _mm256_hsub_ps(vRealMul_4, vImagMul_4);
                prod_4 = _mm256_permute_ps(prod_4, 0xD8);
                
                fTemp = pStates + j + 2;
                vStates = _mm256_loadu_ps(fTemp);
                vStates_2 = _mm256_loadu_ps(fTemp + UF1);
                vStates_3 = _mm256_loadu_ps(fTemp + UF2);
                vStates_4 = _mm256_loadu_ps(fTemp + UF3);
                
                vUpdatesStates = _mm256_add_ps(vStates, prod);
                vUpdatesStates_2 = _mm256_add_ps(vStates_2, prod_2);
                vUpdatesStates_3 = _mm256_add_ps(vStates_3, prod_3);
                vUpdatesStates_4 = _mm256_add_ps(vStates_4, prod_4);
                
                fTemp = pStates + j;
                _mm256_storeu_ps(fTemp, vUpdatesStates);
                _mm256_storeu_ps(fTemp + UF1, vUpdatesStates_2);
                _mm256_storeu_ps(fTemp + UF2, vUpdatesStates_3);
                _mm256_storeu_ps(fTemp + UF3, vUpdatesStates_4);
                
                j += UF4;
            }
            if (scalarLoopCount) {
                /* Perform vector operations if the remaining elements are greater than equal to VECTOR_UNITS_FOR_256 */
                for (; j + UF1 < filtOrder; j += UF1)
                {
                    vCoeffs = _mm256_loadu_ps(coeffs + j);
                    vRealMul = _mm256_mul_ps(vInputs, vCoeffs);
                    vCoeffs = _mm256_permute_ps(vCoeffs, 0xb1);
                    vCoeffs = _mm256_mul_ps(vCoeffs, negFactor);
                    vImagMul = _mm256_mul_ps(vInputs, vCoeffs);
                    prod = _mm256_hsub_ps(vRealMul, vImagMul);
                    prod = _mm256_permute_ps(prod, 0xD8);
                    vStates = _mm256_loadu_ps(pStates + j + 2);
                    vUpdatesStates = _mm256_add_ps(vStates, prod);
                    _mm256_storeu_ps(pStates + j, vUpdatesStates);
                }
                /* Process the remaining elements using scalar operations */
                for (; j < filtOrder; j+=2)
                {
                    prodRe = coeffs[j] * inputRe - (coeffs[j + 1] * inputIm);
                    prodIm = coeffs[j] * inputIm + (coeffs[j + 1] * inputRe);
                    pStates[j] = pStates[j + 2] + prodRe;
                    pStates[j + 1] = pStates[j + 3] + prodIm;
                }
            }
            out[i + samplesOffset] = pStates[0];
            out[i + 1 + samplesOffset] = pStates[1];
        }
    }
}
/**
 * Copies the initial states into the states array
 * @param S : structure discreteFIRTransDblCmplx
 * @param frameLen : length of each frame
 * @param nChan : number of channels
 * @param filtOrder : Filter Length
 * @param states : states array
 * @param coeffs : coefficients array
 * @param initialStates : initial conditions array
 * @param stateSize : final statesize
 * @param initStateSize : Initial conditions StateSize
 * @param isRealCoeffs : is true when coeffs are real datatype
 * Output
 * @return void
 **/
void MWDSPCRL_avx2_fir_dft_sgl_cmplx_init(discreteFIRTransSglCmplx *S, size_t frameLen, size_t nChan, size_t filtOrder, float* states, const float* coeffs, float* initialStates, size_t stateSize, size_t initStateSize, size_t isRealCoeffs){
    
    float* pStatesRe;
    float* pStatesIm;
    size_t idx, k, stateLen, tmp, i;
    if((nChan > 1) && (initStateSize != 2))
    {
        if((stateSize) && (initStateSize != stateSize - 4 * nChan))
        {
            for (i = 0; i < nChan; i++) {
                tmp = i * (initStateSize + 4);
                memcpy(&states[tmp + 2],&initialStates[0],initStateSize * sizeof(float));
            }
        }
        else if((stateSize) && (initStateSize==stateSize- 4 * nChan))
        {
            size_t tempStateSize;
            tempStateSize = initStateSize/nChan;
            for (i = 0; i < nChan; i++) {
                tmp=i * (tempStateSize + 4);
                memcpy(&states[tmp + 2],&initialStates[i * tempStateSize],tempStateSize * sizeof(float));
            }
            
        }
    }
    else if(initStateSize==stateSize - 4){
        memcpy(&states[2],&initialStates[0],initStateSize*sizeof(float));
    }
    else
    {
        if(nChan==1)
        {
            for(i = 2; i < stateSize-2; i+=2){
                states[i] = initialStates[0];
                states[i+1] = initialStates[1];
            }
        }
        else
        {
            size_t j;
            for (i = 0; i < nChan; i++) {
                tmp=i * 2 * (filtOrder+1) + 2;
                for(j=0; j < filtOrder-1; j++)
                {
                    states[tmp++]=initialStates[0];
                    states[tmp++]=initialStates[1];
                }
            }
        }
    }
    if(isRealCoeffs){
        stateLen = filtOrder + 1;
        pStatesRe=(float*)calloc(stateLen * nChan, sizeof(float));
        pStatesIm=(float*)calloc(stateLen * nChan, sizeof(float));
        idx=0;
        for (k = 0; k < stateLen * nChan; k++)
        {
            pStatesRe[k] = states[idx++];
            pStatesIm[k] = states[idx++];
        }
        idx=0;
        for(i =0; i < nChan; i++)
        {
            tmp = i * stateLen * 2;
            for(k = 0; k < stateLen; k++)
            {
                states[tmp]=pStatesRe[idx];
                states[tmp + stateLen]=pStatesIm[idx++];
                tmp++;
            }
        }
        free(pStatesRe);
        free(pStatesIm);
    }
    
    S->frameLen = frameLen;
    S->nChan = nChan;
    if(isRealCoeffs)
        S->filtOrder = filtOrder;
    else
        S->filtOrder = filtOrder * 2;
    S->isRealCoeffs = isRealCoeffs;
    S->coeffs=coeffs;
    S->states=states;
}
/* function for stepProcess */
void MWDSPCRL_avx2_fir_dft_sgl_cmplx_process(discreteFIRTransSglCmplx *S, const float* in, float* out){
    if(S->isRealCoeffs){
        firTransRealCoeffs(S, in, out);
    }
    else{
        firTransCmplxCoeffs(S, in, out);
    }
}
