/* Copyright 2020-2021 The MathWorks, Inc. */
#include "matmul_sgl_avx2_opr.h"
#include <immintrin.h>

// C = A * B
// Size of A: M x K
// Size of B: K x N

#define SIMD_FLOAT_WIDTH 8
void MWSPCG_sgemm_matmul_avx2(char* transa, char* transb, const int* m32, const int* n32,
	const int* k32, const float* alpha, const float* a, const int* lda32,
	const float* b, const int* ldb32, const float* beta, float* c,
	const int* ldc32)
{
	long i_colC, i_colA, i_rowC, i, j;
	long M, N, K;
	float* p_colA, * p_scalarB, * p_colC;
	float* pA, * pB, * pC;
	float tempSum, tempA, tempB;
	int remLoopCount;

	__m256 A8x1, scalarB, C8x1;

	pA = (float*)&a[0];
	pB = (float*)&b[0];
	pC = (float*)&c[0];

	M = (long)*m32;
	N = (long)*n32;
	K = (long)*k32;
	remLoopCount = M & 0x7;

	// Arguments not used
	(void)transa;
	(void)transb;
	(void)alpha;
	(void)lda32;
	(void)ldb32;
	(void)beta;
	(void)ldc32;

	for (i_colC = 0; i_colC < N; i_colC++) {
		p_colC = pC + i_colC * M;

		for (i_rowC = 0; i_rowC < M / 8; i_rowC++) {
			C8x1 = _mm256_setzero_ps();
			p_colA = pA + i_rowC * (long)SIMD_FLOAT_WIDTH;
			p_scalarB = pB + K * i_colC;

			for (i_colA = 0; i_colA < K; i_colA++) {

				A8x1	= _mm256_loadu_ps(p_colA);
				scalarB = _mm256_broadcast_ss(p_scalarB);
				C8x1	= _mm256_fmadd_ps(A8x1, scalarB, C8x1);

				p_scalarB++;
				p_colA += M;
			}
			_mm256_storeu_ps(p_colC, C8x1);
			p_colC += (long)SIMD_FLOAT_WIDTH;
		}

		// Remainder Loop: Scalar Multiplications
		p_scalarB = pB + K * i_colC;
		p_colA = pA + i_rowC * (long)SIMD_FLOAT_WIDTH;
		for (i = 0; i < remLoopCount; i++) {
			tempSum = 0;
			for (j = 0; j < K; j++) {
				tempA	= p_colA[j * M + i];
				tempB	= *(p_scalarB+j);
				tempSum += tempA * tempB;
			}
			*p_colC = tempSum;
			p_colC++;
		}
	}

	return;
}
