function dspUnlinkFVToolFromMask(blkh)
%dspUnlinkFVToolFromMask Callback for un-linking FVTool from a block mask.
%   The handle to FVTool will be removed from the UserData of the block (in
%   a field of a structure called 'fvtool', e.g. ud.fvtool) and replaced
%   with a unique tag that matches a tag set on the fvtool figure.

%   Copyright 2015-2019 The MathWorks, Inc.

ud = get_param(blkh, 'UserData');
if isfield(ud,'fvtool')
    % Overwrite object in UserData with uniqueTag
    storedFVToolLink = ud.fvtool;
    if ~isnumeric(storedFVToolLink) && ~isempty(storedFVToolLink) && isvalid(storedFVToolLink)
        uniqueTag = getfullname(blkh);
        set(storedFVToolLink, 'Tag', uniqueTag);
        ud.fvtool = uniqueTag;
        set_param(blkh, 'UserData', ud);
    end
end
end
