function [h,l,framing] = dspblk2chsbank(blkh, ...
    hpf, lpf, framingIn, inpProc, dtRndMode, dtOFMode)
% DSPBLK2CHSBANK DSP System Toolbox 2-Channel Synthesis Filter Bank block helper function.

% Copyright 2002-2018 The MathWorks, Inc.

h = [];
l = [];

framing = dspblkAdjustMultiRateFraming(inpProc, framingIn);

fullblk     = getfullname(blkh);
sum_blk     = [fullblk '/Sum'];
dt_cnvt_blk = [fullblk '/Data Type Conversion'];

% Under the block mask, set the Sum and Convert
% block rounding and overflow parameters to what
% was specified at the top-level of the mask
rndModeVec = {'Ceiling','Convergent','Floor','Nearest','Round','Simplest','Zero'};
rndMode = rndModeVec{dtRndMode};
set_param(sum_blk,     'RndMeth', rndMode);
set_param(dt_cnvt_blk, 'RndMeth', rndMode);

if (dtOFMode == 2)
    set_param(sum_blk,     'SaturateOnIntegerOverflow', 'on');
    set_param(dt_cnvt_blk, 'SaturateOnIntegerOverflow', 'on');
else
    set_param(sum_blk,     'SaturateOnIntegerOverflow', 'off');
    set_param(dt_cnvt_blk, 'SaturateOnIntegerOverflow', 'off');
end

[M,N] = size(hpf);
if (M ~= 1 && N ~= 1)
    error(message('dsp:dspblk2chsbank:invalidCoefficient1'));
end

[M,N] = size(lpf);
if (M ~= 1 && N ~= 1)
    error(message('dsp:dspblk2chsbank:invalidCoefficient2'));
end

if(~isempty(hpf) && ~isempty(lpf))
    % Need to reshuffle the coefficients into phase order
    h = phaseReshuffle(hpf);
    l = phaseReshuffle(lpf);
end

% ---------------------------------------------------------
function y = phaseReshuffle(x)
    % Need to reshuffle the coefficients into phase order
    y = x(:);
    len = length(x);
    if (rem(len, 2) ~= 0)
        nzeros = 2 - rem(len, 2);
        y = [y(:); zeros(nzeros,1)];
    end
    len = length(y);
    nrows = len / 2;
    % Re-arrange the coefficients
    y = reshape(y, 2, nrows).';
