function dspblkDSTMinMax(blkh)
%DSPBLKMINMAX Block dynamic dialog UI helper function
%   Used by the DSP System Toolbox Minimum and Maximum blocks

% Copyright 2015-2017 The MathWorks, Inc.

% Update dialog parameter visibilities
% ------------------------------------
maskPrmNames = get_param(blkh,'MaskNames');
mask_vis_old = get_param(blkh,'MaskVisibilities');
mask_vis_new = mask_vis_old;

fcnParamStringVal = get_param(blkh,'fcn');
indexBaseParamVis = 'off';
operateOverPrmVis = 'off';
inputProcParamVis = 'off';
resetPortParamVis = 'off';
isRunnningMinMax  = isequal(fcnParamStringVal,'Running');

if isRunnningMinMax
    inputProcParamVis = 'on';
    resetPortParamVis = 'on';
else
    % Includes: 'Value', 'Index', 'Value and Index'
    operateOverPrmVis = 'on';
    
    % 'Index' and 'Value and Index' also need "Index base" param
    if isequal(fcnParamStringVal, 'Value and Index') || ...
            isequal(fcnParamStringVal, 'Index')
        indexBaseParamVis = 'on';
    end
end

mask_vis_new{strcmp(maskPrmNames,'indexBase')}       = indexBaseParamVis;
mask_vis_new{strcmp(maskPrmNames,'operateOver')}     = operateOverPrmVis;
mask_vis_new{strcmp(maskPrmNames,'InputProcessing')} = inputProcParamVis;
mask_vis_new{strcmp(maskPrmNames,'reset')}           = resetPortParamVis;

if ~isequal(mask_vis_old,mask_vis_new)
    set_param(blkh, 'MaskVisibilities', mask_vis_new);
end

% Cannot read the value of 'operateOver' unless it is already visible
blockMaskObject = Simulink.Mask.get(blkh);
dimEBMaskParam  = blockMaskObject.getParameter('Dimension');
if ~isRunnningMinMax && isequal(get_param(blkh,'operateOver'),'Specified dimension')
    dimEBMaskParam.Visible = 'on'; % show 'dimension' parameter
else
    dimEBMaskParam.Visible = 'off';
end

end % dspblkDSTMinMax
