function dspblkDifference(blkh)
% dspblkDifference Mask dynamic dialog function for Difference block

% Copyright 2017-2019 The MathWorks, Inc.

% First pass to update block dialog visibilities
mask_vis_old = get_param(blkh,'MaskVisibilities');
mask_vis_new = updateMaskVis(blkh, mask_vis_old);
if ~isequal(mask_vis_old, mask_vis_new)
    set_param(blkh,'MaskVisibilities', mask_vis_new);
end

% Re-read the dialog after initial visibility changes AGAIN, in
% order to catch edge case of switching between the settings
% (Running = 'No' and 'Specify dimension') and Running = 'Yes'.
% Otherwise when you switch back to Running = 'No', you might
% not see all the parameters visible on the dialog (specDimIndex).
mask_vis_old = get_param(blkh,'MaskVisibilities');
mask_vis_new = updateMaskVis(blkh, mask_vis_old);
if ~isequal(mask_vis_old, mask_vis_new)
    set_param(blkh,'MaskVisibilities', mask_vis_new);
end

end

% -------------------------------------------------------------------
function mask_vis_new = updateMaskVis(blkh, mask_vis_new)

[dimParamIdx, specDimIndex] = ...
    dspblkGetMaskParamIndicesFromParamNames(blkh, 'dim', 'Dimension');

if strcmp(get_param(blkh, 'Run'), 'Yes')
    % RUNNING DIFFERENCE: Both parameters are N/A
    mask_vis_new{dimParamIdx}  = 'off'; % 'Difference along' popup
    mask_vis_new{specDimIndex} = 'off'; % 'Dimension' edit box
else
    % OTHERWISE: Keep 'dim' widget ENABLED
    mask_vis_new{dimParamIdx} = 'on';
    % Read setting and update remaining visibilities
    if strcmp(get_param(blkh,'dim'),'Specified dimension')
        mask_vis_new{specDimIndex} = 'on'; % 'Dimension' edit box
    else
        mask_vis_new{specDimIndex} = 'off'; % 'Dimension' edit box
    end
end

end
