function varargout = dspblkMean(blkh, actionStr)
% dspblkVariance DSP System Toolbox Mean block helper function.

% Copyright 1995-2017 The MathWorks, Inc.

isRunning = strcmp(get_param(blkh,'run'),'on');
isRstPort = isRunning && ~strcmp(get_param(blkh,'reset_popup'),'None');

if (nargin > 1) && strcmp(actionStr, 'icon')
    % Input and output port labels
    if isRstPort
        s.i1 = 1; s.i1s = 'I';
        s.i2 = 2; s.i2s = 'Rst';
    else
        s.i1 = 1; s.i1s = '';
        s.i2 = 1; s.i2s = '';
    end
    s.o1 = 1; s.o1s = '';
    
    % Block icon
    if isRunning
        x = [-35 NaN 100 NaN 58 42 50 50 50 42 59 NaN 34 ...
            18 26 26 26 34 18 NaN 66 82 74 74 74 82 66 NaN ...
            34 18 18 34 34 18 NaN 58 42 42 58 58 42 NaN 82 66 ...
            66 82 82 66 NaN 34 34 42 42 NaN 58 58 66 66];
        y = [0 NaN 100 NaN 76 76 76 76 28 28 28 NaN 68 68 68 ...
            68 36 36 36 NaN 84 84 84 84 20 20 20 NaN 54 54 ...
            52 52 50 50 NaN 50 50 54 54 52 52 NaN 52 52 50 ...
            50 54 54 NaN 52 52 52 52 NaN 52 52 52 52];
    else
        x = [0 NaN 100 NaN 42 58 50 50 50 58 42 NaN 42 58 58 42];
        y = [0 NaN 100 NaN 80 80 80 80 20 20 20 NaN 48 48 51 51];
    end
    
    varargout = {s, x, y};
    
else
    % Dynamic dialog: Mask Parameter visibilities
    mask_vis_old = get_param(blkh,'MaskVisibilities');
    mask_vis_new = mask_vis_old;
    
    [inpProcDDIdx, rstDDIdx, dirModeDDIdx, dimEBIdx] = ...
        dspblkGetMaskParamIndicesFromParamNames(blkh, ...
        'InputProcessing', 'reset_popup', 'directionMode', 'dimension');
    
    if isRunning
        mask_vis_new{inpProcDDIdx} = 'on';
        mask_vis_new{rstDDIdx}     = 'on';
        mask_vis_new{dirModeDDIdx} = 'off';
        mask_vis_new{dimEBIdx}     = 'off';
    else
        mask_vis_new{inpProcDDIdx} = 'off';
        mask_vis_new{rstDDIdx}     = 'off';
        mask_vis_new{dirModeDDIdx} = 'on';
        % We cannot READ the 'directionMode' parameter value unless
        % it is first made visible (e.g. in set_param above).
        % After 'directionMode' is visible (below), read it afterward
        % and then adjust the Dimension edit box visibility accordingly.
        % Do this below AFTER all of the other visibility updates.
    end
    
    if ~isequal(mask_vis_old, mask_vis_new)
        set_param(blkh,'MaskVisibilities',mask_vis_new);
    end
    
    % We could not READ the 'directionMode' parameter value above
    % unless it was first made visible (e.g. possibly after set_param).
    % Instead, read 'directionMode' value here and adjust the controlled
    % 'dimension' edit box parameter visibility accordingly:
    blockMaskObj = Simulink.Mask.get(blkh);
    dimMaskParam = blockMaskObj.getParameter('dimension');
    if ~isRunning && strcmp(get_param(blkh,'directionMode'),'Specified dimension')
        dimMaskParam.Visible = 'on';
    else
        dimMaskParam.Visible = 'off';
    end
    
    varargout = {};
    
end % 'icon' or 'dynamic'
