function varargout = dspblkVariance(blkh, actionStr)
% dspblkVariance DSP System Toolbox Variance block helper function.

% Copyright 1995-2017 The MathWorks, Inc.

isRunning = strcmp(get_param(blkh,'run'), 'on');

if (nargin > 1) && strcmp(actionStr, 'icon')
    if isRunning && ~strcmp(get_param(blkh,'reset_popup'), 'None')
        % Two input ports
        s.i1 = 1; s.i1s = 'In';
        s.i2 = 2; s.i2s = 'Rst';
    else
        % One input port (do not label)
        s.i1 = 1; s.i1s = '';
        s.i2 = 1; s.i2s = '';
    end
    % Output port (no label)
    s.o1 = 1; s.o1s = '';
    % Return port structure and icon text
    if isRunning
        varargout = {s, 'Running\nVAR'};
    else
        varargout = {s, 'VAR'};
    end
else
    % Dynamic dialog: Mask Parameter visibilities
    mask_vis_old = get_param(blkh,'MaskVisibilities');
    mask_vis_new = mask_vis_old;
    
    % MAIN tab params
    [inpProcDDIdx, rstDDIdx, dirModeDDIdx, dimEBIdx] = ...
        dspblkGetMaskParamIndicesFromParamNames(blkh, ...
        'InputProcessing', 'reset_popup', 'directionMode', 'dimension');

    if isRunning
        mask_vis_new{inpProcDDIdx} = 'on';
        mask_vis_new{rstDDIdx}     = 'on';
        mask_vis_new{dirModeDDIdx} = 'off';
        mask_vis_new{dimEBIdx}     = 'off';
    else
        mask_vis_new{inpProcDDIdx} = 'off';
        mask_vis_new{rstDDIdx}     = 'off';
        mask_vis_new{dirModeDDIdx} = 'on';
        % We cannot READ the 'directionMode' parameter value unless
        % it is first made visible (e.g. in set_param above).
        % After 'directionMode' is visible (below), read it afterward
        % and then adjust the Dimension edit box visibility accordingly.
        % Do this below AFTER all of the other visibility updates.
    end
    
    % DATA TYPES tab params
    dtParams = {'prodOutputMode', 'memoryMode', 'accumMode', 'outputMode'};
    for idx = 1:length(dtParams)
        dtMdPrm = dtParams{idx}; % dtMode parameter
        dtMdIdx = dspblkGetMaskParamIndicesFromParamNames(blkh, dtMdPrm);
        if strcmp(get_param(blkh, dtMdPrm), 'Binary point scaling')
            mask_vis_new{dtMdIdx+1} = 'on';  % dtWordLength
            mask_vis_new{dtMdIdx+2} = 'on';  % dtFracLength
        else
            mask_vis_new{dtMdIdx+1} = 'off'; % dtWordLength
            mask_vis_new{dtMdIdx+2} = 'off'; % dtFracLength
        end
    end
    
    if ~isequal(mask_vis_old, mask_vis_new)
        set_param(blkh, 'MaskVisibilities', mask_vis_new);
    end
    
    % We could not READ the 'directionMode' parameter value above
    % unless it was first made visible (e.g. possibly after set_param).
    % Instead, read 'directionMode' value here and adjust the controlled
    % 'dimension' edit box parameter visibility accordingly:
    blockMaskObj = Simulink.Mask.get(blkh);
    dimMaskParam = blockMaskObj.getParameter('dimension');
    if ~isRunning && strcmp(get_param(blkh,'directionMode'),'Specified dimension')
        dimMaskParam.Visible = 'on';
    else
        dimMaskParam.Visible = 'off';
    end
    
    varargout = {};
    
end % 'icon' or 'dynamic'
