function dspblkfft(blkh)
%DSPBLKFFT Block dynamic dialog UI helper function
%   Used by the DSP System Toolbox FFT and IFFT library blocks

% Copyright 2015 The MathWorks, Inc.

fftMaskObj = Simulink.Mask.get(blkh);

% Property dialog UI controls
maskFixPtOpPrmsGrp  = fftMaskObj.getDialogControl('FixPtOpParamsGroupBox');
maskFixPtTextLabel  = fftMaskObj.getDialogControl('FixPtBlurbTextLabel');
maskTypesTablePanel = fftMaskObj.getDialogControl('TypesTablePanel');
maskFixPtNotSpptLbl = fftMaskObj.getDialogControl('FFTWFixPtNotSupportedLabel');

if strcmp(get_param(blkh,'FFTImplementation'), 'FFTW')
    % Hide the 'Output in bit-reversed order' checkbox
    % Hide all the Data Types tab params and other UI
    % Show the explanatory Data Types tab text string
    maskFixPtOpPrmsGrp.Visible  = 'off';
    maskFixPtTextLabel.Visible  = 'off';
    maskTypesTablePanel.Visible = 'off';
    maskFixPtNotSpptLbl.Visible = 'on';
    lockScaleParamVis           = 'off'; % mask parameter (not property)
    bitRevOrdParamVis           = 'off'; % mask parameter (not property)
else
    maskFixPtOpPrmsGrp.Visible  = 'on';
    maskFixPtTextLabel.Visible  = 'on';
    maskTypesTablePanel.Visible = 'on';
    maskFixPtNotSpptLbl.Visible = 'off';
    lockScaleParamVis           = 'on'; % mask parameter (not property)
    bitRevOrdParamVis           = 'on'; % mask parameter (not property)
end

if strcmp(get_param(blkh,'InheritFFTLength'), 'on')
    fftLengthParamVis = 'off'; % mask parameter
    wrapInputParamVis = 'off'; % mask parameter
else
    fftLengthParamVis = 'on'; % mask parameter
    wrapInputParamVis = 'on'; % mask parameter
end

% Update mask parameter visibilities if necessary
maskPrmNames = get_param(blkh,'MaskNames');
mask_vis_old = get_param(blkh,'MaskVisibilities');
mask_vis_new = mask_vis_old;
mask_vis_new{strcmp(maskPrmNames,'BitRevOrder')} = bitRevOrdParamVis;
mask_vis_new{strcmp(maskPrmNames,'LockScale')}   = lockScaleParamVis;
mask_vis_new{strcmp(maskPrmNames,'FFTLength')}   = fftLengthParamVis;
mask_vis_new{strcmp(maskPrmNames,'WrapInput')}   = wrapInputParamVis;
if ~isequal(mask_vis_old,mask_vis_new)
    set_param(blkh, 'MaskVisibilities', mask_vis_new);
end

end % dspblkfft
