function varargout = dspblkfirdn2(blkh, action, FilterSource, varargin)
% DSPBLKFIRDN Mask dynamic dialog function for FIR decimation block

% Copyright 1995-2021 The MathWorks, Inc.

switch action
    case 'icon'
        s.in = ''; s.out = '';
        s.i1 = 1; s.s1 = '';
        if FilterSource == 1 || FilterSource == 4
            % Coefficients from 'Dialog parameters' or 'Auto'
            D = varargin{1};
            if isempty(D)  || ~isnumeric(D) || ~isscalar(D) || isfi(D)
                s.str = 'x[?]';  % Default display
            else
                s.str=['x[' num2str(D) 'n]'];
            end
        elseif FilterSource == 2
            % Coefficients from input port
            L = varargin{1};
            if isempty(L)  || ~isnumeric(L) || ~isscalar(L) || isfi(L)
                s.str = 'x[?]';  % Default display
            else
                s.str= ['x[' num2str(L) 'n]'];
            end
            s.in='In'; s.out='Out';
            s.i1=2; s.s1='Num';
        else
            % Coefficients from filter object
            hd = varargin{1};
            if (isempty(hd) || ~isFilterValid(hd))
                s.str = 'x[?]';  % Default display
            else
                s.str=['x[' num2str(hd.DecimationFactor) 'n]'];
            end
            s.str = [s.str '\nFilter:\n' get_param(blkh,'FilterObject')];
        end
        varargout{1} = s;
        
    case 'init'
        % NO-OP as of R2019a
        
    case 'setup'
        filterDefined = false; % default
        h  = [];
        D  = [];
        outBufIC = 0;
        filtStruct = 1; % Direct form
        block = get_param(blkh,'Object');
        if FilterSource == 1 || FilterSource == 4
            % Coefficients from 'Dialog parameters' or 'Auto'
            dtRows     = varargin{1};
            D          = varargin{3};
            filtStruct = varargin{4};
            outBufIC   = varargin{5};
            framingIn  = varargin{6};
            inpProc    = varargin{7};
            if ~strcmp(block.framing, 'Allow multirate processing')
                AllowArbitraryInputLength = varargin{8};
            end
            if isfield(block.UserData,'filter')
                block.UserData = rmfield(block.UserData,'filter');
            end
            
            if FilterSource == 1
                % Coefficient source: 'Dialog parameters'
                h = varargin{2};
            else
                % Coefficient source: 'Auto'
                if isempty(D) || ~isnumeric(D)
                    h = [];
                else
                    validateattributes(D, {'numeric',}, ...
                        {'positive', 'real', 'scalar', 'finite', 'nonnan'}, ...
                        '', 'Decimation factor');
                    h = designMultirateFIR(1, double(D));
                end
            end
            
            dtInfo = dspGetUDTFixptDataTypeInfo(blkh, dtRows, true);
            dtInfo.arithmetic = 0; % Default: double-precision arithmetic
            dtInfo.inputWordLength = 16;
            dtInfo.inputFracLength = 15;
            
            if filtStruct == 1
                block.UserData.filterConstructor = 'mfilt.firdecim';
            else
                block.UserData.filterConstructor = 'mfilt.firtdecim';
            end
            block.UserData.filterConstructorArgs = {D,h};
            
            if ~(isempty(h) || isempty(D))
                % Don't attempt any calculations in the mask helper on these
                % parameters if any of them is currently empty or not defined.
                
                filterDefined = true;
                % Do more checking before using h,D parameters
                if ~isnumeric(h) || isfi(h)
                    error(message('dsp:dspblkfirdn2:paramDTypeError1'));
                end
                if ~isnumeric(D) || isfi(D)
                    error(message('dsp:dspblkfirdn2:paramDTypeError2'));
                end
                if ~isvector(h)
                    error(message('dsp:dspblkfirdn2:invalidCoefficient'));
                end
                if ~isreal(D) || ~ isscalar(D) || (D < 1) || (fix(D) ~= D)
                    error(message('dsp:dspblkfirdn2:paramRealScalarError'));
                end
            end
            
        elseif FilterSource == 2
            % Input arguments for setup case when coeffs from input port:
            dtRows     = varargin{1};
            D          = varargin{2};
            filtStruct = varargin{3};
            outBufIC   = varargin{4};
            framingIn  = varargin{5};
            inpProc    = varargin{6};
            if ~strcmp(block.framing, 'Allow multirate processing')
                AllowArbitraryInputLength = varargin{7};
            end
            if isfield(block.UserData,'filter')
                block.UserData = rmfield(block.UserData,'filter');
            end
            
            %dtInfo = dspGetFixptDataTypeInfo(blkh,47);
            dtInfo = dspGetUDTFixptDataTypeInfo(blkh, dtRows, true);
            dtInfo.arithmetic = 0; % Default: double-precision arithmetic
            dtInfo.inputWordLength = 16;
            dtInfo.inputFracLength = 15;
            
            if isempty(D)
                % Don't attempt any calculations in the mask helper on these
                % parameters if any of them is currently empty or not defined.
                args.CoeffSource = FilterSource;   
                args.h = h;
                args.D = D;
                args.filtStruct = filtStruct;
                args.outBufIC = outBufIC;
                
                framing   = dspblkAdjustMultiRateFraming(inpProc, framingIn);
                varargout = {args,dtInfo,framing};
                return;
            end
            filterDefined = true;
            if filtStruct == 1
                block.UserData.filterConstructor = 'mfilt.firdecim';
            else
                block.UserData.filterConstructor = 'mfilt.firtdecim';
            end
            block.UserData.filterConstructorArgs = {D};
            % Do more checking before using h,D parameters
            if ~isnumeric(D) || isfi(D)
                error(message('dsp:dspblkfirdn2:paramDTypeError2'));
            end
            if ~isreal(D) || ~ isscalar(D) || (D < 1) || (fix(D) ~= D)
                error(message('dsp:dspblkfirdn2:paramRealScalarError'));
            end
            
            % Close FVTool plot window, if open
            dspLinkFVTool2Mask(blkh,'close');
            
        else
            % Coefficients from filter object
            hd        = varargin{1};
            framingIn = varargin{2};
            inpProc   = varargin{3};
            if ~strcmp(block.framing, 'Allow multirate processing')
                AllowArbitraryInputLength = varargin{4};
            end
            if isfield(block.UserData,'filterConstructor')
                block.UserData = rmfield(block.UserData,'filterConstructor');
                block.UserData = rmfield(block.UserData,'filterConstructorArgs');
            end
            block.UserData.filter = [];
            
            if ~isempty(hd)
                if isFilterValid(hd)
                    if ~isa(hd,'dsp.FIRDecimator')
                        FilterSource = 5; 
                        block.UserData.filter = hd;
                        hdx = reffilter(hd); % Get the reference coeffs, not the quantized ones
                        if isa(hd,'mfilt.firdecim')
                            filtStruct = 1; % Direct form
                        else
                            filtStruct = 2; % Direct form transposed
                        end
                    else
                        if ~any(strcmpi({'Property','Auto'},hd.NumeratorSource))
                            error(message('dsp:dspblkfirdn2:unsupportedCoeffsFromPort'));
                        end
                        hd_clone =  clone(hd);
                        release(hd_clone);
                        block.UserData.filter = hd_clone;
                        hdx = hd_clone;
                        if strcmp(hd.Structure,'Direct form')
                            filtStruct = 1; % Direct form
                        else
                            filtStruct = 2; % Direct form transposed
                        end
                    end
                    h = hdx.Numerator;
                    D = hdx.DecimationFactor;
                    filterDefined = true;
                else
                    error(message('dsp:dspblkfirdn2:invalidFilterObject1'));
                end
            end
            dtInfo = getFixptDataTypeInfoFromFilterObject(hd);
        end
        
        if filterDefined
            % Update FVTool plot window, if open
            if dspIsFVToolOpen(blkh)
                dspLinkFVTool2Mask(blkh,'update');
            end
            
            if (filtStruct == 1)
                % Direct form
                % Need to reshuffle the coefficients into phase order
                len = length(h);
                h = flipud(h(:));
                if (rem(len, D) ~= 0)
                    nzeros = D - rem(len, D);
                    h = [zeros(nzeros,1); h];
                end
                len = length(h);
                nrows = len / D;
                % Re-arrange the coefficients
                h = flipud(reshape(h, D, nrows).');
            else
                % Transposed direct form
                % Need to reshuffle the coefficients into phase order
                len = length(h);
                if (rem(len, D) ~= 0)
                    nzeros = D - rem(len, D);
                    h = [h zeros(1,nzeros)];
                end
                len = length(h);
                nrows = len / D;
                % Re-arrange the coefficients
                h = reshape(h, D, nrows).';
            end
        else
            % Close FVTool plot window, if open
            dspLinkFVTool2Mask(blkh,'close');
        end
        
        % Gather up outputs
        args.CoeffSource = FilterSource;
        args.h = h;
        args.D = D;
        args.filtStruct = filtStruct;
        args.outBufIC = outBufIC;
        if ~strcmp(block.framing, 'Allow multirate processing')
            args.AllowArbitraryInputLength = AllowArbitraryInputLength;
        else
            args.AllowArbitraryInputLength = double(false);
        end
        framing   = dspblkAdjustMultiRateFraming(inpProc, framingIn);
        varargout = {args, dtInfo, framing};

    otherwise
        % Dynamic dialog (visible/enable) control
        dspmltiFIRDynamicDialogUpdate(blkh);
        varargout = {};
end

%------------------------------------------------------------------------------
function filterValid = isFilterValid(hd)

switch class(hd)
    case {'mfilt.firdecim', ...
            'mfilt.firtdecim','dsp.FIRDecimator'}
        filterValid = 1;
    otherwise
        filterValid = 0;
end

%------------------------------------------------------------------------------
function dtInfo = getFixptDataTypeInfoFromFilterObject(hd)

if isa(hd,'dsp.FIRDecimator')
   dtInfo = getFIRRateConversionFixptInfoFromSysObj(hd); 
else
   dtInfo = getFixptDataTypeInfoFromMFILT(hd);   
end
       
%--------------------------------------------------------------------------
function dtInfo = getFixptDataTypeInfoFromMFILT(hd)
  
% Initialize all to defaults
  dtInfo = initializeFIRRateConversionFixedPointDefaults();

  if ~isempty(hd) && isfdtbxinstalled
      switch hd.Arithmetic
        case 'double'
          dtInfo.arithmetic = 0;
        case 'single'
          dtInfo.arithmetic = 1;
        case 'fixed'
          dtInfo.arithmetic = 2;

          if strcmpi(hd.OverflowMode, 'wrap')
              dtInfo.overflowMode = 1;
          else
              dtInfo.overflowMode = 2;
          end

          if strcmpi(hd.RoundMode, 'ceil')
              dtInfo.roundingMode = 1;
          elseif strcmpi(hd.RoundMode, 'convergent')
              dtInfo.roundingMode = 2;
          elseif strcmpi(hd.RoundMode, 'floor')
                dtInfo.roundingMode = 3;
          elseif strcmpi(hd.RoundMode, 'nearest')
              dtInfo.roundingMode = 4;
          elseif strcmpi(hd.RoundMode, 'round')
              dtInfo.roundingMode = 5;  
          elseif strcmpi(hd.RoundMode, 'fix')
              dtInfo.roundingMode = 7;    %zero
          end

          if ~hd.Signed
               error(message('dsp:dspblkfirdn2:invalidFilterObject2'));
          end

          if isprop(hd,'CastBeforeSum') && ~hd.CastBeforeSum
               warning(message('dsp:dspblkfirdn2:invalidFilterObject3'));
          end

          dtInfo.inputWordLength  = hd.InputWordLength;
          dtInfo.inputFracLength  = hd.InputFracLength;

          dtInfo.firstCoeffMode = 0; % Binary point scaling
          dtInfo.firstCoeffWordLength = hd.CoeffWordLength;
          dtInfo.firstCoeffFracLength = hd.NumFracLength;

          dtInfo.prodOutputMode = 0; % Binary point scaling
          dtInfo.prodOutputWordLength = hd.ProductWordLength;
          dtInfo.prodOutputFracLength = hd.ProductFracLength;

          dtInfo.accumMode = 0; % Binary point scaling
          dtInfo.accumWordLength = hd.AccumWordLength;
          dtInfo.accumFracLength = hd.AccumFracLength;

          dtInfo.outputMode = 0; % Binary point scaling
          dtInfo.outputWordLength = hd.OutputWordLength;
          dtInfo.outputFracLength = hd.OutputFracLength;

        otherwise
           error(message('dsp:dspblkfirdn2:invalidFilterObject4', hd.arithmetic));
      end
  end
