function dspblkmagfft2(action)
% DSPBLKMAGFFT2 Mask dynamic dialog function for
% Magnitude FFT power spectrum estimation block

% Copyright 1995-2015 The MathWorks, Inc.

blk = gcb;
if nargin<1, action='dynamic'; end

switch action
case 'dynamic'
    % Execute dynamic dialogs

    % Cache original dialog mask enables
    ena_orig = get_param(blk,'maskenables');
    vis_orig = get_param(blk,'maskvisibilities');
    vis_new  = vis_orig;
    
    % Determine if FFT length edit box is visible
    iFFTedit = 4; iFFTWrap = 5;
    if strcmp(get_param(blk,'fftLenInherit'), 'off')
        vis_new{iFFTedit} = 'on';
        vis_new{iFFTWrap} = 'on';
    else
        vis_new{iFFTedit} = 'off';
        vis_new{iFFTWrap} = 'off';
    end

    % Set visibilities if a change was made; keep enables in sync
    if ~isequal(vis_new,vis_orig),
        set_param(blk,'maskvisibilities',vis_new);
    end
    if ~isequal(vis_new,ena_orig)
        set_param(blk,'maskenables',vis_new);
    end

case 'update'
    sqname   = ['Magnitude' char(10) 'Squared'];
    sqrtname = 'Magnitude';
    fullblk  = getfullname(blk);
    if strcmp(get_param(blk,'mag_or_magsq'), 'Magnitude squared')
      if exist_block(blk,sqrtname)
        delete_line(fullblk,'FFT/1',[sqrtname '/1'])
        delete_line(fullblk,[sqrtname '/1'], 'Out/1')
        pos = get_param([blk '/Magnitude'],'position');
        delete_block([blk '/Magnitude'])
        add_block('built-in/Math',[blk '/Magnitude Squared' char(10) ...
                    'Squared'],'position',pos, 'name', sqname,'function','magnitude^2')
        add_line(fullblk,'FFT/1',[sqname '/1'])
        add_line(fullblk,[sqname '/1'], 'Out/1')
      end
    else
      if exist_block(blk,sqname)
        delete_line(fullblk,'FFT/1',[sqname '/1'])
        delete_line(fullblk,[sqname '/1'], 'Out/1')
        pos = get_param([blk '/Magnitude Squared'],'position');
        delete_block([blk '/Magnitude Squared'])
        add_block('built-in/Abs',[blk '/Magnitude'],'position',pos,'name',sqrtname)
        add_line(fullblk,'FFT/1',[sqrtname '/1'])
        add_line(fullblk,[sqrtname '/1'], 'Out/1')
      end
    end

end

% [EOF] dspblkmagfft2.m
