function dspblknswit(action,varargin)
% DSPBLKNSWIT DSP System Toolbox N-Sample Switch block helper function.

% Copyright 1995-2020 The MathWorks, Inc.

if nargin==0 
    action = 'dynamic'; 
end

blk     = gcbh;
fullblk = getfullname(blk);
reset   = strcmp(get_param(blk,'Reset'),'on');

switch action
case 'update'   
   enable_blk = [fullblk '/N-Sample Enable'];
   port_blk = [fullblk '/Rst'];
   
   % Check if 3rd inport block is present:
   port_present = ~isempty(find_system(blk,'searchdepth',1,...
      'followlinks','on','lookundermasks','on','name','Rst'));
   
   if reset,
      % Set the N-Sample Enable block to have reset port and trigger type:
      TriggerType = get_param(blk,'TriggerType');
      set_param(enable_blk,'reset','on', ...
                       'TriggerType',TriggerType);
      
      % Add a 3rd inport:
      if ~port_present,
         add_block('built-in/Inport',port_blk);
         set_param(port_blk,'Position',[20 85 40 105]);
         add_line(fullblk,'Rst/1','N-Sample Enable/1');
      end
      
   else
      if port_present,
         % Remove 3rd inport block:
         delete_line(fullblk,'Rst/1','N-Sample Enable/1');
         delete_block(port_blk);
      end
      set_param(enable_blk,'reset','off');
   end
   
case 'dynamic'
   % Dynamic dialog callback:
   
   mask_enables = get_param(blk,'maskenables');
   if reset,
      mask_enables{3} = 'on';
   else
      mask_enables{3} = 'off';
   end
   set_param(blk,'maskenables',mask_enables);
end

% [EOF] dspblknswit.m


