function str = dspblkpeaks(blkh, action)
% DSPBLKPEAKS Peak Finder block dialog helper function

% Copyright 1995-2020 The MathWorks, Inc.

switch action
    case 'icon'
        outIdx = strcmpi(get_param(blkh,'outputIdx'),'on');
        outVal = strcmpi(get_param(blkh,'outputVal'),'on');
        pol = get_param(blkh,'polarity');
        switch pol
            case 'Maxima'
                str.txt='Maxima';
            case 'Minima'
                str.txt='Minima';
            case 'Maxima and Minima'
                str.txt='Extrema';
        end
        
        if (outIdx == 1) && (outVal == 1)
            % Index and Value
            str.i1 = 2;  str.s1 = 'Idx';
            str.i2 = 3;  str.s2 = 'Val';
            if (pol == 3)
                str.i3 = 4; str.s3='Pol';
            else
                str.i3 = 1;  str.s3 = '';
            end
        elseif (outIdx == 1) && (outVal == 0)
            % Index
            str.i1 = 2;  str.s1 = '';
            str.i2 = 2;  str.s2 = 'Idx';
            if (pol == 3)
                str.i3 = 3; str.s3='Pol';
            else
                str.i3 = 1;  str.s3 = '';
            end
        elseif (outIdx == 0) && (outVal == 1)
            % Value
            str.i1 = 2;  str.s1 = '';
            str.i2 = 2;  str.s2 = 'Val';
            if (pol == 3)
                str.i3 = 3; str.s3='Pol';
            else
                str.i3 = 1;  str.s3 = '';
            end
        else
            % Count only
            str.i1 = 1;  str.s1 = '';
            str.i2 = 1;  str.s2 = '';
            str.i3 = 1;  str.s3 = '';
        end
        
    case 'dynamic'
        % DYNAMIC DIALOG
        % If "Ignore peaks" checkbox is checked, then make the
        % mask parameters 'Threshold' and 'Saturate' visible
        % (any any UI widgets containing those mask params)
        threshParamVisOnOffValue = get_param(blkh,'NoiseDistinguish');
        [thrshMPIdx, ovrflMPIdx] = ...
            dspblkGetMaskParamIndicesFromParamNames( ...
            blkh, 'thresh', 'overflowMode');

        % Apply visibilty setting to Group Box UI containing 'overflowMode'
        % -----------------------------------------------------------------
        blockMaskObject  = Simulink.Mask.get(blkh);
        fixptOpPrmGrpBox = ...
            blockMaskObject.getDialogControl('FixPtOpParamsGroupBox');
        fixptOpPrmGrpBox.Visible = threshParamVisOnOffValue;
        
        % Apply visibilty setting to individual mask parameter UI
        % -----------------------------------------------------------------
        mask_vis_old = get_param(blkh,'MaskVisibilities');
        mask_vis_new = mask_vis_old;
        mask_vis_new{thrshMPIdx} = threshParamVisOnOffValue;
        mask_vis_new{ovrflMPIdx} = threshParamVisOnOffValue;
        if ~isequal(mask_vis_old, mask_vis_new)
            set_param(blkh,'MaskVisibilities',mask_vis_new);
        end
end
