function varargout = dspblkrepeat2(blkh,action,varargin)
% DSPBLKREPEAT2 DSP System Toolbox Repeat block helper function.

% Copyright 1995-2020 The MathWorks, Inc.

switch action
    case 'icon'
        % Determine string to display in icon
        % This represents the  repetition count parameter
        % literal repeat count string (exactly what user entered)
        litRepeatCt  = varargin{1};
        % evaluated repeat count (could be empty if problem occurred)
        evalRepeatCt = varargin{2};

        if isempty(evalRepeatCt)
            % Problem probably occurred
            fctstr = litRepeatCt;
        else
            % have an evaluated expression
            if ~isnumeric(evalRepeatCt) || numel(evalRepeatCt)~=1
                fctstr = '?';
            else
                fctstr = num2str(evalRepeatCt);
            end
        end
        
        fctstr=['Repeat\n' fctstr 'x'];
        varargout = {fctstr};
        
    case 'init'
        modeArg = varargin{1};
        switch modeArg
            case 2
                set_param(blkh,'RateOptions', 'Allow multirate processing');
                set_param(blkh,'mode', 'Unused parameter value');
            case 3
                set_param(blkh,'RateOptions', 'Enforce single-rate processing');
                set_param(blkh,'mode', 'Unused parameter value');
        end
        
    case 'dynamic'
        [RateOptionsArg, ICArg] = deal(3,4);
        blk = gcbh;
        maskVisOld = get_param(blk, 'MaskVisibilities');
        maskVisNew = maskVisOld;
        maskEnOld  = get_param(blk, 'MaskEnables');
        maskEnNew  = maskEnOld;
        
        [maskEnNew{RateOptionsArg}, maskVisNew{RateOptionsArg}] = deal('on');
            [maskEnNew{ICArg}, maskVisNew{ICArg}] = deal('on');
        
        if strcmpi(get_param(blk,'InputProcessing'), 'Elements as channels (sample based)')
            [maskEnNew{RateOptionsArg}, maskVisNew{RateOptionsArg}] = deal('off','on');
            set_param(blk,'RateOptions','Allow multirate processing');
        else
            % FB processing or Inherit
            if (strcmpi(get_param(blk,'InputProcessing'), 'Columns as channels (frame based)') && ...
                strcmpi(get_param(blk,'RateOptions'), 'Enforce single-rate processing'))
                [maskEnNew{ICArg}, maskVisNew{ICArg}] = deal('off');
            end
        end
        
        if ( ~isequal(maskVisNew, maskVisOld) || ~isequal(maskEnNew, maskEnOld) )
            set_param(blk, 'MaskVisibilities', maskVisNew, 'MaskEnables', maskEnNew);
        end
end
