function dspblkspectrumestimator(blk, action, varargin)
% DSPBLKSSPECTRUMESTIMATOR DSP System Toolbox Spectrum Estimator block
% mask helper function

%   Copyright 2015-2022 The MathWorks, Inc.

% This function modifies settings of blocks in the subsystem. This
% should not dirty the model:
model = bdroot(blk);
dirtyFlag = get_param(model,'Dirty');
c = onCleanup(@()set_param(model,'Dirty',dirtyFlag));

SpectrumBlkName = [blk '/Spectrum Estimator'];

maskNames = get_param(blk,'MaskNames');
maskValues = get_param(blk,'MaskValues');

switch action
    
    case 'dynamic' % Update dialog visibilities
        
        visibilities = get_param(blk,'MaskVisibilities');
        original_visibilities = visibilities;
        
        method = getMaskValue(maskNames,maskValues,'Method');
        
        % Checking the InheritSampleRate box has an effect on the
        % SampleRate edit box only in Window mode. In RBW mode, the sample
        % rate edit box is always visible
        InheritFs = getMaskValue(maskNames,maskValues,'InheritSampleRate');
        isInheritFs  = strcmp(InheritFs,'on');
        freqRes    = getMaskValue(maskNames,maskValues,'FrequencyResolutionMethod');
        
        % Change widget visibilities based on frequency resolution method
        % (window or RBW)
        RBWIndex                  = find(ismember(maskNames,'RBW'));
        WindowIndex               = find(ismember(maskNames,'Window'));
        WindowModeIndex           = find(ismember(maskNames,'WindowMode'));
        WindowLengthIndex         = find(ismember(maskNames,'WindowLength'));
        FFTLengthIndex            = find(ismember(maskNames,'FFTLength'));
        FFTLengthSourceIndex      = find(ismember(maskNames,'FFTLengthSource'));
        InheritSampleRateIndex    = find(ismember(maskNames,'InheritSampleRate'));
        SampleRateIndex           = find(ismember(maskNames,'SampleRate'));
        FreqResIndex              = find(ismember(maskNames,'FrequencyResolutionMethod'));
        BankFreqResIndex          = find(ismember(maskNames,'FilterBankResolutionMethod'));
        OverlapIndex              = find(ismember(maskNames,'Overlap'));
        NumTapsPerBandIndex       = find(ismember(maskNames,'NumTapsPerBand'));
        SidelobeIndex             = find(ismember(maskNames,'SidelobeAttenuation'));
        FrequencyBandsSourceIndex = find(ismember(maskNames,'FrequencyBandsSource'));
        FrequencyBandsIndex       = find(ismember(maskNames,'FrequencyBands'));
        if strcmp(method,'Welch')
            visibilities{FreqResIndex}                = 'on';
            visibilities{WindowIndex}                 = 'on';
            visibilities{OverlapIndex}                = 'on';
            visibilities{NumTapsPerBandIndex}         = 'off';
            visibilities{BankFreqResIndex}            = 'off';
            visibilities{FrequencyBandsSourceIndex}   = 'off';
            visibilities{FrequencyBandsIndex}         = 'off';
            switch freqRes
                case 'Auto'
                    visibilities{RBWIndex}               = 'off';
                    visibilities{WindowModeIndex}        = 'off';
                    visibilities{WindowLengthIndex}      = 'off';
                    visibilities{FFTLengthIndex}         = 'off';
                    visibilities{FFTLengthSourceIndex}   = 'off';
                    visibilities{InheritSampleRateIndex} = 'off';
                    visibilities{SampleRateIndex}        = 'on';
                case 'RBW'
                    visibilities{RBWIndex}               = 'on';
                    visibilities{WindowModeIndex}        = 'off';
                    visibilities{WindowLengthIndex}      = 'off';
                    visibilities{FFTLengthIndex}         = 'off';
                    visibilities{FFTLengthSourceIndex}   = 'off';
                    visibilities{InheritSampleRateIndex} = 'off';
                    visibilities{SampleRateIndex}        = 'on';
                case 'Window length'
                    visibilities{RBWIndex}        = 'off';
                    visibilities{WindowModeIndex} = 'on';
                    windowMode = getMaskValue(maskNames,maskValues,'WindowMode');
                    isWindowLengthSameAsInput = strcmp(windowMode,'Same as input frame length');
                    if isWindowLengthSameAsInput
                        visibilities{WindowLengthIndex} = 'off';
                    else
                        visibilities{WindowLengthIndex} = 'on';
                    end
                    visibilities{FFTLengthSourceIndex} = 'on';
                    FFTSource = getMaskValue(maskNames,maskValues,'FFTLengthSource');
                    if strcmp(FFTSource,'Auto')
                        visibilities{FFTLengthIndex}   = 'off';
                    else
                        visibilities{FFTLengthIndex}   = 'on';
                    end
                    visibilities{InheritSampleRateIndex} = 'on';
                    
                    if isInheritFs
                        visibilities{SampleRateIndex} = 'off';
                    else
                        visibilities{SampleRateIndex} = 'on';
                    end
                    index = find(ismember(maskNames,'WindowLength'));
                    if isWindowLengthSameAsInput
                        visibilities{index} = 'off';
                    else
                        visibilities{index} = 'on';
                    end
            end
            window = getMaskValue(maskNames,maskValues,'Window');
            if strcmp(window,'Kaiser') || strcmp(window,'Chebyshev')
                visibilities{SidelobeIndex}          = 'on';
            else
                visibilities{SidelobeIndex}          = 'off';
            end
        else
            % These parameters do not apply for the filter bank method
            visibilities{FreqResIndex}           = 'off';
            visibilities{WindowIndex}            = 'off';
            visibilities{RBWIndex}               = 'off';
            visibilities{WindowModeIndex}        = 'off';
            visibilities{WindowLengthIndex}      = 'off';
            visibilities{OverlapIndex}           = 'off';
            visibilities{SidelobeIndex}          = 'off';
            visibilities{FFTLengthSourceIndex}   = 'off';
            visibilities{FFTLengthIndex}         = 'off';
            visibilities{NumTapsPerBandIndex}    = 'on';
            visibilities{BankFreqResIndex}       = 'on';

            bankRes    = getMaskValue(maskNames,maskValues,'FilterBankResolutionMethod');
            switch bankRes
                case {'Auto','RBW'}
                    visibilities{InheritSampleRateIndex}         = 'off';
                    visibilities{SampleRateIndex}                = 'on';
                    visibilities{FrequencyBandsSourceIndex}   = 'off';
                    visibilities{FrequencyBandsIndex}         = 'off';
                    if strcmp(bankRes,'RBW')
                        visibilities{RBWIndex}                       = 'on';
                    else
                        visibilities{RBWIndex}                       = 'off';
                    end
                case 'Number of frequency bands'
                    visibilities{RBWIndex}                       = 'off';
                    visibilities{FrequencyBandsSourceIndex}      = 'on';
                    NumBandsSource = getMaskValue(maskNames,maskValues,'FrequencyBandsSource');
                    if strcmp(NumBandsSource,'Same as input frame size')
                        visibilities{FrequencyBandsIndex}   = 'off';
                    else
                        visibilities{FrequencyBandsIndex}   = 'on';
                    end
                    visibilities{InheritSampleRateIndex} = 'on';
                    if isInheritFs
                        visibilities{SampleRateIndex} = 'off';
                    else
                        visibilities{SampleRateIndex} = 'on';
                    end
            end
        end
        
        % Change SpectralAverages and ForgettingFactor visibilities based on
        % Average
        average = getMaskValue(maskNames,maskValues,'AveragingMethod');
        forgettingFactorPort = getMaskValue(maskNames, maskValues, 'ForgettingFactorPort');
        SpectralAveragesIndex = find(ismember(maskNames,'SpectralAverages'));
        ForgettingFactorIndex = find(ismember(maskNames,'ForgettingFactor'));
        ForgettingFactorPortIndex = find(ismember(maskNames,'ForgettingFactorPort'));
        
        if strcmp(average, 'Running')
           visibilities{SpectralAveragesIndex} = 'on';
           visibilities{ForgettingFactorIndex} = 'off';
           visibilities{ForgettingFactorPortIndex} = 'off';
        elseif strcmp(average, 'Exponential') && strcmpi(forgettingFactorPort, 'on')
           visibilities{SpectralAveragesIndex} = 'off';
           visibilities{ForgettingFactorIndex} = 'off';
           visibilities{ForgettingFactorPortIndex} = 'on';
        else
            visibilities{SpectralAveragesIndex} = 'off';
            visibilities{ForgettingFactorIndex} = 'on';
            visibilities{ForgettingFactorPortIndex} = 'on';
        end
        
        if ~isequal(original_visibilities,visibilities)
            set_param(blk,'MaskVisibilities',visibilities),
        end
        
    case 'init' % Called by the mask initialization callback
        
        % Validate values on mask
        validateParameters(blk , maskNames , false);
        
        method = getMaskValue(maskNames,maskValues,'Method');
        set_param(SpectrumBlkName,'Method',method);
        spectrumType = getMaskValue(maskNames,maskValues,'SpectrumType');
        set_param(SpectrumBlkName,'SpectrumType',spectrumType);
        powerUnits = getMaskValue(maskNames,maskValues,'PowerUnits');
        set_param(SpectrumBlkName,'PowerUnits',powerUnits);
        simulateUsing = getMaskValue(maskNames,maskValues,'SimulateUsing');
        set_param(SpectrumBlkName,'SimulateUsing',simulateUsing);
        window = getMaskValue(maskNames,maskValues,'Window');
        set_param(SpectrumBlkName,'Window',window);
        
        inheritFs = getMaskValue(maskNames,maskValues,'InheritSampleRate');

        WelchMethod    = getMaskValue(maskNames,maskValues,'FrequencyResolutionMethod');
        BankMethod     = getMaskValue(maskNames,maskValues,'FilterBankResolutionMethod');
        if strcmp(method,'Welch')
            readFs = ~(strcmp(WelchMethod,'Window length') && strcmp(inheritFs,'on'));
        else
            readFs = ~(strcmp(BankMethod,'Number of frequency bands') && strcmp(inheritFs,'on'));
        end
        if readFs
            Fs = getMaskValue(maskNames,maskValues,'SampleRate');
            set_param(SpectrumBlkName,'InheritSampleRate','off');
            set_param(SpectrumBlkName,'SampleRate',Fs);
        else
            set_param(SpectrumBlkName,'InheritSampleRate','on');
        end
        
        averagingMethod = getMaskValue(maskNames,maskValues,'AveragingMethod');
        set_param(SpectrumBlkName,'AveragingMethod',averagingMethod);
                
        freqRange = getMaskValue(maskNames,maskValues,'FrequencyRange');
        switch freqRange
            case 'One-sided'
                set_param(SpectrumBlkName,'FrequencyRange','onesided');
            case 'Two-sided'
                set_param(SpectrumBlkName,'FrequencyRange','twosided');
            case 'Centered'
                set_param(SpectrumBlkName,'FrequencyRange','centered');
        end
        
        simStatus = get_param(model,'SimulationStatus');
        if strcmp(simStatus,'stopped') || strcmp(simStatus,'initializing')
            % Update output ports based on block settings
            % Get the expected indices corresponding to the different
            % ports depending on which outputs are requested
            maxHoldPort = 2;
            numPorts   = 1;
            OutputMaxHoldSpectrum = getMaskValue(maskNames,maskValues,'OutputMaxHoldSpectrum');
            if strcmp(OutputMaxHoldSpectrum,'on')
                minHoldPort = maxHoldPort + 1;
                numPorts = numPorts + 1;
            else
                minHoldPort = maxHoldPort;
            end
            OutputMinHoldSpectrum = getMaskValue(maskNames,maskValues,'OutputMinHoldSpectrum');
            if strcmp(OutputMinHoldSpectrum,'on')
                freqPort = minHoldPort + 1;
                numPorts = numPorts + 1;
            else
                freqPort = minHoldPort;
            end
            OutputFrequencyVector = getMaskValue(maskNames,maskValues,'OutputFrequencyVector');
            if strcmp(OutputFrequencyVector,'on')
                rbwPort = freqPort + 1;
                numPorts = numPorts + 1;
            else
                rbwPort = freqPort;
            end
            
            OutputRBW = getMaskValue(maskNames,maskValues,'OutputRBW');
            if strcmp(OutputRBW,'on')
                numPorts = numPorts + 1;
            end
            % Delete/add inports as required
            pos = getInPortPosition(2);
            processInputPort(blk, 'lambda','ForgettingFactorPort',2,pos);
            connectInputPort(blk,'lambda','ForgettingFactorPort',2);
            set_param([blk '/x'],'Position', pos{1});
            % Delete/add outports as required
            pos = getOutPortPosition(numPorts);
            processOutputPort(blk,'maxHold','OutputMaxHoldSpectrum',maxHoldPort,pos);
            processOutputPort(blk,'minHold','OutputMinHoldSpectrum',minHoldPort,pos);
            processOutputPort(blk,'Freq','OutputFrequencyVector',freqPort,pos);
            processOutputPort(blk,'RBW','OutputRBW',rbwPort,pos);
            set_param([blk '/Pxx'],'Position',pos{1});
            % Reconnect ports
            connectOutputPort(blk,'maxHold','OutputMaxHoldSpectrum',maxHoldPort);
            connectOutputPort(blk,'minHold','OutputMinHoldSpectrum',minHoldPort);
            connectOutputPort(blk,'Freq','OutputFrequencyVector',freqPort);
            connectOutputPort(blk,'RBW','OutputRBW',rbwPort);
        end
        
    case 'setup'  % Called in the block's initFcn callback
        
        % Refresh dialog
        dspblkspectrumestimator(blk, 'dynamic');
        
        % Validate values on mask
        validateParameters(blk , maskNames, true);
        
        method =  getMaskValue(maskNames,maskValues,'Method');
        
        if strcmp(method,'Welch')
            % Setup the buffer parameters and the FFT length
            freqResMethod = getMaskValue(maskNames,maskValues,'FrequencyResolutionMethod');
            
            if ~strcmp(freqResMethod,'Window length') % RBW or Auto
                Fs = slResolve(getMaskValue(maskNames,maskValues,'SampleRate'),blk);
                if strcmp(freqResMethod,'RBW')
                    RBWMode = 'Property';
                else
                    RBWMode = 'Auto';
                end
                
                RBW =  slResolve(getMaskValue(maskNames,maskValues,'RBW'),blk);
                Window = getMaskValue(maskNames,maskValues,'Window');
                SidelobeAttenuation = slResolve(getMaskValue(maskNames,maskValues,'SidelobeAttenuation'),blk);
                
                isonesided = strcmp(getMaskValue(maskNames,maskValues,'FrequencyRange'),'One-sided');
                
                bufferLength = getWindowLength(Fs,RBWMode,RBW,Window,SidelobeAttenuation,isonesided);
                overlapPercent = slResolve(getMaskValue(maskNames,maskValues,'Overlap'),blk);
                overlapLength  = getNumWelchOverlapSamples(bufferLength,overlapPercent);
                
                set_param([blk '/Buffer'],'InheritSize','off'),
                set_param([blk '/Buffer'],'N',num2str(bufferLength)),
                set_param([blk '/Buffer'],'V', num2str(overlapLength)),
                
                % In RBW mode, the FFT length is always internally set to be
                % equal to the window length
                set_param(SpectrumBlkName,'FFTLengthSource','Auto'),
                
            else % Freq Resolution Method = Window length
                
                windowMode = getMaskValue(maskNames,maskValues,'WindowMode');
                if ~strcmp(windowMode,'Same as input frame length')
                    set_param([blk '/Buffer'],'InheritSize','off'),
                    set_param([blk '/Buffer'],'N','WindowLength'),
                    
                    WindowLength = slResolve( getMaskValue(maskNames,maskValues,'WindowLength'),blk);
                    overlapPercent = slResolve(getMaskValue(maskNames,maskValues,'Overlap'),blk);
                    overlapLength = getNumWelchOverlapSamples(WindowLength,overlapPercent);
                    set_param([blk '/Buffer'],'V',num2str(overlapLength)),
                else
                    set_param([blk '/Buffer'],'InheritSize','on'),
                    set_param([blk '/Buffer'],'OverlapPercent','Overlap'),
                end
                
                FFTsource = getMaskValue(maskNames,maskValues,'FFTLengthSource');
                set_param(SpectrumBlkName,'FFTLengthSource',FFTsource),
                if strcmp(FFTsource,'Property')
                    FFTLength = slResolve(get_param(blk,'FFTLength'),blk);
                    set_param(SpectrumBlkName,'FFTLength',num2str(FFTLength)),
                    set_param(SpectrumBlkName,'AdjustFFTLength','off'),
                else % AUTO
                    set_param(SpectrumBlkName,'AdjustFFTLength','on'),
                end
                
            end
            window = getMaskValue(maskNames,maskValues,'Window');
            if strcmp(window,'Kaiser') || strcmp(window,'Chebyshev')
                sidelobeAttenuation = slResolve(get_param(blk,'SidelobeAttenuation'),blk);
                set_param(SpectrumBlkName,'SidelobeAttenuation',num2str(sidelobeAttenuation)),
            end
        else  % Filter Bank Mode
            % Setup the buffer parameters and the FFT length
            freqResMethod = getMaskValue(maskNames,maskValues,'FilterBankResolutionMethod');
            set_param([blk '/Buffer'],'OverlapPercent','0'),
            set_param(SpectrumBlkName,'FFTLengthSource','Auto'),
            if strcmp(freqResMethod,'Number of frequency bands') 
                NumBandsSource = getMaskValue(maskNames,maskValues,'FrequencyBandsSource');
                if strcmp(NumBandsSource,'Specify on dialog')
                    NumBands = slResolve(get_param(blk,'FrequencyBands'),blk);
                    set_param(SpectrumBlkName,'AdjustFFTLength','off'), 
                    set_param([blk '/Buffer'],'InheritSize','off'),
                    set_param([blk '/Buffer'],'N',num2str(NumBands)),
                else
                    set_param(SpectrumBlkName,'AdjustFFTLength','on'),
                    set_param([blk '/Buffer'],'InheritSize','on'),
                end
            else % RBW/Auto
                Fs = slResolve(getMaskValue(maskNames,maskValues,'SampleRate'),blk);
                if strcmp(freqResMethod,'RBW')
                    RBWMode = 'Property';
                else
                    RBWMode = 'Auto';
                end
                RBW =  slResolve(getMaskValue(maskNames,maskValues,'RBW'),blk);
                isonesided = strcmp(getMaskValue(maskNames,maskValues,'FrequencyRange'),'One-sided');
                bufferLength = geFilterBankBufferLength(Fs,RBWMode,RBW,isonesided);
                
                set_param(SpectrumBlkName,'FFTLengthSource','Auto'),
                set_param([blk '/Buffer'],'InheritSize','off'),
                set_param([blk '/Buffer'],'N',num2str(bufferLength)),
                
            end
        end
        average =  getMaskValue(maskNames,maskValues,'AveragingMethod');
        if strcmp(average, 'Running')
           SpectralAverages = slResolve(get_param(blk,'SpectralAverages'),blk);
           set_param(SpectrumBlkName,'SpectralAverages',num2str(SpectralAverages)),
        end
end

% -------------------------------------------------------------------------

function value = getMaskValue(MaskNames,MaskValues,ParameterName)
index  = find(ismember(MaskNames,ParameterName));
value  = MaskValues{index}; %#ok

% -------------------------------------------------------------------------

function value = isParameterVisible(MaskNames,Visibilities,ParameterName)
index  = find(ismember(MaskNames,ParameterName));
value  = strcmp(Visibilities{index},'on'); %#ok

% -------------------------------------------------------------------------

function processOutputPort(blk,outName,paramName,portNumber,position)
% Frequency output port
inPort = find_system(blk,'MatchFilter',@Simulink.match.allVariants, 'LookUnderMasks', 'on', 'FollowLinks', 'on', 'Name', outName); % look only inside active choice of VSS
if strcmp(get_param(blk,paramName),'on')
    if isempty(inPort)
        add_block('built-in/Outport', [blk '/' outName]);
    else
        lineHandles = get_param([blk '/' outName],'LineHandles');
        if lineHandles.Inport ~= -1
            delete_line(lineHandles.Inport);
        end
    end
    set_param([blk '/' outName],'Position',position{portNumber});
else
    if ~isempty(inPort)
        lineHandles = get_param([blk '/' outName],'LineHandles');
        if lineHandles.Inport ~= -1
            delete_line(lineHandles.Inport);
        end
        delete_block([blk '/' outName]);
    end
end

% -------------------------------------------------------------------------

function processInputPort(blk, inputName, paramName, portNumber, position)

% Forgetting factor input port
inPort = find_system(blk,'MatchFilter',@Simulink.match.allVariants, 'LookUnderMasks', 'on', 'FollowLinks', 'on', 'Name', inputName); % look only inside active choice of VSS
if strcmp(get_param(blk,paramName),'on')
    if isempty(inPort)
        add_block('built-in/Inport', [blk '/' inputName]);
    else
        lineHandles = get_param([blk '/' inputName],'LineHandles');
        if lineHandles.Outport ~= -1
            delete_line(lineHandles.Outport);
        end
    end
    set_param([blk '/' inputName],'Position',position{portNumber});
else
    if ~isempty(inPort)
        lineHandles = get_param([blk '/' inputName],'LineHandles');
        if lineHandles.Outport ~= -1
            delete_line(lineHandles.Outport);
        end
        delete_block([blk '/' inputName]);
    end
end

% -------------------------------------------------------------------------

function connectOutputPort(blk,outName,paramName,index)
if  strcmp(get_param(blk,paramName),'on')
    portData  = get_param([blk '/' outName],'PortConnectivity');
    if (portData(1).SrcBlock==-1)
        add_line(blk,['Spectrum Estimator/' num2str(index)],[outName '/1'],'AUTOROUTING','ON');
    end
    set_param([blk '/' outName],'Port',num2str(index))
end

% -------------------------------------------------------------------------

function connectInputPort(blk,inputName,paramName,index)
if  strcmp(get_param(blk,paramName),'on')
    portData  = get_param([blk '/' inputName],'PortConnectivity');
    if (isempty(portData(1).DstBlock))
        add_line(blk,[inputName '/1'],['Spectrum Estimator/' num2str(index)],'AUTOROUTING','ON');
    end
    set_param([blk '/' inputName],'Port',num2str(index))
end

% -------------------------------------------------------------------------

function pos = getOutPortPosition(numPorts)

pos{1} = [];
pos{2} = [];
pos{3} = [];
pos{4} = [];
pos{5} = [];

switch numPorts
    case 1
        pos{1} = [310   162   350   178];
    case 2
        pos{1} = [310    92   350   108];
        pos{2} = [310   232   350   248];
    case 3
        pos{1} = [310    72   350    88];
        pos{2} = [310   162   350   178];
        pos{3} = [310   252   350   268];
    case 4
        pos{1} = [310    57   350    73];
        pos{2} = [310   127   350   143];
        pos{3} = [310   197   350   213];
        pos{4} = [310   267   350   283];
    case 5
        pos{1} = [310    52   350    68];
        pos{2} = [310   107   350   123];
        pos{3} = [310   162   350   178];
        pos{4} = [310   217   350   233];
        pos{5} = [310   272   350   288];
end

% -------------------------------------------------------------------------

function pos = getInPortPosition(numPorts)

pos{1} = [];
pos{2} = [];

switch numPorts
    case 1
        pos{1} = [310   162   350   178];
    case 2
        pos{1} = [10    93   40    107];
        pos{2} = [5     232  45    248];  
end

% -------------------------------------------------------------------------

function validateParameters(blk , MaskNames ,  forceCheck)

visibilities = get_param(blk,'MaskVisibilities');

if isParameterVisible(MaskNames,visibilities,'RBW')
    % Validate RBW
    [rbw,~] = slResolve(get_param(blk,'RBW'),blk);
    if ~isempty(rbw) || forceCheck
        validateattributes(rbw,{'double'}, {'positive','real','scalar','finite','nonnan'},'','RBW');
    end
end

if isParameterVisible(MaskNames,visibilities,'WindowLength')
    % Validate window length
    [L,~] = slResolve(get_param(blk,'WindowLength'),blk);
    if ~isempty(L) || forceCheck
        validateattributes(L,{'double'}, {'positive','real','scalar','finite','nonnan'},'','WindowLength');
    end
end

if isParameterVisible(MaskNames,visibilities,'SidelobeAttenuation')
    [R,~] = slResolve(get_param(blk,'SidelobeAttenuation'),blk);
    if ~isempty(R) || forceCheck
        validateattributes(R,{'double'}, {'positive','real','scalar','>=',45,'finite','nonnan'},'','SidelobeAttenuation');
        
    end
end

if isParameterVisible(MaskNames,visibilities,'Overlap')
    % Validate overlap percent
    [overlap,~] = slResolve(get_param(blk,'Overlap'),blk);
    if ~isempty(overlap)|| forceCheck
        validateattributes(overlap,{'double'}, {'real','scalar','finite','nonnan','>=',0,'<',100},'','Overlap');
    end
end

if isParameterVisible(MaskNames,visibilities,'FFTLength')
    [nfft,~] = slResolve(get_param(blk,'FFTLength'),blk);
    if ~isempty(nfft) || forceCheck
        validateattributes(nfft,{'double'}, {'positive','real','scalar','integer','finite','nonnan'},'','FFTLength');
    end
end

if isParameterVisible(MaskNames,visibilities,'SampleRate')
    % Validate sample rate
    [Fs,~] = slResolve(get_param(blk,'SampleRate'),blk);
    if ~isempty(Fs) || forceCheck
        validateattributes(Fs,{'double'}, {'positive','real','scalar','finite','nonnan'},'','SampleRate');
    end
end

if isParameterVisible(MaskNames,visibilities,'NumTapsPerBand')
   % Validate NumTapsPerBand
   [L,~] = slResolve(get_param(blk,'NumTapsPerBand'),blk);
   if ~isempty(L) || forceCheck
       validateattributes(L,{'double'}, {'positive','real','scalar','integer','finite','nonnan'},'','NumTapsPerBand');
   end
end

if isParameterVisible(MaskNames,visibilities,'FrequencyBands')
   % Validate NumTapsPerBand
   [L,~] = slResolve(get_param(blk,'FrequencyBands'),blk);
   if ~isempty(L) || forceCheck
       validateattributes(L,{'double'}, {'positive','real','scalar','integer','finite','nonnan'},'','FrequencyBands');
   end
end

if isParameterVisible(MaskNames,visibilities,'SpectralAverages')
    % Validate number of averages
    [L,~] = slResolve(get_param(blk,'SpectralAverages'),blk);
    if ~isempty(L) || forceCheck
        validateattributes(L,{'double'}, {'positive','real','scalar','integer','finite','nonnan'},'','SpectralAverages');
    end
end

if isParameterVisible(MaskNames,visibilities,'ForgettingFactor')
    % Validate forgetting factor
    [L,~] = slResolve(get_param(blk,'ForgettingFactor'),blk);
    if ~isempty(L) || forceCheck
        validateattributes(L,{'double'}, {'real','scalar','finite','nonnan','>=',0,'<=',1},'','ForgettingFactor');
    end
end

% Validate reference load
[load,~] = slResolve(get_param(blk,'ReferenceLoad'),blk);
if ~isempty(load)|| forceCheck
    validateattributes(load,{'double'}, {'positive','real','scalar','finite','nonnan'},'','ReferenceLoad');
end

% -------------------------------------------------------------------------

function segLen = geFilterBankBufferLength(SampleRate,RBWSource,RBWValue,isonesided)
% Determine the buffer length based on the desired RBW in Filter Bank mode

% The resolution bandwidth is RBW = Fs/NFFT. Therefore, the required FFT
% length is ceil(Fs/RBW).

if strcmp(RBWSource,'Auto')
    if isonesided
        RBW = (SampleRate/2)/1024;
    else
        RBW = SampleRate/1024;
    end
else
    RBW = RBWValue;
end

segLen = ceil(SampleRate / RBW);

% -------------------------------------------------------------------------

function  segLen = getWindowLength(SampleRate,RBWSource,RBWValue,Window,SidelobeAttenuation,isonesided)
% GETWINDOWLENGTH - determine the length of the buffer based on the desired
% RBW

% Segment length will depend on ENBW (which in turns depends on segment
% length). Thus, an initial ENBW is obtained using a segment length of
% 1000
ENBW = getENBW(Window,SidelobeAttenuation,1000);
if strcmp(RBWSource,'Auto')
    if isonesided
        RBW = (SampleRate/2)/1024;
    else
        RBW = SampleRate/1024;
    end
else
    RBW = RBWValue;
end

% Compute segment length
segLen = ceil(ENBW*SampleRate/RBW);

% Iterate over segment length to minimize
% error between requested RBW and actual RBW:
count = 1;
segLenVect = segLen;
numBins = SampleRate/RBW;
while(count<100) % protect against very long convergence
    % Multiply by 1e4 and devide by 1e4 to avoid rounding issues on AVX vs
    % AVX2 machines
    ENBW = round(getENBW(Window,SidelobeAttenuation,ceil(segLen))*1e8)/1e8;
    new_segLen = ceil(ENBW * numBins);
    err = abs(new_segLen - segLen);
    if (err == 0) % we have converged
        segLen = new_segLen;
        break;
    end
    if ~any(segLenVect == new_segLen)
        segLenVect = [ segLenVect new_segLen]; %#ok
        segLen = new_segLen;
        count = count + 1;
    else
        % We hit a previously computed segment length. The sequence
        % will repeat. Break out and select the segment length that
        % minimizes the error
        L = length(segLenVect);
        computed_RBW = zeros(L,1);
        for ind=1:L
            % Get RBW corresponding to segLenVect(ind)
            computed_RBW(ind) = getENBW(Window,SidelobeAttenuation,segLenVect(ind)) * SampleRate / segLenVect(ind);
        end
        % Select segment length that minimizes absolute error between
        % actual and desired RBW:
        RBWErr = abs(RBW -  computed_RBW);
        [~,ind_min] = min(RBWErr);
        segLen = segLenVect(ind_min);
        break;
    end
end

% -------------------------------------------------------------------------

function [ENBW, winFcn, winParam] = getENBW(Win,SidelobeAttenuation,L)
% Get window parameters based on a segment length L

winParam = [];
switch Win
    case 'Rectangular'
        ENBW = 1;
        winFcn = @rectwin;
    case 'Hann'
        w = hann(L,'periodic');
        ENBW = (sum(w.^2)/sum(w)^2)*L;
        winFcn = @(x) hann(x,'periodic');
    case 'Hamming'
        w = hamming(L,'periodic');
        ENBW = (sum(w.^2)/sum(w)^2)*L;
        winFcn = @(x) hamming(x,'periodic');
    case 'Flat Top'
        w = flattopwin(L,'periodic');
        ENBW = (sum(w.^2)/sum(w)^2)*L;
        winFcn = @(x) flattopwin(x,'periodic');
    case 'Chebyshev'
        SLA = SidelobeAttenuation;
        w = chebwin(L,SLA);
        ENBW = (sum(w.^2)/sum(w)^2)*L;
        winFcn = @chebwin;
        winParam = SLA;
    case 'Kaiser'
        SLA = SidelobeAttenuation;
        if SLA > 50
            winParam = 0.1102*(SLA-8.7);
        elseif SLA < 21
            winParam = 0;
        else
            winParam = (0.5842*(SLA-21)^0.4) + 0.07886*(SLA-21);
        end
        w = kaiser(L,winParam);
        ENBW = (sum(w.^2)/sum(w)^2)*L;
        winFcn = @kaiser;
end
