function [x,y, si,so,disp_str,dtInfo] = dspblksqenc(action)
% DSPBLKSQENC DSP System Toolbox Scalar quantization encoder mask helper function.

% Copyright 1995-2017 The MathWorks, Inc.

if nargin==0, action = 'dynamic'; end

blkh = gcbh;

switch action
case 'icon'
  dtInfo = dspGetFixptDataTypeInfo(blkh,1);
  
  % graphical
  x = [0.11 0.28 0.28 0.48 0.48 0.68 0.68 0.85 NaN];
  y = [0.1 0.1 0.3 0.3 0.5 0.5 0.7 0.7 NaN];
  
  % string
  cbOUTQUstr     = get_param(blkh,'outQU');     % member of ALWAYS_ON_ITEMS
  cbOUTQERRORstr = get_param(blkh,'outQError'); % member of ALWAYS_ON_ITEMS
  if (strcmp(cbOUTQUstr, 'on') || strcmp(cbOUTQERRORstr, 'on'))
      disp_str='  SQ Codec';
  else
      disp_str='SQ Encoder';
  end
  
  % port label
  i = 1;
  j = 1;
  si(i).port = i;
  si(i).txt = 'U'; i=i+1;
  puPARAMSRCstr  = get_param(blkh,'paramSrc');
  cbOUTQUstr     = get_param(blkh,'outQU');     % member of ALWAYS_ON_ITEMS
  cbOUTQERRORstr = get_param(blkh,'outQError'); % member of ALWAYS_ON_ITEMS
  
  if strncmp(puPARAMSRCstr, 'Input ports',1)
      si(i).port = i;
      si(i).txt = 'B'; i = i+1;
      if (strcmpi(cbOUTQUstr, 'on') ||strcmpi(cbOUTQERRORstr, 'on'))
          si(i).port = i;
          si(i).txt = 'C'; i = i+1;
      end
  end
  
  so(j).port = j;
  so(j).txt = 'I'; j=j+1;
  if strcmpi(cbOUTQUstr, 'on')
      so(j).port = j;
      so(j).txt = 'Q(U)'; j = j+1;
  end
  if strcmpi(cbOUTQERRORstr, 'on')
      so(j).port = j;
      so(j).txt = 'Err'; j = j+1;
  end
  
  puPARTTYPEstr  = get_param(blkh,'partType');
  cbOUTSTATUSstr = get_param(blkh,'outStatus');
  if (strncmp(puPARTTYPEstr, 'Bounded',1) && strcmpi(cbOUTSTATUSstr, 'on'))
      so(j).port = j;
      so(j).txt = 'S'; j = j+1;
  end
  
  for m=i:3, si(m)=si(i-1); end
  for n=j:4, so(n)=so(j-1); end
  
case 'dynamic'
  % Execute dynamic dialogs
  %---------------------------------------------------------------------------
  % STEP-1: snap current states of mask items
  mask_enables      = get_param(blkh, 'MaskEnables');
  old_mask_enables  = mask_enables;
  %allowOverrides, roundingMode, overflowMode
  [puPARAMSRC, puPARTTYPE, ~, ~, puSEARCHMETHOD, puTIEBREAKRULE, ...
      cbOUTQU, cbOUTQERROR, ~, ~, ~, ~, puIDTYPE,...
      ~, puROUNDINGMODE, cbOVERFLOWMODE] = ...
      deal(1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16);
  
  %---------------------------------------------------------------------------
  % STEP-2:
  ALWAYS_ON_ITEMS = [ ...
      puPARAMSRC puPARTTYPE puSEARCHMETHOD ...
      puTIEBREAKRULE cbOUTQU cbOUTQERROR ...
      puIDTYPE puROUNDINGMODE cbOVERFLOWMODE];
  mask_enables(ALWAYS_ON_ITEMS) = {'on'};
  
  %---------------------------------------------------------------------------
  % STEP-3:
  % pop-ups/checkbox those control dynamics of other items (these might be
  % controlled by others)
  puPARAMSRCstr  = get_param(blkh,'paramSrc');  % member of ALWAYS_ON_ITEMS
  puPARTTYPEstr  = get_param(blkh,'partType');  % member of ALWAYS_ON_ITEMS
  cbOUTQUstr     = get_param(blkh,'outQU');     % member of ALWAYS_ON_ITEMS
  cbOUTQERRORstr = get_param(blkh,'outQError'); % member of ALWAYS_ON_ITEMS

  if strncmp(puPARAMSRCstr, 'Specify ...',1)
      puPARAMSRCnum = 1;
  else % unbounded
      puPARAMSRCnum = 2;
  end
  
  if strncmp(puPARTTYPEstr, 'Bounded',1)
      puPARTTYPEnum = 1;
  else
      puPARTTYPEnum = 2;
  end
  
  if strcmp(cbOUTQUstr, 'on')
      cbOUTQUnum = 1;
  else
      cbOUTQUnum = 2;
  end
  
  if strcmp(cbOUTQERRORstr, 'on')
      cbOUTQERRORnum = 1;
  else
      cbOUTQERRORnum = 2;
  end
  
  %---------------------------------------------------------------------------
  % STEP-4: any items NOT a member of ALWAYS_ON_ITEMS
  NOT_ALWAYS_ON_ITEMS = setdiff(1:16, ALWAYS_ON_ITEMS);
  ebBBOUNDARYstatus = (puPARAMSRCnum == 1 && puPARTTYPEnum == 1);
  ebUBOUNDARYstatus = (puPARAMSRCnum == 1 && puPARTTYPEnum == 2);
  ebCODEBOOKstatus  = (puPARAMSRCnum == 1 && (cbOUTQUnum == 1 || cbOUTQERRORnum == 1));
  cbOUTSTATUSstatus = (puPARTTYPEnum == 1);
  puINVALIDINstatus = (puPARTTYPEnum == 1);
  
  cbALLOWOVERRIDESstatus   = 0; % permanently disable checkbox
  cbADDITIONALPARAMSstatus = 0; % permanently disable checkbox
  
  NOT_ALWAYS_ON_ITEMSstatus = [ ...
      ebBBOUNDARYstatus ebUBOUNDARYstatus ...
      ebCODEBOOKstatus  cbOUTSTATUSstatus ...
      puINVALIDINstatus cbALLOWOVERRIDESstatus ...
      cbADDITIONALPARAMSstatus ];
  
  mask_enables(NOT_ALWAYS_ON_ITEMS) = {'off'};
  for i=1:length(NOT_ALWAYS_ON_ITEMS)
      if NOT_ALWAYS_ON_ITEMSstatus(i)
          mask_enables{NOT_ALWAYS_ON_ITEMS(i)} = 'on';
      end
  end
  
  %---------------------------------------------------------------------------
  % STEP-5: Set mask visibilities and mask enables
  if ~isequal(mask_enables, old_mask_enables)
      set_param(blkh, 'MaskVisibilities', mask_enables);
  end
  % Backward-compatibility: UBoundary and codebook always enabled (also)
  mask_enables{4} = 'on';
  mask_enables{9} = 'on';
  set_param(blkh, 'MaskEnables', mask_enables);
  
end % end of switch statement
