function varargout = dspblkupfir2(blkh, action, FilterSource, varargin)
% DSPBLKUPFIR Mask dynamic dialog function for FIR interpolation block

% Copyright 1995-2022 The MathWorks, Inc.

switch action
  case 'icon'
    s.in = ''; s.out = ''; 
    s.i1 = 1; s.s1 = '';
    if FilterSource == 1 || FilterSource == 4
        % Coefficients from 'Dialog parameters' or 'Auto'
        L = varargin{1};
        if isempty(L)  || ~isnumeric(L) || ~isscalar(L) || isfi(L)
            s.str = 'x[?]';  % Default display
        else
            s.str= ['x[n/' num2str(L) ']'];
        end
    elseif FilterSource == 2
        % Coefficients from input port
        L = varargin{1};
        if isempty(L)  || ~isnumeric(L) || ~isscalar(L) || isfi(L)
            s.str = 'x[?]';  % Default display
        else
            s.str= ['x[n/' num2str(L) ']'];
        end        
        s.in='In'; s.out='Out';
        s.i1=2; s.s1='Num';
    else
        % Coefficients from filter object
        hd = varargin{1};
         if isempty(hd) || ~isa(hd,'dsp.FIRInterpolator')
            s.str = 'x[?]';  % Default display
        else
            s.str=['x[n/' num2str(hd.InterpolationFactor) ']'];
        end
        s.str = [s.str '\nFilter:\n' get_param(blkh,'FilterObject')];
    end
    varargout{1} = s;
    
  case 'init'
    % NO-OP as of R2019a
    
  case 'setup'      
    filterDefined = false; % default
    h  = [];
    L  = [];
    outBufIC = 0;
    block = get_param(blkh,'Object');
    if FilterSource == 1 || FilterSource == 4
        % Coefficients from 'Dialog parameters' or 'Auto'
        % dspblkupfir2('setup',FilterSource,h,L,outputBufInitCond)
        dtRows    = varargin{1};
        L         = varargin{3};
        outBufIC  = varargin{4};        
        framingIn = varargin{5};
        inpProc   = varargin{6};
        
        if isfield(block.UserData,'filter')
            block.UserData = rmfield(block.UserData,'filter');
        end
        
        if FilterSource == 1
            % Coefficient source: 'Dialog parameters'
            h = varargin{2};
        else
            % Coefficient source: 'Auto'
            if isempty(L) || ~isnumeric(L)
                h = [];
            else
                validateattributes(L, {'numeric',}, ...
                        {'positive', 'real', 'scalar', 'finite', 'nonnan'}, ...
                        '', 'Interpolation factor');
                h = designMultirateFIR(double(L), 1);
            end
        end
        
        %dtInfo = dspGetFixptDataTypeInfo(blkh,47);
        dtInfo = dspGetUDTFixptDataTypeInfo(blkh, dtRows, true); 
        dtInfo.arithmetic = 0; % Default: double-precision arithmetic
        dtInfo.inputWordLength = 16;
        dtInfo.inputFracLength = 15;
        
        block.UserData.filterConstructor = 'dsp.internal.mfilt.firinterp';
        block.UserData.filterConstructorArgs = {L,h};
        
        if ~(isempty(h) || isempty(L))
            % Don't attempt any calculations in the mask helper on these
            % parameters if any of them is currently empty or not defined.
            
            % Do more checking before using h,L,outBufIC parameters
            if ~isnumeric(h) || isfi(h)
                error(message('dsp:dspblkupfir2:invalidCoefficient1'));
            end
            if isfi(outBufIC) || ischar(outBufIC)
                error(message('dsp:dspblkupfir2:paramDTypeError1'));
            end
            if ~isnumeric(L) || isfi(L)
                error(message('dsp:dspblkupfir2:paramDTypeError2'));
            end
            if ~isreal(L) || ~ isscalar(L) || (L < 1) || (fix(L) ~= L)
                error(message('dsp:dspblkupfir2:paramRealScalarError'));
            end
            
            filterDefined = true;
            
            if ~isvector(h)
                error(message('dsp:dspblkupfir2:invalidCoefficient2'));
            end
        end
    elseif FilterSource == 2
        % Input arguments for setup case when coeffs from input port:
        % dspblkupfir2('setup',FilterSource,L,outputBufInitCond)
        dtRows    = varargin{1};
        L         = varargin{2};
        outBufIC  = varargin{3};        
        framingIn = varargin{4};
        inpProc   = varargin{5};
        
        if isfield(block.UserData,'filter')
            block.UserData = rmfield(block.UserData,'filter');
        end
        
        %dtInfo = dspGetFixptDataTypeInfo(blkh,47);
        dtInfo = dspGetUDTFixptDataTypeInfo(blkh, dtRows, true); 
        dtInfo.arithmetic = 0; % Default: double-precision arithmetic
        dtInfo.inputWordLength = 16;
        dtInfo.inputFracLength = 15;      
        
        block.UserData.filterConstructor = 'dsp.internal.mfilt.firinterp';
        block.UserData.filterConstructorArgs = {L};
        
        if ~isempty(L)
            % Don't attempt any calculations in the mask helper on these
            % parameters if any of them is currently empty or not defined.
            
            % Do more checking before using L,outBufIC parameters
            if isfi(outBufIC) || ischar(outBufIC)
                error(message('dsp:dspblkupfir2:paramDTypeError1'));
            end
            if ~isnumeric(L) || isfi(L)
                error(message('dsp:dspblkupfir2:paramDTypeError2'));
            end
            if ~isreal(L) || ~ isscalar(L) || (L < 1) || (fix(L) ~= L)
                error(message('dsp:dspblkupfir2:paramRealScalarError'));
            end
            
            filterDefined = true;
        end
    else
        % Input arguments for setup case when coeffs from filter object:
        % dspblkupfir2('setup',FilterSource,FilterObject)
        hd        = varargin{1};
        framingIn = varargin{2};
        inpProc   = varargin{3};
        
        if isfield(block.UserData,'filterConstructor')
            block.UserData = rmfield(block.UserData,'filterConstructor');
            block.UserData = rmfield(block.UserData,'filterConstructorArgs');
        end
        block.UserData.filter = [];
        
        if ~isempty(hd)
            if isa(hd,'dsp.internal.mfilt.firinterp')|| isa(hd,'dsp.FIRInterpolator')
                if isa(hd,'dsp.internal.mfilt.firinterp')
                    FilterSource = 5;
                    block.UserData.filter = hd;
                    hdx = reffilter(hd); % Get the reference coeffs, not the quantized ones
                else
                    
                    if ~any(strcmpi({'Property','Auto'},hd.NumeratorSource))
                       error(message('dsp:dspblkupfir2:unsupportedCoeffsFromPort'));  
                    end
                    
                    hd_clone = clone(hd);
                    release(hd_clone);
                    block.UserData.filter = hd_clone;
                    hdx = hd_clone;
                end
                h = hdx.Numerator;
                L = hdx.InterpolationFactor;
                filterDefined = true;
            else
                error(message('dsp:dspblkupfir2:invalidFilterObject'));
            end
        end
        dtInfo = getFixptDataTypeInfoFromFilterObject(hd);
    end

    if filterDefined
        % Update FVTool plot window, if open
        if dspIsFVToolOpen(blkh)
            dspLinkFVTool2Mask(blkh,'update');
        end

        % Need to reshuffle the coefficients into phase order        
        len = length(h);       
        if (rem(len, L) ~= 0)
            nzeros = L - rem(len, L);
            h = [h(:); zeros(nzeros,1)];
        end
        len = length(h);
        nrows = len / L;
        % Re-arrange the coefficient
        h = reshape(h, L, nrows).';       

        %Scale the initial conditions by 1/L
        %This is put in to maintain backward compatibility        
        outBufIC = outBufIC ./L;
    else
        % Close FVTool plot window, if open
        dspLinkFVTool2Mask(blkh,'close');
    end

    % Gather up outputs
    args.CoeffSource = FilterSource;
    args.h = h;
    args.L = L;
    args.outBufIC = outBufIC;

    % Set the multi-channel parallelism simulation to true
    args.ParallelChSim = double(true);

    framing   = dspblkAdjustMultiRateFraming(inpProc, framingIn);
    varargout = {args,dtInfo, framing};

  otherwise
    % Dynamic dialog (visible/enable) control
    dspmltiFIRDynamicDialogUpdate(blkh);
    varargout = {};
end

%------------------------------------------------------------------------------
function dtInfo = getFixptDataTypeInfoFromFilterObject(hd)

if isa(hd,'dsp.FIRInterpolator')
   dtInfo = getFIRRateConversionFixptInfoFromSysObj(hd); 
else
   dtInfo = getFixptDataTypeInfoFromMFILT(hd);   
end

%--------------------------------------------------------------------------
function dtInfo = getFixptDataTypeInfoFromMFILT(hd)
  
% Initialize all to defaults
  dtInfo = initializeFIRRateConversionFixedPointDefaults();

  if ~isempty(hd) && isfdtbxinstalled
      switch hd.Arithmetic
        case 'double'
          dtInfo.arithmetic = 0;
        case 'single'
          dtInfo.arithmetic = 1;
        case 'fixed'
          dtInfo.arithmetic = 2;

          if strcmpi(hd.OverflowMode, 'wrap')
              dtInfo.overflowMode = 1;
          else
              dtInfo.overflowMode = 2;
          end

          if strcmpi(hd.RoundMode, 'ceil')
              dtInfo.roundingMode = 1;
          elseif strcmpi(hd.RoundMode, 'convergent')
              dtInfo.roundingMode = 2;
          elseif strcmpi(hd.RoundMode, 'floor')
                dtInfo.roundingMode = 3;
          elseif strcmpi(hd.RoundMode, 'nearest')
              dtInfo.roundingMode = 4;
          elseif strcmpi(hd.RoundMode, 'round')
              dtInfo.roundingMode = 5;  
          elseif strcmpi(hd.RoundMode, 'fix')
              dtInfo.roundingMode = 7;    %zero
          end

          if ~hd.Signed
              error(message('dsp:dspblkupfir2:invalidCoefficient3'));
          end

          if isprop(hd,'CastBeforeSum') && ~hd.CastBeforeSum
              warning(message('dsp:dspblkupfir2:invalidFilterObject1'));
          end

          dtInfo.inputWordLength  = hd.InputWordLength;
          dtInfo.inputFracLength  = hd.InputFracLength;

          dtInfo.firstCoeffMode = 0; % Binary point scaling
          dtInfo.firstCoeffWordLength = hd.CoeffWordLength;
          dtInfo.firstCoeffFracLength = hd.NumFracLength;

          dtInfo.prodOutputMode = 0; % Binary point scaling
          dtInfo.prodOutputWordLength = hd.ProductWordLength;
          dtInfo.prodOutputFracLength = hd.ProductFracLength;

          dtInfo.accumMode = 0; % Binary point scaling
          dtInfo.accumWordLength = hd.AccumWordLength;
          dtInfo.accumFracLength = hd.AccumFracLength;

          dtInfo.outputMode = 0; % Binary point scaling
          dtInfo.outputWordLength = hd.OutputWordLength;
          dtInfo.outputFracLength = hd.OutputFracLength;

        otherwise
          error(message('dsp:dspblkupfir2:invalidFilterObject2', hd.arithmetic));         
      end
  end
