function varargout = dspblkupsamp2(blkh,action,varargin)
% DSPBLKUPSAMP2 DSP System Toolbox Upsample block helper function.

% Copyright 1995-2020 The MathWorks, Inc.

switch action
    case 'icon'
        % Determine string to display in icon
        % This represents the upsampling value
        % literal upsampling string (exactly what user entered)
        litUpSample  = varargin{1}; 
        % evaluated upsampling value (could be empty if problem occurred)
        evalUpSample = varargin{2};
        
        if isempty(evalUpSample)
            % Problem probably occurred
            upSampleStr = litUpSample;
        else
            % have an evaluated expression
            if ~isnumeric(evalUpSample) || numel(evalUpSample)~=1
                upSampleStr = '?';
            else
                upSampleStr = num2str(evalUpSample);
            end
        end
        x = [0 NaN 1 NaN .3 .3 NaN .3 .2 NaN .3 .4];
        y = [0 NaN 1 NaN .2 .8 NaN .8 .6 NaN .8 .6];
        varargout = {upSampleStr, x,y};
        
    case 'init'
        modeArg = varargin{1};
        switch modeArg
            case 2
                set_param(blkh,'RateOptions', 'Allow multirate processing');
                set_param(blkh,'mode', 'Unused parameter value');
            case 3
                set_param(blkh,'RateOptions', 'Enforce single-rate processing');
                set_param(blkh,'mode', 'Unused parameter value');
        end

    case 'dynamic'
        [RateOptionsArg, ICArg] = deal(4,5);
        blk = gcbh;
        maskVisOld = get_param(blk, 'MaskVisibilities');
        maskVisNew = maskVisOld;
        maskEnOld  = get_param(blk, 'MaskEnables');
        maskEnNew  = maskEnOld;
        
        [maskEnNew{RateOptionsArg}, maskVisNew{RateOptionsArg}] = deal('on');
            [maskEnNew{ICArg}, maskVisNew{ICArg}] = deal('on');
        
        if strcmpi(get_param(blk,'InputProcessing'), 'Elements as channels (sample based)')
            [maskEnNew{RateOptionsArg}, maskVisNew{RateOptionsArg}] = deal('off','on');
            set_param(blk,'RateOptions','Allow multirate processing');
        else
            % FB processing
            if (strcmpi(get_param(blk,'InputProcessing'), 'Columns as channels (frame based)') && ...
                strcmpi(get_param(blk,'RateOptions'), 'Enforce single-rate processing'))
                [maskEnNew{ICArg}, maskVisNew{ICArg}] = deal('off');
            end
        end
        if ( ~isequal(maskVisNew, maskVisOld) || ~isequal(maskEnNew, maskEnOld) )
            set_param(blk, 'MaskVisibilities', maskVisNew, 'MaskEnables', maskEnNew);
        end
end
