function dspblkwaveletscattering(blk, action, varargin)
% DSPBLKWAVELETSCATTERING Wavelet Scattering block helper function

% Copyright 2022 The MathWorks, Inc.

model = bdroot(blk);
dirtyFlag = get_param(model,'Dirty');
c = onCleanup(@()set_param(model,'Dirty',dirtyFlag));

switch action
    case 'init'

        parameters = {'SignalLength','OverlapLength','QualityFactors','OversamplingFactor'};
        specifyFs = get_param(blk, 'SpecifySampleRate');
        if strcmp(specifyFs,'on')
            parameters{end+1} = 'SampleRate';
            parameters{end+1} = 'InvarianceScaleSeconds'; 
        else
            parameters{end+1} = 'InvarianceScaleSamples'; 
        end
        for index=1:length(parameters)
            str = get_param(blk,parameters{index});
            [val,defined] =  slResolve(get_param(blk,parameters{index}),blk);
            coder.internal.errorIf(isempty(str) || (defined && isempty(val)),'dsp:waveletscattering:InvalidEmptyParameter',parameters{index})
        end

    case 'visibility'
        maskNames = get_param(blk,'MaskNames');
        visibilities = get_param(blk,'MaskVisibilities');

        SampleRateIndex = find(ismember(maskNames,'SampleRate'));
        InvarianceScaleSamplesIndex = find(ismember(maskNames,'InvarianceScaleSamples'));
        InvarianceScaleSecondsIndex = find(ismember(maskNames,'InvarianceScaleSeconds'));

        specifyFs = get_param(blk,'SpecifySampleRate');
        if strcmp(specifyFs,'on')
            visibilities{SampleRateIndex} = 'on';
            visibilities{InvarianceScaleSamplesIndex} = 'off';
            visibilities{InvarianceScaleSecondsIndex} = 'on';
        else
            visibilities{SampleRateIndex} = 'off';
            visibilities{InvarianceScaleSamplesIndex} = 'on';
            visibilities{InvarianceScaleSecondsIndex} = 'off';
        end

        set_param(blk,'MaskVisibilities',visibilities),

end