function dspiirhalfbandvisibilities(blk)
% Control parameter visibility for IIR Halfband Decimator/Interpolator
% masked blocks

%   Copyright 2017 The MathWorks, Inc.

visibilities = get_param(blk,'MaskVisibilities');
original_visibilities = visibilities;

maskNames = get_param(blk,'MaskNames');
maskValues = get_param(blk,'MaskValues');

SpecificationIndex = ismember(maskNames,'Specification');
Spec = maskValues{SpecificationIndex};
isCoeff = strcmp(Spec,'Coefficients');

StopbandAttenuationIdx = ismember(maskNames,'StopbandAttenuation');
if isCoeff || strcmp(Spec,'Filter order and transition width')
    visibilities{StopbandAttenuationIdx} = 'off';
else
    visibilities{StopbandAttenuationIdx} = 'on';
end

TransitionWidthIdx = ismember(maskNames,'TransitionWidth');
if isCoeff || strcmp(Spec,'Filter order and stopband attenuation')
    visibilities{TransitionWidthIdx} = 'off';
else
    visibilities{TransitionWidthIdx} = 'on';
end

FilterOrderIdx = ismember(maskNames,'FilterOrder');
if isCoeff || strcmp(Spec,'Transition width and stopband attenuation')
    visibilities{FilterOrderIdx} = 'off';
else
    visibilities{FilterOrderIdx} = 'on';
end

StructureIdx = ismember(maskNames,'Structure');
HasTrailingFirstOrderSectionIdx = ismember(maskNames,'HasTrailingFirstOrderSection');
HasPureDelayBranchIdx = ismember(maskNames,'HasPureDelayBranch');
if isCoeff
    visibilities{StructureIdx} = 'on';
    visibilities{HasTrailingFirstOrderSectionIdx} = 'on';
    visibilities{HasPureDelayBranchIdx} = 'on';
else
    visibilities{StructureIdx} = 'off';
    visibilities{HasTrailingFirstOrderSectionIdx} = 'off';
    visibilities{HasPureDelayBranchIdx} = 'off';
end
   
StructureIndex = ismember(maskNames,'Structure');
Structure = maskValues{StructureIndex};

AllpassCoefficients2Idx = ismember(maskNames,'AllpassCoefficients2');
if  (isCoeff && strcmp(Structure,'Minimum multiplier'))
    visibilities{AllpassCoefficients2Idx} = 'on';
else
    visibilities{AllpassCoefficients2Idx} = 'off';
end

WDFCoefficients2Idx = ismember(maskNames,'WDFCoefficients2');
if (isCoeff && strcmp(Structure,'Wave Digital Filter'))
    visibilities{WDFCoefficients2Idx} = 'on';
else
    visibilities{WDFCoefficients2Idx} = 'off';
end

DesignMethodIdx = ismember(maskNames,'DesignMethod');
if (isCoeff)
    visibilities{DesignMethodIdx} = 'off';
else
    visibilities{DesignMethodIdx} = 'on';
end
   
DelayIdx = ismember(maskNames,'Delay');
if (isCoeff && strcmp(maskValues{HasPureDelayBranchIdx},'on'))
    visibilities{DelayIdx} = 'on';
else
    visibilities{DelayIdx} = 'off';
end

AllpassCoefficients1Idx = ismember(maskNames,'AllpassCoefficients1');
CoefficientsPortIdx = ismember(maskNames,'CoefficientsPort');
if (isCoeff && strcmp(maskValues{HasPureDelayBranchIdx},'off') && ...
        strcmp(maskValues{CoefficientsPortIdx},'off') && strcmp(Structure,'Minimum multiplier'))
    visibilities{AllpassCoefficients1Idx} = 'on';
else
    visibilities{AllpassCoefficients1Idx} = 'off';
end

AllpassCoefficients2Idx = ismember(maskNames,'AllpassCoefficients2');
if (isCoeff  && strcmp(maskValues{CoefficientsPortIdx},'off') && ... 
                strcmp(Structure,'Minimum multiplier'))
    visibilities{AllpassCoefficients2Idx} = 'on';
else
    visibilities{AllpassCoefficients2Idx} = 'off';
end

WDFCoefficients1Idx = ismember(maskNames,'WDFCoefficients1');
if (isCoeff && strcmp(maskValues{HasPureDelayBranchIdx},'off') && strcmp(Structure,'Wave Digital Filter'))
    visibilities{WDFCoefficients1Idx} = 'on';
else
    visibilities{WDFCoefficients1Idx} = 'off';
end

InheritSampleRateIndex    = find(ismember(maskNames,'InheritSampleRate'));
SampleRateIndex           = find(ismember(maskNames,'SampleRate'));
if (isCoeff)
    visibilities{InheritSampleRateIndex} = 'off';
    visibilities{SampleRateIndex}        = 'off';
else
    visibilities{InheritSampleRateIndex} = 'on';
    
    isInherit = strcmp(maskValues{InheritSampleRateIndex},'on');
    if isInherit
        visibilities{SampleRateIndex}        = 'off';
    else
        visibilities{SampleRateIndex}        = 'on';
    end 
end

if ~isequal(original_visibilities,visibilities)
    set_param(blk,'MaskVisibilities',visibilities),
end