function dspmltiFIRDynamicDialogUpdate(blkh)
% dspmltiFIRDynamicDialogUpdate Shared multirate FIR dynamic dialog functionality

% Copyright 2015-2022 The MathWorks, Inc.

switch get_param(blkh,'FilterSource')
    case 'Dialog parameters'
        filtNOTObjPrmOnOffStr = 'on';  % Show/hide based on "NOT in 'Filter object' mode"
        filtFrmObjectOnOffStr = 'off'; % Show/hide based on 'Filter object' mode
        filtCofDlgPrmOnOffStr = 'on';  % Show/hide coeff on dialog
        filtCofLblPrmOnOffStr = 'on';  % Show/hide coeff label on dialog
        filtCofTypPrmOnOffStr = 'on';  % Show/hide coeff UDT (type)
        fvtoolButtonVisible   = 'on';  % Show/hide FVTool button
        
    case 'Input port'
        filtNOTObjPrmOnOffStr = 'on';
        filtFrmObjectOnOffStr = 'off';
        filtCofDlgPrmOnOffStr = 'off';
        filtCofLblPrmOnOffStr = 'off';
        filtCofTypPrmOnOffStr = 'off';
        fvtoolButtonVisible   = 'off';
        
    case 'Filter object'
        filtNOTObjPrmOnOffStr = 'off';
        filtFrmObjectOnOffStr = 'on';
        filtCofDlgPrmOnOffStr = 'off';
        filtCofLblPrmOnOffStr = 'off';
        filtCofTypPrmOnOffStr = 'off';
        fvtoolButtonVisible   = 'on';
        
    otherwise
        % Automatic coefficients mode
        filtNOTObjPrmOnOffStr = 'on';
        filtFrmObjectOnOffStr = 'off';
        filtCofDlgPrmOnOffStr = 'off';
        filtCofLblPrmOnOffStr = 'on';
        filtCofTypPrmOnOffStr = 'on';
        fvtoolButtonVisible   = 'on';
end

isFIRRateConversionBlock = ...
    strcmp(get_param(blkh,'MaskType'), 'FIR Rate Conversion');
isFIRDecimationBlock = ...
    strcmp(get_param(blkh,'MaskType'), 'FIR Decimation');

if ~isFIRRateConversionBlock
    % FIR Decimation or FIR Interpolation
    inputProcParamSetting = get_param(blkh,'InputProcessing');
    if strcmp(inputProcParamSetting, 'Elements as channels (sample based)')
        % 'Elements as channels (sample based)'
        %     ->  NO user-specified 'Rate options'
        rateOptionsPrmOnOffStr = 'off';
        rateOptMRLabelOnOffStr = 'on';
    else
        % 'Columns as channels (frame based)' OR 'Inherited ...'
        %     -> user-specified 'Rate options'
        rateOptionsPrmOnOffStr = 'on';
        rateOptMRLabelOnOffStr = 'off';
    end

    if ~strcmp(inputProcParamSetting, 'Columns as channels (frame based)') ...
            || strcmp(get_param(blkh,'framing'), 'Allow multirate processing')
        % Sample-based OR Inherited both allow user-specified output ICs
        % (additionally, multirate proc allows user-specified output ICs)
        outBufferICPrmOnOffStr = 'on';
    else
        outBufferICPrmOnOffStr = 'off';
    end
end

% =======================================
% MASK PARAMETER visibilities and enables
% =======================================

vis_old = get_param(blkh, 'MaskVisibilities');
ena_old = get_param(blkh, 'MaskEnables');    
vis_new = vis_old;
ena_new = ena_old;

% Main tab
maskNames    = get_param(blkh,'MaskNames');
H_Mask_Index = find(strcmp(maskNames(:),'h'));
if ~isempty(H_Mask_Index)
    vis_new{H_Mask_Index} = filtCofDlgPrmOnOffStr;     % 'h' (vis)
    ena_new{H_Mask_Index} = filtCofDlgPrmOnOffStr;     % 'h' (ena)
end
D_Mask_Index = find(strcmp(maskNames(:),'D'));
if ~isempty(D_Mask_Index)
    vis_new{D_Mask_Index} = filtNOTObjPrmOnOffStr; % 'D' (vis)
    ena_new{D_Mask_Index} = filtNOTObjPrmOnOffStr; % 'D' (ena)
end
L_Mask_Index = find(strcmp(maskNames(:),'L'));
if ~isempty(L_Mask_Index)
    vis_new{L_Mask_Index} = filtNOTObjPrmOnOffStr; % 'L' (vis)
    ena_new{L_Mask_Index} = filtNOTObjPrmOnOffStr; % 'L' (ena)
end
M_Mask_Index = find(strcmp(maskNames(:),'M'));
if ~isempty(M_Mask_Index)
    vis_new{M_Mask_Index} = filtNOTObjPrmOnOffStr; % 'M' (vis)
    ena_new{M_Mask_Index} = filtNOTObjPrmOnOffStr; % 'M' (ena)
end
FltStrcIndex = find(strcmp(maskNames(:),'filtStruct'));
if ~isempty(FltStrcIndex)
    vis_new{FltStrcIndex} = filtNOTObjPrmOnOffStr; % 'filtStruct' (vis)
end
FiltObjIndex = find(strcmp(maskNames(:),'FilterObject'));
if ~isempty(FiltObjIndex)
    vis_new{FiltObjIndex} = filtFrmObjectOnOffStr; % 'FilterObject' (vis)
    ena_new{FiltObjIndex} = filtFrmObjectOnOffStr; % 'FilterObject' (ena)
end
framingIndex = find(strcmp(maskNames(:),'framing'));
if ~isempty(framingIndex)
    vis_new{framingIndex} = rateOptionsPrmOnOffStr;
end
outBfICIndex = find(strcmp(maskNames(:),'outputBufInitCond'));
if ~isempty(outBfICIndex)
    vis_new{outBfICIndex} = outBufferICPrmOnOffStr;
end

if isFIRRateConversionBlock
    EnableArbitraryIndex = strcmp(maskNames(:),'AllowArbitraryInputLength');
    if strcmp(get_param(blkh,'rateMode'), 'Allow multirate processing')
        OutputSizeFixedOnOffStr = 'off';
    else
        OutputSizeFixedOnOffStr = 'on';
    end
    vis_new{EnableArbitraryIndex} = OutputSizeFixedOnOffStr;     % 'AllowArbitraryInputLength' (vis)
end

if isFIRDecimationBlock
    EnableArbitraryIndex = strcmp(maskNames(:),'AllowArbitraryInputLength');
    if strcmp(get_param(blkh,'framing'), 'Allow multirate processing') || strcmp(get_param(blkh,'InputProcessing'), 'Elements as channels (sample based)')
        OutputSizeFixedOnOffStr = 'off';
    else
        OutputSizeFixedOnOffStr = 'on';
    end
    vis_new{EnableArbitraryIndex} = OutputSizeFixedOnOffStr;     % 'AllowArbitraryInputLength' (vis)
end

% Data Types tab
vis_new{strcmp(maskNames(:),'roundingMode')}          = filtNOTObjPrmOnOffStr;
vis_new{strcmp(maskNames(:),'overflowMode')}          = filtNOTObjPrmOnOffStr;
vis_new{strcmp(maskNames(:),'firstCoeffDataTypeStr')} = filtCofTypPrmOnOffStr;
vis_new{strcmp(maskNames(:),'firstCoeffMin')}         = filtCofTypPrmOnOffStr;
vis_new{strcmp(maskNames(:),'firstCoeffMax')}         = filtCofTypPrmOnOffStr;
vis_new{strcmp(maskNames(:),'prodOutputDataTypeStr')} = filtNOTObjPrmOnOffStr;
vis_new{strcmp(maskNames(:),'accumDataTypeStr')}      = filtNOTObjPrmOnOffStr;
vis_new{strcmp(maskNames(:),'outputDataTypeStr')}     = filtNOTObjPrmOnOffStr;
vis_new{strcmp(maskNames(:),'outputMin')}             = filtNOTObjPrmOnOffStr;
vis_new{strcmp(maskNames(:),'outputMax')}             = filtNOTObjPrmOnOffStr;
vis_new{strcmp(maskNames(:),'LockScale')}             = filtNOTObjPrmOnOffStr;

% ======================================
% MASK PROPERTY visibilities and enables
% ======================================

blkMaskObj    = Simulink.Mask.get(blkh);
ViewFiltRsp   = blkMaskObj.getDialogControl('ViewFilterResponseButton');
DTPColLabel   = blkMaskObj.getDialogControl('DataTypeColumnLabel');
MinColLabel   = blkMaskObj.getDialogControl('MinimumColumnLabel');
MaxColLabel   = blkMaskObj.getDialogControl('MaximumColumnLabel');
CoeffsLabel   = blkMaskObj.getDialogControl('firstCoeffDataTypeLabel');
PrdTxtLabel   = blkMaskObj.getDialogControl('prodOutputDataTypeLabel');
PrdMinLabel   = blkMaskObj.getDialogControl('prodOutputMinLabel');
PrdMaxLabel   = blkMaskObj.getDialogControl('prodOutputMaxLabel');
AccTxtLabel   = blkMaskObj.getDialogControl('accumDataTypeLabel');
AccMinLabel   = blkMaskObj.getDialogControl('accumMinLabel');
AccMaxLabel   = blkMaskObj.getDialogControl('accumMaxLabel');
OutTxtLabel   = blkMaskObj.getDialogControl('outputDataTypeLabel');
foRndMdPrompt = blkMaskObj.getDialogControl('filtObjRoundModePromptLabel');
foRndMdValStr = blkMaskObj.getDialogControl('filtObjRoundModeValue');
foOvfMdPrompt = blkMaskObj.getDialogControl('filtObjOvrflModePromptLabel');
foOvfMdValStr = blkMaskObj.getDialogControl('filtObjOvrflModeValue');
foCofDTLblStr = blkMaskObj.getDialogControl('filtObjCofDataTypeLabel');
foCofDTValStr = blkMaskObj.getDialogControl('filtObjCofUDTStrValue');
foPrdDTLblStr = blkMaskObj.getDialogControl('filtObjPrdDataTypeLabel');
foPrdDTValStr = blkMaskObj.getDialogControl('filtObjPrdUDTStrValue');
foAccDTLblStr = blkMaskObj.getDialogControl('filtObjAccDataTypeLabel');
foAccDTValStr = blkMaskObj.getDialogControl('filtObjAccUDTStrValue');
foOutDTLblStr = blkMaskObj.getDialogControl('filtObjOutDataTypeLabel');
foOutDTValStr = blkMaskObj.getDialogControl('filtObjOutUDTStrValue');

fvtoolButtonEnabled = 'on'; % DEFAULT

if ~strcmp(get_param(blkh,'FilterSource'), 'Filter object')
    % INVISIBLE (filter object data type property text strings)
    foDTPropTextStrVisibility = 'off';
else
    % VISIBLE (filter object data type property text strings)
    foDTPropTextStrVisibility = 'on';
    
    % Suppress MFILT deprecation warnings
    w = warning('off', 'dsp:mfilt:mfilt:Obsolete');
    restoreWarn = onCleanup(@() warning(w));
    
    blockObject = get(blkh, 'object');
    [FilterObject, ~] = slResolve(blockObject.FilterObject, blkh);
    
    % GET text string settings from specified FilterObject
    [objRndingStr, objOvrflwStr, objCofUDTStr, ...
        objPrdUDTStr, objAccUDTStr, objOutUDTStr] = ...
        getFilterObjectDTTextValues(FilterObject);
    
    % SET all FilterObject specific text properties on dialog
    foRndMdValStr.Prompt = objRndingStr;
    foOvfMdValStr.Prompt = objOvrflwStr;
    foCofDTValStr.Prompt = objCofUDTStr;
    foPrdDTValStr.Prompt = objPrdUDTStr;
    foAccDTValStr.Prompt = objAccUDTStr;
    foOutDTValStr.Prompt = objOutUDTStr;
end

% =====================================
% Control all PARAMETER UI settings here
% =====================================
if ~isequal(vis_new,vis_old) || ~isequal(ena_new,ena_old)
    set_param(blkh, 'MaskVisibilities', vis_new, 'MaskEnables', ena_new);
end

% ====================================
% Control all PROPERTY UI settings here
% ====================================
if ~isFIRRateConversionBlock
    % FIR Decimation or FIR Interpolation -> Text to use when drop-down N/A
    RateOptMRStr = blkMaskObj.getDialogControl('rateOptsAllowMultirateTextVar');
    RateOptMRStr.Visible = rateOptMRLabelOnOffStr;
end
ViewFiltRsp.Enabled   = fvtoolButtonEnabled;
ViewFiltRsp.Visible   = fvtoolButtonVisible;
foRndMdPrompt.Visible = foDTPropTextStrVisibility;
foRndMdValStr.Visible = foDTPropTextStrVisibility;
foOvfMdPrompt.Visible = foDTPropTextStrVisibility;
foOvfMdValStr.Visible = foDTPropTextStrVisibility;
DTPColLabel.Visible   = filtNOTObjPrmOnOffStr;
MinColLabel.Visible   = filtNOTObjPrmOnOffStr;
MaxColLabel.Visible   = filtNOTObjPrmOnOffStr;
CoeffsLabel.Visible   = filtCofLblPrmOnOffStr;
foCofDTLblStr.Visible = foDTPropTextStrVisibility;
foCofDTValStr.Visible = foDTPropTextStrVisibility;
PrdTxtLabel.Visible   = filtNOTObjPrmOnOffStr;
PrdMinLabel.Visible   = filtNOTObjPrmOnOffStr;
PrdMaxLabel.Visible   = filtNOTObjPrmOnOffStr;
foPrdDTLblStr.Visible = foDTPropTextStrVisibility;
foPrdDTValStr.Visible = foDTPropTextStrVisibility;
AccTxtLabel.Visible   = filtNOTObjPrmOnOffStr;
AccMinLabel.Visible   = filtNOTObjPrmOnOffStr;
AccMaxLabel.Visible   = filtNOTObjPrmOnOffStr;
foAccDTLblStr.Visible = foDTPropTextStrVisibility;
foAccDTValStr.Visible = foDTPropTextStrVisibility;
OutTxtLabel.Visible   = filtNOTObjPrmOnOffStr;
foOutDTLblStr.Visible = foDTPropTextStrVisibility;
foOutDTValStr.Visible = foDTPropTextStrVisibility;

% -------------------------------------------------------------------------
function [objRndingStr, objOvrflwStr, objCofUDTStr, objPrdUDTStr, ...
    objAccUDTStr, objOutUDTStr] = getFilterObjectDTTextValues(obj)

% DEFAULT Data Type settings for the filter (System) object settings
objRndingStr = 'Floor';
objOvrflwStr = 'Wrap';
objCofUDTStr = 'Same word length as input';
objPrdUDTStr = 'Full precision';
objAccUDTStr = 'Full precision';
objOutUDTStr = 'Same as accumulator';

if ~isempty(obj)
    if isa(obj,'dsp.FIRDecimator') ||  isa(obj,'dsp.FIRInterpolator') ||  isa(obj,'dsp.FIRRateConverter')
        % Get System object settings
        if strcmp(obj.CoefficientsDataType, 'Custom')
            cofNT = obj.CustomCoefficientsDataType;
            if strcmp(cofNT.DataTypeMode, 'Fixed-point: unspecified scaling')
                objCofUDTStr = strcat('fixdt(1,', int2str(cofNT.WordLength), ')' );
            else
                objCofUDTStr = strcat('fixdt(1,', int2str(cofNT.WordLength), ',', int2str(cofNT.FractionLength), ')' );
            end
        else
            objCofUDTStr = obj.CoefficientsDataType;
        end
        
        if ~(obj.FullPrecisionOverride)
            objRndingStr = obj.RoundingMethod;
            objOvrflwStr = obj.OverflowAction;
            if strcmp(obj.ProductDataType, 'Custom')
                prdNT = obj.CustomProductDataType;
                objPrdUDTStr = strcat('fixdt(1,', int2str(prdNT.WordLength), ',', int2str(prdNT.FractionLength), ')' );
            else
                objPrdUDTStr = obj.ProductDataType;
            end
            if strcmp(obj.AccumulatorDataType, 'Custom')
                accNT = obj.CustomAccumulatorDataType;
                objAccUDTStr   = strcat('fixdt(1,', int2str(accNT.WordLength), ',', int2str(accNT.FractionLength), ')' );
            else
                objAccUDTStr = obj.AccumulatorDataType;
            end
            if strcmp(obj.OutputDataType, 'Custom')
                outNT = obj.CustomOutputDataType;
                objOutUDTStr = strcat('fixdt(1,', int2str(outNT.WordLength), ',', int2str(outNT.FractionLength), ')' );
            else
                objOutUDTStr = obj.OutputDataType;
            end
        end
        
    elseif (isa(obj, 'mfilt.firdecim') || isa(obj, 'mfilt.firtdecim') || isa(obj, 'mfilt.firinterp') || isa(obj, 'mfilt.firsrc')) && strcmpi(obj.arithmetic,'fixed')
        % Get MFILT object ('fixed') settings
        if (obj.CoeffAutoScale)
            objCofUDTStr = strcat('fixdt(1,', int2str(obj.CoeffWordLength), ')' );
        else
            objCofUDTStr = strcat('fixdt(1,', int2str(obj.CoeffWordLength), ',', int2str(obj.NumFracLength), ')' );
        end
        
        if ~strcmp(obj.FilterInternals, 'FullPrecision')
            objRndingStr = obj.RoundMode;
            objOvrflwStr = obj.OverflowMode;
            objPrdUDTStr = strcat('fixdt(1,', int2str(obj.ProductWordLength), ',', int2str(obj.ProductFracLength), ')' );
            objAccUDTStr = strcat('fixdt(1,', int2str(obj.AccumWordLength),   ',', int2str(obj.AccumFracLength),   ')' );
            objOutUDTStr = strcat('fixdt(1,', int2str(obj.OutputWordLength),  ',', int2str(obj.OutputFracLength),  ')' );
        end
    end
end
