function libs = dspliblist
% DSPLIBLIST Return list of DSP System Toolbox libraries.
%
%   See also DSP_LINKS.

% Copyright 1995-2022 The MathWorks, Inc.


% DSP System Toolbox Version 3 and earlier:
libs.obsolete = {'dspsrcs','dspsnks',...
             'dspelmat','dspvect', 'dspmtrx','dspcmplx','dspstat', ...
             'dspbdsp','dspxfrm','dspbuff','dspswit','dspspect',...
             'dspddes','dsparch','dspadpt','dspmlti'};

% DSP System Toolbox Version 4 and later :
libs.deprecated = {'dspsrcs3','dspsnks3', 'dspobslib',...
             'dspddes3','dsparch3','dspmlti3','dspwin32'};

% DSP System Toolbox Version 4 and later :
libs.current = {'dspsrcs4','dspsnks4',...
             'dspadpt3','dspfdesign','dsparch4','dspmlti4'...
             'dspparest3','dspspect3','dsplp',...
             'dspxfrm3','dspstat3','dspquant2','dspsigops',...
             'dspmathops','dspmtrx3','dspfactors','dspinverses','dspsolvers',...
             'dsppolyfun',...
             'dspswit3','dspbuff3','dspindex','dspsigattribs', ...
             'dspdataflow', ...
             'dspfeatures'...
             };
libs.formalNames = {'Sources','Sinks',...
             'Adaptive Filters','Filter Designs','Filter Implementations','Multirate Filters', ...
             'Parametric Estimation','Power Spectrum Estimation',...
             'Linear Prediction','Transforms','Statistics','Quantizers','Signal Operations',...
             'Math Operations','Matrix Operations','Matrix Factorizations','Matrix Inverses',...
             'Linear System Solvers','Polynomial Functions',...
             'Switches and Counters', 'Buffers', 'Indexing', 'Signal Attributes',...
             'Dataflow',...
             'Feature Extractors'
             }; 
libs.formalName = 'DSP System Toolbox';

stack = dbstack;

% Conditionally add dspnetwork, dspvision to allow dsp_links to report on blocks in this library
% that appear in dspsrcs4 and dspsnks4 but are just links to dspnetwork.
if length(stack) > 1 && strcmp(stack(2).name, 'dsp_links')
    libs.current{end+1} = 'dspnetwork';
    libs.current{end+1} = 'dspvision';
    
    libs.formalNames{end+1} = ''; % Not needed: Only used in block capability table.
    libs.formalNames{end+1} = '';
end

% [EOF] dspliblist.m
