function maxChannels = computeMaxChannelsForDevice(deviceName, mode, varargin)
% Determines the maximum number of input or output channels for a specified
% device 

% Copyright 2012-2015 The MathWorks, Inc.

% The device name that is used from the From/To Audio Device blocks.
if strcmp(deviceName, 'No device available.')
    maxChannels = 0;
    return;
end

if strcmpi(mode, 'input')
    if strcmp(deviceName, 'Default')
        devInfo = dspAudioDeviceInfo('defaultInput',varargin{:});
        maxChannels = devInfo.maxInputs;
    elseif strcmp(deviceName, getString(message('dsp:audioDeviceIO:noInputDevice')))
        maxChannels = 0;
    else
        if ~isempty(varargin)
            devInfo = dspAudioDeviceInfo('inputsForApi',varargin{:});
        else
            devInfo = dspAudioDeviceInfo('inputs');
        end
        selDeviceIdx = arrayfun(@(x) strncmp(x.name, deviceName, ...
                                   length(deviceName)), devInfo);
        if ~any(selDeviceIdx)
            maxChannels = 0;
        else
            maxChannels = devInfo(selDeviceIdx).maxInputs;
        end
    end
    return;
end

if strcmpi(mode, 'output')
    if strcmp(deviceName, 'Default')
        devInfo = dspAudioDeviceInfo('defaultOutput',varargin{:});
        maxChannels = devInfo.maxOutputs;
    elseif strcmp(deviceName, getString(message('dsp:audioDeviceIO:noOutputDevice')))
        maxChannels = 0;
    else
        if ~isempty(varargin)
            devInfo = dspAudioDeviceInfo('outputsForApi',varargin{:});
        else
            devInfo = dspAudioDeviceInfo('outputs');
        end
        selDeviceIdx = arrayfun(@(x) strncmp(x.name, deviceName, ...
                                   length(deviceName)), devInfo);
        if ~any(selDeviceIdx)
            maxChannels = 0;
        else
            maxChannels = devInfo(selDeviceIdx).maxOutputs;
        end
    end
    return;
end

assert(false, 'Invalid mode specified');
    