function [outData] = dspBiquadFilterTransform(inData)
% dspBiquadFilterTransform
%   This is an internal function called by Simulink(R) during model load.

% Copyright 2017-2019 The MathWorks, Inc.

% Search for 'CoeffSource' parameter (and remove if found - it is unused)
% (BEGIN: CODE REMOVED FOR THIS - TBD WHILE TEST FAILURES INVESTIGATED)
% tmpData1 = inData;
% if isfield(inData, 'InstanceData')
%     OrigInstcData = inData.InstanceData;
%     itemIdx = 0;
%     for idx=1:length(OrigInstcData)
%         if strcmp(OrigInstcData(idx).Name, 'CoeffSource')
%             itemIdx = idx; break; % early break from loop
%         end
%     end
%     if itemIdx > 0
%         % Remove 'CoeffSource' parameter from the instance data
%         if itemIdx > 1
%             firstPart  = OrigInstcData( 1:(itemIdx - 1) );
%             secondPart = OrigInstcData( (itemIdx + 1):end );
%             tmpData1.NewInstanceData = vertcat(firstPart(:), secondPart(:));
%         else
%             tmpData1.NewInstanceData = OrigInstcData(2:end);
%         end
%     else
%         % No change to the instance data (just a copy)
%         tmpData1.NewInstanceData = OrigInstcData;
%     end
% (END: CODE REMOVED FOR THIS - TBD WHILE TEST FAILURES INVESTIGATED)
% end

% Call dspSlopeBiasToBinPtScalingTransform to flip
% 'Slope and bias scaling' parameter settings to 'Binary point scaling'
% for fixed-point *Mode mask parameters for new block instances.
[tmpData2] = dspSlopeBiasToBinPtScalingTransform(inData);

% Form output structure
outData = tmpData2;
outData.NewBlockPath = inData.ForwardingTableEntry.('__slOldName__');

if isfield(tmpData2, 'NewInstanceData')
    NewInstanceData = tmpData2.NewInstanceData;
    outData.NewInstanceData = NewInstanceData;
elseif isfield(tmpData2, 'InstanceData')
    NewInstanceData = tmpData2.InstanceData;
    outData.NewInstanceData = NewInstanceData;
else
    NewInstanceData = []; % SHOULD NOT GET HERE
end

if ~isempty(NewInstanceData)
    % Change 'FilterSource' property (former mask parameter) legacy choice
    % 'Specify via dialog' to 'Dialog parameters' for new block instances.
    % Similarly, also change 'dfilt object' choice to 'Filter object'.
    for idx=1:length(NewInstanceData)
        
        thisMaskParamName = NewInstanceData(idx).Name;
        
        if strcmp(thisMaskParamName, 'FilterSource')
          % Get current 'FilterSource' string value
          legacyFilterSourceValue = NewInstanceData(idx).Value;
          
          % Translate old choices and apply new string choice
          if ( contains(legacyFilterSourceValue, 'Specify') || ...
                  contains(legacyFilterSourceValue, 'dialog')  )
              
              outData.NewInstanceData(idx).Value = 'Dialog parameters';
              
          elseif ( contains(legacyFilterSourceValue, 'dfilt') || ...
                  contains(legacyFilterSourceValue, 'object') )
              
              outData.NewInstanceData(idx).Value = 'Filter object';
              
          end
          
          break; % early break out of loop
          
        end
    end
    
    % Change any legacy 'InputProcessing' params
    % set to Inherited to instead be frame-based.
    for idx=1:length(NewInstanceData)
        thisMaskParamName = NewInstanceData(idx).Name;
        if strcmp(thisMaskParamName, 'InputProcessing')
          if ~isempty(strfind(NewInstanceData(idx).Value,'Inherited'))
             outData.NewInstanceData(idx).Value = ...
                 'Columns as channels (frame based)';
          end
          break; % early break out of loop
        end
    end
end
