function [outData] = dspChannelizerHDLOptimizedTransform(inData)
% dspChannelizerHDLOptimizedTransform preserves functionality for legacy Channelizer HDL Optimized and IFFT HDL Optimizedblocks.
%
%   This is an internal function called by Simulink(R) during model load.

% Copyright 2015-2019 The MathWorks, Inc.

newInstanceData = inData.InstanceData;

try
    mdlinfo = Simulink.MDLInfo(bdroot);
    sv = str2double(mdlinfo.SimulinkVersion);
                
    if sv < 9.1 % model from before 18a Simulink version
        
        % check if Output Size is not present of it is set to "Same as input size"
        os_found = false;
        os_sameasinputsize = false;
        for ii = 1:numel(newInstanceData)
            if strcmpi(newInstanceData(ii).Name, 'OutputSize')
                os_found = true;
                if strcmpi(newInstanceData(ii).Value, 'same as input size')
                    os_sameasinputsize = true;
                end
                break; % found Output size
            end
        end
        
        % warn if Output Size is found and is set to Same as input size or
        % if it is not found
        if (os_found && os_sameasinputsize) || ~os_found
            subsys_err = DAStudio.message('dsp:HDLChannelizer:BlockBehaviorChangedFrom18a', 'Channelizer HDL Optimized');
            warning('dsp:HDLChannelizer:BlockBehaviorChangedFrom18a',subsys_err);
        end
    end
catch
end


outData.NewInstanceData = newInstanceData;
outData.NewBlockPath    = inData.ForwardingTableEntry.('__slOldName__');

end % dspChannelizerHDLOptimizedTransform
