function [outData] = dspChannelizerTransform(inData)
% dspChannelizerTransform maps the legacy parameter OversamplingRatio to
% DecimationFactor

%   This is an internal function called by Simulink(R) during model load.

% Copyright 2020-2022 The MathWorks, Inc.

instanceData = inData.InstanceData;
outData.NewInstanceData = instanceData;

% Map OversamplingRatio to DecimationFactor
oversamplingRatioIdx = find(ismember({instanceData.Name},'OversamplingRatio'),1);
numFrequencyBandsIdx = find(ismember({instanceData.Name},'NumFrequencyBands'),1);

overSamplingRatio = 1;
if ~isempty(oversamplingRatioIdx)
    overSamplingRatio = slResolve(instanceData(oversamplingRatioIdx).Value,gcb);
    % Remove OversamplingRatio from Output Instance
    outData.NewInstanceData(oversamplingRatioIdx) = [];
end
numFrequencyBands = slResolve(instanceData(numFrequencyBandsIdx).Value,gcb);
decimationFactor = num2str(numFrequencyBands/overSamplingRatio);
% Update the output instance with the new decimation factor
decimationFactorIdx = find(ismember({instanceData.Name},'DecimationFactor'),1);
if isempty(decimationFactorIdx)
   outData.NewInstanceData = [outData.NewInstanceData struct('Name','DecimationFactor','Value',decimationFactor)]; 
end
%  (22b) new parameter 'AllowArbSize'
AllowArbSizeIdx = find(ismember({instanceData.Name},'AllowArbitraryInputLength'),1);
% Populate a newly created AllowArbitraryInputLength with false
if isempty(AllowArbSizeIdx)
    outData.NewInstanceData = [outData.NewInstanceData struct('Name','AllowArbitraryInputLength','Value','off')];
end
% New block path
outData.NewBlockPath = inData.ForwardingTableEntry.('__slOldName__');
