function [outData] = dspColoredNoiseTransform(inData)
%dspColoredNoiseTransform 
%   This is an internal function called by Simulink(R) during model load.

% Copyright 2014-2019 The MathWorks, Inc.

InstanceData = inData.InstanceData;
outData.NewInstanceData = InstanceData;

parameterName = 'Color';
index = -1; % -1 Means the parameter was not found
for i=1:length(InstanceData)
    if strcmp(InstanceData(i).Name, parameterName)
        index = i;
        break;
    end
end

if index == -1 % Need to set Color parameter
    InverseFrequencyPowerStr = localGetVal(inData.InstanceData, 'InverseFrequencyPower', '1');
    InverseFrequencyPower = safeEval(InverseFrequencyPowerStr);
    switch InverseFrequencyPower
        case 1
            colorVal = 'pink';
        case 2
            colorVal = 'brown';
        case 0
            colorVal = 'white';
        case -1
            colorVal = 'blue';
        case -2
            colorVal = 'purple';
        otherwise
            colorVal = 'custom';
    end
    outData.NewInstanceData(end+1) =  struct('Name', parameterName, 'Value', colorVal);
end

outData.NewBlockPath = inData.ForwardingTableEntry.('__slOldName__');

%--------------------------------------------------------------------------

function index = localParamIndex(InstanceData, paramName)
% Search paramName for index of paramName
index = -1; % Means not found

for i=1:length(InstanceData)
    if strcmp(InstanceData(i).Name, paramName)
        index = i;
        break;
    end
end

%--------------------------------------------------------------------------

function value = localGetVal(InstanceData, paramName, defaultValue)
% Attempt to get value from InstanceData. But if it is not in the
% InstanceData, set it to the library default value.

index = localParamIndex(InstanceData, paramName);
% Use the default value if the parameter is not found in the structure
if index == -1
    value = defaultValue;
else
    value = InstanceData(index).Value;
end
