function [outData] = dspConstDiagTransform(inData)
%

% Copyright 2014-2019 The MathWorks, Inc.

% Get input data from old block
           q = localGetVal(inData.InstanceData, 'q' , 'ones(1,3)' );
           s = sprintf('dsp.util.getDiagVect(%s)',q);
       frame = localGetVal(inData.InstanceData, 'frame' , 'off' );
    datatype = localGetVal(inData.InstanceData, 'dataType', 'Inherit from ''Constant(s) along diagonal''');
    isSigned = localGetVal(inData.InstanceData, 'isSigned', 'on');
     wordLen = localGetVal(inData.InstanceData, 'wordLen' , '16' );
  udDataType = localGetVal(inData.InstanceData, 'udDataType', 'sfix(16)');
fracBitsMode = localGetVal(inData.InstanceData, 'fracBitsMode', 'Best precision');
 numFracBits = localGetVal(inData.InstanceData, 'numFracBits', '15');

% Set new block parameters
outData.NewInstanceData = localNVPair('Value', s );
outData.NewInstanceData(2) = localNVPair('VectorParams1D', 'off');

if strcmp(frame, 'off')
    outData.NewInstanceData(3) = localNVPair('SamplingMode', 'Sample based');
else
    outData.NewInstanceData(3) = localNVPair('SamplingMode', 'Frame based');
end

switch datatype
    
    case 'Inherit from ''Constant(s) along diagonal'''
        outData.NewInstanceData(4) = localNVPair('OutDataTypeStr', 'Inherit: Inherit from ''Constant value''');
        
        
    case 'Inherit via back propagation'
        
        outData.NewInstanceData(4) = localNVPair('OutDataTypeStr', 'Inherit: Inherit via back propagation');
        
    case 'User-defined'
        if strcmp(fracBitsMode, 'Best precision')
            outData.NewInstanceData(4) = localNVPair('OutDataTypeStr', sprintf('%s', udDataType));
        else
            outData.NewInstanceData(4) = localNVPair('OutDataTypeStr', sprintf(['slDataTypeAndScale(' '''%s'',''2^(-(%s))'' ) '],udDataType,numFracBits));
        end
        
    case 'Fixed-point'
        
        if strcmp(isSigned, 'on') && strcmp(fracBitsMode,'Best precision')
            outData.NewInstanceData(4) = localNVPair('OutDataTypeStr', sprintf('fixdt(1,%s)',wordLen));
        elseif strcmp(isSigned, 'on') && strcmp(fracBitsMode,'User-defined')
            outData.NewInstanceData(4) = localNVPair('OutDataTypeStr', sprintf('fixdt(1,%s,%s)',wordLen,numFracBits));
        end
        if strcmp(isSigned, 'off') && strcmp(fracBitsMode,'Best precision')
            outData.NewInstanceData(4) = localNVPair('OutDataTypeStr', sprintf('fixdt(0,%s)',wordLen));
        elseif strcmp(isSigned, 'off') && strcmp(fracBitsMode,'User-defined')
            outData.NewInstanceData(4) = localNVPair('OutDataTypeStr', sprintf('fixdt(0,%s,%s)',wordLen,numFracBits));
        end
        
        
    otherwise
        outData.NewInstanceData(4) = localNVPair('OutDataTypeStr',sprintf('%s',datatype));
        
end

% Set new block path
outData.NewBlockPath = 'simulink/Sources/Constant';

end
%--------------------------------------------------------------------------

function entry = localNVPair(name, value)
entry = struct('Name', name, 'Value', value);
end

%--------------------------------------------------------------------------

function index = localParamIndex(InstanceData, paramName)
% Search paramName for index of paramName
index = -1; % Means not found

for i=1:length(InstanceData)
    if strcmp(InstanceData(i).Name, paramName)
        index = i;
        break;
    end
end
end

%--------------------------------------------------------------------------
function value = localGetVal(InstanceData, paramName, defaultValue)
% Attempt to get value from InstanceData. But if it is not in the
% InstanceData, set it to the library default value.

index = localParamIndex(InstanceData, paramName);
if index == -1
    value = defaultValue;
else
    value = InstanceData(index).Value;
end

end
%--------------------------------------------------------------------------
