function [outData] = dspFFTHDLBlockTransform(inData)
% dspFFTHDLBlockTransform preserves functionality for legacy FFT HDL Optimized and IFFT HDL Optimizedblocks.
%
%   This is an internal function called by Simulink(R) during model load.

% Copyright 2015-2019 The MathWorks, Inc.

newInstanceData = inData.InstanceData;

% Obsolete parameters REMOVED (no longer used):

newInstanceData = removeObsoleteParameter(newInstanceData, 'OverflowAction');
newInstanceData = removeObsoleteParameter(newInstanceData, 'FFTLengthSource');
newInstanceData = removeObsoleteParameter(newInstanceData, 'ValidInputPort');

% set the architecture to the original architecture
newInstanceData = setPropertyValue(newInstanceData, 'Architecture','Streaming Radix 2^2');
outData.NewInstanceData = newInstanceData;
outData.NewBlockPath    = inData.ForwardingTableEntry.('__slOldName__');

end % dspFFTBlockTransform

% -------------------------------------------------------------------------
function newInstanceData = removeObsoleteParameter(newInstanceData, parameterName)
for index=1:length(newInstanceData)
    if strcmp(newInstanceData(index).Name, parameterName)
        % Remove the parameter
        newInstanceData = [newInstanceData(1:index-1) newInstanceData(index+1:end)];
        break;
    end
end
end

% %--------------------------------------------------------------------------
% function index = localParamIndex(InstanceData, paramName)
% % Search paramName for index of paramName
% index = -1; % Means not found
% 
% for i=1:length(InstanceData)
%     if strcmp(InstanceData(i).Name, paramName)
%         index = i;
%         break;
%     end
% end
% end

%--------------------------------------------------------------------------
function outData = setPropertyValue(inData, propertyName, propertyValue)
outData = inData;
index = -1; % -1 Means not found
for i=1:length(inData)
    if strcmp(inData(i).Name, propertyName)
        index = i;
        if ~isempty(strfind(inData(i).Value,'Streaming Radix 2 (this choice will be removed -see release notes).'))
           outData(i).Value =  propertyValue;
        end
        break;
    end
end

if index == -1
  outData(end+1) =  struct('Name', propertyName, 'Value', propertyValue);
end

end
