function [outData] = dspFarrowRateConverterTransform(inData)
% dspFarrowRateConverterTransform populates the legacy parameter
% EnableVarSize to false.

%   This is an internal function called by Simulink(R) during model load.

% Copyright 2021-2022 The MathWorks, Inc.

instanceData = inData.InstanceData;
outData.NewInstanceData = instanceData;

EnableVarSizeIdx = find(ismember({instanceData.Name},'EnableVarSize'),1);
AllowArbitraryFixedInputIdx = find(ismember({instanceData.Name},'AllowArbitraryInputLength'),1);

if ~isempty(EnableVarSizeIdx)
    % If EnableVarSize parameter exists (from R2022a models), replace it with
    % an AllowArbitraryInputLength property
    varsize = instanceData(EnableVarSizeIdx).Value;
    outData.NewInstanceData(EnableVarSizeIdx) = [];
    outData.NewInstanceData = [outData.NewInstanceData struct(Name='AllowArbitraryInputLength', Value=varsize)];
elseif isempty(AllowArbitraryFixedInputIdx)
    % Otherwise if AllowArbitrary flag does not exist (older than R2022a), create it and
    % populate the newly created AllowArbitraryInputLength with false
    outData.NewInstanceData = [outData.NewInstanceData struct(Name='AllowArbitraryInputLength', Value='off')];
end

% New block path
outData.NewBlockPath = inData.ForwardingTableEntry.('__slOldName__');