function [outData] = dspFractionalDelayTransform(inData)
% dspFractionalDelayTransform
%   This is an internal function called by Simulink(R) during model load.

% Copyright 2018 The MathWorks, Inc.

OriginalBlockPath = inData.ForwardingTableEntry.('__slOldName__');

% Call dspSlopeBiasToBinPtScalingTransform to flip
% 'Slope and bias scaling' parameter settings to 'Binary point scaling'
% for fixed-point *Mode mask parameters for new block instances.
[tmpData2] = dspSlopeBiasToBinPtScalingTransform(inData);

% Form output structure
outData = tmpData2;

if isfield(tmpData2, 'NewInstanceData')
    NewInstanceData = tmpData2.NewInstanceData;
    outData.NewInstanceData = NewInstanceData;
elseif isfield(tmpData2, 'InstanceData')
    NewInstanceData = tmpData2.InstanceData;
    outData.NewInstanceData = NewInstanceData;
else
    NewInstanceData = []; % SHOULD NOT GET HERE
end

if ~isempty(NewInstanceData)
    % Change any legacy 'InputProcessing' params
    % set to Inherited to instead be frame-based.
    for idx=1:length(NewInstanceData)
        thisMaskParamName = NewInstanceData(idx).Name;
        if strcmp(thisMaskParamName, 'InputProcessing')
          if ~isempty(strfind(NewInstanceData(idx).Value,'Inherited'))
             outData.NewInstanceData(idx).Value = ...
                 'Columns as channels (frame based)';
          end
          break; % early break out of loop
        end
    end
end

outData.NewBlockPath = OriginalBlockPath;
