function [aOutData] = dspIdentityMatrixTransform(aInData)
%

%  Copyright 2021 The MathWorks, Inc.

% Transformation function for Identity Matrix blocks

    aOutData.NewInstanceData = [];

    aOldInstanceData = aInData.InstanceData;

    aNewInstanceData(1).Name = 'InheritOutputPortAttributes';
    aNewInstanceData(2).Name = 'OutputDimensions';

    aNewInstanceData(1).Value = localGetVal(aOldInstanceData, 'Inherit','on');
    aNewInstanceData(2).Value = localGetVal(aOldInstanceData, 'N', '5');
    datatype = localGetVal(aOldInstanceData, 'dataType', 'double');
    isSigned = localGetVal(aOldInstanceData, 'isSigned', 'on');
    wordLen = localGetVal(aOldInstanceData, 'wordLen' , '16' );
    udDataType = localGetVal(aOldInstanceData, 'udDataType', 'sfix(16)');
    fracBitsMode = localGetVal(aOldInstanceData, 'fracBitsMode', 'Best precision');
    numFracBits = localGetVal(aOldInstanceData, 'numFracBits', '15');
    
    aNewInstanceData(3).Name = 'OutDataTypeStr';

    switch datatype
   
    case 'Inherit via back propagation'
        
        aNewInstanceData(3).Value = 'Inherit: Inherit via back propagation';
        
    case 'User-defined'
        if strcmp(fracBitsMode, 'Best precision')
            type = eval(udDataType);
            signOfDType = strcmp(type.Signedness,'Signed');
            fractionLength = -dspfixptbestexp(1.0, str2double(type.WordLength), int32(signOfDType));
            aNewInstanceData(3).Value = sprintf('fixdt(%d,%s,%d)',int32(signOfDType),type.WordLength,int32(fractionLength));
        else
            aNewInstanceData(3).Value = sprintf(['slDataTypeAndScale(' '''%s'',''2^(-(%s))'' ) '],udDataType,numFracBits);
        end
        
    case 'Fixed-point'
        
      if strcmp(isSigned, 'on') && strcmp(fracBitsMode,'Best precision')
          fractionLength = -dspfixptbestexp(1.0, str2double(wordLen), 1);     
          aNewInstanceData(3).Value = sprintf('fixdt(1,%s,%d)',wordLen,int32(fractionLength));
      elseif strcmp(isSigned, 'on') && strcmp(fracBitsMode,'User-defined')
          aNewInstanceData(3).Value = sprintf('fixdt(1,%s,%s)',wordLen,numFracBits);
      end
      if strcmp(isSigned, 'off') && strcmp(fracBitsMode,'Best precision')
          fractionLength = -dspfixptbestexp(1.0, str2double(wordLen), 0);
          aNewInstanceData(3).Value = sprintf('fixdt(0,%s,%d)',wordLen,int32(fractionLength));
      elseif strcmp(isSigned, 'off') && strcmp(fracBitsMode,'User-defined')
          aNewInstanceData(3).Value = sprintf('fixdt(0,%s,%s)',wordLen,numFracBits);
      end
        
        
    otherwise
        aNewInstanceData(3).Value = sprintf('%s',datatype);
        
    end

    aNewInstanceData(4).Name = 'SampleTime';
    aNewInstanceData(4).Value = localGetVal(aOldInstanceData, 'Ts','1');
    
    aOutData.NewBlockPath = 'simulink/Matrix Operations/IdentityMatrix';

    aOutData.NewInstanceData = aNewInstanceData;
end

function iParamIdx = getParamIdx(aInstanceData, prmName)
    iParamIdx = -1;
    
    for i = 1:length(aInstanceData)
        if (strcmp(aInstanceData(i).Name, prmName))
            iParamIdx = i;
            break;
        end                
    end
end

%--------------------------------------------------------------------------
function value = localGetVal(InstanceData, paramName, defaultValue)
% Attempt to get value from InstanceData. But if it is not in the
% InstanceData, set it to the library default value.

index = getParamIdx(InstanceData, paramName);
if index == -1
    value = defaultValue;
else
    value = InstanceData(index).Value;
end

end

