function [outData] = dspInheritedInpuProcessingAndFrameTransform(inData)
% Call dspInheritedInpuProcessingTransform and dspFrameOutputTransform
%
%   This is an internal function called by Simulink(R) during model load.

% Copyright 2016-2018 The MathWorks, Inc.

[outData] = dspInheritedInpuProcessingTransform(inData);
inData.InstanceData = outData.NewInstanceData;
[outData] = dspFrameOutputTransform(inData);

% Also update old models with "Coefficient source" ('filtFrom') parameter
% set to "Multirate object in workspace". New choice is: "Filter object"
outData.NewInstanceData = mapObsoleteParamSetting( ...
    outData.NewInstanceData, 'filtFrom', ...
    'Multirate object in workspace', 'Filter object');

% -------------------------------------------------------------------------
function newInstanceData = mapObsoleteParamSetting(newInstanceData, ...
                                                   parameterName,   ...
                                                   oldSetting,      ...
                                                   newSetting)
for index=1:length(newInstanceData)
    if strcmp(newInstanceData(index).Name, parameterName)
        if strcmp(newInstanceData(index).Value, oldSetting)
            % Update the parameter setting value
            newInstanceData(index).Value = newSetting;
        end
        break;
    end
end
