function [outData] = dspInheritedRateOptionsTransform(inData)
% dspInheritedRateOptionsTransform Flip RateOptions parameters set
% to Inherited to Enforce single-rate processing.
%
%   This is an internal function called by Simulink(R) during model load.

% Copyright 2016-2018 The MathWorks, Inc.

InstanceData = inData.InstanceData;
outData.NewInstanceData = InstanceData;

index = -1; % -1 Means not found
foundInherit = false;
for i=1:length(InstanceData)
    if strcmp(InstanceData(i).Name, 'RateOptions')
        index = i;
        if ~isempty(strfind(InstanceData(i).Value,'Inherit'))
           outData.NewInstanceData(i).Value =  'Enforce single-rate processing';
           foundInherit = true;
        end
        break;
    end
end

if index == -1 % No parameter found --> Inherited
  outData.NewInstanceData(end+1) =  struct('Name', 'RateOptions', 'Value', 'Inherit from input (this choice will be removed - see release notes)');
  outData.NewBlockPath = 'dspobslib/CIC Decimation';
elseif foundInherit
    outData.NewInstanceData(index) = struct('Name', 'RateOptions', 'Value', 'Inherit from input (this choice will be removed - see release notes)');
    outData.NewBlockPath = 'dspobslib/CIC Decimation';
else
    outData.NewBlockPath = inData.ForwardingTableEntry.('__slOldName__');
end

if ~strncmp(outData.NewBlockPath, 'dspobslib', 9)
    % Update old models with "Coefficient source" ('filtFrom') param set
    % to "Multirate object in workspace". New choice is: "Filter object".
    outData.NewInstanceData = mapObsoleteParamSetting( ...
        outData.NewInstanceData, 'filtFrom', ...
        'Multirate object in workspace', 'Filter object');
end

% -------------------------------------------------------------------------
function newInstanceData = mapObsoleteParamSetting(newInstanceData, ...
                                                   parameterName,   ...
                                                   oldSetting,      ...
                                                   newSetting)
for index=1:length(newInstanceData)
    if strcmp(newInstanceData(index).Name, parameterName)
        if strcmp(newInstanceData(index).Value, oldSetting)
            % Update the parameter setting value
            newInstanceData(index).Value = newSetting;
        end
        break;
    end
end
