function [outData] = dspLMSFilterTransform(inData)
% dspLMSFilterTransform
%   This is an internal function called by Simulink(R) during model load.

% Copyright 2018 The MathWorks, Inc.

% Change deprecated 'Slope and bias scaling' or 'User-defined' parameter
% settings to 'Binary point scaling'for fixed-point "*Mode" mask parameters
% for new block instances.

InstanceData            = inData.InstanceData;
outData.NewInstanceData = InstanceData;
outData.NewBlockPath    = inData.ForwardingTableEntry.('__slOldName__');

% Find old-style data type "*Mode" popup parameter names.
% Go through full mask parameter list to hit all of them.
for i=1:length(InstanceData)
    paramName  = InstanceData(i).Name;
    paramValue = InstanceData(i).Value;
    if ~isempty( regexp(paramName, 'Mode', 'once') )
        if ~( strcmp(paramName, 'roundingMode') || ...
                strcmp(paramName, 'overflowMode') )
            if strcmp(paramValue, 'Slope and bias scaling') || ...
                    strcmp(paramValue, 'User-defined')
                % Switch old deprecated mask setting value to the
                % supported 'Binary point scaling' setting value
                outData.NewInstanceData(i).Value = 'Binary point scaling';
            end
        end
    end
end
