function [outData] = dspPowerMeterTransform(inData)
% dspPowerMeterTransform maps the legacy parameter PowerUnits to
% OutputPowerUnits

%   This is an internal function called by Simulink(R) during model load.

% Copyright 2021 The MathWorks, Inc.

instanceData = inData.InstanceData;
outData.NewInstanceData = instanceData;

% Map PowerUnits to OutputPowerUnits
powerUnitsIdx = find(ismember({instanceData.Name},'PowerUnits'),1);

if ~isempty(powerUnitsIdx)
    outData.NewInstanceData(powerUnitsIdx).Name = 'OutputPowerUnits';
end

% Update the output instance with the new OverlapLength parameter =
% WindowLength - 1
OverlapLengthIdx = find(ismember({instanceData.Name},'OverlapLength'),1);
if isempty(OverlapLengthIdx)
    WindowLengthIdx = find(ismember({instanceData.Name},'WindowLength'),1);
    WindowLength = slResolve(instanceData(WindowLengthIdx).Value,gcb);
    OverlapLength = num2str(WindowLength - 1);
    outData.NewInstanceData = [outData.NewInstanceData struct('Name','OverlapLength','Value',OverlapLength)]; 
end

EnableVarSizeIdx = find(ismember({instanceData.Name},'EnableVarSize'),1);
if ~isempty(EnableVarSizeIdx)
    % If EnableVarSize parameter exists (shortlived in R2022b, never
    % exposed), replace it with an AllowArbitraryInputLength property
    varsize = instanceData(EnableVarSizeIdx).Value;
    outData.NewInstanceData(EnableVarSizeIdx) = [];
    outData.NewInstanceData = [outData.NewInstanceData struct(Name='AllowArbitraryInputLength', Value=varsize)];
end

% New block path
outData.NewBlockPath = inData.ForwardingTableEntry.('__slOldName__');