function [outData] = dspTransposeTransform(inData)
% This function is used to forward the dspmtrx3/Transpose block to the
% simulink Math Function block.

% Copyright 2014-2019 The MathWorks, Inc.

isHermitian = strcmp(localGetVal(inData.InstanceData, 'Hermitian', 'off'),'on');
% Set new block parameters
if isHermitian
    outData.NewInstanceData    = localNVPair('Operator', 'hermitian');
    outData.NewInstanceData(end+1) = localNVPair('SaturateOnIntegerOverflow', ...
                          localGetVal(inData.InstanceData, 'overflowFlag', 'off'));
else
   outData.NewInstanceData    = localNVPair('Operator', 'transpose'); 
end

outData.NewBlockPath = 'simulink/Math Operations/Math Function';

end
%--------------------------------------------------------------------------

function entry = localNVPair(name, value)
entry = struct('Name', name, 'Value', value);
end

%--------------------------------------------------------------------------

function index = localParamIndex(InstanceData, paramName)
% Search paramName for index of paramName
index = -1; % Means not found

for i=1:length(InstanceData)
    if strcmp(InstanceData(i).Name, paramName)
        index = i;
        break;
    end
end
end

%--------------------------------------------------------------------------
function value = localGetVal(InstanceData, paramName, defaultValue)
% Attempt to get value from InstanceData. But if it is not in the
% InstanceData, set it to the library default value.

index = localParamIndex(InstanceData, paramName);
if index == -1
    value = defaultValue;
else
    value = InstanceData(index).Value;
end

end