function ConstantRegisterCompileCheck(block, muObj)
% CONSTANTREGISTERCOMPILECHECK Compile check registration
% function for constant blocks that emit frames. The function makes the
% source emit sample-based outputs, and inserts a frame-conversion block to
% conserve results.
%
%  Input arguments:
%    block - handle to the block being updated
%    muObj - model updater object

% Copyright 2015-2019 The MathWorks, Inc.

appendCompileCheck(muObj, block, @CollectData, ...
    @UpdateFrameSource);
end

%--------------------------------------------------------------------------
% Collect block information under compile stage
function blkInfo = CollectData(block, ~)
% Get frameness of output signal
blkInfo.Frame = get_param(block, 'CompiledPortFrameData');
end

%--------------------------------------------------------------------------
function UpdateFrameSource(block, muObj, blkInfo)
% Post compile action:
if OKToReplace(blkInfo)
    if askToReplace(muObj, block)
        funcSet = {'insertFrameConversionBlock',block};
        reasonStr = DAStudio.message('dsp:UpgradeAdvisor:DSPSourceUpgradeReason');
        if doUpdate(muObj)
            insertFrameConversionBlock(block);
        end
        appendTransaction(muObj, block, reasonStr, {funcSet});
    end
end
end

%--------------------------------------------------------------------------
function isFrame = OKToReplace(blkInfo)
    outportFrame = blkInfo.Frame.Outport;
    if ~isempty(outportFrame) && outportFrame
        isFrame = true;
    else
        isFrame = false;
    end
end

%--------------------------------------------------------------------------
function insertFrameConversionBlock(block)
blkLHandles = get_param(block, 'LineHandles');
outPort = blkLHandles.Outport;
if ~isempty(outPort) && outPort~=-1
    InsertExtraBlock(block, get(outPort), 'Post', 80, 0,...
        'dspobslib','dspobslib/Frame Conversion',{'OutFrame'},{'Frame-based'});
end
set_param(block,'SamplingMode','Sample based');
Ts = get_param(block,'FramePeriod');
set_param(block,'SampleTime',Ts);
end
