function FrameSourceRegisterCompileCheck(block, muObj)
% FRAMESOURCEREGISTERCOMPILECHECK Compile check registration
% function for source blocks that emit frames. The function makes the
% source emit sample-based outputs, and inserts a frame-conversion block to
% conserve results.
%
%  Input arguments:
%    block - handle to the block being updated muObj - model updater object

% Copyright 2014-2019 The MathWorks, Inc.

appendCompileCheck(muObj, block, @CollectData, ...
    @UpdateFrameSource);
end

%--------------------------------------------------------------------------
% Collect block information under compile stage
function blkInfo = CollectData(block, ~)

% Get frameness, dimensions, and var-size status of input signal
blkInfo.Frame          = get_param(block, 'CompiledPortFrameData');
end
%--------------------------------------------------------------------------
function UpdateFrameSource(block, muObj, blkInfo)
% Post compile action:
if OKToReplace(block,blkInfo)
    if askToReplace(muObj, block)
        funcSet = {'insertFrameConversionBlock',block};
        reasonStr = DAStudio.message('dsp:UpgradeAdvisor:DSPSourceUpgradeReason');
        if doUpdate(muObj)
            insertFrameConversionBlock(block,blkInfo);
        end
        appendTransaction(muObj, block, reasonStr, {funcSet});
    end
end
end
%--------------------------------------------------------------------------
function flag = OKToReplace(block,blkInfo)
    inportFrame = blkInfo.Frame.Inport;
    isFrameIn = false;
    if ~isempty(inportFrame)
       if any(inportFrame)
           isFrameIn = true;
       end
    end
    flag = ~isFrameIn && any(blkInfo.Frame.Outport) && strcmp(get_param(block,'OutputFrames'),'on');
end
%--------------------------------------------------------------------------
function insertFrameConversionBlock(block,blkInfo)
blkLHandles = get_param(block, 'LineHandles');
frameInfo = blkInfo.Frame.Outport;
for count =1: length(blkLHandles.Outport)
    if frameInfo(count)
        port = blkLHandles.Outport(count);
        if isempty(port) || port == -1
           break; 
        end
        blkLHOutport = get(port);
        InsertExtraBlock(block, blkLHOutport, 'Post', 80, 0,...
            'dspobslib','dspobslib/Frame Conversion',...
            {'OutFrame'},{'Frame-based'});
    end
end
set_param(block,'OutputFrames','off');

end
