function SLInProcRegisterCompileCheck(block, muObj, varargin)
% SLINPROCREGISTERCOMPILECHECK Compile check registration function for Simulink blocks
% with an 'Input processing' popup that must be reset from an inherited mode
%
%  Input arguments:
%    block    - handle to the block being updated
%    muObj    - model updater object
%    varargin - allows the function to be called by Comms Blocks

%   Copyright 2010-2014 The MathWorks, Inc.

appendCompileCheck(muObj, block, @CollectInProcData, ...
    @UpdateInProcNewFrames);

%--------------------------------------------------------------------------
% Collect block information under compile stage
function isFrame = CollectInProcData(block, ~)

% Get frameness of input signal
tp      = get_param(block,'CompiledPortFrameData');
isFrame = tp.Inport(1);

%----------------------------------------------------------------------------
function UpdateInProcNewFrames(block, muObj, isFrame)
% Post compile action: 
% Update the InputProcessing parameter when the input is frame-based

if askToReplace(muObj, block)
    
    if isFrame
        funcSet = uSafeSetParam(muObj, block, ...
            'InputProcessing', 'Columns as channels (frame based)');
        
        reasonStr =  DAStudio.message('dsp:UpgradeAdvisor:InputProcessingReason');
    else
        funcSet = uSafeSetParam(muObj, block, ...
            'InputProcessing', 'Elements as channels (sample based)');
        
        reasonStr =  DAStudio.message('dsp:UpgradeAdvisor:DefaultInputProcessingReason');
    end
    
    appendTransaction(muObj, block, reasonStr, {funcSet});
end


% [EOF]

% LocalWords:  frameness
