function hasTunableParams = filterHasTunableParams(block)
%

%   Copyright 2016 The MathWorks, Inc.

    hasTunableParams = blockHasTunableParam(block, 'Coefficients') ...
        || blockHasTunableParam(block, 'InitialStates');
end

function ret = blockHasTunableParam(block, parameterName)
    obj = get_param(block, 'Object');
    model = bdroot(block);
    modelObject = get_param(model, 'Object');
    tunableParamNames = regexp(modelObject.TunableVars, '\w+', 'match');

    varUsage = Simulink.findVars(obj.getFullName, ...
                                    'DirectUsageDetails.Properties', parameterName, ...
                                    'SearchMethod', 'cached');
    for usageIdx = 1:numel(varUsage)
        name = varUsage(usageIdx).Name;

        pos = find(ismember(tunableParamNames,name), 1);

        if ~isempty(pos)
            ret = true;
            return;
        end
        
        if(strcmp(varUsage(usageIdx).Source, 'base workspace'))
            try
                p = slResolve(name, block, 'variable');
                if(~strcmp(p.CoderInfo.StorageClass, 'Auto'))
                    ret = true;
                    return;
                end
            catch
            end
        end
    end

    ret = false;
end
