function [mapName, relativePathToMapFile, found] = getBlockHelpMapNameAndPath(block_type)
%  Returns the mapName and the relative path to the maps file for this block_type

%  Internal note:
%   First column is the "System object name", corresponding to the block,
%   Second column is the anchor ID, the doc uses for the block.
%   For core blocks, the first column is the 'BlockType'.

% Copyright 2007-2021 The MathWorks, Inc.

    blks = {...
    'FrameConversion'                'dspframeconversion'           ;...
    'DSPFlip'                        'dspflip'                      ;...
    'Buffer'                         'dspbuffer'                    ;...
    'Unbuffer'                       'dspunbuffer'                  ;...
    'DownSample'                     'dspdownsample'                ;...
    'SignalToWorkspace'              'dspsignaltoworkspace'         ;...
    'AllpoleFilter'                  'dspallpolefilter'             ;...
    'TimeScope'                      'dsptimescope'                 ;...
    'ArrayPlot'                      'sigblksarrayplot'             ;...
    'dsp.simulink.DCBlocker'                  'dspdcblocker'                 ;...
    'dsp.simulink.TransferFunctionEstimator'  'dsptransferfunctionestimator' ;...
    'dsp.simulink.PhaseExtractor'             'dspphasextractor'             ;...
    'dsp.HDLFIRRateConverter'        'dsphdlfirrateconverter'       ;...
    'dsp.simulink.VariableBandwidthFIRFilter' 'variablebandwidthfirfilter'   ;...
    'dsp.simulink.VariableBandwidthIIRFilter' 'variablebandwidthiirfilter'   ;...
    'dsp.simulink.NotchPeakFilter'   'notchpeakfilter'              ;...
    'dsp.simulink.ParametricEQFilter'         'parametriceqfilter'           ;...
    'dsp.simulink.CrossSpectrumEstimator'     'crossspectrumsstimator'       ;...
    'dsp.simulink.DigitalDownConverter'       'dspdigitaldownconverter'      ;...
    'dsp.simulink.DigitalUpConverter'         'dspdigitalupconverter'        ;...
    'dsp.simulink.ColoredNoise'      'dspcolorednoise'              ;...
    'dsp.simulink.SampleRateConverter'        'samplerateconverter'          ;...
    'dsp.simulink.FarrowRateConverter'        'farrowrateconverter'          ;...
    'dsp.simulink.FIRHalfbandDecimator'  'firhalfbanddecimator'     ;...
    'dsp.simulink.FIRHalfbandInterpolator'    'firhalfbandinterpolator'      ;...
    'dsp.simulink.IIRHalfbandDecimator'  'iirhalfbanddecimator'     ;...
    'dsp.simulink.IIRHalfbandInterpolator'    'iirhalfbandinterpolator'      ;...
    'dsp.simulink.CICCompensationDecimator'   'ciccompensationdecimator'     ;...
    'dsp.simulink.CICCompensationInterpolator' 'ciccompensationinterpolator' ;...
    'dsp.simulink.LowpassFilter'              'lowpassfilter'                ;...
    'dsp.simulink.HighpassFilter'             'highpassfilter'               ;...
    'dsp.simulink.SVD'               'dspsingularvaluedecomposition';...
    'dsp.simulink.MedianFilter'               'medianfilter'                 ;...
    'dsp.simulink.Differentiator'             'differentiator'               ;...
    'dsp.simulink.Pseudoinverse'     'dsppseudoinverse'             ;...
    'dsp.simulink.PolynomialStabilityTest'     'dsppolynomialstabilitytest'   ;...
    'dsp.simulink.ExtractTriangularMatrix'     'dspextracttriangularmatrix'   ;...
    'dsp.simulink.MovingMinimum'              'movingminimum'                ;...
    'dsp.simulink.MovingMaximum'              'movingmaximum'                ;...
    'dsp.simulink.MovingAverage'     'movingaverage'                ;...
    'dsp.simulink.MovingRMS'         'movingrms'                    ;...
    'dsp.simulink.MovingVariance'    'movingvariance'               ;...
    'dsp.simulink.PowerMeter'                     'powermeter'                   ;...
    'dsp.simulink.MovingStandardDeviation'    'movingstandarddeviation'      ;...
    'dsp.simulink.AllpassFilter'     'allpassfilter'                ;...
    'dsp.simulink.LMSUpdate'          'lmsupdate'                    ;...
    'dsp.simulink.Channelizer'        'channelizer'                  ;...
    'dsp.simulink.ChannelSynthesizer' 'channelsynthesizer'           ;...
    'dsp.simulink.HampelFilter'      'hampelfilter'                 ;...
    'dsp.simulink.ZoomFFT'           'zoomfft'                      ;...
    'dsp.simulink.FrequencyDomainFIRFilter'           'frequencydomainfirfilter'                      ;...
    'dsp.simulink.ComplexBandpassDecimator'           'complexbandpassdecimator'                      ;...
    'dsp.simulink.FrequencyDomainAdaptiveFilter'           'frequencydomainadaptivefilter'                      ;...
    'Dataflow Subsystem'             'dataflowsubsystem'            ;...
    'dsp.simulink.QRSolver'          'dspqrsolver';...
    'dsp.simulink.QRFactorization'   'dspqrfactorization'           ;...
    'dsp.simulink.BinaryFileWriter'  'dspdspsimulinkbinaryfilewriter';...
    'dsp.simulink.FourthOrderSectionFilter'   'fourthordersectionfilter'   ;...
    };

relativePathToMapFile = '/dsp/dsp.map';
found = false;
% See whether or not the block is a DSP System Toolbox core or built-in
i = strcmp(block_type, blks(:,1));

if ~any(i)
    mapName = 'User Defined';
else
    found = true;
    mapName = blks(i,2);
end
