function fixedPointInfo = getCompiledFixedPointInfo(blk)
    % GETCOMPILEDFIXEDPOINTINFO Get the block's compiled fixed-point
    % information
    %
    % blk: Block handle
    
    %   Copyright 2014 The MathWorks, Inc.
    
    errUsage = false;
    if strcmpi(get_param(blk, 'BlockType'), 'S-Function')
        UserData = get_param(blk,'UserData');
        if isfield(UserData, 'fixedPointInfo')
            tmpStruct = UserData.fixedPointInfo;
            fn = fieldnames(tmpStruct);
            for idx=1:numel(fn)
                tmpVec = tmpStruct.(fn{idx});
                fixedPointInfo.(fn{idx}) = numerictype(tmpVec(1), tmpVec(2), tmpVec(3));
            end
        else
            errUsage = true;
        end
        
    elseif strcmpi(get_param(blk, 'BlockType'), 'DiscreteFir')
        
        if strcmpi(get_param(blk,'FilterStructure'), 'Lattice MA')
            props = {'ReflectionCoefficientsDataType', 'ProductDataType', ...
                'AccumulatorDataType','StateDataType', 'OutputDataType'};
            coreBlkParamNames = {'CoefDataTypeName', 'ProductDataTypeName', ...
                'AccumDataTypeName','StateDataTypeName', 'OutDataTypeName'};            
        elseif strcmpi(get_param(blk,'FilterStructure'), 'Direct form Symmetric') || ...
                strcmpi(get_param(blk,'FilterStructure'), 'Direct form antiSymmetric')
            props = {'CoefficientsDataType', 'TapSumDataType', 'ProductDataType', ...
                'AccumulatorDataType', 'OutputDataType'};
            coreBlkParamNames = {'CoefDataTypeName', 'TapSumDataTypeName', 'ProductDataTypeName', ...
                'AccumDataTypeName', 'OutDataTypeName'};
        else
            props = {'CoefficientsDataType', 'ProductDataType', ...
                'AccumulatorDataType', 'OutputDataType'};
            coreBlkParamNames = {'CoefDataTypeName', 'ProductDataTypeName', ...
                'AccumDataTypeName', 'OutDataTypeName'};
        end
        fixedPointInfo = localGetCompiledFixedPointInfoFromCoreBlk(blk, props, coreBlkParamNames);
        
%     elseif strcmpi(get_param(blk, 'BlockType'), 'DiscreteFilter')
% 
%         props = {'Fill in this list'};
%         coreBlkParamNames = {'Fill in this list'};
%         fixedPointInfo = localGetCompiledFixedPointInfoFromCoreBlk(blk, props, coreBlkParamNames);

    else
        errUsage = true;
    end
    if errUsage
        error(message('dsp:block:BlockNotSupported'));
    end
end

function fixedPointInfo = localGetCompiledFixedPointInfoFromCoreBlk(blk, props, coreBlkParamNames)
    blkObj = get_param(blk, 'Object');
    fixedPointInfo = struct;
    for idx=1:length(props)
        fixedPointInfo.(props{idx}) = numerictype(blkObj.(coreBlkParamNames{idx}));
    end
end