function value = getNumWelchOverlapSamples(WindowLength , OverlapPercent)
% This function is used in the mask init code of the Spectrum Estimator,
% Cross-Spectrum Estimator and Discrete Transfer Functon Estimator blocks

% Determine the number of overlap samples on the buffer based on the window
% length and the overlap percentage.

%   Copyright 2015 The MathWorks, Inc.

numSamples = WindowLength*OverlapPercent/100;
upperNumSamples = ceil(numSamples);
lowerNumSamples = floor(numSamples);
percentDiff1 = abs((upperNumSamples*100/WindowLength)-OverlapPercent);
percentDiff2 = abs((lowerNumSamples*100/WindowLength)-OverlapPercent);
if percentDiff1 < percentDiff2
    value = upperNumSamples;
else
    value = lowerNumSamples;
end
if (value == WindowLength)
    % If the number of overlap samples is equal to the segment length,
    % the buffer sets the number of overlap samples to SL-1
    value = WindowLength - 1;
end