function dopts = designoptions(this, dmethod, varargin)
%DESIGNOPTIONS

%   Copyright 2005-2022 The MathWorks, Inc.

if nargin < 2
    error(message('dsp:fdesign:abstractmultirate2:designoptions:notEnoughInputs', inputname( 1 )));
end

% Parse the SystemObject input
sysObjFlag = validatedesignoptionssysobjinput(this,varargin{:});

dopts = designoptions(this.CurrentFDesign, dmethod);

if isempty(fieldnames(dopts))
    return;
end

rcf = getratechangefactors(this);

if ~any(rcf == 1)
    % RSRC
    if ~any(strcmpi('firsrc', dopts.FilterStructure))
        dopts.FilterStructure = {'firsrc'};
    end
elseif rcf(1) < rcf(2)
    % Decimator
    if ~strcmpi(this.Response,'cic')
      if isempty(intersect({'firdecim', 'firtdecim'}, ...
          dopts.FilterStructure)) || ...
          isequal({'firdecim','firinterp','firtdecim'},...
          intersect(dopts.FilterStructure,{'firinterp','firdecim','firtdecim'}))
        dopts.FilterStructure = {'firdecim', 'firtdecim'};
      end
      if any(strcmpi(designmethods(this, 'iir'), dmethod))
        dopts.FilterStructure = {'iirdecim','iirwdfdecim'};
      end
    end
else
    % Interpolator
    if ~strcmpi(this.Response,'cic')
      if isempty(intersect({'firinterp'}, dopts.FilterStructure))
        dopts.FilterStructure = {'firinterp'};
      elseif isequal({'firdecim','firinterp','firtdecim'},...
          intersect(dopts.FilterStructure,{'firinterp','firdecim','firtdecim'}))
        dopts.FilterStructure = {'firinterp'};
      end
      if any(strcmpi(designmethods(this, 'iir'), dmethod))
        dopts.FilterStructure = {'iirinterp','iirwdfinterp'};
      end
    end
end

if isfield(dopts,'FilterStructure')
  dopts.DefaultFilterStructure = dopts.FilterStructure{1};
  
  % If SystemObject parameter was passed as an input with a value of true,
  % then remove structures that are not supported by System objects.
  if sysObjFlag
    hf = feval(getdesignobj(getcurrentspecs(this),dmethod));
    supportedStructs = getsysobjsupportedstructs(hf);
    [s,k] = intersect(dopts.FilterStructure,supportedStructs);
    if isempty(s)
      % Error out if none of the structures is supported by System objects
      error(message('dsp:fdesign:basecatalog:NoSupportedSysObj',dmethod,'''SystemObject'''))
    end
    dopts.FilterStructure = dopts.FilterStructure(sort(k));
  end
end


% [EOF]
