function [specList] = getspeclist(response)
%GETSPECLIST Get list of spec strings

%   Copyright 2013-2019 The MathWorks, Inc.

% List for Lowpass

allowedResponses = {'Arbitrary Magnitude','Arbitrary Magnitude and Phase',...
  'Bandpass','Bandstop','CIC','CIC Compensator','Differentiator','Gaussian',...
  'Halfband','Highpass','Hilbert','Inverse-sinc Lowpass',...
  'Inverse-sinc Highpass','Lowpass','Nyquist','Raised Cosine','Square Root Raised Cosine'};

response = validatestring(response,allowedResponses,'','Response');

switch response

  case 'Arbitrary Magnitude'
    specList = {...
    'N,F,A',...
    'N,B,F,A',...
    'N,B,F,A,C',...
    'F,A,R',...
    'B,F,A,R'};
  
  case 'Arbitrary Magnitude and Phase'
    specList = {...
    'N,F,H',...
    'N,B,F,H'};
  
  case 'Bandpass'
    specList = {...
    'Fst1,Fp1,Fp2,Fst2,Ast1,Ap,Ast2',...
    'N,Fc1,Fc2',...
    'N,Fc1,Fc2,Ast1,Ap,Ast2',...
    'N,Fst1,Fp1,Fp2,Fst2',...
    'N,Fst1,Fp1,Fp2,Fst2,C'};
  
  case 'Bandstop'
    specList = {...
    'Fp1,Fst1,Fst2,Fp2,Ap1,Ast,Ap2',...
    'N,Fc1,Fc2',...
    'N,Fc1,Fc2,Ap1,Ast,Ap2',...
    'N,Fp1,Fst1,Fst2,Fp2',...
    'N,Fp1,Fst1,Fst2,Fp2,C'};
  
   case 'CIC'
    specList = {...
    'Fp,Ast'};
  
   case 'CIC Compensator'
    specList = {...
    'Fp,Fst,Ap,Ast',...
    'N,Fc,Ap,Ast',...
    'N,Fp,Ap,Ast',...
    'N,Fp,Fst',...
    'N,Fst,Ap,Ast'};
  
   case 'Differentiator'
    specList = {...
    'N',...
    'N,Fp,Fst',...
    'N,Fp,Fst,Ap',...
    'N,Fp,Fst,Ast',...
    'Ap',...
    'Fp,Fst,Ap,Ast'};
  
   case 'Gaussian'
    specList = {...
    'Nsym,BT'};
  
   case 'Halfband'
    specList = {...
    'TW,Ast',...
    'N',...
    'N,Ast',...
    'N,TW'};

   case 'Highpass'
    specList = {...
     'Fst,Fp,Ast,Ap',...
    'N,Fc',...
    'N,F3dB',...
    'N,Fc,Ast,Ap',...
    'N,Fp,Ast,Ap',...
    'N,Fst,Fp,Ap',...
    'N,Fst,Fp,Ast',...
    'N,Fst,Ast,Ap',...
    'N,Fst,Fp'};
  
   case 'Hilbert'
    specList = {...
    'N,TW',...
    'TW,Ap'};

   case 'Inverse-sinc Lowpass'
    specList = {...
    'Fp,Fst,Ap,Ast',...
    'N,Fc,Ap,Ast',...
    'N,Fp,Ap,Ast',...
    'N,Fp,Fst',...
    'N,Fst,Ap,Ast'};

   case 'Inverse-sinc Highpass'
    specList = {...
    'Fst,Fp,Ast,Ap',...
    'N,Fc,Ast,Ap',...
    'N,Fp,Ast,Ap',...
    'N,Fst,Fp',...
    'N,Fst,Ast,Ap',...
    };
  
    case 'Lowpass'
    specList = {...
    'Fp,Fst,Ap,Ast',...
    'N,Fc',...
    'N,F3dB',...
    'N,Fc,Ap,Ast',...
    'N,Fp,Ap,Ast',...
    'N,Fp,Fst',...
    'N,Fp,Fst,Ap',...
    'N,Fp,Fst,Ast',...
    'N,Fst,Ap,Ast'};

   case 'Nyquist'
    specList = {...
    'TW,Ast',...
    'N',...
    'N,Ast',...
    'N,TW'};
  
  case 'Raised Cosine'
    specList = {...
    'Ast,Beta',...
    'Nsym,Beta',...
    'N,Beta'};
  
  case 'Square Root Raised Cosine'
    specList = {...
    'Ast,Beta',...
    'Nsym,Beta',...
    'N,Beta'};

end
