classdef (Abstract) abstractlpnorm < fmethod.abstractiirwsos
%fdfmethod.abstractlpnorm class
%   fdfmethod.abstractlpnorm extends fmethod.abstractiir.
%
%    fdfmethod.abstractlpnorm properties:
%       DesignAlgorithm - Property is of type 'ustring' (read only) 
%       FilterStructure - Property is of type 'ustring'  
%       Norm - Property is of type 'posdouble user-defined'  
%       DensityFactor - Property is of type 'double'  
%       MaxPoleRadius - Property is of type 'posdouble user-defined'  
%       InitNorm - Property is of type 'posdouble user-defined'  
%       InitNum - Property is of type 'mxArray'  
%       InitDen - Property is of type 'mxArray'  
%       SOSScaleNorm - Property is of type 'ustring'  
%       SOSScaleOpts - Property is of type 'fdopts.sosscaling'  
%
%    fdfmethod.abstractlpnorm methods:
%       actualdesign -   Perform the actual design.
%       createobj -   Create the object from the coefficients
%       getvalidstructs -   Get the validstructs.
%       isconstrained -   True if the object is constrained.
%       parseic - Make sure InitNum and InitDen are of the correct length
%       set_weights -   PreSet function for weights properties.


properties (AbortSet, SetObservable, GetObservable)
    %NORM Property is of type 'posdouble user-defined' 
    Norm = 128;
    %DENSITYFACTOR Property is of type 'double' 
    DensityFactor = 20;
    %MAXPOLERADIUS Property is of type 'posdouble user-defined' 
    MaxPoleRadius = 1;
    %INITNORM Property is of type 'posdouble user-defined' 
    InitNorm = 2;
    %INITNUM Property is of type 'mxArray' 
    InitNum = [];
    %INITDEN Property is of type 'mxArray' 
    InitDen = [];
    %SOSSCALENORM Property is of type 'ustring' 
    SOSScaleNorm = 'Linf';
    %SOSSCALEOPTS Property is of type 'fdopts.sosscaling' 
    SOSScaleOpts;
end


    methods 
        
        function this = abstractlpnorm
           this.SOSScaleOpts = fdopts.sosscaling;
        end
        
        function set.Norm(obj,value)
        % User-defined DataType = 'posdouble user-defined'
        obj.Norm = set_norm(obj,value);
        end

        function set.DensityFactor(obj,value)
            % DataType = 'double'
        validateattributes(value,{'double'}, {'scalar'},'','DensityFactor')
        obj.DensityFactor = set_densityfactor(obj,value);
        end

        function set.MaxPoleRadius(obj,value)
        % User-defined DataType = 'posdouble user-defined'
        obj.MaxPoleRadius = set_maxpoleradius(obj,value);
        end

        function set.InitNorm(obj,value)
        % User-defined DataType = 'posdouble user-defined'
        obj.InitNorm = set_initnorm(obj,value);
        end

        function set.InitNum(obj,value)
        obj.InitNum = value;
        end

        function set.InitDen(obj,value)
        obj.InitDen = value;
        end

        function set.SOSScaleNorm(obj,value)
            % DataType = 'ustring'
        obj.SOSScaleNorm = set_sosscalenorm(obj,value);
        end

        function set.SOSScaleOpts(obj,value)
            % DataType = 'fdopts.sosscaling'
        validateattributes(value,{'fdopts.sosscaling'}, {'scalar'},'','SOSScaleOpts')
        obj.SOSScaleOpts = set_sosscaleopts(obj,value);
        end

    end   % set and get functions 

    methods  % public methods
    varargout = actualdesign(this,hspecs,varargin)
    Hd = createobj(this,coeffs)
    validstructs = getvalidstructs(this)
    b = isconstrained(this)
    args = parseic(this,args,NumOrder,DenOrder)
    w = set_weights(this,w)
end  % public methods 


    methods (Hidden) % possibly private or hidden
    help_initden(~)
    help_lpnorm(this)
    help_maxpole(~)
    d = set_densityfactor(~,d)
    p = set_initnorm(~,p)
    m = set_maxpoleradius(~,m)
    p = set_norm(~,p)
    norm = set_sosscalenorm(this,norm)
    opts = set_sosscaleopts(this,opts)
end  % possibly private or hidden 

end  % classdef

