classdef eqripbsmin < fmethod.abstracteqripbsmin
%fdfmethod.eqripbsmin class
%   fdfmethod.eqripbsmin extends fmethod.abstracteqripbsmin.
%
%    fdfmethod.eqripbsmin properties:
%       DesignAlgorithm - Property is of type 'ustring' (read only) 
%       FilterStructure - Property is of type 'ustring'  
%       DensityFactor - Property is of type 'double'  
%       MinPhase - Property is of type 'bool'  
%       MaxPhase - Property is of type 'bool'  
%       UniformGrid - Property is of type 'bool'  
%
%    fdfmethod.eqripbsmin methods:
%       designargs -   Return the arguments for the design method.
%       get_maxphase - PreGet function for the 'maxphase' property.
%       set_UniformGrid -   PreSet function for the 'UniformGrid' property.
%       thisset_maxphase - SET_MAXPHASE   PreSet function for the 'maxphase' property.

%   Copyright 2015-2020 The MathWorks, Inc.


properties (Access=protected, AbortSet, SetObservable, GetObservable)
    %PRIVMAXPHASE Property is of type 'bool'
    privMaxPhase = false;
end

properties (SetAccess=protected, AbortSet, SetObservable, GetObservable, Hidden)
    %PRIVUGRIDFLAG Property is of type 'int' (hidden)
    privUGridFlag = 2;
end

properties (Transient, SetObservable, GetObservable)
    %MAXPHASE Property is of type 'bool' 
    MaxPhase
    %UNIFORMGRID Property is of type 'bool' 
    UniformGrid = true;
end


    methods  % constructor block
        function this = eqripbsmin
        %EQRIPBSMIN   Construct an EQRIPBSMIN object.
        
        %   Author(s): J. Schickler
        
        % this = fdfmethod.eqripbsmin;
        
        this.DesignAlgorithm = 'Equiripple';
        
        
        end  % eqripbsmin
        
    end  % constructor block

    methods 
        function value = get.MaxPhase(obj)
        value = get_maxphase(obj,obj.MaxPhase);
        end
        function set.MaxPhase(obj,value)
        validateattributes(value,{'logical','numeric'}, {'scalar'},'','MaxPhase')
        obj.MaxPhase = set_maxphase(obj,logical(value));
        end

        function set.privMaxPhase(obj,value)
            % DataType = 'bool'
        validateattributes(value,{'logical'}, {'scalar'},'','privMaxPhase')
        obj.privMaxPhase = value;
        end

        function set.UniformGrid(obj,value)
            % DataType = 'bool'
        validateattributes(value,{'logical','numeric'}, {'scalar'},'','UniformGrid')
        obj.UniformGrid = set_UniformGrid(obj,value);
        end

        function set.privUGridFlag(obj,value)
            % DataType = 'int'
        validateattributes(value,{'numeric'},{'scalar'},'','privUGridFlag')
        value = round(value); %  round to obtain an integer
        obj.privUGridFlag = value;
        end

    end   % set and get functions 

    methods  % public methods
    args = designargs(this,hs)
    maxphase = get_maxphase(this,~)
    ugrid = set_UniformGrid(this,ugrid)
    maxphase = thisset_maxphase(this,maxphase)
end  % public methods 


    methods (Hidden) % possibly private or hidden
    help(this)
    help_uniformgrid(~)
    s = thisdesignopts(~,s)
end  % possibly private or hidden 

end  % classdef

