classdef eqriphbmin < fdfmethod.abstracteqriphb
%fdfmethod.eqriphbmin class
%   fdfmethod.eqriphbmin extends fdfmethod.abstracteqriphb.
%
%    fdfmethod.eqriphbmin properties:
%       DesignAlgorithm - Property is of type 'ustring' (read only) 
%       FilterStructure - Property is of type 'ustring'  
%       DensityFactor - Property is of type 'double'  
%       MinPhase - Property is of type 'bool'  
%       StopbandShape - Property is of type 'stopbandshapes enumeration: {'flat','linear','1/f'}'  
%       StopbandDecay - Property is of type 'double'  
%
%    fdfmethod.eqriphbmin methods:
%       convert2specword - Convert minimum order spec to spec with order for
%       getexamples - Get the examples.
%       getfresp -   Get the fresp.
%       searchmincoeffwl - Search for min. coeff wordlength.

%   Copyright 2015-2020 The MathWorks, Inc.


properties (AbortSet, SetObservable, GetObservable)
    %STOPBANDSHAPE Property is of type 'stopbandshapes enumeration: {'flat','linear','1/f'}' 
    StopbandShape = 'flat';
    %STOPBANDDECAY Property is of type 'double' 
    StopbandDecay = 0;
end


    methods  % constructor block
        function h = eqriphbmin
        %EQRIPHBMIN   Construct an EQRIPHBMIN object.
        
        %   Author(s): R. Losada
        
        % h = fdfmethod.eqriphbmin;
        
        h.DesignAlgorithm = 'Equiripple';
        
        
        end  % eqriphbmin
        
    end  % constructor block

    methods 
        
        function vals = getAllowedStringValues(~,prop)
            switch prop
                case 'StopbandShape'
                    vals = {'flat','linear','1/f'};
                otherwise
                    vals = {};
            end
        end
        
        function varargout = set(obj,varargin)
            [varargout{1:nargout}] = signal.internal.signalset(obj,varargin{:});
        end
        
        function set.StopbandShape(obj,value)
        value = validatestring(value,getAllowedStringValues(obj,'StopbandShape'),'','StopbandShape');
        obj.StopbandShape = value;
        end

        function set.StopbandDecay(obj,value)
            % DataType = 'double'
        validateattributes(value,{'double'}, {'scalar'},'','StopbandDecay')
        obj.StopbandDecay = value;
        end

    end   % set and get functions 

    methods  % public methods
    [fspecsword,dm,dopts,Nstep] = convert2specword(this,cfspecs,N)
    examples = getexamples(this)
    fresp = getfresp(this)
    Hbest = searchmincoeffwl(this,args,varargin)
end  % public methods 


    methods (Hidden) % possibly private or hidden
    dev = computedev(h,hs)
    args = designargs(h,hs)
    help(this)
    str = validspecobj(h)
end  % possibly private or hidden 

end  % classdef

