classdef eqriphbordntw < fdfmethod.abstracteqriphb
%fdfmethod.eqriphbordntw class
%   fdfmethod.eqriphbordntw extends fdfmethod.abstracteqriphb.
%
%    fdfmethod.eqriphbordntw properties:
%       DesignAlgorithm - Property is of type 'ustring' (read only) 
%       FilterStructure - Property is of type 'ustring'  
%       DensityFactor - Property is of type 'double'  
%       MinPhase - Property is of type 'bool'  
%       ZeroPhase - Property is of type 'bool'  
%       StopbandShape - Property is of type 'stopbandshapes enumeration: {'flat','linear','1/f'}'  
%       StopbandDecay - Property is of type 'double'  
%
%    fdfmethod.eqriphbordntw methods:
%       getexamples - Get the examples.
%       getfresp -   Get the fresp.

%   Copyright 2015-2020 The MathWorks, Inc.


properties (AbortSet, SetObservable, GetObservable)
    %ZEROPHASE Property is of type 'bool' 
    ZeroPhase = false;
    %STOPBANDSHAPE Property is of type 'stopbandshapes enumeration: {'flat','linear','1/f'}' 
    StopbandShape = 'flat';
    %STOPBANDDECAY Property is of type 'double' 
    StopbandDecay = 0;
end


    methods  % constructor block
        function h = eqriphbordntw
        %EQRIPHBORDNTW   Construct an EQRIPHBORDNTW object.
        
        %   Author(s): R. Losada
        
        % h = fdfmethod.eqriphbordntw;
        
        h.DesignAlgorithm = 'Equiripple';
        
        end  % eqriphbordntw
        
    end  % constructor block

    methods 
        function set.ZeroPhase(obj,value)
            % DataType = 'bool'
        validateattributes(value,{'logical'}, {'scalar'},'','ZeroPhase')
        obj.ZeroPhase = value;
        end
        
        function vals = getAllowedStringValues(~,prop)
            switch prop
                case 'StopbandShape'
                    vals = {'flat','linear','1/f'};
                otherwise
                    vals = {};
            end
        end
        
        function varargout = set(obj,varargin)
            [varargout{1:nargout}] = signal.internal.signalset(obj,varargin{:});
        end
        
        function set.StopbandShape(obj,value)
        value = validatestring(value,getAllowedStringValues(obj,'StopbandShape'),'','StopbandShape');
        obj.StopbandShape = value;
        end

        function set.StopbandDecay(obj,value)
            % DataType = 'double'
        validateattributes(value,{'double'}, {'scalar'},'','StopbandDecay')
        obj.StopbandDecay = value;
        end

    end   % set and get functions 

    methods  % public methods
    examples = getexamples(this)
    fresp = getfresp(this)
end  % public methods 


    methods (Hidden) % possibly private or hidden
    b = actualdesign(this,hs)
    args = designargs(h,hs)
    help(this)
    help_limitedstopband(this)
    help_zerophase(this)
    str = validspecobj(h)
end  % possibly private or hidden 

end  % classdef

