classdef eqriphpmin < fdfmethod.abstracteqriphpmin
%fdfmethod.eqriphpmin class
%   fdfmethod.eqriphpmin extends fdfmethod.abstracteqriphpmin.
%
%    fdfmethod.eqriphpmin properties:
%       DesignAlgorithm - Property is of type 'ustring' (read only) 
%       FilterStructure - Property is of type 'ustring'  
%       DensityFactor - Property is of type 'double'  
%       MinPhase - Property is of type 'bool'  
%       MaxPhase - Property is of type 'bool'  
%       MinOrder - Property is of type 'minorderrestrict enumeration: {'any','even','odd'}'  
%       StopbandShape - Property is of type 'stopbandshapes enumeration: {'flat','linear','1/f'}'  
%       StopbandDecay - Property is of type 'double'  
%       UniformGrid - Property is of type 'bool'  
%
%    fdfmethod.eqriphpmin methods:
%       convert2specword - Convert minimum order spec to spec with order for
%       designargs - Return the arguments for the design method.
%       searchmincoeffwl - Search for min. coeff wordlength.
%       set_UniformGrid -   PreSet function for the 'UniformGrid' property.

%   Copyright 2015-2020 The MathWorks, Inc.


properties (SetAccess=protected, AbortSet, SetObservable, GetObservable, Hidden)
    %PRIVUGRIDFLAG Property is of type 'int' (hidden)
    privUGridFlag = 2;
end

properties (Transient, SetObservable, GetObservable)
    %UNIFORMGRID Property is of type 'bool' 
    UniformGrid = true;
end


methods  % constructor block
    function this = eqriphpmin
        %EQRIPHPMIN   Construct an EQRIPHPMIN object.
        
        %   Author(s): J. Schickler
        
        % this = fdfmethod.eqriphpmin;
        
        this.DesignAlgorithm = 'Equiripple';
        
        
    end  % eqriphpmin
    
    %------------------------------------------------------------------------
    function varargout = set(obj,varargin)
        [varargout{1:nargout}] = signal.internal.signalset(obj,varargin{:});
    end
    
end  % constructor block

    methods 
        function set.UniformGrid(obj,value)
            % DataType = 'bool'
        validateattributes(value,{'logical','numeric'}, {'scalar'},'','UniformGrid')
        obj.UniformGrid = set_UniformGrid(obj,value);
        end

        function set.privUGridFlag(obj,value)
            % DataType = 'int'
        validateattributes(value,{'numeric'},{'scalar'},'','privUGridFlag')
        value = round(value); %  round to obtain an integer
        obj.privUGridFlag = value;
        end

    end   % set and get functions 

    methods  % public methods
    [fspecsword,dm,dopts,Nstep] = convert2specword(cfmethod,cfspecs,N)
    args = designargs(this,hspecs)
    Hbest = searchmincoeffwl(this,args,varargin)
    ugrid = set_UniformGrid(this,ugrid)
end  % public methods 


    methods (Hidden) % possibly private or hidden
    help(this)
    help_uniformgrid(~)
end  % possibly private or hidden 

end  % classdef

