classdef eqriplp < fdfmethod.abstracteqriplp
%fdfmethod.eqriplp class
%   fdfmethod.eqriplp extends fdfmethod.abstracteqriplp.
%
%    fdfmethod.eqriplp properties:
%       DesignAlgorithm - Property is of type 'ustring' (read only) 
%       FilterStructure - Property is of type 'ustring'  
%       DensityFactor - Property is of type 'double'  
%       MinPhase - Property is of type 'bool'  
%       Wpass - Property is of type 'posdouble user-defined'  
%       Wstop - Property is of type 'posdouble user-defined'  
%       MaxPhase - Property is of type 'bool'  
%       StopbandShape - Property is of type 'stopbandshapes enumeration: {'flat','linear','1/f'}'  
%       StopbandDecay - Property is of type 'double'  
%       UniformGrid - Property is of type 'bool'  
%
%    fdfmethod.eqriplp methods:
%       designargs -   Return the arguments for the design method.
%       set_UniformGrid -   PreSet function for the 'UniformGrid' property.

%   Copyright 2015-2020 The MathWorks, Inc.


properties (SetAccess=protected, AbortSet, SetObservable, GetObservable, Hidden)
    %PRIVUGRIDFLAG Property is of type 'int' (hidden)
    privUGridFlag = 2;
end

properties (Transient, SetObservable, GetObservable)
    %UNIFORMGRID Property is of type 'bool' 
    UniformGrid = true;
end


    methods  % constructor block
        function this = eqriplp
        %EQRIPLP   Construct an EQRIPLP object.
        
        %   Author(s): J. Schickler
        
        % this = fdfmethod.eqriplp;
        
        this.DesignAlgorithm = 'Equiripple';
        
        
        end  % eqriplp
        
    end  % constructor block

    methods 
        function set.UniformGrid(obj,value)
            % DataType = 'bool'
        validateattributes(value,{'logical','numeric'}, {'scalar'},'','UniformGrid')
        obj.UniformGrid = set_UniformGrid(obj,value);
        end

        function set.privUGridFlag(obj,value)
            % DataType = 'int'
        validateattributes(value,{'numeric'},{'scalar'},'','privUGridFlag')
        value = round(value); %  round to obtain an integer
        obj.privUGridFlag = value;
        end

    end   % set and get functions 

    methods  % public methods
    args = designargs(this,hs)
    ugrid = set_UniformGrid(this,ugrid)
end  % public methods 


    methods (Hidden) % possibly private or hidden
    help(this)
    help_uniformgrid(this)
    s = thisdesignopts(this,s)
end  % possibly private or hidden 

end  % classdef

