classdef multistage < fdfmethod.abstractnstages
%fdfmethod.multistage class
%   fdfmethod.multistage extends fdfmethod.abstractnstages.
%
%    fdfmethod.multistage properties:
%       DesignAlgorithm - Property is of type 'ustring' (read only) 
%       FilterStructure - Property is of type 'ustring'  
%       rcf - Property is of type 'int'  
%       NStages - Property is of type 'mxArray'  
%       UseHalfbands - Property is of type 'bool'  
%       HalfbandDesignMethod - Property is of type 'HalfbandFilterDesignMethods enumeration: {'equiripple','kaiserwin','butter','ellip','iirlinphase'}'  
%
%    fdfmethod.multistage methods:
%       actualdesign -   Perform the actual design.
%       validspecobj -   Returns the name of the valid specification object.

%   Copyright 2015-2022 The MathWorks, Inc.


properties (AbortSet, SetObservable, GetObservable)
    %USEHALFBANDS Property is of type 'bool' 
    UseHalfbands = false;
    %HALFBANDDESIGNMETHOD Property is of type 'HalfbandFilterDesignMethods enumeration: {'equiripple','kaiserwin','butter','ellip','iirlinphase'}' 
    HalfbandDesignMethod = 'equiripple';
end


methods  % constructor block
    function this = multistage
        %MULTISTAGE   Construct a MULTISTAGE object.

        %   Author(s): R. Losada

        % this = fdfmethod.multistage;

        this.DesignAlgorithm = 'Multistage equiripple';


    end  % multistage

end  % constructor block

methods
    function set.UseHalfbands(obj,value)
        % DataType = 'bool'
        validateattributes(value,{'logical'}, {'scalar'},'','UseHalfbands')
        obj.UseHalfbands = value;
    end

    function vals = getAllowedStringValues(~,prop)
        switch prop
            case 'HalfbandDesignMethod'
                vals = {'equiripple','kaiserwin','butter','ellip','iirlinphase'};
            otherwise
                vals = {};
        end
    end

    function varargout = set(obj,varargin)
        [varargout{1:nargout}] = signal.internal.signalset(obj,varargin{:});
    end

    function set.HalfbandDesignMethod(obj,value)
        value = validatestring(value,getAllowedStringValues(obj,'HalfbandDesignMethod'),'','HalfbandDesignMethod');
        obj.HalfbandDesignMethod = value;
    end

end   % set and get functions

methods  % public methods
    varargout = actualdesign(this,hs,varargin)
    str = validspecobj(this)
end   % public methods


methods (Hidden) % possibly private or hidden
    help(this)
end  % possibly private or hidden

end  % classdef

