classdef multistagenyq < fdfmethod.abstractnstages
%fdfmethod.multistagenyq class
%   fdfmethod.multistagenyq extends fdfmethod.abstractnstages.
%
%    fdfmethod.multistagenyq properties:
%       DesignAlgorithm - Property is of type 'ustring' (read only) 
%       FilterStructure - Property is of type 'ustring'  
%       rcf - Property is of type 'int'  
%       NStages - Property is of type 'mxArray'  
%       HalfbandDesignMethod - Property is of type 'HalfbandFilterDesignMethods enumeration: {'equiripple','kaiserwin','butter','ellip','iirlinphase'}'  
%
%    fdfmethod.multistagenyq methods:
%       actualdesign -   Perform the actual design.
%       validspecobj -   Return the valid specification object.

%   Copyright 2015-2022 The MathWorks, Inc.


properties (AbortSet, SetObservable, GetObservable)
    %HALFBANDDESIGNMETHOD Property is of type 'HalfbandFilterDesignMethods enumeration: {'equiripple','kaiserwin','butter','ellip','iirlinphase'}' 
    HalfbandDesignMethod = 'equiripple';
end


methods  % constructor block
    function this = multistagenyq
        %MULTISTAGENYQ   Construct a MULTISTAGENYQ object.

        %   Author(s): R. Losada

        % this = fdfmethod.multistagenyq;

        this.DesignAlgorithm = 'Multistage equiripple';


    end  % multistagenyq

end  % constructor block

methods

    function vals = getAllowedStringValues(~,prop)
        switch prop
            case 'HalfbandDesignMethod'
                vals = {'equiripple','kaiserwin','butter','ellip','iirlinphase'};
            otherwise
                vals = {};
        end
    end

    function varargout = set(obj,varargin)
        [varargout{1:nargout}] = signal.internal.signalset(obj,varargin{:});
    end

    function set.HalfbandDesignMethod(obj,value)
        value = validatestring(value,getAllowedStringValues(obj,'HalfbandDesignMethod'),'','HalfbandDesignMethod');
        obj.HalfbandDesignMethod = value;
    end

end   % set and get functions

methods  % public methods
    varargout = actualdesign(this,hs,varargin)
    vso = validspecobj(this)
end  % public methods


methods (Hidden) % possibly private or hidden
    help(this)
end  % possibly private or hidden

end  % classdef

