function [nobj,NumStages] = designMultistageParser(varargin)
%

%   Copyright 2018 The MathWorks, Inc.

p = inputParser; 
 
p.addRequired('M');
p.addOptional('Fs',48000);
p.addOptional('TW',NaN);
p.addOptional('Astop',80);
p.addParameter('NumStages','auto');
p.addParameter('CostTolerance',1e-6);
p.addParameter('MinTotalCoeffs',false);
p.addParameter('CostMethod','estimate');

p.parse(varargin{:});
res = p.Results;

M    = double(res.M);
Fs   = double(res.Fs);
TW   = double(res.TW);
Ast  = double(res.Astop);
Ctol = double(res.CostTolerance);

if isnan(TW)
    TW = 0.2*Fs/M;
end

validateattributes(Fs,{'numeric'},{'scalar','real',...
    'finite','positive'},...
    'designMultistage','Sample Rate',2);
validateattributes(TW,{'numeric'},{'scalar','real',...
    'finite','positive','<',Fs/M},...
    'designMultistage','Transition Width',3);
validateattributes(Ast,{'numeric'},{'scalar','real',...
    'finite','positive'},...
    'designMultistage','Stopband Attenuation',4);
validateattributes(Ctol,{'numeric'},{'scalar','real',...
    'finite','nonnegative'},...
    'designMultistage','Cost Tolerance');
validateattributes(res.MinTotalCoeffs,{'logical'},{'scalar'},...
    'designMultistage','MinTotalCoeffs');
s = validatestring(res.CostMethod,{'estimate','design'},...
                'designMultistage','CostMethod'); 
            
nobj = filterdesign.internal.nyquistNstage;
nobj.SampleRate           = Fs;
nobj.TransitionWidth      = TW;
nobj.Astop                = Ast;
nobj.RateChangeFactor     = M;
nobj.CostTol              = Ctol;
nobj.MinTotalCoeffs       = res.MinTotalCoeffs;
nobj.HalfbandDesignMethod = 'equiripple';
nobj.NyquistDesignMethod  = 'equiripple';
nobj.CostTiebreaker       = 'NumCoeffs';
nobj.CostMeasure          = s;

NumStages = res.NumStages;
