function b = designNyquistMinOrder(maxLM,tw,Astop)
% DESIGNNYQUISTMINORDER Design nyquist min order filter

%   Copyright 2019-2022 The MathWorks, Inc.

%#codegen

coder.varsize('b');
% If the transition width is specified
R = tw * maxLM / 2;
Astop_lin = 10^(-Astop/20);
% Before designing the filter make sure that the minimum order based on the
% current filter specification is not negative
N = computeorder(maxLM, tw, Astop_lin);
coder.internal.errorIf(N < 0, 'dsp:designMultirateFIR:invalidOrder');
% Design the filter
b = firnyquist('minorder',maxLM,R,Astop_lin);
% perform initial measurements
[~, ~, ~, ~, ~, Astop_m] = filterdesign.internal.lowpassmeasure(b, tw, maxLM, "Stopband");
if Astop_m < Astop
    count = 0;
    while(Astop_m < Astop && count < 10)
        N = N + 2;
        Astop_d = determineastop(N, tw);
        alpha   = determinealpha(Astop_d);
        win = kaiser(N + 1, alpha);
        b = lowpasslband(N,maxLM,win);
        [~, ~, ~, ~, ~, Astop_m] = filterdesign.internal.lowpassmeasure(b, tw, maxLM, "Stopband");
        count = count + 1;
    end
end
% Provide warning if stopband attenuation specification is not met
AstopWarningThreshold = 100; 
coder.internal.warningIf((Astop_m < Astop) && (Astop > AstopWarningThreshold), 'dsp:designMultirateFIR:failedToConverge');
end
%--------------------------------------------------------------------------
% Compute order based on the current filter specification 
function N = computeorder(L, TW, Dev)
fp = 1./L - TW./2;
fs = 1./L + TW./2;
% Find the minimum order required
[N,~,~] = kaiserord([fp,fs],[1 0],[Dev,Dev]);
% Make sure order is even
if (rem(N,2) == 1)
	N = N + 1;
end
end
%--------------------------------------------------------------------------
% Determine stop band attenuation based on the current filter order and
% transition width
function Astop = determineastop(filterOrder, transitionWidth)
D = filterOrder * transitionWidth/2;
Astop = 2 * pi * 2.285 * D + 7.95;
if isempty(coder.target)
    coder.internal.warningIf(Astop <= 21,'dsp:designMultirateFIR:lowOrder');
end
end
%--------------------------------------------------------------------------
function alpha = determinealpha(Astop)
alpha = 1;
if Astop >= 50
    alpha = 0.1102*(Astop - 8.7);
elseif Astop < 50 && Astop > 21
    alpha = 0.5842*(Astop - 21)^.4 + 0.07886*(Astop - 21);
elseif Astop <= 21
    alpha = 0;
end
end