function [h,w] = freqz(b,~,w,NFFT,Fs)
%FREQZ Compute the frequency response of the filter coefficients

% Copyright 2019 The MathWorks, Inc.

%#codegen

% Make b a row
b = b(:).';

n  = length(b);

if (~all(w == 0))
    % If the frequency vector is specified
    digw = 2.*pi.*w./Fs; % Convert from Hz to rad/sample for computational purposes
    s = exp(1i*digw); % Digital frequency must be used for this calculation
    h = polyval(b,s)./exp(1i*digw*(n-1));
else
    % If the NFFT is specified
    s = 2;    
    if s*NFFT < n
        % Data is larger than FFT points, wrap modulo s*nfft
        b = datawrap(b,s.*NFFT);
    end
    h = fft(b,s.*NFFT);
    h = h(1:NFFT);

    deltaF = Fs/2/NFFT;
    w(1,:) = linspace(0,Fs/2-deltaF,NFFT);
    w(1,NFFT) = Fs/2-Fs/2/NFFT;
end
end

