function [isvalid, errmsg, msgid] = thisvalidate(this)
%VALIDATE   Validate the specs

%   Copyright 2006-2021 The MathWorks, Inc.

isvalid = true;
errmsg  = '';
msgid   = '';

F0 = this.F0;
Fs = this.Fs;

if this.NormalizedFrequency
    warning(message('dsp:fspecs:octavewordncenterfreq:thisvalidate:NormalizedFrequency', 'NormalizedFrequency', 'normalizefreq'));
    Fs = 48000;
    F0 = F0*Fs/2;
end

validFreq = this.getvalidcenterfrequencies;
if isempty(find(F0 == validFreq, 1))
    [~, idx] = min(abs(F0-validFreq));
    validf = validFreq(idx);
    F0request = F0;
    if this.NormalizedFrequency
        F0 = validf/Fs*2;
        validfstr = num2str(validFreq/Fs*2, 5); % 5-digit precision recommended in ISO 266:1997
    else
        F0 = validf;
        validfstr = num2str(validFreq, 5);
    end
    this.F0 = F0;
    
    propName = 'F0';
    if isprop(this,'FromFilterDesigner') && this.FromFilterDesigner
      propName = signal.internal.filterdesigner.convertpropnames('F0');
    end
    % The ISO 266:1997 standard (among others) allows center frequencies to
    % be expressed with as little as 5 significant digits, so we only warn
    % if we had to move the center frequency more than that. We also show
    % all the values in the warning with 5 significant digits only.
    if round(validf,5,'significant') ~= round(F0request,5,'significant')
        warning(message('dsp:fspecs:octavewordncenterfreq:thisvalidate:InvalidF0',propName,validfstr,propName,num2str(F0,5)));
    end
end    

