classdef(Abstract,CaseInsensitiveProperties=true) abstractcic < mfilt.abstractsiso
    %ABSTRACTCIC Constructor this class.
    
    %mfilt.abstractcic class
    %   mfilt.abstractcic extends mfilt.abstractsiso.
    %
    %    mfilt.abstractcic properties:
    %       PersistentMemory - Property is of type 'bool'
    %       NumSamplesProcessed - capture (read only)
    %       FilterStructure - Property is of type 'ustring'  (read only)
    %       States - Property is of type 'mxArray'
    %       DifferentialDelay - Property is of type 'posint user-defined'
    %       NumberOfSections - Property is of type 'posint user-defined'
    %       Arithmetic - Property is of type 'filterdesign_cic_arith enumeration: {'fixed'}'
    %
    %    mfilt.abstractcic methods:
    %       blockparams -   Return the parameters to set-up the block.
    %       cfi -   Return the information for the CFI.
    %       cic_info -   Get the information about this object.
    %       cic_init - Initialization utility used in CIC concrete classes.
    %       cic_loadpublicinterface -   Load the public interface.
    %       cic_savepublicinterface - SAVEPUBLICINTERFACE
    %       coefficient_info -   Get the coefficient information for this filter.
    %       coefficientnames - COEFFICIENTS CIC do not have coefficients
    %       coefficients - CIC do not have coefficients
    %       defaultarithmetic -   Returns the default arithmetic.
    %       dispatch - Returns DFILT for analysis.
    %       dispstr - Display string of coefficients.
    %       doFrameProcessing - Returns true if frame processing if supported by realizemdl()
    %       drawmask -   Draw the mask for the filter specifications.
    %       exportinfo - Export information for the DFILT class.
    %       formatstates -   Format the states for filtering.
    %       getdiffdelay - Overloaded GetFunction for the DifferentialDelay property.
    %       getinitialconditions - Get the initial conditions.
    %       getnumstages - Overloaded GetFunction for the NumberOfStages property
    %       getrealizemdlraterestrictions - Get rate restrictions for the realizemdl
    %       internalsettings - Returns the fixed-point settings viewed by the algorithm.
    %       isblockable - True if the object supports the block method
    %       ishdlable - True if HDL can be generated for the filter object.
    %       thisisrealizable -   True if the object is realizable.
    %       loadarithmetic -   Load the arithmetic information.
    %       loadmetadata -   Load the meta data.
    %       multirate_info - THISINFO
    %       nadd - Returns the number of adders
    %       nominalgain -   Nominal gain of a CICDECIM/CICINTERP filter.
    %       parse_filterstates - Store filter states in hTar for realizemdl
    %       polyphase - Polyphase decomposition.
    %       thisreffilter -   CIC reference filter.
    %       removelsbs - Remove LSBs while preserving MSBs.
    %       set_filterquantizer -   PreSet function for the 'filterquantizer' property.
    %       set_privfq -   PreSet function for the 'privfq' property.
    %       setbps - SetFunction for the BitsPerStage property.
    %       setcasfilter - Set the cascaded filter.
    %       setdiffdelay - Overloaded set for the DifferentialDelay property.
    %       sethdl_abstractcic - Set the properties of hdlfiltercomp (hhdl) from the
    %       setnumstages - SENUMDELAY Overloaded set for the NumberOfStages property.
    %       specifyall -   Set the object to SpecifyWordLengths mode.
    %       thisismaxphase -   True if the object is maxphase.
    %       thisisminphase -   True if the object is minphase.
    %       thisisreal -   Returns true if the Numerator is real.
    %       thisisstable -   Returns true.
    %       thisnsections -   Returns the number of sections.
    %       thisnstates - NSTATES  Number of states in discrete-time filter.
    %       thisreset - THISREST Resets the states of a CIC filter.
    %       thissetstates - Overloaded set for the States property.
    %       ziexpand -   Expand the CIC object for multichannels.
    %       ziscalarexpand - Expand empty or scalar initial conditions to a matrix.
    %
    %   Author: P. Costa
    %   Copyright 1999-2020 The MathWorks, Inc.
    
    properties (Access=protected, SetObservable, GetObservable)
        %PRIVDIFFERENTIALDELAY Property is of type 'posint user-defined'
        privDifferentialDelay = 1;
        %PRIVNUMBEROFSTAGES Property is of type 'posint user-defined'
        privNumberOfStages = 2;
    end
    
    properties (SetObservable, GetObservable)
        %DIFFERENTIALDELAY Property is of type 'posint user-defined'
        DifferentialDelay = 1;
        %ARITHMETIC Property is of type 'filterdesign_cic_arith enumeration: {'fixed'}'
        Arithmetic = 'fixed';
    end
    
    properties (Transient, SetObservable, GetObservable)
        %NUMBEROFSECTIONS Property is of type 'posint user-defined'
        NumberOfSections = 2;
    end
    
    properties (Transient, SetObservable, GetObservable, Hidden)
        %NUMBEROFSTAGES Property is of type 'posint user-defined'  (hidden)
        NumberOfStages = [];
        %INPUTBITWIDTH Property is of type 'mxArray'  (hidden)
        InputBitWidth = [];
        %OUTPUTBITWIDTH Property is of type 'mxArray'  (hidden)
        OutputBitWidth = [];
    end
    
    
    methods
        function value = get.DifferentialDelay(obj)
            value = getdiffdelay(obj,obj.DifferentialDelay);
        end
        function set.DifferentialDelay(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.DifferentialDelay = setdiffdelay(obj,value);
        end
        
        function set.privDifferentialDelay(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privDifferentialDelay = value;
        end
        
        function value = get.NumberOfStages(obj)
            value = getobsoleteprop(obj,obj.NumberOfStages,'NumberOfStages','NumberOfSections',true,false);
        end
        function set.NumberOfStages(obj,value)
            % User-defined DataType = 'posint user-defined'
            % Set Old property
            obj.NumberOfStages = value;
            % Set New property
            obj.NumberOfSections = value;
            % Warn
            
            setobsoleteprop(obj,value,'NumberOfStages','NumberOfSections',true,false);
        end
        
        function value = get.NumberOfSections(obj)
            value = getnumstages(obj,obj.NumberOfSections);
        end
        function set.NumberOfSections(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.NumberOfSections = setnumstages(obj,value);
        end
        
        function set.privNumberOfStages(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privNumberOfStages = value;
        end
        
        function value = get.InputBitWidth(obj)
            value = getobsoleteprop(obj,obj.InputBitWidth,'InputBitWidth','InputWordLength',true,false);
        end
        function set.InputBitWidth(obj,value)
            obj.InputBitWidth = setobsoleteprop(obj,value,'InputBitWidth','InputWordLength',true,false);
        end
        
        function value = get.OutputBitWidth(obj)
            value = getobsoleteprop(obj,obj.OutputBitWidth,'OutputBitWidth','OutputWordLength',true,false);
        end
        function set.OutputBitWidth(obj,value)
            obj.OutputBitWidth = setobsoleteprop(obj,value,'OutputBitWidth','OutputWordLength',true,false);
        end
        
        function set.Arithmetic(obj,value)
            % Enumerated DataType = 'filterdesign_cic_arith enumeration: {'fixed'}'
            value = validatestring(value,{'fixed'},'','Arithmetic');
            obj.Arithmetic = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        params = blockparams(this,mapstates,varargin)
        fi = cfi(this)
        [p,int,comb,v,intv,combv] = cic_info(this)
        cic_init(Hm,varargin)
        cic_loadpublicinterface(this,s)
        s = cic_savepublicinterface(this)
        [p,v] = coefficient_info(this)
        c = coefficientnames(Hd)
        c = coefficients(Hd)
        da = defaultarithmetic(this)
        Hd = dispatch(Hb)
        s = dispstr(~,~,varargin)
        flag = doFrameProcessing(~)
        varargout = drawmask(this,varargin)
        s = exportinfo(~)
        zi = formatstates(this,zi)
        M = getdiffdelay(Hm,dummy)
        ic = getinitialconditions(Hd)
        N = getnumstages(Hm,dummy)
        r = getrealizemdlraterestrictions(~,~)
        s = internalsettings(h)
        b = isblockable(~)
        [result,errstr,erroObj] = ishdlable(filterobj)
        b = thisisrealizable(this)
        loadarithmetic(this,s)
        loadmetadata(this,s)
        [p,v] = multirate_info(Hm)
        n = nadd(this)
        g = nominalgain(this)
        hTar = parse_filterstates(Hd,hTar)
        varargout = polyphase(Hd)
        Href = thisreffilter(this)
        y = removelsbs(h,x,numofLSB)
        fq = set_filterquantizer(this,fq)
        privfq = set_privfq(this,privfq)
        value = setbps(h,value)
        setcasfilter(Hm,R,M,N)
        D = setdiffdelay(Hm,D)
        sethdl_abstractcic(this,hhdl)
        N = setnumstages(Hm,N)
        specifyall(this,flag)
        b = thisismaxphase(h,tol)
        b = thisisminphase(h,tol)
        b = thisisreal(this)
        b = thisisstable(this)
        n = thisnsections(this)
        n = thisnstates(Hm)
        thisreset(h)
        zcir = thissetstates(this,zi)
        zi = ziexpand(this,x,zi)
        S = ziscalarexpand(Hm,S)
        info = qtoolinfo(this)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [p,v] = abstractcic_info(Hm)
    end  % possibly private or hidden
    
end  % classdef

% -------------------------------------------------------------------------
function value = setobsoleteprop(this, value, oldprop, newprop, warn, err)

if nargin < 6, err     = false; end

if err
    obsoleteerror(oldprop, newprop);
elseif warn
    obsoletewarning(oldprop, newprop);
end

if ~isempty(newprop)
    % Store the value in the new property.
    this.(newprop) = value;
    
    % Don't store anything.  The property needs to have a get function as well.
    value = [];
end
end

% -------------------------------------------------------------------------
function value = getobsoleteprop(this, value, oldprop, newprop, warn, err)

if nargin < 6, err     = false; end
if nargin < 5, warn    = false; end
if nargin < 4, newprop = '';    end
if islogical(newprop)
    warn = newprop;
    newprop = '';
end

if err
    obsoleteerror(oldprop, newprop);
elseif warn
    obsoletewarning(oldprop, newprop);
end

if ~isempty(newprop)
    % Store the value in the new property.
    value = this.(newprop);
end
end

% -------------------------------------------------------------------------
function varargout = obsoletewarning(oldprop, newprop)

if isempty(newprop)
    advice = '';
else
    advice = getString(message('signal:siguddutils:advice',newprop));
end

identifier = 'signal:siguddutils:obsoletePropWarn';
msgObj = message(identifier, oldprop,oldprop,advice);

if nargout
    varargout = {msgObj};
else
    warning(msgObj);
end
end

