classdef(Abstract,CaseInsensitiveProperties=true) abstractcicdecim < mfilt.abstractcic
    %MFILT.ABSTRACTCICDECIM is a class.

%   Copyright 2017-2020 The MathWorks, Inc.
    
    %mfilt.abstractcicdecim class
    %   mfilt.abstractcicdecim extends mfilt.abstractcic.
    %
    %    mfilt.abstractcicdecim properties:
    %       PersistentMemory - Property is of type 'bool'
    %       NumSamplesProcessed - capture (read only)
    %       FilterStructure - Property is of type 'ustring'  (read only)
    %       States - Property is of type 'mxArray'
    %       DifferentialDelay - Property is of type 'posint user-defined'
    %       NumberOfSections - Property is of type 'posint user-defined'
    %       Arithmetic - Property is of type 'filterdesign_cic_arith enumeration: {'fixed'}'
    %       DecimationFactor - Property is of type 'posint user-defined'
    %       InputOffset - Property is of type 'spt_uint32 user-defined'
    %
    %    mfilt.abstractcicdecim methods:
    %       convertchoices -   Returns the convert choices.
    %       filtmsb - Most significant bit of a CIC decimation filter.
    %       gain - Gain of a Cascaded Integrator-Comb (CIC) decimation filter.
    %       genmcode -   Generate an MATLAB code object for this filter.
    %       getdecim - Get the decimation factor.
    %       loadpublicinterface -   Load the public interface.
    %       multirate_info - THISINFO
    %       params - CIC filter parameters.
    %       savepublicinterface -   Save the public interface.
    %       setdecim - Overloaded set for the RateChangeFactor property.
    %       thisinfo -   Get the information about this object.
    %       tocicdecim -   Convert to a CIC Decimator.
    %       updatefilterinternals -  Update internal settings
    
    
    properties (SetObservable, GetObservable)
        %DECIMATIONFACTOR Property is of type 'posint user-defined'
        DecimationFactor = 2;
        %INPUTOFFSET Property is of type 'spt_uint32 user-defined'
        InputOffset double = 0;
    end
    
    properties (SetObservable, GetObservable, Hidden)
        %BITSPERSECTION Property is of type 'mxArray'  (hidden)
        BitsPerSection = [];
        %BITSPERSTAGE Property is of type 'mxArray'  (hidden)
        BitsPerStage = [];
    end
    
    
    methods
        function value = get.BitsPerSection(obj)
            value = getbps(obj,obj.BitsPerSection);
        end
        function set.BitsPerSection(obj,value)
            obj.BitsPerSection = setbps(obj,value);
        end
        
        function value = get.BitsPerStage(obj)
            value = getbps(obj,obj.BitsPerStage);
        end
        function set.BitsPerStage(obj,value)
            obj.BitsPerStage = setbps(obj,value);
        end
        
        function value = get.DecimationFactor(obj)
            value = getdecim(obj,obj.DecimationFactor);
        end
        function set.DecimationFactor(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.DecimationFactor = setdecim(obj,value);
        end
        
        function set.InputOffset(obj,value)
            % User-defined DataType = 'spt_uint32 user-defined'
            obj.InputOffset = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        [targs,strs] = convertchoices(this)
        Bmax = filtmsb(this)
        g = gain(this)
        h = genmcode(this,varname,place)
        M = getdecim(Hm,dummy)
        loadpublicinterface(this,s)
        [p,v] = multirate_info(Hm)
        [R,M,N] = params(this)
        s = savepublicinterface(this)
        M = setdecim(Hm,M)
        [p,v] = thisinfo(this)
        Hm = tocicdecim(this)
        updatefilterinternals(this,clearflag)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        bps = getbps(this,bps)
        privthisreset(Hm)
        bps = setbps(this,bps)
        [NMult,NAdd,NStates,MPIS,APIS] = thiscost(this,M)
    end  % possibly private or hidden
    
end  % classdef

