classdef(Abstract,CaseInsensitiveProperties=true) abstractcicinterp < mfilt.abstractcic
    %MFILT.ABSTRACTCICINTERP is a class.

%   Copyright 2017-2020 The MathWorks, Inc.
    
    %mfilt.abstractcicinterp class
    %   mfilt.abstractcicinterp extends mfilt.abstractcic.
    %
    %    mfilt.abstractcicinterp properties:
    %       PersistentMemory - Property is of type 'bool'
    %       NumSamplesProcessed - capture (read only)
    %       FilterStructure - Property is of type 'ustring'  (read only)
    %       States - Property is of type 'mxArray'
    %       DifferentialDelay - Property is of type 'posint user-defined'
    %       NumberOfSections - Property is of type 'posint user-defined'
    %       Arithmetic - Property is of type 'filterdesign_cic_arith enumeration: {'fixed'}'
    %       InterpolationFactor - Property is of type 'posint user-defined'
    %
    %    mfilt.abstractcicinterp methods:
    %       convertchoices -   Return the convert choices.
    %       filtmsb - Most significant bit of a CIC interpolation filter.
    %       gain - Gain of a Cascaded Integrator-Comb (CIC) interpolation filter.
    %       genmcode -   Generate an MATLAB code object for this filter.
    %       getinterp - Get the interpolation factor.
    %       loadpublicinterface -   Load the public interface.
    %       multirate_info - THISINFO
    %       params - CIC filter parameters.
    %       savepublicinterface -   Save the public interface.
    %       setbps - SetFunction for the BitsPerStage property.
    %       setinterp - Overloaded set for the privRateChangeFactor property.
    %       thisinfo -   Get the information for this object.
    %       tocicinterp -   Convert to a CIC Interpolator.
    %       updatefilterinternals -  Update internal settings
    
    
    properties (SetObservable, GetObservable)
        %INTERPOLATIONFACTOR Property is of type 'posint user-defined'
        InterpolationFactor = 2;
    end
    
    
    methods
        function value = get.InterpolationFactor(obj)
            value = getinterp(obj,obj.InterpolationFactor);
        end
        function set.InterpolationFactor(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.InterpolationFactor = setinterp(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        [targs,strs] = convertchoices(this)
        Bmax = filtmsb(Hm)
        g = gain(h,J)
        h = genmcode(this,varname,place)
        L = getinterp(Hm,dummy)
        loadpublicinterface(this,s)
        [p,v] = multirate_info(Hm)
        [R,M,N] = params(this)
        s = savepublicinterface(this)
        value = setbps(h,value)
        L = setinterp(Hm,L)
        [p,v] = thisinfo(this)
        Hm = tocicinterp(this)
        updatefilterinternals(this,clearflag)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        privthisreset(Hm)
        [NMult,NAdd,NStates,MPIS,APIS] = thiscost(this,M)
    end  % possibly private or hidden
    
end  % classdef

