classdef(Abstract,CaseInsensitiveProperties=true) abstractfarrowsrc < mfilt.abstractmultirate
    %ABSTRACTFARROWSRC Abstract constructor produces an error
    %   OUT = ABSTRACTFARROWSRC(ARGS) <long description>

    %mfilt.abstractfarrowsrc class
    %   mfilt.abstractfarrowsrc extends mfilt.abstractmultirate.
    %
    %    mfilt.abstractfarrowsrc properties:
    %       PersistentMemory - Property is of type 'bool'
    %       NumSamplesProcessed - capture (read only)
    %       FilterStructure - Property is of type 'ustring'  (read only)
    %       States - Property is of type 'mxArray'
    %       Arithmetic - Property is of type 'filterdesign_arith enumeration: {'double','single','fixed'}'
    %       Coefficients - Property is of type 'mxArray'
    %       InterpolationFactor - Property is of type 'posdouble user-defined'
    %       DecimationFactor - Property is of type 'posdouble user-defined'
    %
    %    mfilt.abstractfarrowsrc methods:
    %       coefficient_info - MULTIRATE_INFO
    %       thisdisp -   Display this object.
    %       dispstr - Display string of coefficients.
    %       doFrameProcessing - Returns true if frame processing if supported by realizemdl()
    %       get_coefficients -   PreGet function for the 'coefficients' property.
    %       get_ratechangefactors - PreGet function for the 'ratechangefactors' property
    %       getlogreport -   Get the logreport.
    %       getratechangefactors - Get the ratechangefactors.
    %       getrealizemdlraterestrictions - Get rate restrictions for the realizemdl
    %       isfixedptable - True is the structure has an Arithmetic field
    %       quantizecoeffs -  Quantize coefficients
    %       set_coefficients -   PreSet function for the 'coefficients' property.
    %       set_interpolationfactor - PreSet function for the 'interpolationfactor' property
    %       setrefcoeffs -   Set the refcoeffs.
    %       thisisreal -   True if the object is real.
    %       thisisstable -   True if the object is stable.
    %       thissetstates - Overloaded set for the States property.
    %
    %   Copyright 2007-2018 The MathWorks, Inc.
    
    properties (Access=protected, SetObservable, GetObservable)
        %PRIVCOEFFS Property is of type 'mxArray'
        privcoeffs = [];
        %REFCOEFFS Property is of type 'mxArray'
        refcoeffs = [];
    end
    
    properties (SetObservable, GetObservable)
        %COEFFICIENTS Property is of type 'mxArray'
        Coefficients = [ -1, 1; 1, 0 ];
        %INTERPOLATIONFACTOR Property is of type 'posdouble user-defined'
        InterpolationFactor double {mustBeReal, mustBeFinite, mustBePositive} = 3;
        %DECIMATIONFACTOR Property is of type 'posdouble user-defined'
        DecimationFactor double {mustBeReal, mustBeFinite, mustBePositive} = 2;
    end
    
    properties (Transient, SetObservable, GetObservable)
        %ARITHMETIC Property is of type 'filterdesign_arith enumeration: {'double','single','fixed'}'
        Arithmetic = 'double';
    end
    
    
    methods
        function value = get.Arithmetic(obj)
            value = get_arith(obj,obj.Arithmetic);
        end
        function set.Arithmetic(obj,value)
            % Enumerated DataType = 'filterdesign_arith enumeration: {'double','single','fixed'}'
            obj.Arithmetic = set_arith(obj,value);
        end
        
        function value = get.Coefficients(obj)
            value = get_coefficients(obj);
        end
        function set.Coefficients(obj,value)
            obj.Coefficients = set_coefficients(obj,value);
        end
        
        function set.refcoeffs(obj,value)
            obj.refcoeffs = setrefcoeffs(obj,value);
        end
        
        function set.InterpolationFactor(obj,value)
            % User-defined DataType = 'posdouble user-defined'
            obj.InterpolationFactor = set_interpolationfactor(obj,value);
        end
        
        function set.DecimationFactor(obj,value)
            % User-defined DataType = 'posdouble user-defined'
            obj.DecimationFactor = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        [p,v] = coefficient_info(this)
        thisdisp(this)
        s = dispstr(Hd,varargin)
        flag = doFrameProcessing(~)
        coefficients = get_coefficients(this,coefficients)
        R = get_ratechangefactors(this,R)
        logreport = getlogreport(this)
        rcf = getratechangefactors(this)
        r = getrealizemdlraterestrictions(~,~)
        fixflag = isfixedptable(Hd)
        quantizecoeffs(h,eventData)
        c = set_coefficients(this,c)
        L = set_interpolationfactor(this,L)
        refcoeffs = setrefcoeffs(this,refcoeffs)
        b = thisisreal(this)
        b = thisisstable(this)
        S = thissetstates(Hd,S)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        Hd = dispatch(this)
        loadpublicinterface(this,s)
        loadreferencecoefficients(this,s)
        s = savepublicinterface(this)
        s = savereferencecoefficients(this)
        c = thiscoefficients(this)
        n = thisnstates(this)
    end  % possibly private or hidden
    
end  % classdef

