classdef(Abstract,CaseInsensitiveProperties = true) abstractfirdecim < mfilt.abstractfirmultirate
    %ABSTRACTFIRDECIM Constructor for this class.
    
    %mfilt.abstractfirdecim class
    %   mfilt.abstractfirdecim extends mfilt.abstractfirmultirate.
    %
    %    mfilt.abstractfirdecim properties:
    %       PersistentMemory - Property is of type 'bool'
    %       NumSamplesProcessed - capture (read only)
    %       FilterStructure - Property is of type 'ustring'  (read only)
    %       States - Property is of type 'mxArray'
    %       Numerator - Property is of type 'DFILTNonemptyVector user-defined'
    %       DecimationFactor - Property is of type 'posint user-defined'
    %       Arithmetic - Property is of type 'filterdesign_arith enumeration: {'double','single','fixed'}'
    %       PolyphaseAccum - Property is of type 'mxArray'
    %       InputOffset - Property is of type 'spt_uint32 user-defined'
    %
    %    mfilt.abstractfirdecim methods:
    %       abstractfirdecim_loadpublicinterface -   Load the public interface.
    %       check_if_optimizezeros_possible - CHECK _IF_OPTIMIZEZEROS_POSSIBLE
    %       convertchoices -   Returns the convert choices.
    %       disp - Object display.
    %       filt2struct -   Returns a structure representation of the filter.
    %       genmcode -   Generate an MATLAB code object for this object.
    %       getdecim - Get the decimation factor.
    %       isblockable - True if the object supports the block method
    %       thisisrealizable -   True if the object is realizable.
    %       loadr14 -   Load R14 version of class.
    %       multirate_info - THISINFO
    %       naddp1 - Returns the number of additions + 1.
    %       parse_filterstates - Store filter states in hTar for realizemdl
    %       polyaccscalarexpand - Expand empty or scalar PolyphaseAccum to a vector.
    %       quantizeacc - Quantize PolyphaseAccum
    %       resetpolym - Reset the polyphase matrix.
    %       savepublicinterface -   Save the public interface.
    %       set_filterquantizer -   PreSet function for the 'filterquantizer' property.
    %       set_inputoffset -   PreSet function for the 'inputoffset' property.
    %       set_phaseindex -   PreSet function for the 'phaseindex' property.
    %       set_polyphaseaccum -   PreSet function for the 'polyphaseaccum' property.
    %       set_privfq -   PreSet function for the 'privfq' property.
    %       setdecim - Overloaded set for the DecimationFactor property.
    %       setnum - Overloaded set for the Numerator property.
    %       setpolyphasematrix - Overloaded set function on the PolyphaseMatrix property.
    %       thisnpolyphase -   Return the number of polyphases.
    %       tosysobj - Convert mfilt FIR decimator structure to System object
    %       validateacc - Quantize PolyphaseAccum
    %
    %   Author: V. Pellissier
    %   Copyright 1999-2018 The MathWorks, Inc.
    
    
    properties
        %DECIMATIONFACTOR Property is of type 'posint user-defined'
        DecimationFactor double {mustBeReal, mustBeFinite, mustBePositive} = 2 ;
        %ARITHMETIC Property is of type 'filterdesign_arith enumeration: {'double','single','fixed'}'
        Arithmetic = 'double';
        %POLYPHASEACCUM Property is of type 'mxArray'
        PolyphaseAccum = [  ];
        %INPUTOFFSET Property is of type 'spt_uint32 user-defined'
        InputOffset double = 0;
    end
    
    
    methods
        function value = get.DecimationFactor(obj)
            value = getdecim(obj);
        end
        function set.DecimationFactor(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.DecimationFactor = setdecim(obj,value);
        end
        
        function value = get.Arithmetic(obj)
            value = get_arith(obj,obj.Arithmetic);
        end
        function set.Arithmetic(obj,value)
            % Enumerated DataType = 'filterdesign_arith enumeration: {'double','single','fixed'}'
            value = validatestring(value,{'double','single','fixed'},'','Arithmetic');
            obj.Arithmetic = set_arith(obj,value);
        end
        
        function set.PolyphaseAccum(obj,value)
            obj.PolyphaseAccum = set_polyphaseaccum(obj,value);
        end
        
        function set.InputOffset(obj,value)
            % User-defined DataType = 'spt_uint32 user-defined'
            obj.InputOffset = set_inputoffset(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        abstractfirdecim_loadpublicinterface(this,s)
        check_if_optimizezeros_possible(this,hTar)
        [targs,strs] = convertchoices(this)
        thisdisp(this)
        s = filt2struct(this)
        hcode = genmcode(this,varname,place)
        M = getdecim(Hm)
        b = isblockable(~)
        b = thisisrealizable(this)
        loadr14(H,s)
        [p,v] = multirate_info(Hm)
        n = naddp1(h)
        hTar = parse_filterstates(Hd,hTar)
        S = polyaccscalarexpand(Hm,S)
        quantizeacc(h,eventData)
        resetpolym(Hm,num)
        s = savepublicinterface(this)
        newfq = set_filterquantizer(this,newfq)
        inputoffset = set_inputoffset(h,inputoffset)
        phaseindex = set_phaseindex(h,phaseindex)
        polyphaseaccum = set_polyphaseaccum(h,polyphaseaccum)
        privfq = set_privfq(this,privfq)
        M = setdecim(Hm,M)
        num = setnum(Hm,num)
        p = setpolyphasematrix(Hm,p)
        n = thisnpolyphase(this)
        Hs = tosysobj(this,returnSysObj)
        validateacc(h)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [out,coeffnames,variables] = mapcoeffstoports(this,varargin)
        specifyall(this,flag)
        thissetdecim(Hm,M)
        validatestates(h)
    end  % possibly private or hidden
    
end  % classdef

