classdef(Abstract,CaseInsensitiveProperties=true) abstractfirinterp < mfilt.abstractfirmultirate
    %ABSTRACTFIRINTERP   Abstract constructor produces an error.
    
    %mfilt.abstractfirinterp class
    %   mfilt.abstractfirinterp extends mfilt.abstractfirmultirate.
    %
    %    mfilt.abstractfirinterp properties:
    %       PersistentMemory - Property is of type 'bool'
    %       NumSamplesProcessed - capture (read only)
    %       FilterStructure - Property is of type 'ustring'  (read only)
    %       States - Property is of type 'mxArray'
    %       Numerator - Property is of type 'DFILTNonemptyVector user-defined'
    %       InterpolationFactor - Property is of type 'posint user-defined'
    %
    %    mfilt.abstractfirinterp methods:
    %       abstractfirinterp_loadpublicinterface -   Load the public interface.
    %       abstractfirinterp_savepublicinterface -   Save the public interface.
    %       check_if_optimizezeros_possible - CHECK _IF_OPTIMIZEZEROS_POSSIBLE
    %       convertchoices -   Return the convert targets.
    %       doFrameProcessing - Returns true if frame processing if supported by realizemdl()
    %       getblockraterestrictions - Get rate restrictions for the block method.
    %       getinterp - Get the interpolation factor.
    %       getrealizemdlraterestrictions - Get rate restrictions for the realizemdl
    %       thisisrealizable -   True if the object is realizable.
    %       loadpublicinterface -   Load the public interface.
    %       nadd - Returns the number of adders
    %       resetpolym - Reset the polyphase matrix.
    %       savepublicinterface -   Save the public interface.
    %       setinterp - Overloaded set for the InterpolationFactor property.
    %       setnum - Overloaded set for the Numerator property.
    %       thisnpolyphase -   Return the number of polyphases.
    %       tosysobj - Convert mfilt FIR interpolator structure to System object
    %
    %   Author(s): R. Losada
    %   Copyright 1999-2018 The MathWorks, Inc.
    
    properties
        %INTERPOLATIONFACTOR Property is of type 'posint user-defined'
        InterpolationFactor double {mustBeReal, mustBeFinite, mustBePositive} = 2;
    end
    
    methods
        function value = get.InterpolationFactor(obj)
            value = getinterp(obj,obj.InterpolationFactor);
        end
        function set.InterpolationFactor(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.InterpolationFactor = setinterp(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        abstractfirinterp_loadpublicinterface(this,s)
        s = abstractfirinterp_savepublicinterface(this)
        check_if_optimizezeros_possible(this,hTar)
        [targs,strs] = convertchoices(this)
        flag = doFrameProcessing(~)
        r = getblockraterestrictions(~,inputProcessing)
        L = getinterp(Hm,dummy)
        r = getrealizemdlraterestrictions(~,inputProcessing)
        b = thisisrealizable(this)
        loadpublicinterface(this,s)
        n = nadd(this)
        resetpolym(Hm,num)
        s = savepublicinterface(this)
        L = setinterp(Hm,L)
        num = setnum(Hm,num)
        n = thisnpolyphase(this)
        Hs = tosysobj(this,returnSysObj)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [p,v] = firinterp_info(Hm)
        [out,coeffnames,variables] = mapcoeffstoports(this,varargin)
    end  % possibly private or hidden
    
end  % classdef

