classdef(Abstract,CaseInsensitiveProperties=true) abstractfirmultirate < mfilt.abstractpolyphase
    %ABSTRACTFIRMULTIRATE Constructor for this class.
    
    %mfilt.abstractfirmultirate class
    %   mfilt.abstractfirmultirate extends mfilt.abstractpolyphase.
    %
    %    mfilt.abstractfirmultirate properties:
    %       PersistentMemory - Property is of type 'bool'
    %       NumSamplesProcessed - capture (read only)
    %       FilterStructure - Property is of type 'ustring'  (read only)
    %       States - Property is of type 'mxArray'
    %       Numerator - Property is of type 'DFILTNonemptyVector user-defined'
    %
    %    mfilt.abstractfirmultirate methods:
    %       coefficientnames -  Coefficient names.
    %       dispatch - Returns DFILT for analysis.
    %       dispstr - Display string of coefficients.
    %       double -   Cast filter to a double-precision arithmetic version.
    %       formnum -   Form numerator from polyphase matrix.
    %       getnum - Get the numerator vector.
    %       loadreferencecoefficients -   Load the reference coefficients.
    %       optimizecoeffwlfir - OPTIMIZECOEFFWL Optimize coefficient wordlength for FIR filters.
    %       resetpolym - Reset the polyphase matrix.
    %       set2int - Scales the coefficients to integer numbers.
    %       setnum - Overloaded set for the Numerator property.
    %       setrefvals -   Set reference values.
    %       supersetnum - SETNUM Overloaded set for the Numerator property.
    %       thisfiltquant_plugins - FILTQUANT_PLUGINS Table of filterquantizer plugins
    %       thisisfir -   Returns true.
    %       thisisreal -   Returns true if the Numerator is real.
    %       thisisstable -   Returns true.
    %
    %   Author: V. Pellissier
    %   Copyright 1999-2003 The MathWorks, Inc.
    
    
    properties
        %NUMERATOR Property is of type 'DFILTNonemptyVector user-defined'
        Numerator = [];
    end
    
    methods
        function value = get.Numerator(obj)
            value = getnum(obj,obj.Numerator);
        end
        function set.Numerator(obj,value)
            % User-defined DataType = 'DFILTNonemptyVector user-defined'
            obj.Numerator = setnum(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        c = coefficientnames(Hd)
        Hd = dispatch(Hb)
        s = dispstr(Hd,varargin)
        h = double(this)
        num = formnum(this,polym,ncoeffs)
        num = getnum(Hm,dummy)
        loadreferencecoefficients(this,s)
        [Hbest,mrfflag] = optimizecoeffwlfir(this,Href,varargin)
        resetpolym(Hm,num)
        varargout = set2int(this,coeffWL,inWL)
        num = setnum(Hm,num)
        setrefvals(this,refvals)
        num = supersetnum(Hm,num)
        constr = thisfiltquant_plugins(h,arith)
        b = thisisfir(this)
        b = thisisreal(this)
        b = thisisstable(this)
        info = qtoolinfo(~)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        v = coefficientvariables(this)
        Href = constraincoeffwlfir(this,Href,WL,varargin)
        b = defaultfilter(this,L,M)
        loadr14decim(H)
        Hbest = minimizecoeffwlfir(this,Href,varargin)
        Hd = optimizestopbandfir(this,Href,WL,varargin)
        rcnames = refcoefficientnames(this)
        c = thiscoefficients(this)
    end  % possibly private or hidden
    
end  % classdef

