classdef(Abstract,CaseInsensitiveProperties=true) abstractiirmultirate < mfilt.abstractsiso
    %ABSTRACTIIRMULTIRATE   Abstract constructor produces an error.

    %mfilt.abstractiirmultirate class
    %   mfilt.abstractiirmultirate extends mfilt.abstractsiso.
    %
    %    mfilt.abstractiirmultirate properties:
    %       PersistentMemory - Property is of type 'bool'
    %       NumSamplesProcessed - capture (read only)
    %       FilterStructure - Property is of type 'ustring'  (read only)
    %       States - Property is of type 'mxArray'
    %       Polyphase - Property is of type 'mxArray'
    %
    %    mfilt.abstractiirmultirate methods:
    %       appendcoeffstageindex - Append stage index to coefficient names
    %       chkIfRedrawNecessary - checks to see whether the FILTER blk needs to be redrawn
    %       doFrameProcessing - Returns true if frame processing if supported by realizemdl()
    %       genmcode -   Generate an MATLAB code object for this object.
    %       get_phase -   PreGet function for the 'phase' property.
    %       getrealizemdlraterestrictions - Get rate restrictions for the realizemdl
    %       isfixedptable -   True if the object is fixedptable.
    %       thisisrealizable -   True if the object is realizable.
    %       parse_coeffstoexport - Store coefficient names and values into hTar for
    %       realizemdl - Filter realization (Simulink diagram).
    %       set_phase -   PreSet function for the 'phase' property.
    %       thisispolyphase - ISPOLYPHASE   True if the object is polyphase.
    %       thisisreal -   True if the object is real.
    %       thisisstable -   True if the object is stable.
    %       tosysobj - Convert mfilt iir multirate structure to System object
    %
    %   Author(s): R. Losada
    %   Copyright 2005 The MathWorks, Inc.
    
    
    properties (Access=protected, SetObservable, GetObservable)
        %PRIVPHASE Property is of type 'mxArray'
        privphase = [];
    end
    
    properties (SetObservable, GetObservable)
        %POLYPHASE Property is of type 'mxArray'
        Polyphase = [];
    end
    
    
    methods
        function value = get.Polyphase(obj)
            value = get_phase(obj,obj.Polyphase);
        end
        function set.Polyphase(obj,value)
            obj.Polyphase = set_phase(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        coeff = appendcoeffstageindex(this,coeff,index)
        [redraw,h] = chkIfRedrawNecessary(Hd,h,sys,filter_structure,rate_factor)
        flag = doFrameProcessing(~)
        hcode = genmcode(this,varname,place)
        phase = get_phase(this,phase)
        r = getrealizemdlraterestrictions(~,~)
        b = isfixedptable(this)
        b = thisisrealizable(this)
        [hTar,domapcoeffstoports] = parse_coeffstoexport(Hd,hTar)
        realizemdl(H,varargin)
        phase = set_phase(this,phase)
        b = thisispolyphase(this)
        b = thisisreal(this)
        b = thisisstable(this)
        Hs = tosysobj(this,returnSysObj)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [p,v] = coefficient_info(this)
        c = coefficientnames(this)
        c = thiscoeffs(this)
        loadreferencecoefficients(this,s)
        N = nadd(this)
        N = nmult(this,optimones,optimnegones)
        p = polyphase(this,str)
        quantizecoeffs(this)
        s = savereferencecoefficients(this)
        [out,coeffnames] = super_mapcoeffstoports(this,varargin)
        [lib,srcblk,s] = superblockparams(Hd,mapstates,link2obj,varname,hTar)
        n = thisnpolyphase(this)
        n = thisnstates(this)
    end  % possibly private or hidden
    
end  % classdef

