classdef (Abstract,CaseInsensitiveProperties=true) abstractmultirate < dfilt.abstractfilter
    %ABSTRACTMULTIRATE Constructor for this class.
    
    %mfilt.abstractmultirate class
    %   mfilt.abstractmultirate extends dfilt.abstractfilter.
    %
    %    mfilt.abstractmultirate properties:
    %       PersistentMemory - Property is of type 'bool'
    %       NumSamplesProcessed - capture (read only)
    %       FilterStructure - Property is of type 'ustring'  (read only)
    %       States - Property is of type 'mxArray'
    %
    %    mfilt.abstractmultirate methods:
    %       allocate -   Determine the correct output length based on input length, rate
    %       cfi -   Return the information for the CFI.
    %       checkrequiredlicense - check required license for realizemdl
    %       coefficient_info -   Get the coefficient information for this filter.
    %       defaulttbstimulus - returns a cell array of stimulus types.
    %       deprecationMessage - Post deprecation message during MFILT object
    %       dgdfgen - generate the dg_dfilt structure from a specified filter structure
    %       dispatch - Returns the contained DFILT objects.
    %       exportinfo - Export information for the DFILT class.
    %       filtquant_plugins - Table of filterquantizer plugins
    %       getRateOptionParamName - Get the rateOptionParamName.
    %       getblockraterestrictions - Get rate restrictions for the block method.
    %       getrealizemdlraterestrictions - Get rate restrictions for the realizemdl
    %       isfixedptable -   True if the object is fixedptable.
    %       isparallelfilterable -   True if the object is parallelfilterable.
    %       thisisrealizable -   Return true if the object is realizable
    %       loadmetadata -   Load the meta data.
    %       parse_coeffstoexport - Store coefficient names and values into hTar for
    %       quantizecoeffs -  Quantize coefficients
    %       thisreffilter -   Returns the double representation of the filter object.
    %       ss -   State-space conversion
    %       sysobj - Generate a filter System object
    %       updateprops - Update phantom properties each time a dynamic property is added or removed.
    %       ziscalarexpand - Expand empty or scalar initial conditions to a vector.
    %
    %   Author: V. Pellissier
    %   Copyright 1999-2022 The MathWorks, Inc.
    
    
    properties (Access=protected)
        %FILTERS Property is of type 'mxArray'
        Filters = [];
        %PRIVLICPROP Property is of type 'mxArray'
        privLicProp = [];
    end
    
    
    methods
        function set.privLicProp(obj,value)
            obj.privLicProp = set_privLicProp(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        len = allocate(Hm,lx,offset)
        fi = cfi(this)
        checkrequiredlicense(Hd,hTar)
        [p,v] = coefficient_info(this)
        stimcell = defaulttbstimulus(Hb)
        deprecationMessage(h,replacementObject)
        DGDF = dgdfgen(Hd,hTar,doMapCoeffsToPorts)
        Hd = dispatch(Hb)
        s = exportinfo(Hd)
        constr = filtquant_plugins(h,arith)
        rateOptionParamName = getRateOptionParamName(~)
        r = getblockraterestrictions(this,inputProcessing)
        r = getrealizemdlraterestrictions(this,inputProcessing)
        b = isfixedptable(this)
        b = isparallelfilterable(this)
        b = thisisrealizable(this)
        loadmetadata(this,s)
        [hTar,domapcoeffstoports] = parse_coeffstoexport(Hd,hTar)
        quantizecoeffs(h,eventData)
        Hd = thisreffilter(this)
        ss(h)
        Hs = sysobj(this,varargin)
        updateprops(h,eventData)
        S = ziscalarexpand(Hd,S)
        realizemdl(Hd,varargin);

    end  % public methods
    
    methods (Hidden) % possibly private or hidden
        Hd = getfilters(Hm)
        str = getinfoheader(Hm)
        privvals = getprivvals(this)
        flag = ismultirate(~)
        quantizestates(h,eventData)
        val = set_privLicProp(~,val)
        setprivvals(this,privvals)
    end  % possibly private or hidden
    
methods(Static)
    function this = loadobj(s)
        if isfield(s,'class')
            s.class = dsp.internal.mfilt.mapInternalmfilt(s.class);
        end
        this = loadobj@dfilt.abstractfilter(s);
   end
end
end  % classdef

