function realizemdl(Hd,varargin)
%REALIZEMDL Filter realization (Simulink diagram).
%     REALIZEMDL(Hd) automatically generates architecture model of filter
%     Hd in a Simulink subsystem block using individual sum, gain, and
%     delay blocks, according to user-defined specifications.
%
%     REALIZEMDL(Hd, PARAMETER1, VALUE1, PARAMETER2, VALUE2, ...) generates
%     the model with parameter/value pairs.
%
%     See also DFILT/REALIZEMDL

%   Copyright 2022 The MathWorks, Inc.

realizemdl@dfilt.abstractfilter(Hd,varargin{:});

idx = find(strcmpi(varargin,'Destination'));

if ~isempty(idx)
    sys = varargin{idx+1};
    if ~strcmpi(sys,{'current','new'})
        removeArbsizeFromDownsample(sys);
    end
end
end

function removeArbsizeFromDownsample(sys)
% Find all Downsample blocks, and set their AllowArbitraryFixedInput flag to 'off'
    dsblocks = getfullname(Simulink.findBlocksOfType(sys,'DownSample'));
    
    if isempty(dsblocks)
        return
    end

    % If findBlocksOfType returned a single string
    if ~iscell(dsblocks)
        set_param(dsblocks,'AllowArbitraryFixedInput','off');
        return
    elseif iscell(dsblocks)
        for i=1:numel(dsblocks)
            bi = dsblocks{i};
            set_param(bi,'AllowArbitraryFixedInput','off');
        end
    end
end

