classdef (Abstract,CaseInsensitiveProperties=true) abstractsrc < mfilt.abstractfirmultirate
    %ABSTRACTSRC   Abstract constructor produces an error.
    
    %mfilt.abstractsrc class
    %   mfilt.abstractsrc extends mfilt.abstractfirmultirate.
    %
    %    mfilt.abstractsrc properties:
    %       PersistentMemory - Property is of type 'bool'
    %       NumSamplesProcessed - capture (read only)
    %       FilterStructure - Property is of type 'ustring'  (read only)
    %       States - Property is of type 'mxArray'
    %       Numerator - Property is of type 'DFILTNonemptyVector user-defined'
    %       RateChangeFactors - Property is of type 'posint_vector user-defined'
    %       InputOffset - Property is of type 'mxArray'
    %
    %    mfilt.abstractsrc methods:
    %       convertchoices -   Return the convert targets.
    %       doFrameProcessing - Returns true if frame processing if supported by realizemdl()
    %       filt2struct -   Returns a structure representation of the filter.
    %       genmcode -   Generate an MATLAB code object for this object.
    %       getratechangefactor - Get the rate change factor factor.
    %       getrealizemdlraterestrictions - Get rate restrictions for the realizemdl
    %       loadpublicinterface -   Load the public interface.
    %       loadr14 -   Load R14 version of class.
    %       multirate_info - THISINFO
    %       nadd - Returns the number of adders
    %       savepublicinterface -   Save the public interface.
    %       src_loadpublicinterface -   Load the public interface.
    %       src_savepublicinterface -   Save the public interface.
    %       supersetratechangefactor - SETRATE Overloaded set for the RateChangeFactor property.
    %       thisnpolyphase -   Return the number of polyphases.
    %       tofftfirinterp -   Convert to an Overlap-Add interpolator.
    %       tofirdecim -   Convert to an FIR decimator.
    %       tofirfracinterp -   Convert to a fractional interpolator.
    %       tofirinterp -   Convert to an FIR interpolator.
    %       tofirtdecim -   Convert to an FIR Transposed Decimator.
    %
    %   Author(s): R. Losada
    %   Copyright 1999-2018 The MathWorks, Inc.
    
    
    properties (SetObservable, GetObservable)
        %RATECHANGEFACTORS Property is of type 'posint_vector user-defined'
        RateChangeFactors = [];
        %INPUTOFFSET Property is of type 'mxArray'
        InputOffset = 0;
    end
    
    
    methods
        function value = get.RateChangeFactors(obj)
            value = getratechangefactor(obj,obj.RateChangeFactors);
        end
        function set.RateChangeFactors(obj,value)
            % User-defined DataType = 'posint_vector user-defined'
            obj.RateChangeFactors = setratechangefactor(obj,value);
        end
        
        function set.InputOffset(obj,value)
            obj.InputOffset = set_inputoffset(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        [targs,strs] = convertchoices(this)
        flag = doFrameProcessing(~)
        s = filt2struct(this)
        hcode = genmcode(this,varname,place)
        R = getratechangefactor(Hm,dummy)
        r = getrealizemdlraterestrictions(~,~)
        loadpublicinterface(this,s)
        loadr14(H,s)
        [p,v] = multirate_info(Hm)
        n = nadd(this)
        s = savepublicinterface(this)
        src_loadpublicinterface(this,s)
        s = src_savepublicinterface(this)
        R = supersetratechangefactor(Hm,R)
        n = thisnpolyphase(this)
        Hm = tofftfirinterp(this)
        Hm = tofirdecim(this)
        Hm = tofirfracinterp(this)
        Hm = tofirinterp(this)
        Hm = tofirtdecim(this)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [out,coeffnames,variables] = mapcoeffstoports(this,varargin)
        io = set_inputoffset(this,io)
        Hm = tofirfracdecim(this)
    end  % possibly private or hidden
    
end  % classdef

