function Hd = dispatch(Hm)
%DISPATCH Returns the contained DFILT objects.

%   Author: R. Losada
%   Copyright 1999-2019 The MathWorks, Inc.

% Validate the cascade first
validateratechangefactors(Hm);

% We generate the filters on the fly
% Form matrix of rate change factors
m = [];
Hmstages = nstages(Hm);
for n = 1:Hmstages
    m = [m;Hm.Stage(n).privRateChangeFactor]; %#ok<AGROW>
end

% Look for interpolators, include first decimator or src
indx = find(m(:,2) > 1, 1 );

% If index is empty, we have only interpolators
if isempty(indx)
    indx = Hmstages;
end

% Form array of equivalent dfilts
for n = 1:indx
    [b,a] = tf(Hm.Stage(n));
    % Compute equivalent interpolation factor
    Leq = prod(m(n+1:indx,1));
    % Upsample but remove trailing zeros
    bup = upsample(b,Leq); bup = bup(1:find(bup ~= 0, 1, 'last' ));
    aup = upsample(a,Leq); aup = aup(1:find(aup ~= 0, 1, 'last' ));
    h(n) = dfilt.df1(bup,aup); %#ok<AGROW>
end

% Find last decimator or dfilt
indx2 = find(m(:,2) >= 1 & m(:,1) == 1, 1, 'last' );

% If no more decimators we are done
if ~isempty(indx2)
    % Find first interpolator after the first decimator
    indx3 = find(m(indx:end,1) > 1 & m(indx:end,2) == 1, 1 ) + indx - 1;
    % If there are dfilts after interpolator stages, then correct for it
    if ~isempty(indx3) && indx2 > indx3
        indx2 = indx3-1;
    end        
        
    % Add remaining decimators
    for n = indx+1:indx2
        [b,a] = tf(Hm.Stage(n));
        % Compute equivalent decimation factor
        Meq = prod(m(indx:n-1,2));
        % Upsample but remove trailing zeros
        bup = upsample(b,Meq); bup = bup(1:find(bup ~= 0, 1, 'last' ));
        aup = upsample(a,Meq); aup = aup(1:find(aup ~= 0, 1, 'last' ));
        h(n) = dfilt.df1(bup,aup);
    end

    % Now add possible remaining interpolators and dfilts after
    % interpolators
    if ~isempty(indx3)
        % Add remaining interpolators and dfilts
        for n = indx3:Hmstages
            [b,a] = tf(Hm.Stage(n));
            % Compute equivalent interpolation factor
            Leq = prod(m(n+1:Hmstages,1));
            % Upsample but remove trailing zeros
            bup = upsample(b,Leq); bup = bup(1:find(bup ~= 0, 1, 'last' ));
            aup = upsample(a,Leq); aup = aup(1:find(aup ~= 0, 1, 'last' ));
            h(n) = dfilt.df1(bup,aup);
        end
    end
end


Hd = cascade(h);


% [EOF]
