%QREPORT Quantization report.
%
%   MFILT will be removed in a future release. Use dsp.CICDecimator,
%   dsp.CICInterpolator, dsp.FIRDecimator, dsp.FIRInterpolator,
%   dsp.FilterCascade, dsp.FarrowRateConverter, dsp.FIRRateConverter,
%   dsp.IIRHalfbandDecimator, or dsp.IIRHalfbandInterpolator instead.
%
%   R = QREPORT(Hd) returns the logging report R stored in the filter
%   object Hd. The logging capability is integrated to the 'filter' method
%   with the 'Arithmetic' property set to 'fixed'. It is triggered when the
%   'Logging' FI preference is 'on'. The stored report corresponds to the
%   last simulation. It is overwritten each time the filter command is
%   executed.
%
%   QREPORT provides users with a way to instrument fixed-point filters and
%   gives insight on how the filter is responding to a given stimulus. The
%   report object R contains a structure-specific list of internal signals
%   of the filter. Each signal contains:
%   - the minimum and maximum values that were recorded during the last
%     simulation (values are logged before quantization),
%   - the range of the signal,
%   - the number of overflows.
%
%   Notice that this method requires Fixed-Point Designer.
%
%   % EXAMPLE #1: Quantization report of a FIR decimator filter.
%   fipref('LoggingMode', 'on');
%   Hd = design(fdesign.decimator, 'equiripple');
%   Hd. arithmetic = 'fixed';
%   rng default; % for reproducible results from rand
%   y = filter(Hd, rand(100,1));
%   R = qreport(Hd)
%
%   % EXAMPLE #2: Quantization report of a Lowpass filter.
%   fipref('loggingmode','on');
%   hd = design(fdesign.lowpass,'equiripple');
%   hd.arithmetic = 'fixed';
%   hd.InputWordLength = 32;
%   fs = 1000;          % Input sampling frequency.
%   t = 0:1/fs:1.5;     % Signal length = 1501 samples.
%   x = sin(2*pi*10*t); % Amplitude = 1 sinusoid.
%   y = filter(hd,x); 
%   rlog = qreport(hd)
%
%   See also DFILT/FUNCTIONS

%   Author(s): V. Pellissier
%   Copyright 2005-2015 The MathWorks, Inc.



% [EOF]
