classdef (CaseInsensitiveProperties) oneptlp_t1 < mpr.abstractoneptlp
    %mpr.oneptlp_t1 class
    %   mpr.oneptlp_t1 extends mpr.abstractoneptlp.
    %
    
    %    mpr.oneptlp_t1 properties:
    %       M - Property is of type 'mxArray'  (read only)
    %       fgrid - Property is of type 'mxArray'  (read only)
    %       fext - Property is of type 'mxArray'  (read only)
    %       Agrid - Property is of type 'mxArray'  (read only)
    %       Aext - Property is of type 'mxArray'  (read only)
    %       Ggrid - Property is of type 'mxArray'  (read only)
    %       Gext - Property is of type 'mxArray'  (read only)
    %       Wgrid - Property is of type 'mxArray'  (read only)
    %       Wext - Property is of type 'mxArray'  (read only)
    %       errgrid - Property is of type 'mxArray'  (read only)
    %       errext - Property is of type 'mxArray'  (read only)
    %       analyticerr - Property is of type 'mxArray'  (read only)
    %       measurederr - Property is of type 'mxArray'  (read only)
    %       DensityFactor - Property is of type 'mxArray'  (read only)
    %       iter - Property is of type 'mxArray'  (read only)
    %
    %    mpr.oneptlp_t1 methods:
    
    % Copyright 2018 The MathWorks, Inc.
    
    
    methods  % constructor block
        function this = oneptlp_t1(N,Fst,dF,wstruct)
            %ONEPTLP   Construct an ONEPTLP object.
            %   H = ONEPTLP_T1(N,Fst,DF) constructs a type I, one-passband-point
            %   lowpass MPR object H given a filter order N, a stopband-edge frequency
            %   Fst, and a density factor DF.
            %
            %   N must be even (type I lowpass only). If not specified, it defaults to
            %   100.
            %
            %   Fst must be greater than zero and less than one. If not specified, it
            %   defaults to 0.2.
            %
            %   DF must be a positive integer. If not specified, it defaults to 16.
            %
            %   H = ONEPTLP_T1(N,Fst,DF,Wstruct) specifies a structure with parameters to
            %   determine the weights. Wstruct has the following fields:
            %       iresp - impulse response of filter to shape weights (used for
            %               Nyquist designs but can be set to 1)
            %       nneg  - boolean indicating whether the response should be
            %               non-negative  (also used for Nyquist designs)
            %       decay - stopband decay rate in dB.
            
            
            %   Author(s): R. Losada
            
            
            % Set up defaults
            if nargin < 1, N = 100; end
            if nargin < 2, Fst = 0.2; end
            if nargin > 2, this.DensityFactor = dF; end
            if nargin < 4, wstruct.nneg = false; wstruct.iresp = 1; wstruct.decay = 0; end
            
            
            % The algorithm works with half the order
            if rem(N,2) == 1
                error(message('dsp:mpr:oneptlp_t1:oneptlp_t1:oddOrder'));
            end
            M = N/2;
            this.M = M;
            
            % Initialize all properties
            init(this,Fst,wstruct);
            
            
        end  % oneptlp
        
    end  % constructor block
    
    methods (Hidden) % possibly private or hidden
        %----------------------------------------
        function b = determine_impresp(this)
            %DETERMINE_IMPRESP
            
            %   Author(s): R. Losada
            
            M = this.M;
            N = M*2;
            
            % Evaluate approximating polynomial at N+1 evenly spaced points
            w = linspace(0,2-2/(N+1),N+1); % % Don't include factor of pi
            Gw = evalapprox(this,w);
            
            hz = ifft(Gw, 'symmetric');
            
            b = [hz(M+2:end),hz(1:M+1)];
            
            
            
        end  % determine_impresp
        
        %----------------------------------------
        function determine_weights(this,wstruct)
            %DETERMINE_WEIGHTS
            
            %   Author(s): R. Losada
            
            % For now, the weights are determined in a way necessary for Nyquist
            % designs
            nyquist_weights(this,wstruct);
            
            
        end  % determine_weights
        
    end  % possibly private or hidden
    
end  % classdef

