classdef (CaseInsensitiveProperties=true,TruncatedProperties=true) abstractfixedfilterq < dfilt.filterquantizer
    %quantum.abstractfixedfilterq class
    %   quantum.abstractfixedfilterq extends dfilt.filterquantizer.
    %
    %    quantum.abstractfixedfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %
    %    quantum.abstractfixedfilterq methods:
    %       abstractfixed_blockparams -   Return the generic settings.
    %       abstractfixed_discreteblockparams -   Return the generic settings for blocks
    %       conv2sltype - Returns SLTYPE for the given WL, FL
    %       copy -   Copy this object.
    %       core2fi - Translate CoreEmbedded.fi to embedded.Fi
    %       dispstr -   Return the formatted strings.
    %       fi2core - Translate embedded.fi to CoreEmbedded.Fi
    %       fixed_genmcode -   Return the fixed point generic MATLAB code.
    %       get_coeffautoscale -   PreGet function for the 'coeffautoscale' property.
    %       get_coeffwl -   PreGet function for the 'coeffwl' property.
    %       get_infl -   PreGet function for the 'infl' property.
    %       get_inwl -   PreGet function for the 'inwl' property.
    %       get_signed -   PreGet function for the 'signed' property.
    %       getbestprecision - Return best precision for Product and Accumulator
    %       loadobj -   Load the object.
    %       maproundmode - Map RoundMode enum to System object RoundMethod enum
    %       saveobj -   Save the object.
    %       set_coeffautoscale -   PreSet Function for the Coefficient AutoScale.
    %       set_coeffwl - Set function on 'CoeffWordLength' property
    %       set_infl -   PreSet function for the 'InputFracLength' property.
    %       set_inwl -   PreSet function for the 'InputWordLength' property.
    %       set_ncoeffs -   Set function for the 'ncoeffs' property.
    %       setdefaultcoeffwl - Set the default coefficient word length

%   Copyright 2018-2019 The MathWorks, Inc.
    
    
    properties (Access=protected, SetObservable)
        %FIMATH Property is of type 'mxArray'
        fimath = fimath( 'RoundMode', 'convergent', 'OverflowMode', 'wrap', 'SumMode', 'SpecifyPrecision', 'ProductMode', 'SpecifyPrecision', 'SumWordLength', 40, 'SumFractionLength', 30 );
        %INHERITSETTINGS Property is of type 'bool'
        InheritSettings = false;
        %PRIVCOEFFWL Property is of type 'posint user-defined'
        privcoeffwl = 16;
        %PRIVCOEFFAUTOSCALE Property is of type 'bool'
        privCoeffAutoScale = true;
        %PRIVCOEFFFL Property is of type 'int32'
        privcoefffl = 15;
        %PRIVSIGNED Property is of type 'bool'
        privsigned = true;
        %PRIVINWL Property is of type 'posint user-defined'
        privinwl = 16;
        %PRIVINFL Property is of type 'int32'
        privinfl = 15;
        %VERSION Property is of type 'mxArray'
        version = [];
        %MAXPROD Property is of type 'mxArray'
        maxprod = [  ];
        %MAXSUM Property is of type 'mxArray'
        maxsum = [  ];
        %PRIVLICPROP Property is of type 'mxArray'
        privLicProp = [];
    end
    
    properties (SetObservable)
        %COEFFWORDLENGTH Property is of type 'mxArray'
        CoeffWordLength {mustBePositive} = [];
        %COEFFAUTOSCALE Property is of type 'mxArray'
        CoeffAutoScale = [];
        %SIGNED Property is of type 'mxArray'
        Signed = [];
        %ROUNDMODE Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
        RoundMode = 'convergent';
        %OVERFLOWMODE Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
        OverflowMode = 'wrap';
        %INPUTWORDLENGTH Property is of type 'mxArray'
        InputWordLength = [];
        %INPUTFRACLENGTH Property is of type 'mxArray'
        InputFracLength = [];
    end
    
    
    methods
        function value = get.CoeffWordLength(obj)
            value = get_coeffwl(obj,obj.CoeffWordLength);
        end
        function set.CoeffWordLength(obj,value)
            obj.CoeffWordLength = set_coeffwl(obj,value);
        end
        
        function value = get.CoeffAutoScale(obj)
            value = get_coeffautoscale(obj,obj.CoeffAutoScale);
        end
        function set.CoeffAutoScale(obj,value)
            obj.CoeffAutoScale = set_coeffautoscale(obj,value);
        end
        
        function value = get.Signed(obj)
            value = get_signed(obj,obj.Signed);
        end
        function set.Signed(obj,value)
            obj.Signed = set_signed(obj,value);
        end
        
        function value = get.RoundMode(obj)
            value = get_rm(obj,obj.RoundMode);
        end
        function set.RoundMode(obj,value)
            % Enumerated DataType = 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
            value = validatestring(value,{'convergent','ceil','fix','floor','round','nearest'},'','RoundMode');
            obj.RoundMode = set_rm(obj,value);
        end
        
        function value = get.OverflowMode(obj)
            value = get_om(obj,obj.OverflowMode);
        end
        function set.OverflowMode(obj,value)
            % Enumerated DataType = 'OverflowType enumeration: {'wrap','saturate'}'
            value = validatestring(value,{'wrap','saturate'},'','OverflowMode');
            obj.OverflowMode = set_om(obj,value);
        end
        
        function value = get.InputWordLength(obj)
            value = get_inwl(obj,obj.InputWordLength);
        end
        function set.InputWordLength(obj,value)
            obj.InputWordLength = set_inwl(obj,value);
        end
        
        function value = get.InputFracLength(obj)
            value = get_infl(obj,obj.InputFracLength);
        end
        function set.InputFracLength(obj,value)
            obj.InputFracLength = set_infl(obj,value);
        end
        
        function set.InheritSettings(obj,value)
            % DataType = 'bool'
            validateattributes(value,{'numeric','logical'}, {'scalar','nonnan'},'','InheritSettings')
            value = logical(value); %  convert to logical
            obj.InheritSettings = value;
        end
        
        function set.privcoeffwl(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privcoeffwl = value;
        end
        
        function set.privCoeffAutoScale(obj,value)
            % DataType = 'bool'
            validateattributes(value,{'numeric','logical'}, {'scalar','nonnan'},'','privCoeffAutoScale')
            value = logical(value); %  convert to logical
            obj.privCoeffAutoScale = value;
        end
        
        function set.privcoefffl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privcoefffl')
            obj.privcoefffl = value;
        end
        
        function set.privsigned(obj,value)
            % DataType = 'bool'
            validateattributes(value,{'numeric','logical'}, {'scalar','nonnan'},'','privsigned')
            value = logical(value); %  convert to logical
            obj.privsigned = value;
        end
        
        function set.privinwl(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privinwl = value;
        end
        
        function set.privinfl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privinfl')
            obj.privinfl = value;
        end
        
        function value = get.version(obj)
            value = get_version(obj,obj.version);
        end
        
        function set.privLicProp(obj,value)
            obj.privLicProp = set_privLicProp(obj,value);
        end
        
        function values = getAllowedStringValues(~,prop)
            % This function gives the valid string values for object properties.
            switch prop
                case 'OverflowMode'
                    values = {'wrap','saturate'};
                case 'RoundMode'
                    values = {'convergent','ceil','fix','floor','round','nearest'};
                otherwise
                    values = {};
            end
        end
    end   % set and get functions
    
    methods  % public methods
        p = abstractfixed_blockparams(this)
        p = abstractfixed_discreteblockparams(this)
        sltype = conv2sltype(this,varargin)
        Hcopy = copy(Hd)
        y = core2fi(q,x)
        varargout = dispstr(this,varargin)
        y = fi2core(q,x)
        h = fixed_genmcode(this)
        coeffautoscale = get_coeffautoscale(q,coeffautoscale)
        coeffwl = get_coeffwl(q,coeffwl)
        infl = get_infl(q,infl)
        inwl = get_inwl(q,inwl)
        signed = get_signed(q,signed)
        s = getbestprecision(q)
        roundingMethod = maproundmode(this)
        s = saveobj(this)
        coeffautoscale = set_coeffautoscale(this,coeffautoscale)
        coeffwl = set_coeffwl(q,coeffwl)
        infl = set_infl(this,infl)
        inwl = set_inwl(q,inwl)
        set_ncoeffs(q,ncoeffs)
        setdefaultcoeffwl(this,filtobj)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        affq_specifyall(this,flag)
        v = formatinfo(this,pre,wl,fl,extrastr)
        [accWL,accFL] = fullprecisionaccum(q,accinWL,accinFL,bits2add)
        [prodWL,prodFL] = fullprecisionproduct(q,coeffWL,coeffFL,multWL,multFL)
        om = get_om(q,om)
        rm = get_rm(q,rm)
        v = get_version(~,v)
        inputautoscalefl(this,s,binptaligned)
        logi = isparallelfilterable(this)
        prodFL = keeplsbproduct(q,coeffFL,multFL)
        accFL = keepmsbaccum(q,accinWL,accinFL,bits2add,accWL)
        prodFL = keepmsbproduct(q,coeffWL,coeffFL,multWL,multFL,prodWL)
        Pnn = nlminputcomp(this,Hf,M,Pnn)
        [vp,Vp] = nlmrescaleinput(this,vp,Vp)
        [x,inlog] = quantizeinput(q,x)
        S = quantizestates(q,S)
        om = set_om(q,om)
        val = set_privLicProp(~,val)
        rm = set_rm(q,rm)
        signed = set_signed(q,signed)
        om = thisset_om(q,om)
        rm = thisset_rm(q,rm)
        updateinternalsettings(q)
        validaterefcoeffs(q,prop,val)
        S = validatestates(q,S)
    end  % possibly private or hidden
    
    
    methods (Static) % static methods
        this = loadobj(s)
    end  % static methods
    
end  % classdef

