classdef(CaseInsensitiveProperties=true) abstractfixediirfilterq < quantum.abstractfixednonscalarfilterq
    %quantum.abstractfixediirfilterq class
    %   quantum.abstractfixediirfilterq extends quantum.abstractfixednonscalarfilterq.
    %
    %    quantum.abstractfixediirfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputMode - Property is of type 'OutputModeType enumeration: {'AvoidOverflow','BestPrecision','SpecifyPrecision'}'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       NumAccumFracLength - Property is of type 'mxArray'
    %       DenAccumFracLength - Property is of type 'mxArray'
    %       NumProdFracLength - Property is of type 'mxArray'
    %       DenProdFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       DenFracLength - Property is of type 'mxArray'
    %
    %    quantum.abstractfixediirfilterq methods:
    %       disp - Object display.
    %       iir_blockparams -   Block params for IIRs.
    %       iir_genmcode -   IIR specific MATLAB code.
    %       quantizecoeffs -   Quantize coefficients.
    %       set_denaccq - Specify word and fraction length of the accum passed to the mexfunction.
    %       set_denaccumfl -   PreSet function for the 'DenAccumFracLength' property.
    %       set_denfl -   PreSet Function for the 'DenFracLength' property.
    %       set_denprodfl -   PreSet function for the 'DenProdFracLength' property.
    %       set_denprodq - Specify product word and fraction length for the mexfunction.
    %       set_numaccumfl -   PreSet Function for the 'NumAccumFracLength' property.
    %       set_numprodfl -   PreSet function for the 'NumProdFracLength' property.
    %       validaterefcoeffs - Utility to check for valid reference coefficients.

%   Copyright 2018-2019 The MathWorks, Inc.
    
    
    properties (Access=protected, SetObservable)
        %FIMATH2 Property is of type 'mxArray'
        fimath2 = fimath( 'RoundMode', 'convergent', 'OverflowMode', 'wrap', 'SumMode', 'KeepMSB', 'SumWordLength', 40, 'SumFractionLength', 30 );
        %PRIVCOEFFFL2 Property is of type 'int32'
        privcoefffl2 = 15;
    end
    
    properties (SetObservable)
        %NUMACCUMFRACLENGTH Property is of type 'mxArray'
        NumAccumFracLength = [];
        %DENACCUMFRACLENGTH Property is of type 'mxArray'
        DenAccumFracLength = [];
        %NUMPRODFRACLENGTH Property is of type 'mxArray'
        NumProdFracLength = [];
        %DENPRODFRACLENGTH Property is of type 'mxArray'
        DenProdFracLength = [];
        %NUMFRACLENGTH Property is of type 'mxArray'
        NumFracLength = [];
        %DENFRACLENGTH Property is of type 'mxArray'
        DenFracLength = [];
    end
    
    
    methods
        function value = get.NumAccumFracLength(obj)
            value = get_numaccumfl(obj,obj.NumAccumFracLength);
        end
        function set.NumAccumFracLength(obj,value)
            obj.NumAccumFracLength = set_numaccumfl(obj,value);
        end
        
        function value = get.DenAccumFracLength(obj)
            value = get_denaccumfl(obj,obj.DenAccumFracLength);
        end
        function set.DenAccumFracLength(obj,value)
            obj.DenAccumFracLength = set_denaccumfl(obj,value);
        end
        
        function value = get.NumProdFracLength(obj)
            value = get_numprodfl(obj,obj.NumProdFracLength);
        end
        function set.NumProdFracLength(obj,value)
            obj.NumProdFracLength = set_numprodfl(obj,value);
        end
        
        function value = get.DenProdFracLength(obj)
            value = get_denprodfl(obj,obj.DenProdFracLength);
        end
        function set.DenProdFracLength(obj,value)
            obj.DenProdFracLength = set_denprodfl(obj,value);
        end
        
        function value = get.NumFracLength(obj)
            value = get_numfl(obj,obj.NumFracLength);
        end
        function set.NumFracLength(obj,value)
            obj.NumFracLength = set_numfl(obj,value);
        end
        
        function value = get.DenFracLength(obj)
            value = get_denfl(obj,obj.DenFracLength);
        end
        function set.DenFracLength(obj,value)
            obj.DenFracLength = set_denfl(obj,value);
        end
        
        function set.privcoefffl2(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privcoefffl2')
            obj.privcoefffl2 = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        disp(this,varargin)
        p = iir_blockparams(this,forceDigitalFilterBlock)
        h = iir_genmcode(this)
        [bq,aq] = quantizecoeffs(q,b,a)
        [accWL,accFL] = set_denaccq(q,inWL,inFL,ncoeffs)
        denaccumfl = set_denaccumfl(this,denaccumfl)
        denfl = set_denfl(this,denfl)
        denprodfl = set_denprodfl(this,denprodfl)
        [prodWL,prodFL] = set_denprodq(q,coeffWL,coeffFL,multWL,multFL)
        numaccumfl = set_numaccumfl(this,numaccumfl)
        numprodfl = set_numprodfl(this,numprodfl)
        validaterefcoeffs(q,prop,val)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        denaccumfl = get_denaccumfl(q,denaccumfl)
        denfl = get_denfl(q,denfl)
        denprodfl = get_denprodfl(q,denprodfl)
        numaccumfl = get_numaccumfl(q,numaccumfl)
        numprodfl = get_numprodfl(q,numprodfl)
        iir_thisloadobj(this,s)
        inheritstates(q,S)
        S = quantizestates(q,S)
        accummode = set_accummode(q,accummode)
        cbs = set_cbs(q,cbs)
        productmode = set_productmode(this,productmode)
        super_thisautoscale(this,s,binptaligned)
        superdf1t_thisautoscale(this,s,binptaligned)
        thisset_accumwl(q,accumwl)
        om = thisset_om(q,om)
        thisset_prodwl(q,prodwl)
        rm = thisset_rm(q,rm)
    end  % possibly private or hidden
    
end  % classdef

