classdef(Abstract,CaseInsensitiveProperties=true) abstractfixedinfilterq < dfilt.filterquantizer
    %quantum.abstractfixedinfilterq class
    %   quantum.abstractfixedinfilterq extends dfilt.filterquantizer.
    %
    %    quantum.abstractfixedinfilterq properties:
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %
    %    quantum.abstractfixedinfilterq methods:
    %       conv2sltype - Returns SLTYPE for the given WL, FL
    %       copy -   Copy this object.
    %       disp - Object display.
    %       get_infl -   PreGet function for the 'infl' property.
    %       get_inwl -   PreGet function for the 'inwl' property.
    %       loadobj -   Load the object.
    %       saveobj -   Save the object.
    %       set_infl -   PreSet function for the 'InputFracLength' property.
    %       set_inwl -   PreSet function for the 'InputWordLength' property.
    %       set_ncoeffs -   Set function for the 'ncoeffs' property.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    
    properties (Access=protected, SetObservable)
        %PRIVINWL Property is of type 'posint user-defined'
        privinwl = 16;
        %PRIVINFL Property is of type 'int32'
        privinfl = 15;
        %INHERITSETTINGS Property is of type 'bool'
        InheritSettings = false;
        %PRIVLICPROP Property is of type 'mxArray'
        privLicProp = [];
    end
    
    properties (SetObservable)
        %INPUTWORDLENGTH Property is of type 'mxArray'
        InputWordLength {mustBePositive} = [];
        %INPUTFRACLENGTH Property is of type 'mxArray'
        InputFracLength = [];
    end
    
    
    methods
        function value = get.InputWordLength(obj)
            value = get_inwl(obj,obj.InputWordLength);
        end
        function set.InputWordLength(obj,value)
            obj.InputWordLength = set_inwl(obj,value);
        end
        
        function value = get.InputFracLength(obj)
            value = get_infl(obj,obj.InputFracLength);
        end
        function set.InputFracLength(obj,value)
            obj.InputFracLength = set_infl(obj,value);
        end
        
        function set.privinwl(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privinwl = value;
        end
        
        function set.privinfl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privinfl')
            obj.privinfl = value;
        end
        
        function set.InheritSettings(obj,value)
            % DataType = 'bool'
            validateattributes(value,{'numeric','logical'}, {'scalar','nonnan'},'','InheritSettings')
            value = logical(value); %  convert to logical
            obj.InheritSettings = value;
        end
        
        function set.privLicProp(obj,value)
            obj.privLicProp = set_privLicProp(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        sltype = conv2sltype(this,varargin)
        Hcopy = copy(Hd)
        disp(this,varargin)
        infl = get_infl(this,infl)
        inwl = get_inwl(this,inwl)
        s = saveobj(this)
        infl = set_infl(this,infl)
        inwl = set_inwl(this,inwl)
        set_ncoeffs(q,ncoeffs)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        inputautoscalefl(this,s,binptaligned)
        Pnn = nlminputcomp(this,Hf,M,Pnn)
        [vp,Vp] = nlmrescaleinput(this,vp,Vp)
        [x,inlog] = quantizeinput(q,x)
        val = set_privLicProp(~,val)
    end  % possibly private or hidden
    
    
    methods (Static) % static methods
        this = loadobj(s)
    end  % static methods
    
end  % classdef

