classdef(CaseInsensitiveProperties=true) df1treport < quantum.abstractiirreport
    %DF1TREPORT   Construct a DF1TREPORT object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.df1treport class
    %   quantum.df1treport extends quantum.abstractiirreport.
    %
    %    quantum.df1treport properties:
    %       Input - Property is of type 'quantum.abstractlog'  (read only)
    %       Output - Property is of type 'quantum.abstractlog'  (read only)
    %       NumProd - Property is of type 'quantum.abstractlog'  (read only)
    %       DenProd - Property is of type 'quantum.abstractlog'  (read only)
    %       NumAcc - Property is of type 'quantum.abstractlog'  (read only)
    %       DenAcc - Property is of type 'quantum.abstractlog'  (read only)
    %       NumStates - Property is of type 'quantum.abstractlog'  (read only)
    %       DenStates - Property is of type 'quantum.abstractlog'  (read only)
    %       Multiplicand - Property is of type 'quantum.abstractlog'  (read only)
    %
    %    quantum.df1treport methods:
    %       disp -   Display this object.
    
    %   Author(s): V. Pellissier
    
    properties (SetAccess=protected, SetObservable)
        %NUMSTATES Property is of type 'quantum.abstractlog'  (read only)
        NumStates = [];
        %DENSTATES Property is of type 'quantum.abstractlog'  (read only)
        DenStates = [];
        %MULTIPLICAND Property is of type 'quantum.abstractlog'  (read only)
        Multiplicand = [];
    end
    
    methods  % constructor block
        function this = df1treport(datatype,in,out,numstates,denstates,multiplicand,numprod,denprod,numacc,denacc)        
            narginchk(10,10);
            this.DataType = datatype;
            this.Input = in;
            this.Output = out;
            this.Multiplicand = multiplicand;
            this.NumStates = numstates;
            this.DenStates = denstates;
            this.NumProd = numprod;
            this.DenProd = denprod;
            this.NumAcc = numacc;
            this.DenAcc = denacc;
        end  % df1treport
    end  % constructor block
    
    methods
        function set.NumStates(obj,value)
            % DataType = 'quantum.abstractlog'
            validateattributes(value,{'quantum.abstractlog'}, {'scalar'},'','NumStates')
            obj.NumStates = value;
        end
        
        function set.DenStates(obj,value)
            % DataType = 'quantum.abstractlog'
            validateattributes(value,{'quantum.abstractlog'}, {'scalar'},'','DenStates')
            obj.DenStates = value;
        end
        
        function set.Multiplicand(obj,value)
            % DataType = 'quantum.abstractlog'
            validateattributes(value,{'quantum.abstractlog'}, {'scalar'},'','Multiplicand')
            obj.Multiplicand = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        disp(this)
    end  % public methods
    
end  % classdef

