classdef(CaseInsensitiveProperties=true) doublelog < quantum.abstractlog
    %DOUBLELOG   Construct a DOUBLELOG object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.doublelog class
    %   quantum.doublelog extends quantum.abstractlog.
    %
    %    quantum.doublelog properties:
    %       Max - Property is of type 'mxArray'  (read only)
    %       Min - Property is of type 'mxArray'  (read only)
    %       NOperations - Property is of type 'mxArray'  (read only)
    %       MinFxPtRange - Property is of type 'mxArray'  (read only)
    %       MaxFxPtRange - Property is of type 'mxArray'  (read only)
    %       NOutOfRange - Property is of type 'mxArray'  (read only)
    %
    %    quantum.doublelog methods:
    
    %   Author(s): V. Pellissier
    
    properties (SetAccess=protected, SetObservable)
        %MINFXPTRANGE Property is of type 'mxArray'  (read only)
        MinFxPtRange = [];
        %MAXFXPTRANGE Property is of type 'mxArray'  (read only)
        MaxFxPtRange = [];
        %NOUTOFRANGE Property is of type 'mxArray'  (read only)
        NOutOfRange = [];
    end
    
    methods  % constructor block
        function this = doublelog(q)
            this.Max = double(max(q.Max));
            this.Min = double(min(q.Min));
            
            r = q.Range;
            this.MinFxPtRange = r(1);
            this.MaxFxPtRange = r(2);
            
            this.NOutOfRange = q.NOverflows;
            this.NOperations = q.NOperations;
        end  % doublelog
        
    end  % constructor block
        
    methods (Hidden) % possibly private or hidden
        dispinfo(this,name)
    end  % possibly private or hidden
    
end  % classdef

