classdef(CaseInsensitiveProperties=true) fixedcicinterpfilterq < quantum.abstractcicfilterq
    %FIXEDCICINTERPFILTERQ   Construct a FIXEDCICINTERPFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixedcicinterpfilterq class
    %   quantum.fixedcicinterpfilterq extends quantum.abstractcicfilterq.
    %
    %    quantum.fixedcicinterpfilterq properties:
    %       RoundMode - Property is of type 'ustring'  (read only)
    %       OverflowMode - Property is of type 'ustring'  (read only)
    %       CastBeforeSum - Property is of type 'bool'  (read only)
    %       InputWordLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       FilterInternals - Property is of type 'CICFilterInternalsType enumeration: {'FullPrecision','MinWordLengths','SpecifyWordLengths','SpecifyPrecision'}'
    %       SectionWordLengths - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       SectionFracLengths - Property is of type 'mxArray'
    %       OutputFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixedcicinterpfilterq methods:
    %       cicinterpdggen -  CICDECIMDGGEN Directed Graph generator for cic interpolator filter
    %       cicinterpfilter - Filter method for the MFILT.CICINTERP filter in fixed-point mode.
    %       getlog -   Get the log.
    %       quantizestates -   Quantize the states for a CIC interpolation filter.
    %       ufifcnhndl -   Return function handle used for updatefilterinternals
    
    %   Author(s): P. Costa
    
    methods  % constructor block
        function h = fixedcicinterpfilterq

        end  % fixedcicinterpfilterq
        
    end  % constructor block
    
    methods  % public methods
        DGDF = cicinterpdggen(q,Hd,states)
        [y,zf] = cicinterpfilter(q,x,zi,R,M,N)
        [outlog,intlog,comblog] = getlog(this,y,yIntOut,zInt,yCombOut,zComb,inlog)
        states = quantizestates(this,states)
        fcnhndl = ufifcnhndl(this)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        n = thiscombNops(this,inlog,outlog)
        n = thisintNops(this,inlog,outlog)
    end  % possibly private or hidden
    
end  % classdef

