classdef(CaseInsensitiveProperties=true) fixeddf1filterq < quantum.abstractfixedfilterq
    %FIXEDDF1FILTERQ   Construct a FIXEDDF1FILTERQ object.

%   Copyright 2018-2019 The MathWorks, Inc.
    
    %quantum.fixeddf1filterq class
    %   quantum.fixeddf1filterq extends quantum.abstractfixedfilterq.
    %
    %    quantum.fixeddf1filterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       DenFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       NumProdFracLength - Property is of type 'mxArray'
    %       DenProdFracLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       NumAccumFracLength - Property is of type 'mxArray'
    %       DenAccumFracLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixeddf1filterq methods:
    %       blockparams -   Return the parameters for the block.
    %       df1_blockparams -   Return the DF1 specific block parameters.
    %       df1bodyconnect - specifies the connection and quantization parameters in the
    %       df1filter - Filter for the DFILT.DF1 class in Fixed-Point
    %       df1footconnect - specifies the connection and quantization parameters in the
    %       df1headconnect - specifies the blocks, connection and quantization parameters in the
    %       df1header_order0 - specifies the blocks, connection and quantization parameters in the
    %       disp - Object display.
    %       genmcode -   Generate MATLAB code.
    %       get_accummode -   PreGet function for the 'accummode' property.
    %       get_outwl -   PreGet function for the 'outwl' property.
    %       get_productmode -   PreGet function for the 'productmode' property.
    %       getlog -   Get the log.
    %       info -   Return the info for the object.
    %       internalsettings -   Returns fixed-point settings as viewed by the algorithm.
    %       prependzero -   Prepend a zero to the numerator states.
    %       quantizecoeffs -   Quantize coefficients.
    %       quantizestates -   Quantize the states of a DF1 filter.
    %       set_accummode -   PreSet function for the 'AccumMode' property.
    %       set_accumwl -   PreSet function for the 'AccumWordLength' property.
    %       set_denaccfl - SET_DENACCUMFL   PreSet function for the 'DenAccumFracLength' property.
    %       set_denaccq - Specify word and fraction length of the accum passed to the mexfunction.
    %       set_denfl -   PreSet function for the 'DenFracLength' property.
    %       set_denprodfl -   PreSet function for the 'DenProdFracLength' property.
    %       set_denprodq - Specify product word and fraction length for the mexfunction.
    %       set_infl -   PreSet function for the 'InputFracLength' property.
    %       set_inwl -   PreSet function for the 'InputWordLength' property.
    %       set_numaccfl - SET_NUMACCUMFL   PreSet function for the 'NumAccumFracLength' property.
    %       set_numaccq - Specify word and fraction length of the accum passed to the mexfunction.
    %       set_numfl -   PreSet function for the 'NumFracLength' property.
    %       set_numprodfl -   PreSet function for the 'NumProdFracLength'.
    %       set_numprodq - Specify product word and fraction length for the mexfunction.
    %       set_outfl -   PreSet function for the 'OutputFracLength' property.
    %       set_outwl -   PreSet function for the 'OutputWordLength' property.
    %       set_productmode -   PreSet function for the 'ProductMode' property.
    %       set_prodwl -   PreSet function for the 'ProductWordLength'.
    %       setsysobjfixedpoint - Set converted System object fixed point properties
    %       specifyall -   Set the object to full specified precision mode.
    %       thisset_om -   Overloaded SetFunction for the 2nd FIMATH OverFlow mode.
    %       thisset_rm -   Overloaded SetFunction for the 2nd FIMATH Round mode.
    %       validaterefcoeffs - Utility to check for valid reference coefficients.
    
    %   Author(s): P. Costa
    
    properties (Access=protected, SetObservable)
        %FIMATH2 Property is of type 'mxArray'
        fimath2 = fimath( 'RoundMode', 'convergent', 'OverflowMode', 'wrap', 'SumMode', 'KeepMSB', 'SumWordLength', 40, 'SumFractionLength', 30 );
        %PRIVCOEFFFL2 Property is of type 'int32'
        privcoefffl2 = 14;
        %PRIVPRODUCTMODE Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
        privProductMode = 'FullPrecision';
        %PRIVACCUMMODE Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
        privAccumMode = 'KeepMSB';
        %PRIVOUTFL Property is of type 'int32'
        privoutfl = 15;
        %PRIVOUTWL Property is of type 'posint user-defined'
        privoutwl = 16;
    end
    
    properties (SetObservable)
        %NUMFRACLENGTH Property is of type 'mxArray'
        NumFracLength = [];
        %DENFRACLENGTH Property is of type 'mxArray'
        DenFracLength = [];
        %PRODUCTMODE Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
        ProductMode = 'FullPrecision';
        %PRODUCTWORDLENGTH Property is of type 'mxArray'
        ProductWordLength = [];
        %NUMPRODFRACLENGTH Property is of type 'mxArray'
        NumProdFracLength = [];
        %DENPRODFRACLENGTH Property is of type 'mxArray'
        DenProdFracLength = [];
        %ACCUMMODE Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
        AccumMode = 'FullPrecision';
        %ACCUMWORDLENGTH Property is of type 'mxArray'
        AccumWordLength = [];
        %NUMACCUMFRACLENGTH Property is of type 'mxArray'
        NumAccumFracLength = [];
        %DENACCUMFRACLENGTH Property is of type 'mxArray'
        DenAccumFracLength = [];
        %CASTBEFORESUM Property is of type 'bool'
        CastBeforeSum = false;
        %OUTPUTWORDLENGTH Property is of type 'mxArray'
        OutputWordLength = [];
        %OUTPUTFRACLENGTH Property is of type 'mxArray'
        OutputFracLength = [];
    end
    
    
    methods  % constructor block
        function this = fixeddf1filterq
            updateinternalsettings(this);
        end  % fixeddf1filterq
        
    end  % constructor block
    
    methods
        function value = get.NumFracLength(obj)
            value = get_numfl(obj,obj.NumFracLength);
        end
        function set.NumFracLength(obj,value)
            obj.NumFracLength = set_numfl(obj,value);
        end
        
        function value = get.DenFracLength(obj)
            value = get_denfl(obj,obj.DenFracLength);
        end
        function set.DenFracLength(obj,value)
            obj.DenFracLength = set_denfl(obj,value);
        end
        
        function set.privcoefffl2(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privcoefffl2')
            obj.privcoefffl2 = value;
        end
        
        function value = get.ProductMode(obj)
            value = get_productmode(obj,obj.ProductMode);
        end
        function set.ProductMode(obj,value)
            % Enumerated DataType = 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
            value = validatestring(value,{'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'},'','ProductMode');
            obj.ProductMode = set_productmode(obj,value);
        end
        
        function set.privProductMode(obj,value)
            % Enumerated DataType = 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
            value = validatestring(value,{'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'},'','privProductMode');
            obj.privProductMode = value;
        end
        
        function value = get.ProductWordLength(obj)
            value = get_prodwl(obj,obj.ProductWordLength);
        end
        function set.ProductWordLength(obj,value)
            obj.ProductWordLength = set_prodwl(obj,value);
        end
        
        function value = get.NumProdFracLength(obj)
            value = get_numprodfl(obj,obj.NumProdFracLength);
        end
        function set.NumProdFracLength(obj,value)
            obj.NumProdFracLength = set_numprodfl(obj,value);
        end
        
        function value = get.DenProdFracLength(obj)
            value = get_denprodfl(obj,obj.DenProdFracLength);
        end
        function set.DenProdFracLength(obj,value)
            obj.DenProdFracLength = set_denprodfl(obj,value);
        end
        
        function value = get.AccumMode(obj)
            value = get_accummode(obj,obj.AccumMode);
        end
        function set.AccumMode(obj,value)
            % Enumerated DataType = 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
            value = validatestring(value,{'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'},'','AccumMode');
            obj.AccumMode = set_accummode(obj,value);
        end
        
        function set.privAccumMode(obj,value)
            % Enumerated DataType = 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
            value = validatestring(value,{'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'},'','privAccumMode');
            obj.privAccumMode = value;
        end
        
        function value = get.AccumWordLength(obj)
            value = get_accumwl(obj,obj.AccumWordLength);
        end
        function set.AccumWordLength(obj,value)
            obj.AccumWordLength = set_accumwl(obj,value);
        end
        
        function value = get.NumAccumFracLength(obj)
            value = get_numaccfl(obj,obj.NumAccumFracLength);
        end
        function set.NumAccumFracLength(obj,value)
            obj.NumAccumFracLength = set_numaccfl(obj,value);
        end
        
        function value = get.DenAccumFracLength(obj)
            value = get_denaccfl(obj,obj.DenAccumFracLength);
        end
        function set.DenAccumFracLength(obj,value)
            obj.DenAccumFracLength = set_denaccfl(obj,value);
        end
        
        function value = get.CastBeforeSum(obj)
            value = get_cbs(obj,obj.CastBeforeSum);
        end
        function set.CastBeforeSum(obj,value)
            % DataType = 'bool'
            validateattributes(value,{'numeric','logical'}, {'scalar','nonnan'},'','CastBeforeSum')
            value = logical(value); %  convert to logical
            obj.CastBeforeSum = set_cbs(obj,value);
        end
        
        function value = get.OutputWordLength(obj)
            value = get_outwl(obj,obj.OutputWordLength);
        end
        function set.OutputWordLength(obj,value)
            obj.OutputWordLength = set_outwl(obj,value);
        end
        
        function value = get.OutputFracLength(obj)
            value = get_outfl(obj,obj.OutputFracLength);
        end
        function set.OutputFracLength(obj,value)
            obj.OutputFracLength = set_outfl(obj,value);
        end
        
        function set.privoutfl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privoutfl')
            obj.privoutfl = value;
        end
        
        function set.privoutwl(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privoutwl = value;
        end
        
        function values = getAllowedStringValues(obj,prop)
            % This function gives the valid string values for object properties.
            values = getAllowedStringValues@quantum.abstractfixedfilterq(obj, prop);
            switch prop
                case 'ProductMode'
                    values = {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'};
                case 'AccumMode'
                    values = {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'};
            end
        end
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,forceDigitalFilterBlock)
        p = df1_blockparams(this,forceDigitalFilterBlock)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = df1bodyconnect(q,NL,H,mainparams)
        [y,zfNum,zfDen,nTIf,dTIf,noverflows] = df1filter(q,b,a,x,ziNum,ziDen,nTI,dTI,limitcycleflag)
        [NL,PrevIPorts,PrevOPorts,mainparams] = df1footconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = df1headconnect(q,NL,H,mainparams)
        Head = df1header_order0(q,num,den,H,info)
        disp(this,varargin)
        h = genmcode(this)
        accummode = get_accummode(q,accummode)
        outwl = get_outwl(q,outwl)
        productmode = get_productmode(q,productmode)
        [ol,npl,dpl,naccl,daccl] = getlog(this,y,num,den,numAcc,denAcc,x)
        [p,v] = info(this)
        s = internalsettings(q)
        S = prependzero(q,S)
        [bq,aq] = quantizecoeffs(q,b,a)
        S = quantizestates(q,S)
        accummode = set_accummode(this,accummode)
        accumwl = set_accumwl(this,accumwl)
        accumfl = set_denaccfl(this,accumfl)
        [accWL,accFL] = set_denaccq(q,inWL,inFL,ncoeffs)
        denfl = set_denfl(this,denfl)
        prodfl = set_denprodfl(this,prodfl)
        [prodWL,prodFL] = set_denprodq(q,coeffWL,coeffFL,multWL,multFL)
        infl = set_infl(q,infl)
        inwl = set_inwl(q,inwl)
        accumfl = set_numaccfl(this,accumfl)
        [accWL,accFL] = set_numaccq(q,inWL,inFL,ncoeffs)
        numfl = set_numfl(this,numfl)
        prodfl = set_numprodfl(this,prodfl)
        [prodWL,prodFL] = set_numprodq(q,coeffWL,coeffFL,multWL,multFL)
        outfl = set_outfl(this,outfl)
        outwl = set_outwl(q,outwl)
        productmode = set_productmode(this,productmode)
        prodwl = set_prodwl(this,prodwl)
        setsysobjfixedpoint(this,Hs)
        specifyall(this,flag)
        om = thisset_om(q,om)
        rm = thisset_rm(q,rm)
        validaterefcoeffs(q,prop,val)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        h = df1_genmcode(this)
        df1_thisloadobj(this,s)
        accumfl = get_accumfl(q,accumfl)
        accumwl = get_accumwl(q,accumwl)
        cbs = get_cbs(q,cbs)
        accumfl = get_denaccfl(q,accumfl)
        denfl = get_denfl(q,denfl)
        prodfl = get_denprodfl(q,prodfl)
        accumfl = get_numaccfl(q,accumfl)
        numfl = get_numfl(q,numfl)
        prodfl = get_numprodfl(q,prodfl)
        outfl = get_outfl(q,outfl)
        prodfl = get_prodfl(q,prodfl)
        prodwl = get_prodwl(q,prodwl)
        den = getdenominator(Hd,den)
        inheritstates(q,S)
        Sden = nulldenstate(q)
        Snum = nullnumstate(q)
        S = nullstate1(q)
        S = nullstate2(q)
        cbs = set_cbs(q,cbs)
        super_thisautoscale(this,s,binptaligned)
        thisautoscale(this,s,binptaligned)
        thisloadobj(this,s)
        updateinternalsettings(q)
        S = validatestates(q,S)
        S = validatestatesobj(q,S)
    end  % possibly private or hidden
    
end  % classdef

