classdef(CaseInsensitiveProperties=true) fixeddf1sosfilterq < quantum.abstractfixedsosfilterq
    %FIXEDDF1SOSFILTERQ   Construct a FIXEDDF1SOSFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixeddf1sosfilterq class
    %   quantum.fixeddf1sosfilterq extends quantum.abstractfixedsosfilterq.
    %
    %    quantum.fixeddf1sosfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputMode - Property is of type 'OutputModeType enumeration: {'AvoidOverflow','BestPrecision','SpecifyPrecision'}'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       NumAccumFracLength - Property is of type 'mxArray'
    %       DenAccumFracLength - Property is of type 'mxArray'
    %       NumProdFracLength - Property is of type 'mxArray'
    %       DenProdFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       DenFracLength - Property is of type 'mxArray'
    %       ScaleValueFracLength - Property is of type 'mxArray'
    %       NumStateWordLength - Property is of type 'mxArray'
    %       DenStateWordLength - Property is of type 'mxArray'
    %       NumStateFracLength - Property is of type 'mxArray'
    %       DenStateFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixeddf1sosfilterq methods:
    %       blockparams -   Return the block parameters.
    %       df1sosbodyconnect - specifies the connection and quantization parameters in the
    %       df1sosfilter - Filter for DFILT.DF1SOS class in fixed-point
    %       df1sosfootconnect - specifies the connection and quantization parameters in the
    %       df1sosheadconnect - specifies the blocks, connection and quantization parameters in the
    %       df1sosheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       disp - Object display.
    %       genmcode -   Generate MATLAB code.
    %       get_dstatefl -   PreGet function for the 'dstatefl' property.
    %       get_dstatewl -   PreGet function for the 'dstatewl' property.
    %       get_nstatefl -   PreGet function for the 'nstatefl' property.
    %       get_nstatewl -   PreGet function for the 'nstatewl' property.
    %       info -   Return the info for the object.
    %       internalsettings - Returns the fixed-point settings viewed by the algorithm.
    %       set_dstatefl -   PreSet function for the 'dstatefl' property.
    %       set_dstatewl -   PreSet function for the 'DenStateWordLength' property.
    %       set_nstatefl -   PreSet function for the 'NumStateFracLength' property.
    %       set_nstatewl -   PreSet function for the 'nstatewl' property.
    %       set_outq - Specify output word and fraction length for the mexfunction.
    %       thiscopy -   Copy the properties at this level.
    
    %   Author(s): V. Pellissier
    
    properties (Access=protected, SetObservable)
        %PRIVNSTATEWL Property is of type 'posint user-defined'
        privnstatewl = 16;
        %PRIVDSTATEWL Property is of type 'posint user-defined'
        privdstatewl = 16;
        %PRIVNSTATEFL Property is of type 'int32'
        privnstatefl = 15;
        %PRIVDSTATEFL Property is of type 'int32'
        privdstatefl = 15;
    end
    
    properties (SetObservable)
        %NUMSTATEWORDLENGTH Property is of type 'mxArray'
        NumStateWordLength = [];
        %DENSTATEWORDLENGTH Property is of type 'mxArray'
        DenStateWordLength = [];
        %NUMSTATEFRACLENGTH Property is of type 'mxArray'
        NumStateFracLength = [];
        %DENSTATEFRACLENGTH Property is of type 'mxArray'
        DenStateFracLength = [];
    end
    
    
    methods  % constructor block
        function q = fixeddf1sosfilterq
            % Force defaults
            q.fimath.SumWordLength = 40;
            q.fimath.SumFractionLength = 30;
            q.fimath2.SumWordLength = 40;
            q.fimath2.SumFractionLength = 30;
            
            % Fire set functions
            nstWL = q.NumStateWordLength;
            q.NumStateWordLength = nstWL+1;
            q.NumStateWordLength = nstWL;
        end  % fixeddf1sosfilterq
    end  % constructor block
    
    methods
        function value = get.NumStateWordLength(obj)
            value = get_nstatewl(obj,obj.NumStateWordLength);
        end
        function set.NumStateWordLength(obj,value)
            obj.NumStateWordLength = set_nstatewl(obj,value);
        end
        
        function value = get.DenStateWordLength(obj)
            value = get_dstatewl(obj,obj.DenStateWordLength);
        end
        function set.DenStateWordLength(obj,value)
            obj.DenStateWordLength = set_dstatewl(obj,value);
        end
        
        function value = get.NumStateFracLength(obj)
            value = get_nstatefl(obj,obj.NumStateFracLength);
        end
        function set.NumStateFracLength(obj,value)
            obj.NumStateFracLength = set_nstatefl(obj,value);
        end
        
        function value = get.DenStateFracLength(obj)
            value = get_dstatefl(obj,obj.DenStateFracLength);
        end
        function set.DenStateFracLength(obj,value)
            obj.DenStateFracLength = set_dstatefl(obj,value);
        end
        
        function set.privnstatewl(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privnstatewl = value;
        end
        
        function set.privdstatewl(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privdstatewl = value;
        end
        
        function set.privnstatefl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privnstatefl')
            obj.privnstatefl = value;
        end
        
        function set.privdstatefl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privdstatefl')
            obj.privdstatefl = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,varargin)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = df1sosbodyconnect(q,NL,H,mainparams)
        [y,zf,noverflows] = df1sosfilter(q,num,den,sv,issvnoteq2one,x,zi,limitcycleflag)
        [NL,PrevIPorts,PrevOPorts,mainparams] = df1sosfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = df1sosheadconnect(q,NL,H,mainparams)
        Head = df1sosheader_order0(q,sosMatrix,scaleValues,H,info)
        disp(this,varargin)
        h = genmcode(this)
        dstatefl = get_dstatefl(q,dstatefl)
        dstatewl = get_dstatewl(q,dstatewl)
        nstatefl = get_nstatefl(q,nstatefl)
        nstatewl = get_nstatewl(q,nstatewl)
        [p,v] = info(this)
        s = internalsettings(q)
        dstatefl = set_dstatefl(this,dstatefl)
        dstatewl = set_dstatewl(this,dstatewl)
        nstatefl = set_nstatefl(this,nstatefl)
        nstatewl = set_nstatewl(this,nstatewl)
        set_outq(q,accWL,accFL)
        thiscopy(this,Hd)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [ol,nstl,dstl,npl,dpl,naccl,daccl] = getlog(this,y,zinum,outstage,num,den,numAcc,denAcc,sv,issvnoteq2one,x)
        inheritstates(q,S)
        S = nullstate1(q)
        S = quantizestates(q,S)
        setsysobsectioninputoutput(this,Hs)
        this_setsysobjfixedpoint(this,Hs)
        thisautoscale(this,s,binptaligned)
        thisloadobj(this,s)
        updateinternalsettings(q)
        S = validatestates(q,S)
        S = validatestatesobj(q,S)
    end  % possibly private or hidden
    
end  % classdef

