classdef(CaseInsensitiveProperties=true) fixeddf1tfilterq < quantum.abstractfixediirfilterq
    %FIXEDDF1TFILTERQ   Construct a FIXEDDF1TFILTERQ object.

%   Copyright 2018-2019 The MathWorks, Inc.
    
    %quantum.fixeddf1tfilterq class
    %   quantum.fixeddf1tfilterq extends quantum.abstractfixediirfilterq.
    %
    %    quantum.fixeddf1tfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputMode - Property is of type 'OutputModeType enumeration: {'AvoidOverflow','BestPrecision','SpecifyPrecision'}'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       NumAccumFracLength - Property is of type 'mxArray'
    %       DenAccumFracLength - Property is of type 'mxArray'
    %       NumProdFracLength - Property is of type 'mxArray'
    %       DenProdFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       DenFracLength - Property is of type 'mxArray'
    %       StateWordLength - Property is of type 'mxArray'
    %       StateAutoScale - Property is of type 'mxArray'
    %       NumStateFracLength - Property is of type 'mxArray'
    %       DenStateFracLength - Property is of type 'mxArray'
    %       MultiplicandWordLength - Property is of type 'mxArray'
    %       MultiplicandFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixeddf1tfilterq methods:
    %       blockparams -   Return the block parameters.
    %       df1tbodyconnect - specifies the connection and quantization parameters in the
    %       df1tfilter -   Filter method for DFILT.DF1T class in fixed-point.
    %       df1tfootconnect - specifies the connection and quantization parameters in the
    %       df1theadconnect - specifies the blocks, connection and quantization parameters in the
    %       df1theader_order0 - specifies the blocks, connection and quantization parameters in the
    %       disp - Object display.
    %       genmcode -   Generate the MATLAB code.
    %       get_dstatefl - GET_DENSTATEFL   PreGet function for the 'privdenstatefl' property.
    %       get_multfl -   PreGet function for the 'multfl' property.
    %       get_multwl -   PreGet function for the 'multwl' property.
    %       get_nstatefl - GET_NUMSTATEFL   PreGet function for the 'privnumstatefl' property.
    %       get_stateautoscale -   PreGet function for the 'stateautoscale' property.
    %       get_statewl -   PreGet function for the 'statewl' property.
    %       info -   Return the info for the object.
    %       internalsettings -   Returns fixed-point settings as viewed by the algorithm.
    %       quantizestates -   Quantize the states of a DF1 filter.
    %       set_denaccq - Specify word and fraction length of the accum passed to the mexfunction.
    %       set_denprodq - Specify product word and fraction length for the mexfunction.
    %       set_denstateq -   Define denominator state format
    %       set_dstatefl - SET_DENSTATEFL   PreSet function for the 'DenStateFracLength' property.
    %       set_multfl -   PreSet function for the 'MultiplicandFracLength' property.
    %       set_multwl -   PreSet function for the 'MultiplicandWordLength' property.
    %       set_nstatefl - SET_NUMSTATEFL   PreSet function for the 'NumStateFracLength' property.
    %       set_numaccq - Specify word and fraction length of the accum passed to the mexfunction.
    %       set_numprodq - Specify product word and fraction length for the mexfunction.
    %       set_numstateq -   Define numerator state format
    %       set_outq - Specify output word and fraction length for the mexfunction.
    %       set_statewl -   PreSet function for the 'statewl' property.
    %       setsysobjfixedpoint - Set converted System object fixed point properties
    %       specifyall -   Set the object to full specified precision mode.
    %       updateinternalsettings - Update the fixed-point settings
    %       validatestatesobj -   Validate the FILTSTATES.DFIIR object.
    
    %   Author(s): P. Costa
    
    properties (Access=protected, SetObservable)
        %PRIVSTATEWL Property is of type 'posint user-defined'
        privstatewl = 16;
        %PRIVNSTATEFL Property is of type 'int32'
        privnstatefl = 15;
        %PRIVDSTATEFL Property is of type 'int32'
        privdstatefl = 15;
        %PRIVSTATEAUTOSCALE Property is of type 'bool'
        privStateAutoScale = true;
        %PRIVMULTWL Property is of type 'posint user-defined'
        privmultwl = 16;
        %PRIVMULTFL Property is of type 'int32'
        privmultfl = 15;
    end
    
    properties (SetObservable)
        %STATEWORDLENGTH Property is of type 'mxArray'
        StateWordLength = [];
        %STATEAUTOSCALE Property is of type 'mxArray'
        StateAutoScale = [];
        %NUMSTATEFRACLENGTH Property is of type 'mxArray'
        NumStateFracLength = [];
        %DENSTATEFRACLENGTH Property is of type 'mxArray'
        DenStateFracLength = [];
        %MULTIPLICANDWORDLENGTH Property is of type 'mxArray'
        MultiplicandWordLength = [];
        %MULTIPLICANDFRACLENGTH Property is of type 'mxArray'
        MultiplicandFracLength = [];
    end
    
    
    methods  % constructor block
        function this = fixeddf1tfilterq
             
        end  % fixeddf1tfilterq
        
    end  % constructor block
    
    methods
        function value = get.StateWordLength(obj)
            value = get_statewl(obj,obj.StateWordLength);
        end
        function set.StateWordLength(obj,value)
            obj.StateWordLength = set_statewl(obj,value);
        end
        
        function value = get.StateAutoScale(obj)
            value = get_stateautoscale(obj,obj.StateAutoScale);
        end
        function set.StateAutoScale(obj,value)
            obj.StateAutoScale = set_stateautoscale(obj,value);
        end
        
        function value = get.NumStateFracLength(obj)
            value = get_nstatefl(obj,obj.NumStateFracLength);
        end
        function set.NumStateFracLength(obj,value)
            obj.NumStateFracLength = set_nstatefl(obj,value);
        end
        
        function value = get.DenStateFracLength(obj)
            value = get_dstatefl(obj,obj.DenStateFracLength);
        end
        function set.DenStateFracLength(obj,value)
            obj.DenStateFracLength = set_dstatefl(obj,value);
        end
        
        function value = get.MultiplicandWordLength(obj)
            value = get_multwl(obj,obj.MultiplicandWordLength);
        end
        function set.MultiplicandWordLength(obj,value)
            obj.MultiplicandWordLength = set_multwl(obj,value);
        end
        
        function value = get.MultiplicandFracLength(obj)
            value = get_multfl(obj,obj.MultiplicandFracLength);
        end
        function set.MultiplicandFracLength(obj,value)
            obj.MultiplicandFracLength = set_multfl(obj,value);
        end
        
        function set.privstatewl(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privstatewl = value;
        end
        
        function set.privnstatefl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privnstatefl')
            obj.privnstatefl = value;
        end
        
        function set.privdstatefl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privdstatefl')
            obj.privdstatefl = value;
        end
        
        function set.privStateAutoScale(obj,value)
            % DataType = 'bool'
            validateattributes(value,{'numeric','logical'}, {'scalar','nonnan'},'','privStateAutoScale')
            value = logical(value); %  convert to logical
            obj.privStateAutoScale = value;
        end
        
        function set.privmultwl(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privmultwl = value;
        end
        
        function set.privmultfl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privmultfl')
            obj.privmultfl = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,forceDigitalFilterBlock)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = df1tbodyconnect(q,NL,H,mainparams)
        [y,zfNum,zfDen,noverflows] = df1tfilter(q,b,a,x,ziNum,ziDen,limitcycleflag)
        [NL,PrevIPorts,PrevOPorts,mainparams] = df1tfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = df1theadconnect(q,NL,H,mainparams)
        Head = df1theader_order0(q,num,den,H,info)
        disp(this,varargin)
        h = genmcode(this)
        statefl = get_dstatefl(q,statefl)
        multfl = get_multfl(q,multfl)
        multwl = get_multwl(q,multwl)
        statefl = get_nstatefl(q,statefl)
        stateautoscale = get_stateautoscale(q,stateautoscale)
        statewl = get_statewl(q,statewl)
        [p,v] = info(this)
        s = internalsettings(q)
        S = quantizestates(q,S)
        [accWL,accFL] = set_denaccq(q,inWL,inFL,ncoeffs)
        [prodWL,prodFL] = set_denprodq(q,coeffWL,coeffFL,multWL,multFL)
        [stWL,stFL] = set_denstateq(q,accWL,accFL)
        statefl = set_dstatefl(this,statefl)
        multfl = set_multfl(this,multfl)
        multwl = set_multwl(this,multwl)
        statefl = set_nstatefl(this,statefl)
        [accWL,accFL] = set_numaccq(q,inWL,inFL,ncoeffs)
        [prodWL,prodFL] = set_numprodq(q,coeffWL,coeffFL,multWL,multFL)
        [stWL,stFL] = set_numstateq(q,accWL,accFL)
        set_outq(q,accWL,accFL)
        statewl = set_statewl(this,statewl)
        setsysobjfixedpoint(this,Hs)
        specifyall(this,flag)
        updateinternalsettings(q)
        S = validatestatesobj(q,S)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [ol,nstl,dstl,multl,npl,dpl,naccl,daccl] = getlog(this,y,nstates,dstates,multiplicand,num,den,numAcc,denAcc,x)
        inheritstates(q,S)
        Sden = nulldenstate(q)
        Snum = nullnumstate(q)
        S = nullstate1(q)
        stateautoscale = set_stateautoscale(this,stateautoscale)
        thisautoscale(this,s,binptaligned)
        thisloadobj(this,s)
        S = validatestates(q,S)
    end  % possibly private or hidden
    
end  % classdef

