classdef(CaseInsensitiveProperties=true) fixeddf2filterq < quantum.abstractfixediirfilterq
    %quantum.fixeddf2filterq class
    %   quantum.fixeddf2filterq extends quantum.abstractfixediirfilterq.
    %
    %    quantum.fixeddf2filterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputMode - Property is of type 'OutputModeType enumeration: {'AvoidOverflow','BestPrecision','SpecifyPrecision'}'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       NumAccumFracLength - Property is of type 'mxArray'
    %       DenAccumFracLength - Property is of type 'mxArray'
    %       NumProdFracLength - Property is of type 'mxArray'
    %       DenProdFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       DenFracLength - Property is of type 'mxArray'
    %       StateWordLength - Property is of type 'mxArray'
    %       StateFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixeddf2filterq methods:
    %       blockparams -   Return the parameters
    %       df2bodyconnect - specifies the connection and quantization parameters in the
    %       df2filter - Filter for DFILT.DF2 class in fixed-point mode.
    %       df2footconnect - specifies the connection and quantization parameters in the
    %       df2headconnect - specifies the blocks, connection and quantization parameters in the
    %       df2header_order0 - specifies the blocks, connection and quantization parameters in the
    %       disp - Object display.
    %       genmcode -   Generate the MATLAB code.
    %       get_statefl -   PreGet function for the 'statefl' property.
    %       get_statewl -   PreGet function for the 'statewl' property.
    %       info -   Return the info for the object.
    %       internalsettings -   Returns fixed-point settings as viewed by the algorithm.
    %       set_outq - Specify output word and fraction length for DF2.
    %       set_statefl -   PreSet function for the 'StateFracLength' property.
    %       set_statewl -   PreSet function for the 'StateWordLength' property.
    %       setsysobjfixedpoint - Set converted System object fixed point properties
    %       specifyall -   Set the object to full specified precision mode.
    %       thiscopy -   Copy this object.
    %       updateinternalsettings -   Update the internal settings.

%   Copyright 2018-2019 The MathWorks, Inc.
    
    
    properties (Access=protected, SetObservable)
        %PRIVSTATEWL Property is of type 'posint user-defined'
        privstatewl = 16;
        %PRIVSTATEFL Property is of type 'int32'
        privstatefl = 15;
    end
    
    properties (SetObservable)
        %STATEWORDLENGTH Property is of type 'mxArray'
        StateWordLength = [];
        %STATEFRACLENGTH Property is of type 'mxArray'
        StateFracLength = [];
    end
    
    
    methods
        function value = get.StateWordLength(obj)
            value = get_statewl(obj,obj.StateWordLength);
        end
        function set.StateWordLength(obj,value)
            obj.StateWordLength = set_statewl(obj,value);
        end
        
        function set.privstatewl(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privstatewl = value;
        end
        
        function value = get.StateFracLength(obj)
            value = get_statefl(obj,obj.StateFracLength);
        end
        function set.StateFracLength(obj,value)
            obj.StateFracLength = set_statefl(obj,value);
        end
        
        function set.privstatefl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privstatefl')
            obj.privstatefl = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,forceDigitalFilterBlock)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = df2bodyconnect(q,NL,H,mainparams)
        [y,zf,tapidxf,noverflows] = df2filter(q,b,a,x,zi,tapidxi,limitcycleflag)
        [NL,PrevIPorts,PrevOPorts,mainparams] = df2footconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = df2headconnect(q,NL,H,mainparams)
        Head = df2header_order0(q,num,den,H,info)
        disp(this,varargin)
        h = genmcode(this)
        statefl = get_statefl(q,statefl)
        statewl = get_statewl(q,statewl)
        [p,v] = info(this)
        s = internalsettings(q)
        set_outq(q,accWL,accFL)
        statefl = set_statefl(this,statefl)
        statewl = set_statewl(this,statewl)
        setsysobjfixedpoint(this,Hs)
        specifyall(this,flag)
        thiscopy(this,Hd)
        updateinternalsettings(q)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [ol,stl,npl,dpl,naccl,daccl] = getlog(this,y,states,num,den,numAcc,denAcc,x)
        inheritstates(q,S)
        S = nullstate1(q)
        S = prependzero(q,S)
        S = quantizestates(q,S)
        thisautoscale(this,s,binptaligned)
        thisloadobj(this,s)
    end  % possibly private or hidden
    
end  % classdef

