classdef(CaseInsensitiveProperties=true) fixeddf2tfilterq < quantum.fixeddf1filterq
    %FIXEDDF2TFILTERQ   Construct a FIXEDDF2TFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixeddf2tfilterq class
    %   quantum.fixeddf2tfilterq extends quantum.fixeddf1filterq.
    %
    %    quantum.fixeddf2tfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       DenFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       NumProdFracLength - Property is of type 'mxArray'
    %       DenProdFracLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       NumAccumFracLength - Property is of type 'mxArray'
    %       DenAccumFracLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputFracLength - Property is of type 'mxArray'
    %       StateWordLength - Property is of type 'mxArray'
    %       StateAutoScale - Property is of type 'mxArray'
    %       StateFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixeddf2tfilterq methods:
    %       blockparams -   Return the parameters
    %       df2tbodyconnect - specifies the connection and quantization parameters in the
    %       df2tfilter - Filter for DFILT.DF2T class in fixed-point
    %       df2tfootconnect - specifies the connection and quantization parameters in the
    %       df2theadconnect - specifies connection and quantization parameters in the
    %       df2theader_order0 - specifies the blocks, connection and quantization parameters in the
    %       disp - Object display.
    %       genmcode -   Generate MATLAB code.
    %       get_stateautoscale -   PreGet function for the 'stateautoscale' property.
    %       get_statefl -   PreGet function for the 'statefl' property.
    %       get_statewl -   PreGet function for the 'statewl' property.
    %       info -   Return the info for the object.
    %       internalsettings -   Returns fixed-point settings as viewed by the algorithm.
    %       set_denaccq - Specify word and fraction length of the accum passed to the mexfunction.
    %       set_numaccq - Specify word and fraction length of the accum passed to the mexfunction.
    %       set_stateautoscale -   PreSet function for the 'StateAutoScale' property.
    %       set_statefl -   PreSet function for the 'StateFracLength' property.
    %       set_stateq -   Define state format
    %       set_statewl -   PreSet function for the 'StateWordLength' property.
    %       setsysobjfixedpoint - Set converted System object fixed point properties
    %       specifyall -   Set the object to full specified precision mode.
    
    %   Author(s): P. Costa
    
    properties (Access=protected, SetObservable)
        %PRIVSTATEWL Property is of type 'posint user-defined'
        privstatewl = 16;
        %PRIVSTATEAUTOSCALE Property is of type 'bool'
        privStateAutoScale = true;
        %PRIVSTATEFL Property is of type 'int32'
        privstatefl = 15;
    end
    
    properties (SetObservable)
        %STATEWORDLENGTH Property is of type 'mxArray'
        StateWordLength = [];
        %STATEAUTOSCALE Property is of type 'mxArray'
        StateAutoScale = [];
        %STATEFRACLENGTH Property is of type 'mxArray'
        StateFracLength = [];
    end
    
    
    methods  % constructor block
        function this = fixeddf2tfilterq
            % Create a default number of coefficients
            this.ncoeffs = [1 1];
            
            % Force the default AccumWordLength
            this.AccumWordLength = 40;
             
        end  % fixeddf2tfilterq
        
    end  % constructor block
    
    methods
        function value = get.StateWordLength(obj)
            value = get_statewl(obj,obj.StateWordLength);
        end
        function set.StateWordLength(obj,value)
            obj.StateWordLength = set_statewl(obj,value);
        end
        
        function value = get.StateAutoScale(obj)
            value = get_stateautoscale(obj,obj.StateAutoScale);
        end
        function set.StateAutoScale(obj,value)
            obj.StateAutoScale = set_stateautoscale(obj,value);
        end
        
        function value = get.StateFracLength(obj)
            value = get_statefl(obj,obj.StateFracLength);
        end
        function set.StateFracLength(obj,value)
            obj.StateFracLength = set_statefl(obj,value);
        end
        
        function set.privstatewl(obj,value)
            % User-defined DataType = 'posint user-defined'
            obj.privstatewl = value;
        end
        
        function set.privStateAutoScale(obj,value)
            % DataType = 'bool'
            validateattributes(value,{'numeric','logical'}, {'scalar','nonnan'},'','privStateAutoScale')
            value = logical(value); %  convert to logical
            obj.privStateAutoScale = value;
        end
        
        function set.privstatefl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privstatefl')
            obj.privstatefl = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,forceDigitalFilterBlock)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = df2tbodyconnect(q,NL,H,mainparams)
        [y,zf,noverflows] = df2tfilter(q,b,a,x,zi,limitcycleflag)
        [NL,PrevIPorts,PrevOPorts,mainparams] = df2tfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = df2theadconnect(q,NL,H,mainparams)
        Head = df2theader_order0(q,num,den,H,info)
        disp(this,varargin)
        h = genmcode(this)
        stateautoscale = get_stateautoscale(q,stateautoscale)
        statefl = get_statefl(q,statefl)
        statewl = get_statewl(q,statewl)
        [p,v] = info(this)
        s = internalsettings(q)
        [accWL,accFL] = set_denaccq(q,inWL,inFL,ncoeffs)
        [accWL,accFL] = set_numaccq(q,inWL,inFL,ncoeffs)
        stateautoscale = set_stateautoscale(this,stateautoscale)
        statefl = set_statefl(this,statefl)
        [stWL,stFL] = set_stateq(q,accWL,accFL)
        statewl = set_statewl(this,statewl)
        setsysobjfixedpoint(this,Hs)
        specifyall(this,flag)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [ol,stl,npl,dpl,naccl,daccl] = getlog(this,y,states,num,den,numAcc,denAcc,x)
        inheritstates(q,S)
        S = nullstate1(q)
        S = quantizestates(q,S)
        thisautoscale(this,s,binptaligned)
        thisloadobj(this,s)
        updateinternalsettings(q)
        S = validatestates(q,S)
    end  % possibly private or hidden
    
end  % classdef

