classdef(CaseInsensitiveProperties=true) fixeddffirfilterq < quantum.abstractfixeddffirmultiratefilterq
    %FIXEDDFFIRFILTERQ   Construct a FIXEDDFFIRFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixeddffirfilterq class
    %   quantum.fixeddffirfilterq extends quantum.abstractfixeddffirmultiratefilterq.
    %
    %    quantum.fixeddffirfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       FilterInternals - Property is of type 'FilterInternalsType enumeration: {'FullPrecision','SpecifyPrecision'}'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductWordLength - Property is of type 'mxArray'
    %       ProductFracLength - Property is of type 'mxArray'
    %       AccumWordLength - Property is of type 'mxArray'
    %       AccumFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixeddffirfilterq methods:
    %       blockparams -   Return the parameters for the block.
    %       dffirbodyconnect - specifies the connection and quantization parameters in the
    %       dffirfilter -   Filtering method for DFFIR.
    %       dffirfootconnect - specifies the connection and quantization parameters in the
    %       dffirheadconnect - specifies connection and quantization parameters in the
    %       dffirheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       disp - Object display.
    %       fir_blockparams - BLOCKPARAMS   Return the block params for the fixed point settings.
    %       genmcode -   Generate an MATLAB code object for this object.
    %       getbestprecision - Return best precision for Product and Accumulator
    %       setmaxprod -   Set the maxprod.
    %       setmaxsum -   Set the maxsum.
    
    %   Author(s): V. Pellissier
    
    methods  % constructor block
        function this = fixeddffirfilterq
            % Force Sum and ProductMode to SpecifyPrecision
            this.fimath.ProductMode = 'SpecifyPrecision';
            this.fimath.SumMode = 'SpecifyPrecision';
            
            % Make CastBeforeSum false by default
            this.fimath.CastBeforeSum = false;
        end  % fixeddffirfilterq
        
    end  % constructor block
    
    methods  % public methods
        p = blockparams(this,forceDigitalFilterBlock)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = dffirbodyconnect(q,NL,H,mainparams)
        [y,z,tapidx] = dffirfilter(q,b,x,z,tapidx)
        [NL,PrevIPorts,PrevOPorts,mainparams] = dffirfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = dffirheadconnect(q,NL,H,mainparams)
        Head = dffirheader_order0(q,num,H,info)
        disp(this,varargin)
        p = fir_blockparams(this,forceDigitalFilterBlock)
        hcode = genmcode(this)
        s = getbestprecision(q)
        setmaxprod(this,Hd)
        setmaxsum(this,Hd)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [prodlog,outlog,acclog] = getlog(this,b,y,acc,x,inlog)
        bits2add = nguardbits(q)
        prodfl = set_prodfl(q,prodfl)
        prodwl = set_prodwl(q,prodwl)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
end  % classdef

