classdef(CaseInsensitiveProperties=true) fixeddffirtfilterq < quantum.abstractfixeddffirmultiratefilterq
    %FIXEDDFFIRTFILTERQ   Construct a FIXEDDFFIRTFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixeddffirtfilterq class
    %   quantum.fixeddffirtfilterq extends quantum.abstractfixeddffirmultiratefilterq.
    %
    %    quantum.fixeddffirtfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       FilterInternals - Property is of type 'FilterInternalsType enumeration: {'FullPrecision','SpecifyPrecision'}'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductWordLength - Property is of type 'mxArray'
    %       ProductFracLength - Property is of type 'mxArray'
    %       AccumWordLength - Property is of type 'mxArray'
    %       AccumFracLength - Property is of type 'mxArray'
    %       StateWordLength - Property is of type 'mxArray'  (read only)
    %       StateFracLength - Property is of type 'mxArray'  (read only)
    %
    %    quantum.fixeddffirtfilterq methods:
    %       blockparams -   Returns the parameters for the block.
    %       dffirtbodyconnect - specifies the connection and quantization parameters in the
    %       dffirtfilter -   Filtering method for DFFIRT.
    %       dffirtfootconnect - specifies the connection and quantization parameters in the
    %       dffirtheadconnect - specifies the blocks, connection and quantization parameters in the
    %       dffirtheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       disp - Object display.
    %       fir_blockparams - BLOCKPARAMS   Return the block params for the fixed point settings.
    %       genmcode -   Generate an MATLAB code object for this object.
    %       get_statefl -   PreGet function for the 'statefl' property.
    %       get_statewl -   PreGet function for the 'statewl' property.
    %       getbestprecision - Return best precision for Product and Accumulator
    %       info -   Return the information for the display.
    %       set_statefl -   PreSet function for the 'statefl' property.
    %       set_statewl -   PreSet function for the 'statewl' property.
    %       setmaxprod -   Set the maxprod.
    %       setmaxsum -   Set the maxsum.
    
    %   Author(s): V. Pellissier
    
    properties (Access=protected, SetObservable)
        %PRIVSTATEWL Property is of type 'int32'
        privstatewl = 16;
        %PRIVSTATEFL Property is of type 'int32'
        privstatefl = 15;
    end
    
    properties (SetAccess=protected, Transient, SetObservable)
        %STATEWORDLENGTH Property is of type 'mxArray'  (read only)
        StateWordLength = [];
        %STATEFRACLENGTH Property is of type 'mxArray'  (read only)
        StateFracLength = [];
    end
    
    methods  % constructor block
        function this = fixeddffirtfilterq
            % Force Sum and ProductMode to SpecifyPrecision
            this.fimath.ProductMode = 'SpecifyPrecision';
            this.fimath.SumMode = 'SpecifyPrecision';
            
            % Make CastBeforeSum false by default
            this.fimath.CastBeforeSum = false;
        end  % fixeddffirtfilterq
    end  % constructor block
    
    methods
        function value = get.StateWordLength(obj)
            value = get_statewl(obj,obj.StateWordLength);
        end
        function set.StateWordLength(obj,value)
            obj.StateWordLength = set_statewl(obj,value);
        end
        
        function value = get.StateFracLength(obj)
            value = get_statefl(obj,obj.StateFracLength);
        end
        function set.StateFracLength(obj,value)
            obj.StateFracLength = set_statefl(obj,value);
        end
        
        function set.privstatewl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privstatewl')
            obj.privstatewl = value;
        end
        
        function set.privstatefl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privstatefl')
            obj.privstatefl = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,forceDigitalFilterBlock)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = dffirtbodyconnect(q,NL,H,mainparams)
        [y,z] = dffirtfilter(q,b,x,z)
        [NL,PrevIPorts,PrevOPorts,mainparams] = dffirtfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = dffirtheadconnect(q,NL,H,mainparams)
        Head = dffirtheader_order0(q,num,H,info)
        disp(this,varargin)
        p = fir_blockparams(this,forceDigitalFilterBlock)
        hcode = genmcode(this)
        statefl = get_statefl(q,statefl)
        statewl = get_statewl(q,statewl)
        s = getbestprecision(q)
        [p,v] = info(this)
        statefl = set_statefl(q,statefl)
        statewl = set_statewl(q,statewl)
        setmaxprod(this,Hd)
        setmaxsum(this,Hd)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [prodlog,outlog,acclog,statelog] = getlog(this,b,y,acc,z,x,inlog)
        bits2add = nguardbits(q)
        S = nullstate1(q)
        S = quantizestates(q,S)
        prodfl = set_prodfl(q,prodfl)
        prodwl = set_prodwl(q,prodwl)
        thisset_accumfl(q,accumfl)
        thisset_accumwl(q,accumwl)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
end  % classdef

