classdef(CaseInsensitiveProperties=true) fixeddfsymfirfilterq < quantum.abstractfixeddffirmultiratefilterq
    %FIXEDDFSYMFIRFILTERQ   Construct a FIXEDDFSYMFIRFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixeddfsymfirfilterq class
    %   quantum.fixeddfsymfirfilterq extends quantum.abstractfixeddffirmultiratefilterq.
    %
    %    quantum.fixeddfsymfirfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       FilterInternals - Property is of type 'FilterInternalsType enumeration: {'FullPrecision','SpecifyPrecision'}'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductWordLength - Property is of type 'mxArray'
    %       ProductFracLength - Property is of type 'mxArray'
    %       AccumWordLength - Property is of type 'mxArray'
    %       AccumFracLength - Property is of type 'mxArray'
    %       TapSumWordLength - Property is of type 'mxArray'  (read only)
    %       TapSumFracLength - Property is of type 'mxArray'  (read only)
    %
    %    quantum.fixeddfsymfirfilterq methods:
    %       blockparams -   Return the block parameters.
    %       dfasymfirbodyconnect - specifies the connection and quantization parameters in the
    %       dfasymfirfootconnect - specifies the connection and quantization parameters in the
    %       dfasymfirheadconnect - specifies connection and quantization parameters in the
    %       dfasymfirheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       dfsymfirbodyconnect - specifies the connection and quantization parameters in the
    %       dfsymfirfootconnect - specifies the connection and quantization parameters in the
    %       dfsymfirheadconnect - specifies connection and quantization parameters in the
    %       dfsymfirheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       disp - Object display.
    %       fir_blockparams - BLOCKPARAMS   Return the block params for the fixed point settings.
    %       genmcode -   Generate an MATLAB code object for this object.
    %       getbestprecision - Return best precision for Product and Accumulator
    %       info -   Return the information for the display.
    %       setmaxprod -   Set the maxprod.
    %       setmaxsum -   Set the maxsum.
    
    %   Author(s): V. Pellissier
    
    properties (Access=protected, SetObservable)
        %TAPSUMFIMATH Property is of type 'mxArray'
        TapSumfimath = fimath( 'RoundMode', 'convergent', 'OverflowMode', 'wrap', 'ProductMode', 'SpecifyPrecision', 'ProductWordLength', 17, 'ProductFractionLength', 15, 'SumMode', 'SpecifyPrecision', 'SumWordLength', 17, 'SumFractionLength', 15 );
    end
    
    properties (SetAccess=protected, Transient, SetObservable)
        %TAPSUMWORDLENGTH Property is of type 'mxArray'  (read only)
        TapSumWordLength = [];
        %TAPSUMFRACLENGTH Property is of type 'mxArray'  (read only)
        TapSumFracLength = [];
    end
    
    
    methods  % constructor block
        function this = fixeddfsymfirfilterq
            % Force Sum and ProductMode to SpecifyPrecision
            this.fimath.ProductMode = 'SpecifyPrecision';
            this.fimath.SumMode = 'SpecifyPrecision';
            this.TapSumfimath.ProductMode = 'SpecifyPrecision';
            this.TapSumfimath.SumMode = 'SpecifyPrecision';
            
            % Make CastBeforeSum false by default
            this.fimath.CastBeforeSum = false;
            this.TapSumfimath.CastBeforeSum = false;
        end  % fixeddfsymfirfilterq
    end  % constructor block
    
    methods
        function value = get.TapSumWordLength(obj)
            value = get_tapsumwl(obj,obj.TapSumWordLength);
        end
        function set.TapSumWordLength(obj,value)
            obj.TapSumWordLength = set_tapsumwl(obj,value);
        end
        
        function value = get.TapSumFracLength(obj)
            value = get_tapsumfl(obj,obj.TapSumFracLength);
        end
        function set.TapSumFracLength(obj,value)
            obj.TapSumFracLength = set_tapsumfl(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,forceDigitalFilterBlock)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = dfasymfirbodyconnect(q,NL,H,mainparams)
        [NL,PrevIPorts,PrevOPorts,mainparams] = dfasymfirfootconnect(q,NL,H,mainparams,info)
        [NL,NextIPorts,NextOPorts,mainparams] = dfasymfirheadconnect(q,NL,H,mainparams)
        Head = dfasymfirheader_order0(q,num,H,info)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = dfsymfirbodyconnect(q,NL,H,mainparams)
        [NL,PrevIPorts,PrevOPorts,mainparams] = dfsymfirfootconnect(q,NL,H,mainparams,info)
        [NL,NextIPorts,NextOPorts,mainparams] = dfsymfirheadconnect(q,NL,H,mainparams)
        Head = dfsymfirheader_order0(q,num,H,info)
        disp(h,spacing)
        p = fir_blockparams(this,forceDigitalFilterBlock)
        hcode = genmcode(this)
        s = getbestprecision(q)
        [p,v] = info(this)
        setmaxprod(this,Hd)
        setmaxsum(this,Hd)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [y,z,tapIndex] = dfantisymmetricfirfilter(q,b,x,z,tapIndex)
        [y,z,tapIndex] = dfsymmetricfirfilter(q,b,x,z,tapIndex)
        tapsumfl = get_tapsumfl(q,tapsumfl)
        tapsumwl = get_tapsumwl(q,tapsumwl)
        [prodlog,outlog,acclog,tapsumlog] = getasymlog(this,b,y,acc,tapsum,x,inlog)
        [prodlog,outlog,acclog,tapsumlog] = getsymlog(this,b,y,acc,tapsum,x,inlog)
        bits2add = nguardbits(q)
        prodfl = set_prodfl(q,prodfl)
        prodwl = set_prodwl(q,prodwl)
        tapsumfl = set_tapsumfl(q,tapsumfl)
        tapsumwl = set_tapsumwl(q,tapsumwl)
        thisautoscale(this,s,binptaligned)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
end  % classdef

