classdef(CaseInsensitiveProperties=true) fixedfirfilterq < quantum.abstractfixednonscalarfilterq
    %FIXEDFIRFILTERQ   Construct a FIXEDFIRFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixedfirfilterq class
    %   quantum.fixedfirfilterq extends quantum.abstractfixednonscalarfilterq.
    %
    %    quantum.fixedfirfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputMode - Property is of type 'OutputModeType enumeration: {'AvoidOverflow','BestPrecision','SpecifyPrecision'}'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       NumFracLength - Property is of type 'mxArray'
    %       ProductFracLength - Property is of type 'mxArray'
    %       AccumFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixedfirfilterq methods:
    %       blockparams -   Return the parameters for the block.
    %       dffirbodyconnect - specifies the connection and quantization parameters in the
    %       dffirfootconnect - specifies the connection and quantization parameters in the
    %       dffirheadconnect - specifies connection and quantization parameters in the
    %       dffirheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       fir_blockparams - BLOCKPARAMS   Return the block params for the fixed point settings.
    %       fir_genmcode -   Generate MATLAB code.
    %       fir_thisloadobj -   Load this object
    %       genmcode -   Generate MATLAB code.
    %       info -   Return the info for this object.
    %       internalsettings - Returns the fixed-point settings viewed by the algorithm.
    %       loadobj -   Load the object.
    %       quantizecoeffs -  Quantize coefficients
    %       set_infl -   PreSet function for the 'infl' property.
    %       set_inwl -   PreSet function for the 'inwl' property.
    %       thisloadobj -   Load the object.
    %       update -  Converts to new fixed-point filter quantizer for DFFIR
    
    %   Author(s): J. Schickler
    
    properties (SetObservable)
        %NUMFRACLENGTH Property is of type 'mxArray'
        NumFracLength = [];
        %PRODUCTFRACLENGTH Property is of type 'mxArray'
        ProductFracLength = [];
        %ACCUMFRACLENGTH Property is of type 'mxArray'
        AccumFracLength = [];
    end
    
    
    methods  % constructor block
        function this = fixedfirfilterq
            % Force the default AccumWordLength
            this.AccumWordLength = 40;
        end  % fixedfirfilterq
        
    end  % constructor block
    
    methods
        function value = get.NumFracLength(obj)
            value = get_numfl(obj,obj.NumFracLength);
        end
        function set.NumFracLength(obj,value)
            obj.NumFracLength = set_numfl(obj,value,'NumFracLength');
        end
        
        function value = get.ProductFracLength(obj)
            value = get_prodfl(obj,obj.ProductFracLength);
        end
        function set.ProductFracLength(obj,value)
            obj.ProductFracLength = set_prodfl(obj,value);
        end
        
        function value = get.AccumFracLength(obj)
            value = get_accumfl(obj,obj.AccumFracLength);
        end
        function set.AccumFracLength(obj,value)
            obj.AccumFracLength = set_accumfl(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,varargin)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = dffirbodyconnect(q,NL,H,mainparams)
        [NL,PrevIPorts,PrevOPorts,mainparams] = dffirfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = dffirheadconnect(q,NL,H,mainparams)
        Head = dffirheader_order0(q,num,H,info)
        p = fir_blockparams(this,forceDigitalFilterBlock)
        h = fir_genmcode(this)
        fir_thisloadobj(this,s)
        h = genmcode(this)
        [p,v] = info(this)
        s = internalsettings(q)
        cq = quantizecoeffs(q,c)
        infl = set_infl(q,infl)
        inwl = set_inwl(this,inwl)
        thisloadobj(this,s)
        new = update(this,s)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [y,zf,tapIndex] = dffirfilter(q,b,x,zi,tapIndex)
        inheritstates(q,S)
        S = nullstate1(q)
        S = nullstate2(q)
        S = prependzero(q,S)
        S = quantizestates(q,S)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
    
    methods (Static) % static methods
        this = loadobj(s)
    end  % static methods
    
end  % classdef

