classdef(CaseInsensitiveProperties=true) fixedfirfilterqwstates < quantum.fixedfirfilterq
    %FIXEDFIRFILTERQWSTATES   Construct a FIXEDFIRFILTERQWSTATES object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixedfirfilterqwstates class
    %   quantum.fixedfirfilterqwstates extends quantum.fixedfirfilterq.
    %
    %    quantum.fixedfirfilterqwstates properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputMode - Property is of type 'OutputModeType enumeration: {'AvoidOverflow','BestPrecision','SpecifyPrecision'}'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       NumFracLength - Property is of type 'mxArray'
    %       ProductFracLength - Property is of type 'mxArray'
    %       AccumFracLength - Property is of type 'mxArray'
    %       StateWordLength - Property is of type 'mxArray'
    %       StateAutoScale - Property is of type 'mxArray'
    %       StateFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixedfirfilterqwstates methods:
    %       blockparams -   Returns the parameters for the block.
    %       dffirtbodyconnect - specifies the connection and quantization parameters in the
    %       dffirtfootconnect - specifies the connection and quantization parameters in the
    %       dffirtheadconnect - specifies the blocks, connection and quantization parameters in the
    %       dffirtheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       disp - Object display.
    %       genmcode -   Generate the MATLAB code.
    %       get_stateautoscale -   PreGet function for the 'stateautoscale' property.
    %       get_statefl -   PreGet function for the 'statefl' property.
    %       get_statewl -   PreGet function for the 'statewl' property.
    %       info -   Return the info for this object.
    %       internalsettings - Returns the fixed-point settings viewed by the algorithm.
    %       set_accq - Specify word and fraction length of the accum passed to the mexfunction.
    %       set_stateautoscale -   PreSet function for the 'StateAutoScale' property.
    %       set_statefl -   PreSet function for the 'StateFracLength' property.
    %       set_stateq -   Define state format
    %       set_statewl -   PreSet function for the 'StateWordLength' property.
    %       update -  Converts to new fixed-point filter quantizer for DFFIRT
    
    %   Author(s): J. Schickler
    
    properties (Access=protected, SetObservable)
        %PRIVSTATEWL Property is of type 'int32'
        privstatewl = 16;
        %PRIVSTATEAUTOSCALE Property is of type 'bool'
        privStateAutoScale = true;
        %PRIVSTATEFL Property is of type 'int32'
        privstatefl = 15;
    end
    
    properties (SetObservable)
        %STATEWORDLENGTH Property is of type 'mxArray'
        StateWordLength = [];
        %STATEAUTOSCALE Property is of type 'mxArray'
        StateAutoScale = [];
        %STATEFRACLENGTH Property is of type 'mxArray'
        StateFracLength = [];
    end
    
    
    methods  % constructor block
        function this = fixedfirfilterqwstates
            % Force the default AccumWordLength
            this.AccumWordLength = 40;
        end  % fixedfirfilterqwstates
        
    end  % constructor block
    
    methods
        function value = get.StateWordLength(obj)
            value = get_statewl(obj,obj.StateWordLength);
        end
        function set.StateWordLength(obj,value)
            obj.StateWordLength = set_statewl(obj,value);
        end
        
        function value = get.StateAutoScale(obj)
            value = get_stateautoscale(obj,obj.StateAutoScale);
        end
        function set.StateAutoScale(obj,value)
            obj.StateAutoScale = set_stateautoscale(obj,value);
        end
        
        function value = get.StateFracLength(obj)
            value = get_statefl(obj,obj.StateFracLength);
        end
        function set.StateFracLength(obj,value)
            obj.StateFracLength = set_statefl(obj,value);
        end
        
        function set.privstatewl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privstatewl')
            obj.privstatewl = value;
        end
        
        function set.privStateAutoScale(obj,value)
            % DataType = 'bool'
            validateattributes(value,{'numeric','logical'}, {'scalar','nonnan'},'','privStateAutoScale')
            value = logical(value); %  convert to logical
            obj.privStateAutoScale = value;
        end
        
        function set.privstatefl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privstatefl')
            obj.privstatefl = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,varargin)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = dffirtbodyconnect(q,NL,H,mainparams)
        [NL,PrevIPorts,PrevOPorts,mainparams] = dffirtfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = dffirtheadconnect(q,NL,H,mainparams)
        Head = dffirtheader_order0(q,num,H,info)
        disp(this,varargin)
        h = genmcode(this)
        stateautoscale = get_stateautoscale(q,stateautoscale)
        statefl = get_statefl(q,statefl)
        statewl = get_statewl(q,statewl)
        [p,v] = info(this)
        s = internalsettings(q)
        [accWL,accFL] = set_accq(q,inWL,inFL,ncoeffs)
        stateautoscale = set_stateautoscale(this,stateautoscale)
        statefl = set_statefl(this,statefl)
        [stWL,stFL] = set_stateq(q,accWL,accFL)
        statewl = set_statewl(this,statewl)
        new = update(this,s)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [y,zf] = dffirtfilter(q,b,x,zi)
        inheritstates(q,S)
        S = quantizestates(q,S)
        specifyall(this,flag)
        thisloadobj(this,s)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
end  % classdef

