classdef(CaseInsensitiveProperties=true) fixedfirfilterqwtapsum < quantum.fixedfirfilterq
    %FIXEDFIRFILTERQWTAPSUM   Construct a FIXEDFIRFILTERQWTAPSUM object.

%   Copyright 2018-2019 The MathWorks, Inc.
    
    %quantum.fixedfirfilterqwtapsum class
    %   quantum.fixedfirfilterqwtapsum extends quantum.fixedfirfilterq.
    %
    %    quantum.fixedfirfilterqwtapsum properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputMode - Property is of type 'OutputModeType enumeration: {'AvoidOverflow','BestPrecision','SpecifyPrecision'}'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       NumFracLength - Property is of type 'mxArray'
    %       ProductFracLength - Property is of type 'mxArray'
    %       AccumFracLength - Property is of type 'mxArray'
    %       TapSumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       TapSumWordLength - Property is of type 'mxArray'
    %       TapSumFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixedfirfilterqwtapsum methods:
    %       blockparams -   Return the block parameters.
    %       dfasymfirbodyconnect - specifies the connection and quantization parameters in the
    %       dfasymfirfootconnect - specifies the connection and quantization parameters in the
    %       dfasymfirheadconnect - specifies connection and quantization parameters in the
    %       dfasymfirheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       dfsymfirbodyconnect - specifies the connection and quantization parameters in the
    %       dfsymfirfootconnect - specifies the connection and quantization parameters in the
    %       dfsymfirheadconnect - specifies connection and quantization parameters in the
    %       dfsymfirheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       disp - Object display.
    %       genmcode -   Generate MATLAB code.
    %       get_tapsummode -   PreGet function for the 'tapsummode' property.
    %       getbestprecision - Return best precision for Product and Accumulator
    %       info -   Return the info for this object.
    %       internalsettings - Returns the fixed-point settings viewed by the algorithm.
    %       set_tapsumfl -   PreSet function for the 'TapSumFracLength' property.
    %       set_tapsumq -  Specify word and fraction length of the tapsum passed to the mexfunction.
    %       set_tapsumwl -   PreSet function for the 'TapSumWordLength' property.
    %       thisloadobj -   Load this object.
    %       update -  Converts to new fixed-point filter quantizer for DFASYMFIR\DFSYMFIR
    
    %   Author(s): V. Pellissier
    
    properties (Access=protected, SetObservable)
        %TAPSUMFIMATH Property is of type 'mxArray'
        TapSumfimath = fimath( 'RoundMode', 'convergent', 'OverflowMode', 'wrap', 'ProductMode', 'SpecifyPrecision', 'ProductWordLength', 17, 'ProductFractionLength', 15, 'SumMode', 'SpecifyPrecision', 'SumWordLength', 17, 'SumFractionLength', 15 );
        %PRIVTAPSUMMODE Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
        privTapSumMode = 'KeepMSB';
    end
    
    properties (SetObservable)
        %TAPSUMMODE Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
        TapSumMode = 'FullPrecision';
        %TAPSUMWORDLENGTH Property is of type 'mxArray'
        TapSumWordLength = [];
        %TAPSUMFRACLENGTH Property is of type 'mxArray'
        TapSumFracLength = [];
    end
    
    
    methods  % constructor block
        function this = fixedfirfilterqwtapsum
            % Force the default AccumWordLength
            this.AccumWordLength = 40;
        end  % fixedfirfilterqwtapsum
        
    end  % constructor block
    
    methods
        function value = get.TapSumMode(obj)
            value = get_tapsummode(obj,obj.TapSumMode);
        end
        function set.TapSumMode(obj,value)
            % Enumerated DataType = 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
            value = validatestring(value,{'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'},'','TapSumMode');
            obj.TapSumMode = set_tapsummode(obj,value);
        end
        
        function value = get.TapSumWordLength(obj)
            value = get_tapsumwl(obj,obj.TapSumWordLength);
        end
        function set.TapSumWordLength(obj,value)
            obj.TapSumWordLength = set_tapsumwl(obj,value);
        end
        
        function value = get.TapSumFracLength(obj)
            value = get_tapsumfl(obj,obj.TapSumFracLength);
        end
        function set.TapSumFracLength(obj,value)
            obj.TapSumFracLength = set_tapsumfl(obj,value);
        end
        
        function set.privTapSumMode(obj,value)
            % Enumerated DataType = 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
            value = validatestring(value,{'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'},'','privTapSumMode');
            obj.privTapSumMode = value;
        end
        
        function values = getAllowedStringValues(obj,prop)
            % This function gives the valid string values for object properties.
            values = getAllowedStringValues@quantum.abstractfixedfilterq(obj, prop);
            switch prop
                case 'TapSumMode'
                    values = {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'};
            end
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,varargin)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = dfasymfirbodyconnect(q,NL,H,mainparams)
        [NL,PrevIPorts,PrevOPorts,mainparams] = dfasymfirfootconnect(q,NL,H,mainparams,info)
        [NL,NextIPorts,NextOPorts,mainparams] = dfasymfirheadconnect(q,NL,H,mainparams)
        Head = dfasymfirheader_order0(q,num,H,info)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = dfsymfirbodyconnect(q,NL,H,mainparams)
        [NL,PrevIPorts,PrevOPorts,mainparams] = dfsymfirfootconnect(q,NL,H,mainparams,info)
        [NL,NextIPorts,NextOPorts,mainparams] = dfsymfirheadconnect(q,NL,H,mainparams)
        Head = dfsymfirheader_order0(q,num,H,info)
        disp(this,varargin)
        h = genmcode(this)
        tapsummode = get_tapsummode(q,tapsummode)
        s = getbestprecision(q)
        [p,v] = info(this)
        s = internalsettings(q)
        tapsumfl = set_tapsumfl(this,tapsumfl)
        [tsWL,tsFL] = set_tapsumq(q,inWL,inFL)
        tapsumwl = set_tapsumwl(this,tapsumwl)
        thisloadobj(this,s)
        new = update(this,s)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [y,zf,tapIndex] = dfantisymmetricfirfilter(q,b,x,zi,tapIndex)
        [y,zf,tapIndex] = dfsymmetricfirfilter(q,b,x,zi,tapIndex)
        tapsumfl = get_tapsumfl(q,tapsumfl)
        tapsumwl = get_tapsumwl(q,tapsumwl)
        cbs = set_cbs(q,cbs)
        tapsummode = set_tapsummode(q,tapsummode)
        specifyall(this,flag)
        om = thisset_om(q,om)
        rm = thisset_rm(q,rm)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
end  % classdef

