classdef(CaseInsensitiveProperties=true) fixedfirinterpfilterq < quantum.abstractfixeddffirmultiratefilterq
    %FIXEDFIRINTERPFILTERQ   Construct a FIXEDFIRINTERPFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixedfirinterpfilterq class
    %   quantum.fixedfirinterpfilterq extends quantum.abstractfixeddffirmultiratefilterq.
    %
    %    quantum.fixedfirinterpfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       FilterInternals - Property is of type 'FilterInternalsType enumeration: {'FullPrecision','SpecifyPrecision'}'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductWordLength - Property is of type 'mxArray'
    %       ProductFracLength - Property is of type 'mxArray'
    %       AccumWordLength - Property is of type 'mxArray'
    %       AccumFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixedfirinterpfilterq methods:
    %       firinterpfilter -   Filtering method for fir interpolator.
    %       firsrcfilter -   Filtering method for fir SRC.
    %       setmaxsum -   Set the maxsum.
    
    %   Author(s): R. Losada
    
    methods  % constructor block
        function q = fixedfirinterpfilterq
            % Force Sum and ProductMode to SpecifyPrecision
            q.fimath.ProductMode = 'SpecifyPrecision';
            q.fimath.SumMode = 'SpecifyPrecision';
            
            % Make CastBeforeSum false by default
            q.fimath.CastBeforeSum = false;
        end  % fixedfirinterpfilterq
        
    end  % constructor block
    
    methods  % public methods
        [y,z,tapidx] = firinterpfilter(q,L,p,x,z,tapidx,nx,nchans,ny)
        [y,z,tapidx] = firsrcfilter(q,L,M,p,x,z,tapidx,im,inOffset,Mx,Nx,My)
        setmaxsum(this,Hd)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = firinterpbodyconnect(q,NL,H,mainparams,interp_order)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = firinterpfootconnect(q,NL,H,mainparams,interp_order)
        [NL,NextIPorts,NextOPorts,mainparams] = firinterpheadconnect(q,NL,H,mainparams,interp_order)
        Head = firinterpheader_order0(q,num,interp_order,H,info)
        [NL,PrevIPorts,PrevOPorts,mainparams] = firinterpoutputconnect(q,NL,H,mainparams,interp_order)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = firsrcbodyconnect(q,NL,H,mainparams,interp_order)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = firsrcfootconnect(q,NL,H,mainparams,interp_order)
        [NL,NextIPorts,NextOPorts,mainparams] = firsrcheadconnect(q,NL,H,mainparams,interp_order,flag)
        [NL,PrevIPorts,PrevOPorts,mainparams] = firsrcoutputconnect(q,NL,H,mainparams,interp_order)
        [prodlog,outlog,acclog] = getlog(this,b,y,acc,x,inlog)
        [prodlog,outlog,acclog] = getsrclog(this,b,y,acc,x,inlog,L)
        bits2add = nguardbits(q)
    end  % possibly private or hidden
    
end  % classdef

