classdef(CaseInsensitiveProperties=true) fixedfirtdecimfilterq < quantum.abstractfixedmultiratefilterq
    %FIXEDFIRTDECIMFILTERQ

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixedfirtdecimfilterq class
    %   quantum.fixedfirtdecimfilterq extends quantum.abstractfixedmultiratefilterq.
    %
    %    quantum.fixedfirtdecimfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       NumFracLength - Property is of type 'mxArray'
    %       FilterInternals - Property is of type 'FilterInternalsType enumeration: {'FullPrecision','SpecifyPrecision'}'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductWordLength - Property is of type 'mxArray'
    %       ProductFracLength - Property is of type 'mxArray'
    %       AccumWordLength - Property is of type 'mxArray'
    %       AccumFracLength - Property is of type 'mxArray'
    %       StateWordLength - Property is of type 'mxArray'  (read only)
    %       StateFracLength - Property is of type 'mxArray'  (read only)
    %       PolyAccWordLength - Property is of type 'mxArray'  (read only)
    %       PolyAccFracLength - Property is of type 'mxArray'  (read only)
    %
    %    quantum.fixedfirtdecimfilterq methods:
    %       get_statefl -   PreGet function for the 'statefl' property.
    %       get_statewl -   PreGet function for the 'statewl' property.
    %       getbestprecision - Return best precision for Product and Accumulator
    %       info -   Return the info for this object.
    %       set_statefl -   PreSet function for the 'statefl' property.
    %       set_statewl -   PreSet function for the 'statewl' property.
    %       setmaxsum -   Set the maxsum.
    %       thiscopy -   Copy the properties defined at this level.
    
    %   Author(s): V. Pellissier
    
    properties (Access=protected, SetObservable)
        %POLYACCFIMATH Property is of type 'mxArray'
        PolyAccfimath = fimath( 'RoundMode', 'convergent', 'OverflowMode', 'wrap', 'SumMode', 'SpecifyPrecision', 'SumWordLength', 33, 'SumFractionLength', 30, 'ProductMode', 'SpecifyPrecision', 'CastBeforeSum', false );
        %PRIVSTATEWL Property is of type 'int32'
        privstatewl = 16;
        %PRIVSTATEFL Property is of type 'int32'
        privstatefl = 15;
    end
    
    properties (SetAccess=protected, Transient, SetObservable)
        %STATEWORDLENGTH Property is of type 'mxArray'  (read only)
        StateWordLength = [];
        %STATEFRACLENGTH Property is of type 'mxArray'  (read only)
        StateFracLength = [];
        %POLYACCWORDLENGTH Property is of type 'mxArray'  (read only)
        PolyAccWordLength = [];
        %POLYACCFRACLENGTH Property is of type 'mxArray'  (read only)
        PolyAccFracLength = [];
    end
    
    
    methods  % constructor block
        function q = fixedfirtdecimfilterq
            % Force Sum and ProductMode to SpecifyPrecision
            q.fimath.ProductMode = 'SpecifyPrecision';
            q.fimath.SumMode = 'SpecifyPrecision';
            
            % Force CastBeforeSum false
            q.fimath.CastBeforeSum = false;
            q.PolyAccfimath.CastBeforeSum = false;
        end  % fixedfirtdecimfilterq
        
    end  % constructor block
    
    methods
        function value = get.StateWordLength(obj)
            value = get_statewl(obj,obj.StateWordLength);
        end
        function set.StateWordLength(obj,value)
            obj.StateWordLength = set_statewl(obj,value);
        end
        
        function value = get.StateFracLength(obj)
            value = get_statefl(obj,obj.StateFracLength);
        end
        function set.StateFracLength(obj,value)
            obj.StateFracLength = set_statefl(obj,value);
        end
        
        function set.privstatewl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32', 'double'}, {'scalar'},'','privstatewl')
            obj.privstatewl = value;
        end
        
        function set.privstatefl(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privstatefl')
            obj.privstatefl = value;
        end
        
        function value = get.PolyAccWordLength(obj)
            value = get_polyaccwl(obj,obj.PolyAccWordLength);
        end
        function set.PolyAccWordLength(obj,value)
            obj.PolyAccWordLength = set_polyaccwl(obj,value);
        end
        
        function value = get.PolyAccFracLength(obj)
            value = get_polyaccfl(obj,obj.PolyAccFracLength);
        end
        function set.PolyAccFracLength(obj,value)
            obj.PolyAccFracLength = set_polyaccfl(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        statefl = get_statefl(q,statefl)
        statewl = get_statewl(q,statewl)
        s = getbestprecision(q)
        [p,v] = info(this)
        statefl = set_statefl(q,statefl)
        statewl = set_statewl(q,statewl)
        setmaxsum(this,Hd)
        thiscopy(this,Hd)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        [b_dble,y_dble,acc_dble,z_dble,polyacc_dble] = convert2double(this,b,y,acc,z,polyacc)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = firtdecimbodyconnect(q,NL,H,mainparams,decim_order)
        [y,zf,polyacc,phaseidx] = firtdecimfilter(q,M,p,x,z,polyacc,phaseidx,nx,nchans,ny)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = firtdecimfootconnect(q,NL,H,mainparams,decim_order)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = firtdecimheadconnect(q,NL,H,mainparams,decim_order)
        Head = firtdecimheader_order0(q,num,decim_order,H,info)
        [NL,NextIPorts,NextOPorts,mainparams] = firtdeciminputconnect(q,NL,H,mainparams,decim_order)
        [NL,PrevIPorts,PrevOPorts,mainparams] = firtdecimoutputconnect(q,NL,H,mainparams,decim_order)
        fl = get_polyaccfl(q,fl)
        wl = get_polyaccwl(q,wl)
        [prodlog,outlog,acclog,statelog,polyacclog] = getlog(this,b,y,acc,z,polyacc,x,phaseidx)
        S = nullstate1(q)
        S = quantizeacc(q,S)
        S = quantizestates(q,S)
        fl = set_polyaccfl(q,fl)
        wl = set_polyaccwl(q,wl)
        thisautoscale(this,s,binptaligned)
        thisset_accumfl(q,accumfl)
        thisset_accumwl(q,accumwl)
        om = thisset_om(q,om)
        thisset_prodfl(q,prodfl)
        thisset_prodwl(q,prodwl)
        rm = thisset_rm(q,rm)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
    
    methods (Static) % static methods
        this = loadobj(s)
    end  % static methods
    
end  % classdef

