classdef(CaseInsensitiveProperties=true) fixedlatticearmafilterq < quantum.abstractfixedlatticefilterq
    %FIXEDLATTICEARMAFILTERQ   Construct a FIXEDLATTICEARMAFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixedlatticearmafilterq class
    %   quantum.fixedlatticearmafilterq extends quantum.abstractfixedlatticefilterq.
    %
    %    quantum.fixedlatticearmafilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputMode - Property is of type 'OutputModeType enumeration: {'AvoidOverflow','BestPrecision','SpecifyPrecision'}'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       LatticeFracLength - Property is of type 'mxArray'
    %       StateWordLength - Property is of type 'mxArray'
    %       StateFracLength - Property is of type 'mxArray'
    %       LadderFracLength - Property is of type 'mxArray'
    %       LatticeProdFracLength - Property is of type 'mxArray'
    %       LadderProdFracLength - Property is of type 'mxArray'
    %       LatticeAccumFracLength - Property is of type 'mxArray'
    %       LadderAccumFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixedlatticearmafilterq methods:
    %       blockparams -   Return the block parameters.
    %       disp - Object display.
    %       genmcode -   Generate MATLAB code.
    %       get_ladprodfl -   PreGet function for the 'ladprodfl' property.
    %       info -   Return the info for this object.
    %       internalsettings - Returns the fixed-point settings viewed by the algorithm.
    %       latticearmabodyconnect - specifies the connection and quantization parameters in the
    %       latticearmafilter - Filter for DFILT.LATTICEARMA class in fixed-point
    %       latticearmafootconnect - specifies the connection and quantization parameters in the
    %       latticearmaheadconnect - specifies connection and quantization parameters in the
    %       latticearmaheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       quantizecoeffs -  Quantize coefficients
    %       quantizestates -   Quantize the states.
    %       set_accummode -   PreSet function for the 'AccumMode' property.
    %       set_ladaccq - Specify word and fraction length of the accum passed to the mexfunction.
    %       set_ladaccumfl -   PreSet function for the 'LadderAccumFracLength' property.
    %       set_ladprodfl -   PreSet function for the 'LadderProdFracLength' property.
    %       set_ladprodq - Specify product word and fraction length for the mexfunction.
    %       set_lataccumfl -   PreSet function for the 'LatticeAccumFracLength' property.
    %       set_latprodfl -   PreSet function for the 'LatticeProdFracLength' property.
    %       set_outq - Specify output word and fraction length for the mexfunction.
    %       set_productmode -   PreSet function for the 'ProductMode' property.
    %       thisloadobj -   Load this object.
    
    %   Author(s): V. Pellissier
    
    properties (Access=protected, SetObservable)
        %FIMATH2 Property is of type 'mxArray'
        fimath2 = fimath( 'RoundMode', 'convergent', 'OverflowMode', 'wrap', 'SumMode', 'KeepMSB', 'SumWordLength', 40, 'SumFractionLength', 30 );
        %PRIVCOEFFFL2 Property is of type 'int32'
        privcoefffl2 = 15;
    end
    
    properties (SetObservable)
        %LADDERFRACLENGTH Property is of type 'mxArray'
        LadderFracLength = [];
        %LATTICEPRODFRACLENGTH Property is of type 'mxArray'
        LatticeProdFracLength = [];
        %LADDERPRODFRACLENGTH Property is of type 'mxArray'
        LadderProdFracLength = [];
        %LATTICEACCUMFRACLENGTH Property is of type 'mxArray'
        LatticeAccumFracLength = [];
        %LADDERACCUMFRACLENGTH Property is of type 'mxArray'
        LadderAccumFracLength = [];
    end
    
    
    methods  % constructor block
        function q = fixedlatticearmafilterq
            % Force the default AccumWordLength
            q.AccumWordLength = 40;
        end  % fixedlatticearmafilterq
        
    end  % constructor block
    
    methods
        function value = get.LadderFracLength(obj)
            value = get_ladfl(obj,obj.LadderFracLength);
        end
        function set.LadderFracLength(obj,value)
            obj.LadderFracLength = set_ladfl(obj,value);
        end
        
        function value = get.LatticeProdFracLength(obj)
            value = get_prodfl(obj,obj.LatticeProdFracLength);
        end
        function set.LatticeProdFracLength(obj,value)
            obj.LatticeProdFracLength = set_latprodfl(obj,value);
        end
        
        function value = get.LadderProdFracLength(obj)
            value = get_ladprodfl(obj,obj.LadderProdFracLength);
        end
        function set.LadderProdFracLength(obj,value)
            obj.LadderProdFracLength = set_ladprodfl(obj,value);
        end
        
        function value = get.LatticeAccumFracLength(obj)
            value = get_accumfl(obj,obj.LatticeAccumFracLength);
        end
        function set.LatticeAccumFracLength(obj,value)
            obj.LatticeAccumFracLength = set_lataccumfl(obj,value);
        end
        
        function value = get.LadderAccumFracLength(obj)
            value = get_ladaccumfl(obj,obj.LadderAccumFracLength);
        end
        function set.LadderAccumFracLength(obj,value)
            obj.LadderAccumFracLength = set_ladaccumfl(obj,value);
        end
        
        function set.privcoefffl2(obj,value)
            % DataType = 'int32'
            validateattributes(value,{'int32','double'}, {'scalar'},'','privcoefffl2')
            obj.privcoefffl2 = value;
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(~,varargin)
        disp(this,varargin)
        h = genmcode(this)
        ladprodfl = get_ladprodfl(q,ladprodfl)
        [p,v] = info(this)
        s = internalsettings(q)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = latticearmabodyconnect(q,NL,H,mainparams)
        [y,zf] = latticearmafilter(q,k,kconj,ladder,x,zi)
        [NL,PrevIPorts,PrevOPorts,mainparams] = latticearmafootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = latticearmaheadconnect(q,NL,H,mainparams)
        Head = latticearmaheader_order0(q,num,den,H,info)
        [latq,conjlatq,ladq] = quantizecoeffs(q,lat,conjlat,lad)
        S = quantizestates(this,S)
        accummode = set_accummode(this,accummode)
        [accWL,accFL] = set_ladaccq(q,inWL,inFL,ncoeffs)
        ladaccumfl = set_ladaccumfl(this,ladaccumfl)
        ladprodfl = set_ladprodfl(this,ladprodfl)
        [prodWL,prodFL] = set_ladprodq(q,coeffWL,coeffFL,multWL,multFL)
        lataccumfl = set_lataccumfl(this,lataccumfl)
        latprodfl = set_latprodfl(this,latprodfl)
        set_outq(q,accWL,accFL)
        productmode = set_productmode(this,productmode)
        thisloadobj(this,s)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        ladaccumfl = get_ladaccumfl(q,ladaccumfl)
        ladfl = get_ladfl(q,ladfl)
        [prodlog,outlog,acclog,statelog,ladderprodlog,ladderacclog] = getlog(this,k,kconj,y,acc1,acc2,z1,z2,ladder,ladderacc,x)
        cbs = set_cbs(q,cbs)
        ladfl = set_ladfl(this,ladfl)
        thisautoscale(this,s,binptaligned)
        thisset_accumwl(q,accumwl)
        om = thisset_om(q,om)
        thisset_prodwl(q,prodwl)
        rm = thisset_rm(q,rm)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
end  % classdef

