classdef(CaseInsensitiveProperties=true) fixedlatticefilterq < quantum.abstractfixedlatticefilterq
    %FIXEDLATTICEFILTERQ   Construct a FIXEDLATTICEFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixedlatticefilterq class
    %   quantum.fixedlatticefilterq extends quantum.abstractfixedlatticefilterq.
    %
    %    quantum.fixedlatticefilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputMode - Property is of type 'OutputModeType enumeration: {'AvoidOverflow','BestPrecision','SpecifyPrecision'}'
    %       OutputFracLength - Property is of type 'mxArray'
    %       ProductMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       AccumMode - Property is of type 'ProductNAccumModeType enumeration: {'FullPrecision','KeepMSB','KeepLSB','SpecifyPrecision'}'
    %       AccumWordLength - Property is of type 'mxArray'
    %       CastBeforeSum - Property is of type 'bool'
    %       LatticeFracLength - Property is of type 'mxArray'
    %       StateWordLength - Property is of type 'mxArray'
    %       StateFracLength - Property is of type 'mxArray'
    %       ProductFracLength - Property is of type 'mxArray'
    %       AccumFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixedlatticefilterq methods:
    %       blockparams -   Return the block parameters.
    %       disp - Object display.
    %       genmcode -   Generate MATLAB code.
    %       get_latfl - GET_LATL
    %       getlogallpass -   Get the log.
    %       getlogar -   Get the log.
    %       getlogma - GETLOG   Get the log.
    %       info -   Return the info for this object.
    %       internalsettings - Returns the fixed-point settings viewed by the algorithm.
    %       latticeallpassbodyconnect - specifies the connection and quantization parameters in the
    %       latticeallpassfilter - Filter for DFILT.LATTICEALLPASS class in fixed-point mode
    %       latticeallpassfootconnect - specifies the connection and quantization parameters in the
    %       latticeallpassheadconnect - specifies the connection and quantization parameters in the
    %       latticeallpassheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       latticearbodyconnect - specifies the connection and quantization parameters in the
    %       latticearfilter - Filter for DFILT.LATTICEAR class in fixed-point mode
    %       latticearfootconnect - specifies the connection and quantization parameters in the
    %       latticearheadconnect - specifies the connection and quantization parameters in the
    %       latticearheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       latticeempty - specifies a filter with empty lattice.  It passes the input
    %       latticemamaxbodyconnect - specifies the connection and quantization parameters in the
    %       latticemamaxfilter - Filter for DFILT.LATTICEMAMAX class in fixed-point mode
    %       latticemamaxfootconnect - specifies the connection and quantization parameters in the
    %       latticemamaxheadconnect - specifies connection and quantization parameters in the
    %       latticemamaxheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       latticemaminbodyconnect - specifies the connection and quantization parameters in the
    %       latticemaminfilter - Filter for DFILT.LATTICEMAMIN class in fixed-point mode
    %       latticemaminfootconnect - specifies the connection and quantization parameters in the
    %       latticemaminheadconnect - specifies connection and quantization parameters in the
    %       latticemaminheader_order0 - specifies the blocks, connection and quantization parameters in the
    %       quantizecoeffs -   Quantize the coefficients.
    %       set_infl -   PreSet function for the 'InputFracLength' property.
    %       set_inwl -   PreSet function for the 'InputWordLength' property.
    %       set_latfl - SET_LATL   PreSet function for the 'LatticeFracLength' property.
    %       set_outq - Specify output word and fraction length for the mexfunction.
    %       set_statefl -   PreSet function for the 'StateFracLength' property.
    %       set_statewl -   PreSet function for the 'StateWordLength' property.
    %       setsysobjfixedpoint - Set converted System object fixed point properties
    %       thiscopy -   Copy the properties defined at this level.
    %       thisloadobj -   Load this object.
    %       update -  Converts to new fixed-point filter quantizer for DFFIR
    
    %   Author(s): V. Pellissier
    
    properties (SetObservable)
        %PRODUCTFRACLENGTH Property is of type 'mxArray'
        ProductFracLength = [];
        %ACCUMFRACLENGTH Property is of type 'mxArray'
        AccumFracLength = [];
    end
    
    
    methods  % constructor block
        function q = fixedlatticefilterq
            % Force the default AccumWordLength
            q.AccumWordLength = 40;
        end  % fixedlatticefilterq
        
    end  % constructor block
    
    methods
        function value = get.ProductFracLength(obj)
            value = get_prodfl(obj,obj.ProductFracLength);
        end
        function set.ProductFracLength(obj,value)
            obj.ProductFracLength = set_prodfl(obj,value);
        end
        
        function value = get.AccumFracLength(obj)
            value = get_accumfl(obj,obj.AccumFracLength);
        end
        function set.AccumFracLength(obj,value)
            obj.AccumFracLength = set_accumfl(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        p = blockparams(this,forceDigitalFilterBlock)
        disp(this,varargin)
        h = genmcode(this)
        latfl = get_latfl(q,latfl)
        [prodlog,outlog,acclog,statelog] = getlogallpass(this,k,kconj,y,acc1,acc2,z1,z2,x)
        [prodlog,outlog,acclog,statelog] = getlogar(this,k,kconj,y,acc1,acc2,z1,z2,x)
        [prodlog,outlog,acclog,statelog] = getlogma(this,k,kconj,y,acc1,acc2,z1,z2,x)
        [p,v] = info(this)
        s = internalsettings(q)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = latticeallpassbodyconnect(q,NL,H,mainparams)
        [y,zf] = latticeallpassfilter(q,k,kconj,x,zi)
        [NL,PrevIPorts,PrevOPorts,mainparams] = latticeallpassfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = latticeallpassheadconnect(q,NL,H,mainparams)
        Head = latticeallpassheader_order0(q,num,H,info)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = latticearbodyconnect(q,NL,H,mainparams)
        [y,zf] = latticearfilter(q,k,kconj,x,zi)
        [NL,PrevIPorts,PrevOPorts,mainparams] = latticearfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = latticearheadconnect(q,NL,H,mainparams)
        Head = latticearheader_order0(q,num,H,info)
        Head = latticeempty(q,num,H,info)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = latticemamaxbodyconnect(q,NL,H,mainparams)
        [y,zf] = latticemamaxfilter(q,k,kconj,x,zi)
        [NL,PrevIPorts,PrevOPorts,mainparams] = latticemamaxfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = latticemamaxheadconnect(q,NL,H,mainparams)
        Head = latticemamaxheader_order0(q,num,H,info)
        [NL,PrevIPorts,PrevOPorts,NextIPorts,NextOPorts,mainparams] = latticemaminbodyconnect(q,NL,H,mainparams)
        [y,zf] = latticemaminfilter(q,k,kconj,x,zi)
        [NL,PrevIPorts,PrevOPorts,mainparams] = latticemaminfootconnect(q,NL,H,mainparams)
        [NL,NextIPorts,NextOPorts,mainparams] = latticemaminheadconnect(q,NL,H,mainparams)
        Head = latticemaminheader_order0(q,num,H,info)
        cq = quantizecoeffs(this,c)
        infl = set_infl(this,infl)
        inwl = set_inwl(this,inwl)
        latfl = set_latfl(q,latfl)
        set_outq(q,accWL,accFL)
        statefl = set_statefl(this,statefl)
        statewl = set_statewl(this,statewl)
        setsysobjfixedpoint(this,Hs)
        thiscopy(this,Hd)
        thisloadobj(this,s)
        this = update(this,s)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        inheritstates(q,S)
        lattice_thiscopy(this,Hd)
        S = quantizestates(q,S)
        thisautoscale(this,s,binptaligned)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
end  % classdef

