classdef(CaseInsensitiveProperties=true) fixedlinearfdfilterq < quantum.abstractfixedfarrowfilterq
    %FIXEDLINEARFDFILTERQ   Construct a FIXEDLINEARFDFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixedlinearfdfilterq class
    %   quantum.fixedlinearfdfilterq extends quantum.abstractfixedfarrowfilterq.
    %
    %    quantum.fixedlinearfdfilterq properties:
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputFracLength - Property is of type 'mxArray'
    %       FDWordLength - Property is of type 'mxArray'
    %       FDFracLength - Property is of type 'mxArray'
    %       FilterInternals - Property is of type 'FilterInternalsType enumeration: {'FullPrecision','SpecifyPrecision'}'
    %       ProductWordLength - Property is of type 'mxArray'
    %       ProductFracLength - Property is of type 'mxArray'
    %       AccumWordLength - Property is of type 'mxArray'
    %       AccumFracLength - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       FDAutoScale - Property is of type 'mxArray'
    %       TapSumWordLength - Property is of type 'mxArray'  (read only)
    %       TapSumFracLength - Property is of type 'mxArray'  (read only)
    %
    %    quantum.fixedlinearfdfilterq methods:
    %       disp - Object display.
    %       getlog -   Get the log.
    %       info -   Return the information for the display.
    %       linearfddggen -   Directed Graph generator for FARROW.LINEARFD
    %       loadfdprop - <short description>
    
    %   Author(s): V. Pellissier
    
    properties (SetAccess=protected, Transient, SetObservable)
        %TAPSUMWORDLENGTH Property is of type 'mxArray'  (read only)
        TapSumWordLength = [];
        %TAPSUMFRACLENGTH Property is of type 'mxArray'  (read only)
        TapSumFracLength = [];
    end
    
    properties (SetObservable)
        %FDAUTOSCALE Property is of type 'mxArray'
        FDAutoScale = [];
    end
    
    
    methods  % constructor block
        function this = fixedlinearfdfilterq
            % Force Sum and ProductMode to SpecifyPrecision
            this.fimath.ProductMode = 'SpecifyPrecision';
            this.fimath.SumMode = 'SpecifyPrecision';
            this.fdfimath.ProductMode = 'SpecifyPrecision';
            this.fdfimath.SumMode = 'SpecifyPrecision';
            
            % Make CastBeforeSum false by default
            this.fimath.CastBeforeSum = false;
            this.fdfimath.CastBeforeSum = false;
        end  % fixedlinearfdfilterq
    end  % constructor block
    
    methods
        function value = get.FDAutoScale(obj)
            value = get_fdautoscale(obj,obj.FDAutoScale);
        end
        function set.FDAutoScale(obj,value)
            obj.FDAutoScale = set_fdautoscale(obj,value);
        end
        
        function value = get.TapSumWordLength(obj)
            value = get_tapsumwl(obj,obj.TapSumWordLength);
        end
        function set.TapSumWordLength(obj,value)
            obj.TapSumWordLength = set_tapsumwl(obj,value);
        end
        
        function value = get.TapSumFracLength(obj)
            value = get_tapsumfl(obj,obj.TapSumFracLength);
        end
        function set.TapSumFracLength(obj,value)
            obj.TapSumFracLength = set_tapsumfl(obj,value);
        end
        
    end   % set and get functions
    
    methods  % public methods
        disp(h,spacing)
        [prodlog,outlog,acclog,tapsumlog] = getlog(this,d,y,x,zlog)
        [p,v] = info(this)
        DGDF = linearfddggen(this,Hd,states)
        loadfdprop(this,s)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        tapsumfl = get_tapsumfl(q,tapsumfl)
        tapsumwl = get_tapsumwl(q,tapsumwl)
        [y,z] = linearfdfilter(this,x,d,z)
        tapsumfl = set_tapsumfl(q,tapsumfl)
        tapsumwl = set_tapsumwl(q,tapsumwl)
        specifyall(this,flag)
        thisautoscale(this,s,binptaligned)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
end  % classdef

