classdef(CaseInsensitiveProperties=true) fixedlog < quantum.abstractlog
    %FIXEDLOG   Construct a FIXEDLOG object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixedlog class
    %   quantum.fixedlog extends quantum.abstractlog.
    %
    %    quantum.fixedlog properties:
    %       Max - Property is of type 'mxArray'  (read only)
    %       Min - Property is of type 'mxArray'  (read only)
    %       NOperations - Property is of type 'mxArray'  (read only)
    %       MinRange - Property is of type 'mxArray'  (read only)
    %       MaxRange - Property is of type 'mxArray'  (read only)
    %       NOverflows - Property is of type 'mxArray'  (read only)
    %
    %    quantum.fixedlog methods:
    
    %   Author(s): V. Pellissier
    
    properties (SetAccess=protected, SetObservable)
        %MINRANGE Property is of type 'mxArray'  (read only)
        MinRange = [];
        %MAXRANGE Property is of type 'mxArray'  (read only)
        MaxRange = [];
        %NOVERFLOWS Property is of type 'mxArray'  (read only)
        NOverflows = [];
    end
    
    
    methods  % constructor block
        function this = fixedlog(q)
            this.Max = double(max(q.Max));
            this.Min = double(min(q.Min));
            
            r = q.Range;
            this.MinRange = r(1);
            this.MaxRange = r(2);
            
            this.NOverflows = q.NOverflows;
            this.NOperations = q.NOperations;
        end  % fixedlog
        
        function s = get(this, varargin)
            if isempty(varargin)
                s.Max = this.Max;
                s.Min = this.Min;
                s.NOperations = this.NOperations;
                s.MinRange = this.MinRange;
                s.MaxRange = this.MaxRange;
                s.NOverflows = this.NOverflows;
            end
        end
    end  % constructor block
    
    methods
    end   % set and get functions
    
    methods (Hidden) % possibly private or hidden
        dispinfo(this,name)
    end  % possibly private or hidden
    
end  % classdef

