classdef(CaseInsensitiveProperties=true) fixedscalarfilterq < quantum.abstractfixedoutfilterq
    %FIXEDSCALARFILTERQ   Construct a FIXEDSCALARFILTERQ object.

%   Copyright 2018-2020 The MathWorks, Inc.
    
    %quantum.fixedscalarfilterq class
    %   quantum.fixedscalarfilterq extends quantum.abstractfixedoutfilterq.
    %
    %    quantum.fixedscalarfilterq properties:
    %       CoeffWordLength - Property is of type 'mxArray'
    %       CoeffAutoScale - Property is of type 'mxArray'
    %       Signed - Property is of type 'mxArray'
    %       RoundMode - Property is of type 'RoundType enumeration: {'convergent','ceil','fix','floor','round','nearest'}'
    %       OverflowMode - Property is of type 'OverflowType enumeration: {'wrap','saturate'}'
    %       InputWordLength - Property is of type 'mxArray'
    %       InputFracLength - Property is of type 'mxArray'
    %       OutputWordLength - Property is of type 'mxArray'
    %       OutputMode - Property is of type 'OutputModeType enumeration: {'AvoidOverflow','BestPrecision','SpecifyPrecision'}'
    %       OutputFracLength - Property is of type 'mxArray'
    %       CoeffFracLength - Property is of type 'mxArray'
    %
    %    quantum.fixedscalarfilterq methods:
    %       disp - Object display.
    %       info -   Return the info for this object.
    %       internalsettings - Returns the fixed-point settings viewed by the algorithm.
    %       quantizecoeffs -  Quantize coefficients
    %       scalarblockparams -   Get the block parameters.
    %       scalarfilter - Filter for DFILT.SCALAR class in fixed-point
    %       scalarheader - ORDER0 specifies the blocks, connection and quantization parameters in the
    %       set_coefffl -   PreSet function for the 'CoeffFracLength' property.
    %       set_outq - Specify output word and fraction length for the mexfunction.
    %       thiscopy -   Copy the properties defined at this level.
    %       thisloadobj -   Load the object.
    
    %   Author(s): V. Pellissier
    
    properties (SetObservable)
        %COEFFFRACLENGTH Property is of type 'mxArray'
        CoeffFracLength = [];
    end
    
    
    methods  % constructor block
        function this = fixedscalarfilterq
            % Force Sum and ProductMode to FullPrecision
            this.fimath.ProductMode = 'FullPrecision';
            this.fimath.SumMode = 'FullPrecision';
        end  % fixedscalarfilterq
    end  % constructor block
    
    methods
        function value = get.CoeffFracLength(obj)
            value = get_coefffl(obj,obj.CoeffFracLength);
        end
        function set.CoeffFracLength(obj,value)
            obj.CoeffFracLength = set_coefffl(obj,value);
        end
    end   % set and get functions
    
    methods  % public methods
        disp(this,varargin)
        [p,v] = info(this)
        s = internalsettings(q)
        cq = quantizecoeffs(q,c)
        p = scalarblockparams(this)
        [y,zf] = scalarfilter(q,b,x,zi)
        Head = scalarheader(q,num,H,info)
        coefffl = set_coefffl(this,coefffl)
        set_outq(q,accWL,accFL)
        thiscopy(this,Hd)
        thisloadobj(this,s)
    end  % public methods
    
    
    methods (Hidden) % possibly private or hidden
        coefffl = get_coefffl(q,coefffl)
        inheritstates(q,S)
        S = quantizestates(q,S)
        specifyall(this,flag)
        thisautoscale(this,s,binptaligned)
        updateinternalsettings(q)
    end  % possibly private or hidden
    
end  % classdef

