function varargout = design(this)
%DESIGN   Design the multirate filter.

%   Author(s): J. Schickler
%   Copyright 1999-2021 The MathWorks, Inc.

sendstatus(this, getString(message('dsp:fdtbxgui:fdtbxgui:CreatingFilter')));

% Suppress MFILT deprecation warnings
w = warning('off', 'dsp:mfilt:mfilt:Obsolete');
restoreWarn = onCleanup(@() warning(w));

decf = get(this, 'DecimationFactor');
intf = get(this, 'InterpolationFactor');

switch lower(this.Implementation)
    case 'defaultfilter'
        switch lower(this.Type)
            case 'interpolator'
                Hd = dsp.internal.mfilt.firinterp(intf);
            case 'decimator'
                Hd = mfilt.firdecim(decf); %#ok<MFDECIM>
            case 'fractional-rate converter'
                Hd = mfilt.firsrc(intf, decf); %#ok<MFSRC>
        end
    case 'current'
        b = get(reffilter(this.CurrentFilter), 'Numerator');
        switch lower(this.Type)
            case 'interpolator'
                Hd = dsp.internal.mfilt.firinterp(intf, b); 
            case 'decimator'
                Hd = mfilt.firdecim(decf, b); %#ok<MFDECIM>
            case 'fractional-rate converter'
                Hd = mfilt.firsrc(intf, decf, b); %#ok<MFSRC>
        end
    case 'cic'
        inputs = {evaluatevars(this.DifferentialDelay), ...
            evaluatevars(this.NumberOfSections)};

        if strcmpi(this.Type, 'decimator')
            Hd = mfilt.cicdecim(decf, inputs{:}); %#ok<MCDECIM>
        else
            Hd = dsp.internal.mfilt.cicinterp(intf, inputs{:}); 
        end
    case 'hold'
        Hd = dsp.internal.mfilt.holdinterp(intf);
    case 'linear'
        Hd = dsp.internal.mfilt.linearinterp(intf); 
end

if nargout, varargout = {Hd}; end

info.filter = Hd;
info.mcode  = genmcode(this);

% Send this status here, in case we get a warning status...
sendstatus(this, getString(message('dsp:fdtbxgui:fdtbxgui:CreatingFilterDone')));

send(this, 'FilterDesigned', ...
    sigdatatypes.sigeventdata(this, 'FilterDesigned', info));

set(this, 'isDesigned', true);

% [EOF]
