function flag = checkstable(a)
%CHKSTABLE  Check if polynomial has all its roots inside the unit circle.

%   Copyright 2021 The MathWorks, Inc.
%#codegen

% Remove trailing zeros
indx1 = find(a~=0, 1, 'last' );
% Remove leading zeros as they have no effect on stability but affect the
% normalization
indx2 = find(a, 1);

coder.internal.errorIf(isempty(indx1) || isempty(indx2),'signal:signalpolyutils:SignalErr');

a = a(indx2(1):indx1(1));

a = a./a(1);    % Normalize by a(1)

if length(a) == 1
    flag = 1;
    
elseif length(a) == 2
    
    % One pole given by second coefficient of a, first is always 1.
    flag = isfirstorderstable(a(2));

else
    % Use poly2rc for denominators of order 2 or more
    flag = ispolystable(a);
        
end
end
%----------------------------------------------------------------------------
function isstableflag = isfirstorderstable(p)
% One pole given by second coefficient of a, first is always 1.
if abs(p) < 1        
    isstableflag = 1;
else
    isstableflag = 0;
end
end
%----------------------------------------------------------------------------
function isstableflag = ispolystable(a)
% look at the last coefficient, if greater or equal to 1, unstable
if abs(a(end)) >= 1
    isstableflag = 0;
    return
end

% Use poly2rc to determine stability
[k,~,errorFlag] = poly2rc(a); 
if ~errorFlag
    if all(any(isnan(k))) || all(max(abs(k)) >= 1)
        isstableflag = 0;
    else
        isstableflag = 1;
    end
else
    % If poly2rc fails, one of the elements in k must be equal to one,
    % which makes the system unstable
    isstableflag = 0;
end
end


