function ftransfargchk(var,varname,varargin)
%FTRANSFARGCHK Input argument check.
%   FTRANSFARGCHK(VAR,VARNAME,ATTRIBUTE1,ATTRIBUTE2,...) error out if
%   variable VAR does not match attributes in strings ATTRIBUTE1, ....  The
%   name for the variable used in the error message is contained in string
%   VARNAME.  If VARNAME is empty, then the name of the
%   variable VAR is used.

%   Copyright 1999-2021 The MathWorks, Inc.

%#codegen
% --------------------------------------------------------------------

if isempty(varname)
  varname = inputname(var);
end
for k=1:length(varargin)

   switch(varargin{k})

      case 'overlap'
         [wt,idx] = sort(var(2,:));
         wo       =      var(1,idx);
         Flag     = 1;
         for kk=1:2:length(wt)-1
            if wo(kk) > wo(kk+1)
               Flag = 0;
               break;
            end
         end
         coder.internal.errorIf(~Flag,'dsp:ftransfargchk:FilterErr1', varname);

      case 'real'
         coder.internal.errorIf(~isreal(var),'dsp:ftransfargchk:FilterErr2', varname);

      case 'positive'
         coder.internal.errorIf(var < 0,'dsp:ftransfargchk:FilterErr3', varname);

      case 'negative'
         coder.internal.errorIf(var > 0,'dsp:ftransfargchk:FilterErr4', varname);

      case 'int'
         coder.internal.errorIf(mod(var,1) > eps,'dsp:ftransfargchk:FilterErr5', varname);

      case 'scalar'
        coder.internal.errorIf(~isscalar(var),'dsp:ftransfargchk:FilterErr6', varname);

      case 'string'
         coder.internal.errorIf(~ischar(var),'dsp:ftransfargchk:FilterErr7', varname);

      case 'pass/stop'
         coder.internal.errorIf(~strcmpi(var,'pass') && ~strcmpi(var,'stop'),...
             'dsp:ftransfargchk:FilterErr8', varname);

      case 'vector'
         coder.internal.errorIf(~isvector(var),'dsp:ftransfargchk:FilterErr9', varname);

      case 'vector2'
         coder.internal.errorIf(~isvector(var) || length(var)~=2,...
             'dsp:ftransfargchk:FilterErr10', varname);

      case 'numeric'
         coder.internal.errorIf( ~isnumeric(var),'dsp:ftransfargchk:FilterErr11', varname);

      case 'normalized'
         coder.internal.errorIf((min(var(:)) <= 0)  || (max(var(:)) >= 1),...
             'dsp:ftransfargchk:FilterErr12', varname);

      case 'normalized + edge'
         coder.internal.errorIf((min(var(:)) < 0)  || (max(var(:)) > 1),...
             'dsp:ftransfargchk:FilterErr13', varname);

      case 'full normalized'
         coder.internal.errorIf((min(var(:)) <= -1) || (max(var(:)) >= 1),...
             'dsp:ftransfargchk:FilterErr14', varname);

      case 'full normalized + edge'
         coder.internal.errorIf((min(var(:)) < -1) || (max(var(:)) > 1),...
             'dsp:ftransfargchk:FilterErr15', varname);

      case 'even'
         coder.internal.errorIf(mod(length(var),2) > eps,'dsp:ftransfargchk:FilterErr16', varname);

      case 'odd'
         coder.internal.errorIf(mod(length(var),2) - 1 > eps,'dsp:ftransfargchk:FilterErr17', varname);

      otherwise
         coder.internal.error('dsp:ftransfargchk:FilterErr', varname);
   end

end


% --------------------------------------------------------------------

function t = isvector(v)
%ISVECTOR  True for a vector.
%   ISVECTOR(V) returns 1 if V is a vector and 0 otherwise.

t = (ismatrix(v)) & (min(size(v)) <= 1);

% --------------------------------------------------------------------

function t = isscalar(v)
%ISSCALAR  True for a scalar or empty.
%   ISSCALAR(V) returns 1 if V is a scalar and 0 otherwise.

t = (ismatrix(v)) & (max(size(v)) <= 1);
