function [DH,DW] = ifirgfresp(~, F, GF, W, bf, L)
%IFIRGFRESP Freq resp for g design in advanced ifir.
%
%   Inputs:
%       N - Filter Order
%       F - Frequency edges
%       GF - Frequency grid
%       W - Weights
%       bf - periodic filter iteration
%       L - Interpolation factor

%   Author(s): R. Losada
%   Copyright 1999-2019 The MathWorks, Inc.

DH = determinemagresp(GF,F);

DW = determineweights(GF,F,bf,L,W);

%--------------- Determine desired mag response ---------------------------
function DH = determinemagresp(GF,~)

% There are only two bands
DH = zeros(size(GF)); % Preallocate

% Passband has only one point
DH(1) = 1;

%--------------- Determine weights ---------------------------
function DW = determineweights(GF,~,bf,L,W)

DW = zeros(size(GF)); % Preallocate

DW(1) = W(1);

% Compute the zerophase response of BF(z^L) on the freq. grid
Hz = zerophase(upsample(bf,L),1,GF*pi);

DW(2:end) = abs(Hz(2:end));

