function b = polystable(a)
%POLYSTABLE Polynomial stabilization.
%   POLYSTABLE(A), where A is a vector of polynomial coefficients,
%   stabilizes the polynomial with respect to the unit circle;
%   roots whose magnitudes are greater than one are reflected
%   inside the unit circle.

%   Copyright 2021 The MathWorks, Inc.
%#codegen

if isempty(a) || length(a) == 1
    b = a; 
    return;
end

v = roots(a); i = find(v~=0);
vs = 0.5*(sign(abs(v(i))-1)+1);
v(i) = (1-vs).*v(i) + vs./conj(v(i));
ind = find(a~=0);
b = a(ind(1))*poly(v);

% Return only real coefficients if input was real:
if isreal(a)
	b = real(b);
end

